@@ -3,7 +3,7 @@
 *                    F i n d   P a t t e r n   I n   F i l e s                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -91,6 +91,12 @@ static const FXchar skey[20][3]={
   };
 
 
+// Registry keys for folder strings
+static const FXchar fkey[20][3]={
+  "FA","FB","FC","FD","FE","FF","FG","FH","FI","FJ","FK","FL","FM","FN","FO","FP","FQ","FR","FS","FT"
+  };
+
+
 // Registry keys for file pattern options
 static const FXchar pkey[20][3]={
   "PA","PB","PC","PD","PE","PF","PG","PH","PI","PJ","PK","PL","PM","PN","PO","PP","PQ","PR","PS","PT"
@@ -107,6 +113,7 @@ static const FXchar mkey[20][3]={
 
 // Traverse files under path and search for pattern in each
 FXuint SearchVisitor::traverse(const FXString& path,const FXString& pattern,const FXString& wild,FXint mode,FXuint opts,FXint depth){
+  FXTRACE((1,"SearchVisitor::traverse(path=%s,pattern=%s,wild=%s,mode=%b,opts=%b,depth=%d)\n",path.text(),pattern.text(),wild.text(),mode,opts,depth));
 
   // Compile the pattern
   if(rex.parse(pattern,mode)==FXRex::ErrOK){
@@ -140,7 +147,7 @@ FXuint SearchVisitor::visit(const FXString& path){
 // Search file contents for pattern
 FXint SearchVisitor::searchFile(const FXString& path) const {
   FXString text;
-  FXTRACE((1,"searchFile(%s)\n",path.text()));
+  FXTRACE((1,"searchFile(path=%s)\n",path.text()));
   if(loadFile(path,text)){
     FXString relpath=FXPath::relative(dlg->getDirectory(),path);
     FXString hit;
@@ -148,7 +155,7 @@ FXint SearchVisitor::searchFile(const FXString& path) const {
     FXint lineno=1;
     FXint column=0;
     FXint pos=0;
-    FXTRACE((1,"loadFile(%s) -> %d bytes\n",relpath.text(),text.length()));
+    FXTRACE((1,"loadFile(path=%s) -> %d bytes\n",relpath.text(),text.length()));
     dlg->setSearchingText(relpath);
     while(pos<text.length()){
       if(rex.amatch(text,pos,FXRex::Normal,beg,end,10)){
@@ -188,12 +195,12 @@ FXlong SearchVisitor::loadFile(const FXString& path,FXString& text) const {
 
 // For deserialization
 FindInFiles::FindInFiles():visitor(this){
-  locations=NULL;
-  findstring=NULL;
-  filefolder=NULL;
-  filefilter=NULL;
-  pausebutton=NULL;
-  searching=NULL;
+  locations=nullptr;
+  findstring=nullptr;
+  filefolder=nullptr;
+  filefilter=nullptr;
+  pausebutton=nullptr;
+  searching=nullptr;
   clearElms(optionsHistory,20);
   clearElms(patternHistory,20);
   searchmode=SearchExact|SearchRecurse;
@@ -210,14 +217,14 @@ FindInFiles::FindInFiles(Adie *a):FXDialogBox(a,"Find In Files",DECOR_TITLE|DECO
 
   // Buttons at bottom
   FXHorizontalFrame* bottomline=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
-  new FXLabel(bottomline,tr("Searching: "),NULL,LAYOUT_CENTER_Y|LAYOUT_LEFT|JUSTIFY_RIGHT,0,0,0,0,2,2,VERT_PAD,VERT_PAD);
-  searching=new FXLabel(bottomline,tr("<stopped>"),NULL,LAYOUT_CENTER_Y|LAYOUT_FILL_X|JUSTIFY_LEFT,0,0,0,0,2,2,VERT_PAD,VERT_PAD);
+  new FXLabel(bottomline,tr("Searching: "),nullptr,LAYOUT_CENTER_Y|LAYOUT_LEFT|JUSTIFY_RIGHT,0,0,0,0,2,2,VERT_PAD,VERT_PAD);
+  searching=new FXLabel(bottomline,tr("<stopped>"),nullptr,LAYOUT_CENTER_Y|LAYOUT_FILL_X|JUSTIFY_LEFT,0,0,0,0,2,2,VERT_PAD,VERT_PAD);
   FXHorizontalFrame* buttons=new FXHorizontalFrame(bottomline,LAYOUT_RIGHT|PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT,0,0,0,0,0,0,0,0);
-  new FXButton(buttons,tr("&Close"),NULL,this,ID_CLOSE,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_RIGHT,0,0,0,0,6,6,VERT_PAD,VERT_PAD);
-  new FXButton(buttons,tr("&Delete"),NULL,this,ID_DELETE,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
-  new FXButton(buttons,tr("Stop"),NULL,this,ID_STOP,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
-  pausebutton=new FXToggleButton(buttons,tr("Pause"),tr("Resume"),NULL,NULL,this,ID_PAUSE,FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
-  new FXButton(buttons,tr("&Search"),NULL,this,ID_SEARCH,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
+  new FXButton(buttons,tr("&Close"),nullptr,this,ID_CLOSE,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_RIGHT,0,0,0,0,6,6,VERT_PAD,VERT_PAD);
+  new FXButton(buttons,tr("&Delete"),nullptr,this,ID_DELETE,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
+  new FXButton(buttons,tr("Stop"),nullptr,this,ID_STOP,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
+  pausebutton=new FXToggleButton(buttons,tr("Pause"),tr("Resume"),nullptr,nullptr,this,ID_PAUSE,FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
+  new FXButton(buttons,tr("&Search"),nullptr,this,ID_SEARCH,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,HORZ_PAD,HORZ_PAD,VERT_PAD,VERT_PAD);
 
   // Above button block
   new FXHorizontalSeparator(this,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
@@ -225,18 +232,20 @@ FindInFiles::FindInFiles(Adie *a):FXDialogBox(a,"Find In Files",DECOR_TITLE|DECO
   // Options block
   FXHorizontalFrame* frame=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT,0,0,0,0,0,0,0,0);
   new FXCheckButton(frame,tr("E&xpression\tRegular Expression"),this,ID_REGEX,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
-  new FXCheckButton(frame,tr("I&gnore Case\tCase insensitive"),this,ID_ICASE,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
+  new FXCheckButton(frame,tr("W&ords\tWhole Words"),this,ID_WORDS,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
+  new FXCheckButton(frame,tr("&Ignore Case\tCase insensitive"),this,ID_ICASE,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
   new FXCheckButton(frame,tr("&Recursive\tSearch subdirectories"),this,ID_RECURSIVE,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
   new FXCheckButton(frame,tr("&Hidden Files\tSearch hidden files"),this,ID_HIDDEN,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
-  new FXCheckButton(frame,tr("First &Hit\tRecord only first matches for each file"),this,ID_FIRST_HIT,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
+  new FXCheckButton(frame,tr("First Hi&t\tRecord only first matches for each file"),this,ID_FIRST_HIT,ICON_BEFORE_TEXT|LAYOUT_CENTER_X);
 
   // Entry block
   FXMatrix *matrix=new FXMatrix(this,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
 
   // Text field with history
-  new FXLabel(matrix,tr("S&earch for:"),NULL,JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
+  new FXLabel(matrix,tr("Search &for:"),nullptr,JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
   FXHorizontalFrame* searchbox=new FXHorizontalFrame(matrix,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN,0,0,0,0, 0,0,0,0, 0,0);
   findstring=new FXTextField(searchbox,26,this,ID_SEARCH_TEXT,TEXTFIELD_ENTER_ONLY|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+  findstring->setTipText(tr("Search Pattern"));
   FXVerticalFrame* searcharrows=new FXVerticalFrame(searchbox,LAYOUT_RIGHT|LAYOUT_FILL_Y|PACK_UNIFORM_HEIGHT,0,0,0,0, 0,0,0,0, 0,0);
   FXArrowButton* ar1=new FXArrowButton(searcharrows,this,ID_HIST_UP,FRAME_RAISED|FRAME_THICK|ARROW_UP|ARROW_REPEAT|LAYOUT_FILL_Y|LAYOUT_FIX_WIDTH, 0,0,16,0, 1,1,1,1);
   FXArrowButton* ar2=new FXArrowButton(searcharrows,this,ID_HIST_DN,FRAME_RAISED|FRAME_THICK|ARROW_DOWN|ARROW_REPEAT|LAYOUT_FILL_Y|LAYOUT_FIX_WIDTH, 0,0,16,0, 1,1,1,1);
@@ -245,21 +254,23 @@ FindInFiles::FindInFiles(Adie *a):FXDialogBox(a,"Find In Files",DECOR_TITLE|DECO
   new FXFrame(matrix,0);
 
   // Folder to search
-  new FXLabel(matrix,tr("In &Folder:"),NULL,JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
+  new FXLabel(matrix,tr("In Fo&lder:"),nullptr,JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
   filefolder=new FXTextField(matrix,40,this,ID_FOLDER_TEXT,JUSTIFY_LEFT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FILL_X);
-  new FXButton(matrix,"...",NULL,this,ID_FOLDER,LAYOUT_CENTER_Y|FRAME_RAISED|FRAME_THICK|LAYOUT_FIX_WIDTH,0,0,20,0);
+  filefolder->setTipText(tr("Folder To Search"));
+  new FXButton(matrix,"...\tSelect Folder\tSelect folder to search.",nullptr,this,ID_FOLDER,LAYOUT_CENTER_Y|FRAME_RAISED|FRAME_THICK|LAYOUT_FIX_WIDTH,0,0,20,0);
 
   // Filter for files
-  new FXLabel(matrix,tr("F&ilter:"),NULL,JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
+  new FXLabel(matrix,tr("Filt&er:"),nullptr,JUSTIFY_RIGHT|LAYOUT_FILL_X|LAYOUT_CENTER_Y);
   filefilter=new FXComboBox(matrix,10,this,ID_FILTER_TEXT,COMBOBOX_STATIC|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_COLUMN);
+  filefilter->setTipText(tr("Files matching wildcard"));
   filefilter->setNumVisible(4);
   new FXFrame(matrix,0);
 
   // Matching files
   FXHorizontalFrame* resultbox=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0,0,0,0,0);
   locations=new FXIconList(resultbox,this,ID_FILELIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_DETAILED|ICONLIST_SINGLESELECT);
-  locations->appendHeader(tr("Location"),NULL,200);
-  locations->appendHeader(tr("Context"),NULL,800);
+  locations->appendHeader(tr("Location"),nullptr,200);
+  locations->appendHeader(tr("Context"),nullptr,800);
 
   // Clean array
   clearElms(optionsHistory,20);
@@ -268,6 +279,10 @@ FindInFiles::FindInFiles(Adie *a):FXDialogBox(a,"Find In Files",DECOR_TITLE|DECO
   // Set title
   setTitle(tr("Find In Files"));
 
+  // Set icons
+  setIcon(getApp()->bigicon);
+  setMiniIcon(getApp()->smallicon);
+
   // Initial pattern
   setPatternList(tr("All Files (*)"));
 
@@ -296,6 +311,7 @@ void FindInFiles::readRegistry(){
   for(FXint i=0; i<20; ++i){
     searchHistory[i]=getApp()->reg().readStringEntry(sectionName,skey[i],FXString::null);
     if(searchHistory[i].empty()) break;
+    folderHistory[i]=getApp()->reg().readStringEntry(sectionName,fkey[i],FXString::null);
     patternHistory[i]=getApp()->reg().readUIntEntry(sectionName,pkey[i],0);
     optionsHistory[i]=getApp()->reg().readUIntEntry(sectionName,mkey[i],SearchExact);
     }
@@ -314,11 +330,13 @@ void FindInFiles::writeRegistry(){
   for(FXint i=0; i<20; ++i){
     if(!searchHistory[i].empty()){
       getApp()->reg().writeStringEntry(sectionName,skey[i],searchHistory[i].text());
+      getApp()->reg().writeStringEntry(sectionName,fkey[i],folderHistory[i].text());
       getApp()->reg().writeUIntEntry(sectionName,pkey[i],patternHistory[i]);
       getApp()->reg().writeUIntEntry(sectionName,mkey[i],optionsHistory[i]);
       }
     else{
       getApp()->reg().deleteEntry(sectionName,skey[i]);
+      getApp()->reg().deleteEntry(sectionName,fkey[i]);
       getApp()->reg().deleteEntry(sectionName,pkey[i]);
       getApp()->reg().deleteEntry(sectionName,mkey[i]);
       }
@@ -327,16 +345,18 @@ void FindInFiles::writeRegistry(){
 
 
 // Add string to history buffer
-void FindInFiles::appendHistory(const FXString& text,FXuint patt,FXuint opts){
+void FindInFiles::appendHistory(const FXString& text,const FXString& dir,FXuint patt,FXuint opts){
   if(!text.empty()){
     if(text!=searchHistory[0]){
       for(FXint i=19; i>0; i--){
         swap(searchHistory[i],searchHistory[i-1]);
+        swap(folderHistory[i],folderHistory[i-1]);
         swap(patternHistory[i],patternHistory[i-1]);
         swap(optionsHistory[i],optionsHistory[i-1]);
         }
       }
     searchHistory[0]=text;
+    folderHistory[0]=dir;
     patternHistory[0]=patt;
     optionsHistory[0]=opts;
     index=0;
@@ -419,7 +439,7 @@ void FindInFiles::setPatternList(const FXString& patterns){
   filefilter->clearItems();
   filefilter->fillItems(patterns);
   if(!filefilter->getNumItems()) filefilter->appendItem(tr("All Files (*)"));
-  filefilter->setNumVisible(FXMIN(filefilter->getNumItems(),12));
+  filefilter->setNumVisible(Math::imin(filefilter->getNumItems(),12));
   setCurrentPattern(0);
   }
 
@@ -501,7 +521,7 @@ FXString FindInFiles::getSearchingText() const {
 
 // Update stop button
 long FindInFiles::onUpdStop(FXObject* sender,FXSelector,void*){
-  sender->handle(this,proceed?FXSEL(SEL_COMMAND,ID_DISABLE):FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
+  sender->handle(this,proceed?FXSEL(SEL_COMMAND,ID_DISABLE):FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
   return 1;
   }
 
@@ -515,8 +535,8 @@ long FindInFiles::onCmdStop(FXObject*,FXSelector,void*){
 
 // Update pause/resume button
 long FindInFiles::onUpdPause(FXObject* sender,FXSelector,void*){
-  sender->handle(this,(proceed==0)?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
-  sender->handle(this,visitor.visiting()?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
+  sender->handle(this,(proceed==0)?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
+  sender->handle(this,visitor.visiting()?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),nullptr);
   return 1;
   }
 
@@ -530,7 +550,7 @@ long FindInFiles::onCmdPause(FXObject*,FXSelector,void*){
 
 // Grey out delete if no results
 long FindInFiles::onUpdDelete(FXObject* sender,FXSelector,void*){
-  sender->handle(this,locations->getNumItems()?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
+  sender->handle(this,locations->getNumItems()?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),nullptr);
   return 1;
   }
 
@@ -545,7 +565,7 @@ long FindInFiles::onCmdDelete(FXObject*,FXSelector,void*){
 // Grey out buttons if no search text
 long FindInFiles::onUpdSearch(FXObject* sender,FXSelector,void*){
   FXbool enabled=!visitor.visiting() && !findstring->getText().empty();
-  sender->handle(this,enabled?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
+  sender->handle(this,enabled?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),nullptr);
   return 1;
   }
 
@@ -556,10 +576,11 @@ long FindInFiles::onCmdSearch(FXObject*,FXSelector,void*){
   FXint rexmode=FXRex::Capture;
   FXint limit=1000;
   if(getSearchMode()&SearchCaseFold) rexmode|=FXRex::IgnoreCase;                // Case insensitivity
+  if(getSearchMode()&SearchWords) rexmode|=FXRex::Words;                        // Whole Words
   if(!(getSearchMode()&SearchRegex)) rexmode|=FXRex::Verbatim;                  // Verbatim match
   if(getSearchMode()&SeachHidden) opts|=FXDir::HiddenFiles|FXDir::HiddenDirs;   // Visit hidden files and directories
   if(!(getSearchMode()&SearchRecurse)) limit=2;                                 // Don't recurse
-  appendHistory(getSearchText(),getCurrentPattern(),getSearchMode());
+  appendHistory(getSearchText(),getDirectory(),getCurrentPattern(),getSearchMode());
   proceed=1;
   visitor.traverse(getDirectory(),getSearchText(),getPattern(),rexmode,opts,limit);
   setSearchingText(tr("<stopped>"));
@@ -582,10 +603,11 @@ long FindInFiles::onUpdFlags(FXObject* sender,FXSelector sel,void*){
   switch(FXSELID(sel)){
     case ID_ICASE: value=(searchmode&SearchCaseFold); break;
     case ID_REGEX: value=(searchmode&SearchRegex); break;
+    case ID_WORDS: value=(searchmode&SearchWords); break;
     case ID_RECURSIVE: value=(searchmode&SearchRecurse); break;
     case ID_HIDDEN: value=(searchmode&SeachHidden); break;
     }
-  sender->handle(this,value?FXSEL(SEL_COMMAND,FXWindow::ID_CHECK):FXSEL(SEL_COMMAND,FXWindow::ID_UNCHECK),NULL);
+  sender->handle(this,value?FXSEL(SEL_COMMAND,FXWindow::ID_CHECK):FXSEL(SEL_COMMAND,FXWindow::ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -595,6 +617,7 @@ long FindInFiles::onCmdFlags(FXObject*,FXSelector sel,void*){
   switch(FXSELID(sel)){
     case ID_ICASE: searchmode^=SearchCaseFold; break;
     case ID_REGEX: searchmode^=SearchRegex; break;
+    case ID_WORDS: searchmode^=SearchWords; break;
     case ID_RECURSIVE: searchmode^=SearchRecurse; break;
     case ID_HIDDEN: searchmode^=SeachHidden; break;
     }
@@ -604,7 +627,7 @@ long FindInFiles::onCmdFlags(FXObject*,FXSelector sel,void*){
 
 // Update all hits check button
 long FindInFiles::onUpdFirstHit(FXObject* sender,FXSelector,void*){
-  sender->handle(this,firsthit?FXSEL(SEL_COMMAND,FXWindow::ID_CHECK):FXSEL(SEL_COMMAND,FXWindow::ID_UNCHECK),NULL);
+  sender->handle(this,firsthit?FXSEL(SEL_COMMAND,FXWindow::ID_CHECK):FXSEL(SEL_COMMAND,FXWindow::ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -628,14 +651,14 @@ long FindInFiles::onCmdFolder(FXObject*,FXSelector,void*){
 
 // Update arrows
 long FindInFiles::onUpdHistoryUp(FXObject* sender,FXSelector,void*){
-  sender->handle(this,(index<19 && !searchHistory[index+1].empty())?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
+  sender->handle(this,(index<19 && !searchHistory[index+1].empty())?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),nullptr);
   return 1;
   }
 
 
 // Update arrows
 long FindInFiles::onUpdHistoryDn(FXObject* sender,FXSelector,void*){
-  sender->handle(this,(-1<index)?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
+  sender->handle(this,(-1<index)?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),nullptr);
   return 1;
   }
 
@@ -646,10 +669,12 @@ long FindInFiles::onCmdHistoryUp(FXObject*,FXSelector,void*){
     ++index;
     if(index==0){
       savedsearchtext=getSearchText();
+      savedsearchfolder=getDirectory();
       savedsearchmode=getSearchMode();
       savedcurrentpattern=getCurrentPattern();
       }
     setSearchText(searchHistory[index]);
+    setDirectory(folderHistory[index]);
     setCurrentPattern(patternHistory[index]);
     setSearchMode(optionsHistory[index]);
     }
@@ -666,11 +691,13 @@ long FindInFiles::onCmdHistoryDn(FXObject*,FXSelector,void*){
     --index;
     if(0<=index){
       setSearchText(searchHistory[index]);
+      setDirectory(folderHistory[index]);
       setCurrentPattern(patternHistory[index]);
       setSearchMode(optionsHistory[index]);
       }
     else{
       setSearchText(savedsearchtext);
+      setDirectory(savedsearchfolder);
       setSearchMode(savedsearchmode);
       setCurrentPattern(savedcurrentpattern);
       }
@@ -684,10 +711,10 @@ long FindInFiles::onArrowKey(FXObject*,FXSelector,void* ptr){
   switch(((FXEvent*)ptr)->code){
     case KEY_Up:
     case KEY_KP_Up:
-      return onCmdHistoryUp(this,FXSEL(SEL_COMMAND,ID_HIST_UP),NULL);
+      return onCmdHistoryUp(this,FXSEL(SEL_COMMAND,ID_HIST_UP),nullptr);
     case KEY_Down:
     case KEY_KP_Down:
-      return onCmdHistoryDn(this,FXSEL(SEL_COMMAND,ID_HIST_DN),NULL);
+      return onCmdHistoryDn(this,FXSEL(SEL_COMMAND,ID_HIST_DN),nullptr);
     }
   return 0;
   }
@@ -696,10 +723,10 @@ long FindInFiles::onArrowKey(FXObject*,FXSelector,void* ptr){
 // Wheeling in text field scrolls through history
 long FindInFiles::onMouseWheel(FXObject*,FXSelector,void* ptr){
   if(((FXEvent*)ptr)->code>0){
-    return onCmdHistoryUp(this,FXSEL(SEL_COMMAND,ID_HIST_UP),NULL);
+    return onCmdHistoryUp(this,FXSEL(SEL_COMMAND,ID_HIST_UP),nullptr);
     }
   if(((FXEvent*)ptr)->code<0){
-    return onCmdHistoryDn(this,FXSEL(SEL_COMMAND,ID_HIST_DN),NULL);
+    return onCmdHistoryDn(this,FXSEL(SEL_COMMAND,ID_HIST_DN),nullptr);
     }
   return 1;
   }
@@ -710,10 +737,13 @@ long FindInFiles::onCmdFileDblClicked(FXObject*,FXSelector,void* ptr){
   FXint which=(FXint)(FXival)ptr;
   if(0<=which){
     FXchar name[1024];
-    FXint lineno=0;
-    FXint column=0;
+    FXint  lineno=0;
+    FXint  column=0;
     if(locations->getItem(which)->getText().scan("%1023[^:]:%d:%d",name,&lineno,&column)==3){
-      getApp()->openFileWindow(FXPath::absolute(getDirectory(),name),lineno,column);
+      FXString filename=FXPath::absolute(getDirectory(),name);
+      TextWindow* window=getApp()->openFileWindow(filename);
+      window->visitLine(lineno,column);
+      window->show(PLACEMENT_DEFAULT);
       }
     }
   return 1;
