@@ -3,7 +3,7 @@
 *                   FOX Desktop Setup - FOX Desktop Enviroment                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2021 Sander Jansen.  All Rights Reserved.                  *
+* Copyright (C) 2004,2024 Sander Jansen.  All Rights Reserved.                  *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -92,6 +92,18 @@ const ColorTheme ColorThemes[]={
   {"Solaris"           ,FXRGB(174,178,195),FXRGB(  0,  0,  0),FXRGB(147,151,165),FXRGB(  0,  0,  0),FXRGB(113,139,165),FXRGB(255,255,255),FXRGB(255,255,225),FXRGB(  0,  0,  0),FXRGB(113,139,165),FXRGB(255,255,255)},
   {"Storm"             ,FXRGB(192,192,192),FXRGB(  0,  0,  0),FXRGB(255,255,255),FXRGB(  0,  0,  0),FXRGB(139,  0,139),FXRGB(255,255,255),FXRGB(255,255,225),FXRGB(  0,  0,  0),FXRGB(139,  0,139),FXRGB(255,255,255)},
   {"Sea Sky"           ,FXRGB(165,178,198),FXRGB(  0,  0,  0),FXRGB(255,255,255),FXRGB(  0,  0,  0),FXRGB( 49,101,156),FXRGB(255,255,255),FXRGB(255,255,225),FXRGB(  0,  0,  0),FXRGB( 49,101,156),FXRGB(255,255,255)},
+//|--------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------|
+//|        Name        |        Base      |       Border     |       Back       |      Fore        |      Selback     |      Selfore     |      Tipback     |     Tipfore      |      Menuback    |      Menufore    |
+//|--------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------|
+  {"Golden"            ,FXRGB(237,192, 27),FXRGB(  0,  0,  0),FXRGB(255,243,208),FXRGB(  0,  0,  0),FXRGB(184,231, 71),FXRGB(  0,  0,  0),FXRGB(255,237,172),FXRGB(  0,  0,  0),FXRGB(214,175, 33),FXRGB(  0,  0,  0)},
+
+  {"Envy"              ,FXRGB(144,247,144),FXRGB(  0,  0,  0),FXRGB(213,255,213),FXRGB(  0,  0,  0),FXRGB(255,182,114),FXRGB(  0,  0,  0),FXRGB(194,255,194),FXRGB(  0,  0,  0),FXRGB( 83,213, 83),FXRGB(  0,  0,  0)},
+//|--------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------|
+//|        Name        |        Base      |       Border     |       Back       |      Fore        |      Selback     |      Selfore     |      Tipback     |     Tipfore      |      Menuback    |      Menufore    |
+//|--------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------+------------------|
+  {"Black and White"   ,FXRGB(  8,  8,  8),FXRGB( 77, 77, 77),FXRGB(  0,  0,  0),FXRGB(255,255,255),FXRGB(  0,  0,255),FXRGB(255,255,255),FXRGB(255,255,225),FXRGB(  0,  0,  0),FXRGB(  0,  0,255),FXRGB(255,255,255)},
+  {"Obsidian Coast"    ,FXRGB( 48, 47, 47),FXRGB(  0,  0,  0),FXRGB( 32, 31, 31),FXRGB(224,223,220),FXRGB( 24, 72,128),FXRGB(255,255,255),FXRGB( 16, 48, 80),FXRGB(196,209,224),FXRGB( 24, 72,128),FXRGB(255,255,255)},
+  {"Wonton Soup"       ,FXRGB( 71, 76, 86),FXRGB(  0,  0,  0),FXRGB( 58, 62, 70),FXRGB(182,193,208),FXRGB(117,133,153),FXRGB(209,225,244),FXRGB(182,193,208),FXRGB( 42, 44, 48),FXRGB(117,133,153),FXRGB(209,225,244)},
   };
 
 
@@ -126,7 +138,7 @@ FXIMPLEMENT(FXDesktopSetup,FXMainWindow,FXDesktopSetupMap,ARRAYNUMBER(FXDesktopS
 /*******************************************************************************/
 
 // Construct window
-FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,NULL,NULL,DECOR_ALL,0,0,0,0){
+FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,nullptr,nullptr,DECOR_ALL,0,0,0,0){
   const FXlong milliseconds=1000000L;
 
   // Set title
@@ -188,7 +200,7 @@ FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,NULL,NU
   new FXSeparator(hframe1,SEPARATOR_GROOVE|LAYOUT_FILL_Y);
 
   FXVerticalFrame *themeframe=new FXVerticalFrame(frame1,LAYOUT_FILL_X,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
-  new FXLabel(themeframe,tr("Theme: "),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(themeframe,tr("Theme: "),nullptr,LAYOUT_CENTER_Y);
   list=new FXListBox(themeframe,this,ID_COLOR_THEME,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
   list->setNumVisible(9);
 
@@ -198,52 +210,52 @@ FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,NULL,NU
   FXMatrix* matrix1=new FXMatrix(frame1,2,LAYOUT_FILL_Y|MATRIX_BY_COLUMNS,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,1,1);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_base,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Base Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Base Color"),nullptr,LAYOUT_CENTER_Y);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_border,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Border Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Border Color"),nullptr,LAYOUT_CENTER_Y);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_fore,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Text Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Text Color"),nullptr,LAYOUT_CENTER_Y);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_back,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Background Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Background Color"),nullptr,LAYOUT_CENTER_Y);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_selfore,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Selected Text Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Selected Text Color"),nullptr,LAYOUT_CENTER_Y);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_selback,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Selected Background Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Selected Background Color"),nullptr,LAYOUT_CENTER_Y);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_menufore,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Selected Menu Text Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Selected Menu Text Color"),nullptr,LAYOUT_CENTER_Y);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_menuback,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Selected Menu Background Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Selected Menu Background Color"),nullptr,LAYOUT_CENTER_Y);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_tipfore,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Tip Text Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Tip Text Color"),nullptr,LAYOUT_CENTER_Y);
 
   new FXColorWell(matrix1,FXRGB(0,0,255),&target_tipback,FXDataTarget::ID_VALUE);
-  new FXLabel(matrix1,tr("Tip Background Color"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix1,tr("Tip Background Color"),nullptr,LAYOUT_CENTER_Y);
 
   // Sample gui fragment showing colors
   FXVerticalFrame* frame2=new FXVerticalFrame(hframe1,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,0,0);
 
-  tabbook=new FXTabBook(frame2,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0);
+  tabbook=new FXTabBook(frame2,nullptr,0,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0);
   tabitem=new FXTabItem(tabbook,tr(" Item 1 "));
   tabframe=new FXVerticalFrame(tabbook,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_THICK|FRAME_RAISED);
 
   labeltextframe1=new FXHorizontalFrame(tabframe,LAYOUT_FILL_X);
-  label1=new FXLabel(labeltextframe1,tr("Label with Text"),NULL);
-  textfield1=new FXTextField(labeltextframe1,30,NULL,0,LAYOUT_FILL_X|FRAME_THICK|FRAME_SUNKEN);
+  label1=new FXLabel(labeltextframe1,tr("Label with Text"),nullptr);
+  textfield1=new FXTextField(labeltextframe1,30,nullptr,0,LAYOUT_FILL_X|FRAME_THICK|FRAME_SUNKEN);
   textfield1->setText(tr("Select this text, to see the selected colors"));
 
   labeltextframe2=new FXHorizontalFrame(tabframe,LAYOUT_FILL_X);
   textframe1=new FXHorizontalFrame(labeltextframe2,LAYOUT_FILL_X|FRAME_THICK|FRAME_SUNKEN,0,0,0,0,2,2,2,2,0,0);
-  label3=new FXLabel(textframe1,tr("Selected Text (with focus)"),NULL,LAYOUT_FILL_X,0,0,0,0,1,1,1,1);
+  label3=new FXLabel(textframe1,tr("Selected Text (with focus)"),nullptr,LAYOUT_FILL_X,0,0,0,0,1,1,1,1);
   textframe2=new FXHorizontalFrame(labeltextframe2,LAYOUT_FILL_X|FRAME_THICK|FRAME_SUNKEN,0,0,0,0,2,2,2,2,0,0);
-  label4=new FXLabel(textframe2,tr("Selected Text (no focus)"),NULL,LAYOUT_FILL_X,0,0,0,0,1,1,1,1);
+  label4=new FXLabel(textframe2,tr("Selected Text (no focus)"),nullptr,LAYOUT_FILL_X,0,0,0,0,1,1,1,1);
 
   sep1=new FXSeparator(tabframe,LAYOUT_FILL_X|SEPARATOR_LINE);
 
@@ -252,31 +264,31 @@ FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,NULL,NU
   grpbox1=new FXGroupBox(tabsubframe,tr("MenuPane"),FRAME_GROOVE|LAYOUT_FILL_Y|LAYOUT_FILL_X);
 
   menuframe=new FXVerticalFrame(grpbox1,FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_X|LAYOUT_CENTER_Y,0,0,0,0,0,0,0,0,0,0);
-  menulabels[0]=new FXLabel(menuframe,tr("&Open"),NULL,LABEL_NORMAL,0,0,0,0,16,4);
-  menulabels[1]=new FXLabel(menuframe,tr("S&ave"),NULL,LABEL_NORMAL,0,0,0,0,16,4);
+  menulabels[0]=new FXLabel(menuframe,tr("&Open"),nullptr,LABEL_NORMAL,0,0,0,0,16,4);
+  menulabels[1]=new FXLabel(menuframe,tr("S&ave"),nullptr,LABEL_NORMAL,0,0,0,0,16,4);
   sep2=new FXSeparator(menuframe,LAYOUT_FILL_X|SEPARATOR_GROOVE);
-  menulabels[2]=new FXLabel(menuframe,tr("I&mport"),NULL,LABEL_NORMAL,0,0,0,0,16,4);
-  menulabels[4]=new FXLabel(menuframe,tr("Selected Menu Entry"),NULL,LABEL_NORMAL,0,0,0,0,16,4);
-  menulabels[3]=new FXLabel(menuframe,tr("Print"),NULL,LABEL_NORMAL,0,0,0,0,16,4);
+  menulabels[2]=new FXLabel(menuframe,tr("I&mport"),nullptr,LABEL_NORMAL,0,0,0,0,16,4);
+  menulabels[4]=new FXLabel(menuframe,tr("Selected Menu Entry"),nullptr,LABEL_NORMAL,0,0,0,0,16,4);
+  menulabels[3]=new FXLabel(menuframe,tr("Print"),nullptr,LABEL_NORMAL,0,0,0,0,16,4);
   sep3=new FXSeparator(menuframe,LAYOUT_FILL_X|SEPARATOR_GROOVE);
-  menulabels[5]=new FXLabel(menuframe,tr("&Quit"),NULL,LABEL_NORMAL,0,0,0,0,16,4);
+  menulabels[5]=new FXLabel(menuframe,tr("&Quit"),nullptr,LABEL_NORMAL,0,0,0,0,16,4);
 
   grpbox2=new FXGroupBox(tabsubframe,tr("Tooltips"),FRAME_GROOVE|LAYOUT_FILL_Y|LAYOUT_FILL_X);
 
-  label2=new FXLabel(grpbox2,tr("Sample Tooltip"),NULL,FRAME_LINE|LAYOUT_CENTER_X);
-  label5=new FXLabel(grpbox2,tr("Multiline Sample\n Tooltip"),NULL,FRAME_LINE|LAYOUT_CENTER_X);
+  label2=new FXLabel(grpbox2,tr("Sample Tooltip"),nullptr,FRAME_LINE|LAYOUT_CENTER_X);
+  label5=new FXLabel(grpbox2,tr("Multiline Sample\n Tooltip"),nullptr,FRAME_LINE|LAYOUT_CENTER_X);
 
   FXHorizontalFrame* hframe2=new FXHorizontalFrame(vframe4,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
 
-  new FXLabel(hframe2,tr("Normal Font: "),NULL,LAYOUT_CENTER_Y);
-  fontbutton=new FXButton(hframe2," ",NULL,this,ID_CHOOSE_FONT,LAYOUT_CENTER_Y|FRAME_RAISED|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_X);
+  new FXLabel(hframe2,tr("Normal Font: "),nullptr,LAYOUT_CENTER_Y);
+  fontbutton=new FXButton(hframe2," ",nullptr,this,ID_CHOOSE_FONT,LAYOUT_CENTER_Y|FRAME_RAISED|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_X);
 
   /// File Binding Panel ///
   FXVerticalFrame* vframe5=new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);
 
   // Icon search path
   FXHorizontalFrame* hframe3=new FXHorizontalFrame(vframe5,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
-  new FXLabel(hframe3,tr("Icon Search Path:"),NULL,LAYOUT_CENTER_Y);
+  new FXLabel(hframe3,tr("Icon Search Path:"),nullptr,LAYOUT_CENTER_Y);
   FXTextField* icondirs=new FXTextField(hframe3,2,&target_iconpath,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);
   icondirs->setTipText(tr("List of directories to search for icons."));
 
@@ -297,9 +309,9 @@ FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,NULL,NU
 
   // Buttons
   FXHorizontalFrame *listbuttonframe=new FXHorizontalFrame(vframe6,PACK_UNIFORM_WIDTH|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
-  new FXButton(listbuttonframe,tr("&New\tAdd New Binding"),NULL,this,ID_CREATE_FILEBINDING);
-  new FXButton(listbuttonframe,tr("&Delete\tDelete Selected Binding"),NULL,this,ID_REMOVE_FILEBINDING);
-  new FXButton(listbuttonframe,tr("&Edit\tEdit Binding Name"),NULL,this,ID_RENAME_FILEBINDING);
+  new FXButton(listbuttonframe,tr("&New\tAdd New Binding"),nullptr,this,ID_CREATE_FILEBINDING);
+  new FXButton(listbuttonframe,tr("&Delete\tDelete Selected Binding"),nullptr,this,ID_REMOVE_FILEBINDING);
+  new FXButton(listbuttonframe,tr("&Edit\tEdit Binding Name"),nullptr,this,ID_RENAME_FILEBINDING);
 
   new FXSeparator(hframe4,SEPARATOR_GROOVE|LAYOUT_FILL_Y);
 
@@ -317,11 +329,11 @@ FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,NULL,NU
   // Command to execute
   packer=new FXPacker(vframe7,LAYOUT_FILL_X,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
   new FXLabel(packer,"Command:");
-  FXCheckButton *checkbutton1=new FXCheckButton(packer,tr("Run in terminal\t\tRun command in terminal."),this,ID_RUN_IN_TERMINAL,ICON_BEFORE_TEXT|LAYOUT_LEFT|LAYOUT_SIDE_BOTTOM);
-  FXCheckButton *checkbutton2=new FXCheckButton(packer,tr("Change directory\t\tChange directory before running command."),this,ID_CHANGE_DIRECTORY,ICON_BEFORE_TEXT|LAYOUT_LEFT|LAYOUT_SIDE_BOTTOM);
-  new FXButton(packer,"...",NULL,this,ID_SELECT_COMMAND,LAYOUT_SIDE_RIGHT|LAYOUT_CENTER_Y|FRAME_RAISED|FRAME_THICK);
+  new FXCheckButton(packer,tr("Run in terminal\t\tRun command in terminal."),this,ID_RUN_IN_TERMINAL,ICON_BEFORE_TEXT|LAYOUT_LEFT|LAYOUT_SIDE_BOTTOM);
+  new FXCheckButton(packer,tr("Change directory\t\tChange directory before running command."),this,ID_CHANGE_DIRECTORY,ICON_BEFORE_TEXT|LAYOUT_LEFT|LAYOUT_SIDE_BOTTOM);
+  new FXButton(packer,"...",nullptr,this,ID_SELECT_COMMAND,LAYOUT_SIDE_RIGHT|LAYOUT_CENTER_Y|FRAME_RAISED|FRAME_THICK);
   FXTextField* command=new FXTextField(packer,2,&target_filebinding_command,FXDataTarget::ID_VALUE,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);
-  command->setTipText(tr("Path to program associated with the file\nCommand line arguments are assembled from the selected file(s) as follows:\n  %f  Replaced by current filename;\n  %F  Replaced by selected filenames;\n  %u  Replaced by URL encoding of current filename;\n  %U  Replaced by URL encoding of selected files;\n  %d  Replaced by current working directory;\n  %%  Replaced by simply '%'."));
+  command->setTipText(tr("Path to program associated with the file\nCommand line arguments are assembled from the selected file(s) as follows:\n  %f  Replaced by current pathname;\n  %F  Replaced by selected pathnames;\n  %n  Replaced by current filename;\n  %N  Replaced by selected filenames;\n  %u  Replaced by URL encoding of current filename;\n  %U  Replaced by URL encoding of selected files;\n  %d  Replaced by current working directory;\n  %%  Replaced by simply '%'."));
   new FXSeparator(vframe7,SEPARATOR_GROOVE|LAYOUT_FILL_X);
 
   // Mime types
@@ -336,124 +348,152 @@ FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,NULL,NU
 
   // Icons to show
   FXMatrix *iconsmatrix=new FXMatrix(vframe7,4,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
-  new FXLabel(iconsmatrix,tr("Small"),NULL,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
-  new FXLabel(iconsmatrix,tr("Big"),NULL,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
-  new FXLabel(iconsmatrix,tr("Small Open"),NULL,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
-  new FXLabel(iconsmatrix,tr("Big Open"),NULL,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
-  iconbutton[MINI_ICON]=new FXButton(iconsmatrix,tr("\tChange icon"),NULL,this,ID_SELECT_ICON_MINI,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,68,68, 1,1,1,1);
-  iconbutton[BIG_ICON]=new FXButton(iconsmatrix,tr("\tChange icon"),NULL,this,ID_SELECT_ICON_BIG,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,68,68, 1,1,1,1);
-  iconbutton[MINI_ICON_OPEN]=new FXButton(iconsmatrix,tr("\tChange icon"),NULL,this,ID_SELECT_ICON_MINIOPEN,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,68,68, 1,1,1,1);
-  iconbutton[BIG_ICON_OPEN]=new FXButton(iconsmatrix,tr("\tChange icon"),NULL,this,ID_SELECT_ICON_BIGOPEN,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,68,68, 1,1,1,1);
-  iconimage[MINI_ICON]=NULL;
-  iconimage[BIG_ICON]=NULL;
-  iconimage[MINI_ICON_OPEN]=NULL;
-  iconimage[BIG_ICON_OPEN]=NULL;
+  new FXLabel(iconsmatrix,tr("Small"),nullptr,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
+  new FXLabel(iconsmatrix,tr("Big"),nullptr,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
+  new FXLabel(iconsmatrix,tr("Small Open"),nullptr,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
+  new FXLabel(iconsmatrix,tr("Big Open"),nullptr,LAYOUT_CENTER_X|LAYOUT_FILL_COLUMN);
+  iconbutton[MINI_ICON]=new FXButton(iconsmatrix,tr("\tChange icon"),nullptr,this,ID_SELECT_ICON_MINI,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,68,68, 1,1,1,1);
+  iconbutton[BIG_ICON]=new FXButton(iconsmatrix,tr("\tChange icon"),nullptr,this,ID_SELECT_ICON_BIG,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,68,68, 1,1,1,1);
+  iconbutton[MINI_ICON_OPEN]=new FXButton(iconsmatrix,tr("\tChange icon"),nullptr,this,ID_SELECT_ICON_MINIOPEN,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,68,68, 1,1,1,1);
+  iconbutton[BIG_ICON_OPEN]=new FXButton(iconsmatrix,tr("\tChange icon"),nullptr,this,ID_SELECT_ICON_BIGOPEN,FRAME_RAISED|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,68,68, 1,1,1,1);
+  iconimage[MINI_ICON]=nullptr;
+  iconimage[BIG_ICON]=nullptr;
+  iconimage[MINI_ICON_OPEN]=nullptr;
+  iconimage[BIG_ICON_OPEN]=nullptr;
 
   /// Miscellaneous Parameters Panel ///
   FXHorizontalFrame* hframe5=new FXHorizontalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);
-  FXMatrix* matrix2=new FXMatrix(hframe5,3,LAYOUT_FILL_Y|MATRIX_BY_COLUMNS,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
+
+  // First column of settings
+  FXMatrix* matrix2=new FXMatrix(hframe5,3,LAYOUT_FILL_X|LAYOUT_FILL_Y|MATRIX_BY_COLUMNS,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
 
   // Type speed
-  new FXLabel(matrix2,tr("Typing Speed\t\tTyping Speed"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Typing Speed\t\tTyping Speed"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner1=new FXSpinner(matrix2,4,&target_typingspeed,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner1->setRange(1,9999);
   spinner1->setIncrement(500);
-  new FXLabel(matrix2,"ms",NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,"ms",nullptr,LAYOUT_CENTER_Y);
 
   // Double click speed
-  new FXLabel(matrix2,tr("Double Click Speed\t\tDouble Click Speed"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Double Click Speed\t\tDouble Click Speed"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner2=new FXSpinner(matrix2,4,&target_clickspeed,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner2->setRange(1,9999);
   spinner2->setIncrement(100);
-  new FXLabel(matrix2,"ms",NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,"ms",nullptr,LAYOUT_CENTER_Y);
 
   // Scroll speed
-  new FXLabel(matrix2,tr("Scroll Speed\t\tScroll Speed"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Scroll Speed\t\tScroll Speed"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner3=new FXSpinner(matrix2,4,&target_scrollspeed,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner3->setRange(1,9999);
   spinner3->setIncrement(10);
-  new FXLabel(matrix2,"ms",NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,"ms",nullptr,LAYOUT_CENTER_Y);
 
   // Scroll delay
-  new FXLabel(matrix2,tr("Scroll Delay\t\tScroll Delay"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Scroll Delay\t\tScroll Delay"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner4=new FXSpinner(matrix2,4,&target_scrolldelay,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner4->setRange(1,9999);
   spinner4->setIncrement(100);
-  new FXLabel(matrix2,"ms",NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,"ms",nullptr,LAYOUT_CENTER_Y);
 
   // Cursor blink speed
-  new FXLabel(matrix2,tr("Cursor Blink Speed\t\tCursor Blink Speed"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Cursor Blink Speed\t\tCursor Blink Speed"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner5=new FXSpinner(matrix2,4,&target_blinkspeed,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner5->setRange(1,9999);
   spinner5->setIncrement(100);
-  new FXLabel(matrix2,"ms",NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,"ms",nullptr,LAYOUT_CENTER_Y);
 
   // Animation speed
-  new FXLabel(matrix2,tr("Animation Speed\t\tAnimation Speed"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Animation Speed\t\tAnimation Speed"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner6=new FXSpinner(matrix2,4,&target_animspeed,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner6->setRange(1,9999);
   spinner6->setIncrement(1);
-  new FXLabel(matrix2,"ms",NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,"ms",nullptr,LAYOUT_CENTER_Y);
 
   // Popup menu delay
-  new FXLabel(matrix2,tr("Cascade Menu Popup Delay\t\tAmount of delay before cascading menu is shown"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Cascade Menu Popup Delay\t\tAmount of delay before cascading menu is shown"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner7=new FXSpinner(matrix2,4,&target_menupause,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner7->setRange(1,9999);
   spinner7->setIncrement(100);
-  new FXLabel(matrix2,"ms",NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,"ms",nullptr,LAYOUT_CENTER_Y);
 
   // Tooltip popup delay
-  new FXLabel(matrix2,tr("Tooltip Popup Delay\t\tAmount of Delay before tooltip is shown "),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Tooltip Popup Delay\t\tAmount of Delay before tooltip is shown "),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner8=new FXSpinner(matrix2,4,&target_tooltippause,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner8->setRange(1,9999);
   spinner8->setIncrement(100);
-  new FXLabel(matrix2,"ms",NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,"ms",nullptr,LAYOUT_CENTER_Y);
 
   // Tooltip display time
-  new FXLabel(matrix2,tr("Tooltip Time\t\tTime that tooltips are shown"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Tooltip Time\t\tTime that tooltips are shown"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner9=new FXSpinner(matrix2,4,&target_tooltiptime,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner9->setRange(1,9999);
   spinner9->setIncrement(500);
-  new FXLabel(matrix2,"ms",NULL,LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,"ms",nullptr,LAYOUT_CENTER_Y);
 
   // Drag delta jitter
-  new FXLabel(matrix2,tr("Drag Delta\t\tMinimum distance considered a mouse move"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Drag Delta\t\tMinimum distance considered a mouse move"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner10=new FXSpinner(matrix2,4,&target_dragdelta,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner10->setRange(1,9999);
   spinner10->setIncrement(1);
   new FXFrame(matrix2,FRAME_NONE);
 
   // Mouse wheel lines
-  new FXLabel(matrix2,tr("Wheel Lines"),NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXLabel(matrix2,tr("Wheel Lines"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner11=new FXSpinner(matrix2,4,&target_wheellines,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner11->setRange(1,100);
 
+  // Vertical separator
   new FXSeparator(hframe5,SEPARATOR_GROOVE|LAYOUT_FILL_Y);
 
-  FXMatrix* matrix3=new FXMatrix(hframe5,2,LAYOUT_FILL_Y|MATRIX_BY_COLUMNS,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
+  // Second column of settings
+  FXMatrix* matrix3=new FXMatrix(hframe5,2,LAYOUT_FILL_X|LAYOUT_FILL_Y|MATRIX_BY_COLUMNS,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
 
   // Maximum colors spinner
-  new FXLabel(matrix3,tr("Maximum Colors Allocated"));
+  new FXLabel(matrix3,tr("Maximum Colors Allocated"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner12=new FXSpinner(matrix3,3,&target_maxcolors,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner12->setRange(1,256);
 
   // Gamma correction spinner
-  new FXLabel(matrix3,tr("Gamma Correction"));
+  new FXLabel(matrix3,tr("Gamma Correction"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXRealSpinner* spinner13=new FXRealSpinner(matrix3,3,&target_gamma,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner13->setRange(0.0,5.0);
   spinner13->setIncrement(0.1);
 
   // Scrollbar size spinner
-  new FXLabel(matrix3,tr("Scrollbar Size"));
+  new FXLabel(matrix3,tr("Scrollbar Size"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
   FXSpinner* spinner14=new FXSpinner(matrix3,3,&target_barsize,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK);
   spinner14->setRange(5,100);
 
+  // Xft hint style
+  new FXLabel(matrix3,tr("Xft font hint style"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  FXListBox* list2=new FXListBox(matrix3,&target_hintstyle,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_TOP);
+  list2->fillItems(tr("None\nSlight\nMedium\nFull"));
+  list2->setNumVisible(4);
+
+  // Xft sub-pixel rendering
+  new FXLabel(matrix3,tr("Xft font sub-pixel rendering"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  FXListBox* list3=new FXListBox(matrix3,&target_subpixel,FXDataTarget::ID_VALUE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_TOP);
+  list3->fillItems(tr("Unknown\nRGB\nBGR\nVRGB\nVBGR\nNone"));
+  list3->setNumVisible(6);
+
+  // Xft font hinting
+  new FXLabel(matrix3,tr("Xft font hinting"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXCheckButton(matrix3,FXString::null,&target_hinting,FXDataTarget::ID_VALUE);
+
+  // Xft font autohint
+  new FXLabel(matrix3,tr("Xft font autohint"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXCheckButton(matrix3,FXString::null,&target_autohint,FXDataTarget::ID_VALUE);
+
+  // Xft font anti-aliasing
+  new FXLabel(matrix3,tr("Xft font anti-aliasing"),nullptr,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
+  new FXCheckButton(matrix3,FXString::null,&target_antialias,FXDataTarget::ID_VALUE);
+
   // Close button etc.
   new FXSeparator(main,SEPARATOR_GROOVE|LAYOUT_FILL_X);
   FXHorizontalFrame *closebox=new FXHorizontalFrame(main,LAYOUT_BOTTOM|LAYOUT_FILL_X,0,0,0,0,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING,DEFAULT_SPACING);
-  vendorandapplication=new FXLabel(closebox,FXString::null,NULL,LAYOUT_FILL_X|LAYOUT_CENTER_Y|JUSTIFY_LEFT,0,0,0,0,15);
+  vendorandapplication=new FXLabel(closebox,FXString::null,nullptr,LAYOUT_FILL_X|LAYOUT_CENTER_Y|JUSTIFY_LEFT,0,0,0,0,15);
   vendorandapplication->disable();
-  new FXButton(closebox,tr("&Close"),NULL,this,FXTopWindow::ID_CLOSE,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0,20,20);
+  new FXButton(closebox,tr("&Close"),nullptr,this,FXTopWindow::ID_CLOSE,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0,20,20);
 
   // Tool tip
   tooltip=new FXToolTip(getApp());
@@ -490,6 +530,13 @@ FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,NULL,NU
   maxcolors=125;
   gamma=1.0;
 
+  // Fonts stuff
+  subpixel=0;
+  hintstyle=3;
+  hinting=true;
+  autohint=false;
+  antialias=true;
+
   filebinding.flags=0;
 
   // Color data targets associations
@@ -519,6 +566,11 @@ FXDesktopSetup::FXDesktopSetup(FXApp *ap):FXMainWindow(ap,FXString::null,NULL,NU
   target_barsize.connect(barSize);
   target_maxcolors.connect(maxcolors);
   target_gamma.connect(gamma);
+  target_subpixel.connect(subpixel);
+  target_hintstyle.connect(hintstyle);
+  target_hinting.connect(hinting);
+  target_autohint.connect(autohint);
+  target_antialias.connect(antialias);
 
   // File data target associations
   target_filebinding_description.connect(filebinding.description);
@@ -545,7 +597,7 @@ FXIcon *FXDesktopSetup::createIconFromName(const FXString& name) const {
       return ico;
       }
     }
-  return NULL;
+  return nullptr;
   }
 
 
@@ -554,8 +606,8 @@ void FXDesktopSetup::setupIconButton(const FXString& name,FXint index){
   FXASSERT(0<=index && index<=4);
   if(iconimage[index]){
     delete iconimage[index];
-    iconbutton[index]->setIcon(NULL);
-    iconimage[index]=NULL;
+    iconbutton[index]->setIcon(nullptr);
+    iconimage[index]=nullptr;
     }
   iconimage[index]=createIconFromName(name);
   if(iconimage[index]){
@@ -620,6 +672,17 @@ long FXDesktopSetup::onCmdSelectCommand(FXObject*,FXSelector,void*){
   if(!newcommand.empty()){
     filebinding.command=newcommand;
     }
+#if 0
+  FXString oldcommand=SUGGESTED_FOLDER;
+  FXString newcommand;
+  if(!filebinding.command.empty()){
+    oldcommand=FXPath::dequote(filebinding.command);
+    }
+  newcommand=FXFileDialog::getOpenFilename(this,tr("Select Command"),oldcommand,SUGGESTED_PATTERNS);
+  if(!newcommand.empty()){
+    filebinding.command=FXPath::enquote(newcommand);
+    }
+#endif
   return 1;
   }
 
@@ -699,7 +762,7 @@ long FXDesktopSetup::onCmdFileBinding(FXObject*,FXSelector,void* ptr){
 // Add new file binding
 long FXDesktopSetup::onCmdCreateFileBinding(FXObject*,FXSelector,void*){
   FXString result;
-  if(FXInputDialog::getString(result,this,tr("New File Binding"),tr("Please enter filebinding key:"),NULL)){
+  if(FXInputDialog::getString(result,this,tr("New File Binding"),tr("Please enter filebinding key:"),nullptr)){
     if(result.empty()) return 1;
     if((filebindinglist->findItem(result))>=0){
       FXMessageBox::question(this,MBOX_OK,tr("Duplicate Binding"),tr("The given key %s already exists."),result.text());
@@ -748,7 +811,7 @@ long FXDesktopSetup::onCmdRemoveFileBinding(FXObject*,FXSelector,void*){
 long FXDesktopSetup::onCmdRenameFileBinding(FXObject*,FXSelector,void*){
   FXint no;
   FXString result=filebinding.key;
-  if(FXInputDialog::getString(result,this,tr("Rename File Binding"),tr("Rename File Binding"),NULL)){
+  if(FXInputDialog::getString(result,this,tr("Rename File Binding"),tr("Rename File Binding"),nullptr)){
     if(result==filebinding.key) return 1;
     if((no=filebindinglist->findItem(result))>=0){
       if(FXMessageBox::question(this,MBOX_YES_NO,tr("Replace Binding?"),tr("Would you like to replace the existing binding?"))!=MBOX_CLICKED_YES){
@@ -793,7 +856,7 @@ long FXDesktopSetup::onCmdSelectIcon(FXObject*,FXSelector sel,void*){
 
 // Run in terminal update
 long FXDesktopSetup::onUpdRunInTerminal(FXObject* sender,FXSelector,void*){
-  sender->handle(this,(filebinding.flags&2) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,(filebinding.flags&2) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -807,7 +870,7 @@ long FXDesktopSetup::onCmdRunInTerminal(FXObject*,FXSelector,void*){
 
 // Change directory update
 long FXDesktopSetup::onUpdChangeDirectory(FXObject* sender,FXSelector,void*){
-  sender->handle(this,(filebinding.flags&1) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,(filebinding.flags&1) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -894,7 +957,7 @@ void FXDesktopSetup::setupFileBindings(){
   mimetypelist->clearItems();
   for(entry=0; entry<section.no(); ++entry){
     if(section.empty(entry)) continue;
-    filebindinglist->appendItem(section.key(entry),NULL,NULL,true);
+    filebindinglist->appendItem(section.key(entry),nullptr,nullptr,true);
     mime=section.data(entry).section(';',4);
     if(!mime.empty() && (mimetypelist->findItem(mime)==-1)){
       mimetypelist->appendItem(mime);
@@ -931,7 +994,7 @@ void FXDesktopSetup::initColors(){
 
   // Add Standard Themes to List
   for(i=0; i<numThemes; i++){
-    list->appendItem(tr(ColorThemes[i].name),NULL,(void*)&ColorThemes[i]);
+    list->appendItem(tr(ColorThemes[i].name),nullptr,(void*)&ColorThemes[i]);
     }
 
   // Custom colors were used
@@ -947,7 +1010,7 @@ void FXDesktopSetup::initColors(){
     theme_user.tipfore=theme_current.tipfore;
     theme_user.tipback=theme_current.tipback;
     scheme=list->getNumItems();
-    list->appendItem(tr("Current"),NULL,&theme_user);
+    list->appendItem(tr("Current"),nullptr,&theme_user);
     }
 
   // User defined theme
@@ -1211,6 +1274,29 @@ FXbool FXDesktopSetup::readSettingsFile(const FXString& file){
     // Display tweaks
     maxcolors=desktopsettings.readUIntEntry("SETTINGS","maxcolors",125);
     gamma=desktopsettings.readRealEntry("SETTINGS","displaygamma",1.0);
+
+    // Xft font sub-pixel rendering
+    const FXchar *rgba=desktopsettings.readStringEntry("Xft","rgba","unknown");
+    if(rgba[0]=='u') subpixel=0;
+    else if(rgba[0]=='r') subpixel=1;
+    else if(rgba[0]=='b') subpixel=2;
+    else if(rgba[0]=='v' && rgba[1]=='r') subpixel=3;
+    else if(rgba[0]=='v' && rgba[1]=='b') subpixel=4;
+    else if(rgba[0]=='n') subpixel=5;
+    else subpixel=0;
+
+    // Xft font hint level
+    const FXchar *hints=desktopsettings.readStringEntry("Xft","hintstyle","full");
+    if(hints[0]=='s') hintstyle=1;
+    else if(hints[0]=='m') hintstyle=2;
+    else if(hints[0]=='f') hintstyle=3;
+    else if(hints[0]=='n') hintstyle=0;
+    else hintstyle=0;
+
+    // Xft font flags
+    hinting=desktopsettings.readBoolEntry("Xft","hinting",true);
+    autohint=desktopsettings.readBoolEntry("Xft","autohint",false);
+    antialias=desktopsettings.readBoolEntry("Xft","antialias",true);
     return true;
     }
   return false;
@@ -1261,6 +1347,30 @@ FXbool FXDesktopSetup::writeSettingsFile(const FXString& file){
   desktopsettings.writeUIntEntry("SETTINGS","maxcolors",maxcolors);
   desktopsettings.writeRealEntry("SETTINGS","displaygamma",gamma);
 
+  // Xft font sub-pixel rendering
+  const FXchar *rgba="unknown";
+  if(subpixel==0) rgba="unknown";
+  else if(subpixel==1) rgba="rgb";
+  else if(subpixel==2) rgba="bgr";
+  else if(subpixel==3) rgba="vrgb";
+  else if(subpixel==4) rgba="vbgr";
+  else if(subpixel==5) rgba="none";
+  desktopsettings.writeStringEntry("Xft","rgba",rgba);
+
+  // Xft font hint level
+  const FXchar *hints="full";
+  if(hintstyle==1) hints="slight";
+  else if(hintstyle==2) hints="medium";
+  else if(hintstyle==3) hints="full";
+  else if(hintstyle==0) hints="none";
+  desktopsettings.writeStringEntry("Xft","hintstyle",hints);
+
+  // Xft font flags
+  desktopsettings.writeBoolEntry("Xft","hinting",hinting);
+  desktopsettings.writeBoolEntry("Xft","autohint",autohint);
+  desktopsettings.writeBoolEntry("Xft","antialias",antialias);
+
+
   // Write file
   if(FXDir::createDirectories(FXPath::upLevel(file))){
     if(desktopsettings.unparseFile(file)){
