@@ -3,7 +3,7 @@
 *                      B Z F i l e S t r e a m   C l a s s e s                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2021 by Lyle Johnson. All Rights Reserved.                 *
+* Copyright (C) 1999,2024 by Lyle Johnson. All Rights Reserved.                 *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -47,7 +47,7 @@ private:
 public:
 
   /// Create BZIP2 file stream
-  FXBZFileStream(const FXObject* cont=NULL);
+  FXBZFileStream(const FXObject* cont=nullptr);
 
   /// Create and open BZIP2 file stream
   FXBZFileStream(const FXString& filename,FXStreamDirection save_or_load=FXStreamLoad,FXuval size=8192UL);
