@@ -3,7 +3,7 @@
 *                       C a l e n d a r   W i d g e t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2006,2021 by Sander Jansen.   All Rights Reserved.              *
+* Copyright (C) 2006,2024 by Sander Jansen.   All Rights Reserved.              *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -78,7 +78,7 @@ public:
 public:
 
   /// Constructor
-  FXCalendar(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+  FXCalendar(FXComposite *p,FXObject* tgt=nullptr,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
 
   /// Create
   void create();
