@@ -3,7 +3,7 @@
 *                        D D S   I c o n   O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2008,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2008,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -45,7 +45,7 @@ public:
 public:
 
   /// Construct icon from memory stream formatted in DDS format
-  FXDDSIcon(FXApp* a,const void *pix=NULL,FXColor clr=FXRGB(192,192,192),FXuint opts=0,FXint w=1,FXint h=1);
+  FXDDSIcon(FXApp* a,const FXuchar *pix=nullptr,FXColor clr=FXRGB(192,192,192),FXuint opts=0,FXint w=1,FXint h=1);
 
   /// Save pixels into stream in DDS format
   virtual FXbool savePixels(FXStream& store) const;
