@@ -3,7 +3,7 @@
 *                            D D S   I m a g e   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2008,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2008,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -45,7 +45,7 @@ public:
 public:
 
   /// Construct image from memory stream formatted in DDS format
-  FXDDSImage(FXApp* a,const void *pix=NULL,FXuint opts=0,FXint w=1,FXint h=1);
+  FXDDSImage(FXApp* a,const FXuchar *pix=nullptr,FXuint opts=0,FXint w=1,FXint h=1);
 
   /// Save pixels into stream in DDS format
   virtual FXbool savePixels(FXStream& store) const;
