@@ -3,13 +3,18 @@
 *                      C a l l b a c k   D i s p a t c h e r                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2006,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2006,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 ********************************************************************************/
-#ifndef DISPATCHER_H
-#define DISPATCHER_H
+#ifndef FXDISPATCHER_H
+#define FXDISPATCHER_H
+
+#ifndef FXREACTOR_H
+#include "FXReactor.h"
+#endif
 
 namespace FX {
 
+
 /**
 * A FXDispatcher watches a number of devices and signals for activity
 * and dispatches to the proper function when activity is observed.
@@ -53,7 +58,7 @@ public:
   virtual FXbool init();
 
   /// Add callback cb with new handle hnd to watch-list
-  virtual FXbool addHandle(HandleCallback cb,FXInputHandle hnd,FXuint mode=InputRead,void* ptr=NULL);
+  virtual FXbool addHandle(HandleCallback cb,FXInputHandle hnd,FXuint mode=InputRead,void* ptr=nullptr);
 
   /// Add new handle hnd to watch-list (no callback)
   virtual FXbool addHandle(FXInputHandle hnd,FXuint mode=InputRead);
@@ -69,7 +74,7 @@ public:
   virtual FXbool dispatchHandle(FXInputHandle hnd,FXuint mode,FXuint flags);
 
   /// Add (optionally asynchronous) callback cb for signal sig to signal-set
-  virtual FXbool addSignal(SignalCallback cb,FXint sig,void* ptr=NULL,FXbool async=false);
+  virtual FXbool addSignal(SignalCallback cb,FXint sig,void* ptr=nullptr,FXbool async=false);
 
   /// Add (optionally asynchronous) signal sig to signal-set (no callback)
   virtual FXbool addSignal(FXint sig,FXbool async=false);
@@ -84,12 +89,12 @@ public:
   /// Add timeout callback cb at time due (ns since Epoch).
   /// If callback cb was already set, remove it and return its old
   /// data pointer, then reset it to the new time and data pointer.
-  virtual void* addTimeout(TimeoutCallback cb,FXTime due,void* ptr=NULL);
+  virtual void* addTimeout(TimeoutCallback cb,FXTime due,void* ptr=nullptr);
 
   /// Add timeout callback cb after time interval (ns).
   /// If callback cb was already set, remove it and return its old
   /// data pointer, then reset it to the new time and data pointer.
-  virtual void* addInterval(TimeoutCallback cb,FXTime interval,void* ptr=NULL);
+  virtual void* addInterval(TimeoutCallback cb,FXTime interval,void* ptr=nullptr);
 
   /// Remove timeout callback cb.
   /// If callback cb was set, return its data pointer.
@@ -113,7 +118,7 @@ public:
   /// Add idle callback be executed when dispatch about to block.
   /// If callback cb was already set, remove it and return its old
   /// data pointer, then reset the callback with the new pointer.
-  virtual void* addIdle(IdleCallback cb,void* ptr=NULL);
+  virtual void* addIdle(IdleCallback cb,void* ptr=nullptr);
 
   /// Remove idle callback cb.
   /// If callback cb was set, return its data pointer.
