@@ -3,7 +3,7 @@
 *                          E X E   I m a g e   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2014,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2014,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -44,7 +44,7 @@ public:
 public:
 
   /// Construct image from memory stream comprising Microsoft Windows executable
-  FXEXEImage(FXApp* a,const void *pix=NULL,FXuint opts=0,FXint w=1,FXint h=1,FXint ri=-1,FXint rt=3);
+  FXEXEImage(FXApp* a,const FXuchar *pix=nullptr,FXuint opts=0,FXint w=1,FXint h=1,FXint ri=-1,FXint rt=3);
 
   /// Set resource group (type) to load from
   void setResType(FXint rt){ rtype=rt; }
