@@ -3,7 +3,7 @@
 *                      E x p r e s s i o n   E v a l u a t o r                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -66,8 +66,10 @@ namespace FX {
 * The following functions are available:
 *
 *       abs, acos, acosh, asin, asinh, atan, atanh,
-*       ceil, cos, cosh, exp, floor, log, log10, sin, sinh,
-*       sqr, cub, sqrt, cbrt, round, trunc, tan, tanh, max, min, atan2
+*       cbrt, ceil, cos, cosh, cub, erf, erfc, exp, exp2,
+*       exp10, floor, inverf, inverfc, isfin, isinf, isnan,
+*       log, log2, log10, near, round, sin, sinh, sqr, sqrt,
+*       tan, tanh, trunc, wrap, wrap4, max, min, atan2
 *
 * The expression engine also contains the following constants:
 *
@@ -90,12 +92,14 @@ public:
   enum Error {
     ErrOK,              /// No errors
     ErrEmpty,           /// Empty input
+    ErrMore,            /// More characters after input
     ErrMemory,          /// Out of memory
     ErrParent,          /// Unmatched parentheses
     ErrToken,           /// Illegal token
     ErrComma,           /// Expected comma
     ErrIdent,           /// Unknown identifier
-    ErrColon            /// Expected colon
+    ErrColon,           /// Expected colon
+    ErrLong             /// Expression too long
     };
 
 public:
@@ -107,10 +111,10 @@ public:
   FXExpression(const FXExpression& orig);
 
   /// Compile expression; if error is not NULL, error code is returned
-  FXExpression(const FXchar* expression,const FXchar* variables=NULL,Error* error=NULL);
+  FXExpression(const FXchar* expression,const FXchar* variables=nullptr,Error* error=nullptr);
 
   /// Compile expression; if error is not NULL, error code is returned
-  FXExpression(const FXString& expression,const FXString& variables=FXString::null,Error* error=NULL);
+  FXExpression(const FXString& expression,const FXString& variables=FXString::null,Error* error=nullptr);
 
   /// Assign another expression to this one
   FXExpression& operator=(const FXExpression& orig);
@@ -123,7 +127,7 @@ public:
   * The array of arguments should match the number of variables
   * passed when compiling the expression.
   */
-  FXdouble evaluate(const FXdouble *args=NULL) const;
+  FXdouble evaluate(const FXdouble *args=nullptr) const;
 
   /**
   * Parse expression, return error code if syntax error is found.
@@ -132,7 +136,7 @@ public:
   * The values of the array will be read in place of the variable names
   * in the expression.
   */
-  Error parse(const FXchar* expression,const FXchar* variables=NULL);
+  Error parse(const FXchar* expression,const FXchar* variables=nullptr);
   Error parse(const FXString& expression,const FXString& variables=FXString::null);
 
   /// Returns error code for given error
