@@ -3,7 +3,7 @@
 *                             F i l e   C l a s s                               *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -41,16 +41,13 @@ public:
   FXFile(){ }
 
   /// Construct file and attach existing handle h
-  FXFile(FXInputHandle h,FXuint m=FXIO::Reading);
+  FXFile(FXInputHandle h);
 
   /// Construct and open a file
-  FXFile(const FXString& file,FXuint m=FXIO::Reading,FXuint perm=FXIO::AllReadWrite);
+  FXFile(const FXString& filename,FXuint m=FXIO::Reading,FXuint perm=FXIO::AllReadWrite);
 
   /// Open file
-  virtual FXbool open(const FXString& file,FXuint m=FXIO::Reading,FXuint perm=FXIO::AllReadWrite);
-
-  /// Open device with access mode and handle
-  virtual FXbool open(FXInputHandle h,FXuint m=FXIO::Reading);
+  virtual FXbool open(const FXString& filename,FXuint m=FXIO::Reading,FXuint perm=FXIO::AllReadWrite);
 
   /// Return true if serial access only
   virtual FXbool isSerial() const;
