@@ -3,7 +3,7 @@
 *                  F i l e   S e l e c t i o n   W i d g e t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -153,7 +153,10 @@ public:
 public:
 
   /// Constructor
-  FXFileSelector(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+  FXFileSelector(FXComposite *p,FXObject* tgt=nullptr,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+
+  /// Create server-side resources
+  virtual void create();
 
   /// Return a pointer to the "Accept" button
   FXButton *acceptButton() const { return accept; }
@@ -284,7 +287,7 @@ public:
   FXbool getReadOnly() const;
 
   /// Allow or disallow navigation
-  void allowNavigation(FXbool flag){ navigable=flag; }
+  void allowNavigation(FXbool flag);
 
   /// Is navigation allowed?
   FXbool allowNavigation() const { return navigable; }
