@@ -3,7 +3,7 @@
 *                    F o n t   S e l e c t i o n   D i a l o g                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -65,6 +65,12 @@ public:
   /// Get the current font selection
   const FXFontDesc& getFontDesc() const;
 
+  /// Set sample text for font sample
+  void setSampleText(const FXString& sampletext);
+
+  /// Get sample text for font sample
+  FXString getSampleText() const;
+
   /// Save dialog to a stream
   virtual void save(FXStream& store) const;
 
