@@ -3,7 +3,7 @@
 *                        F o n t   S e l e c t i o n   B o x                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -104,7 +104,7 @@ public:
 public:
 
   /// Constructor
-  FXFontSelector(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+  FXFontSelector(FXComposite *p,FXObject* tgt=nullptr,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
 
   /// Create server-side resources
   virtual void create();
@@ -127,6 +127,12 @@ public:
   /// Get font selection
   const FXFontDesc& getFontDesc() const;
 
+  /// Set sample text for font sample
+  void setSampleText(const FXString& sampletext);
+
+  /// Get sample text for font sample
+  FXString getSampleText() const { return preview->getText(); }
+
   /// Save to a stream
   virtual void save(FXStream& store) const;
 
