@@ -3,7 +3,7 @@
 *                   J P E G - 2 0 0 0   I c o n   O b j e c t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2009,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2009,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -44,7 +44,7 @@ public:
 public:
 
   /// Construct an icon from memory stream formatted in JPEG-2000 format
-  FXJP2Icon(FXApp *a,const void *pix=NULL,FXColor clr=FXRGB(192,192,192),FXuint opts=0,FXint w=1,FXint h=1,FXint q=100);
+  FXJP2Icon(FXApp *a,const FXuchar *pix=nullptr,FXColor clr=FXRGB(192,192,192),FXuint opts=0,FXint w=1,FXint h=1,FXint q=100);
 
   /// True if format is supported
   static const FXbool supported;
