@@ -3,7 +3,7 @@
 *                            J S O N   F i l e   I / O                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2013,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2013,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -49,11 +49,6 @@ public:
   */
   FXJSONFile(const FXString& filename,Direction d=Load,FXuval sz=4096);
 
-  /**
-  * Open JSON file from given handle for direction d.
-  */
-  FXbool open(FXInputHandle h,Direction d=Load,FXuval sz=4096);
-
   /**
   * Open JSON file for direction d.
   */
