@@ -3,7 +3,7 @@
 *                    M e n u   S e p a r a t o r   W i d g e t                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -52,7 +52,7 @@ public:
 public:
 
   /// Construct a menu separator
-  FXMenuSeparator(FXComposite* p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0);
+  FXMenuSeparator(FXComposite* p,FXObject* tgt=nullptr,FXSelector sel=0,FXuint opts=0);
 
   /// Return default width
   virtual FXint getDefaultWidth();
