@@ -3,7 +3,7 @@
 *                          P N G   I m a g e   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -28,9 +28,31 @@
 namespace FX {
 
 
+/**
+* PNG Image save-flags.
+*/
+enum {
+  PNG_FILTER_NONE   = 0,        // No filter
+  PNG_FILTER_SUB    = 1,        // Sub-filter
+  PNG_FILTER_UP     = 2,        // Up-filter
+  PNG_FILTER_AVG    = 3,        // Averaging filter
+  PNG_FILTER_PAETH  = 4,        // Paeth filter
+  PNG_FILTER_BEST   = 5,        // Find best filter for each line
+  PNG_COMPRESS_FAST = 8,        // Fastest compression
+  PNG_COMPRESS_BEST = 16,       // Best compression
+  PNG_IMAGE_GRAY    = 32,       // Write only one grey channel (blue)
+  PNG_IMAGE_OPAQUE  = 64,       // Write no alpha alpha channel
+  PNG_IMAGE_ANALYZE = 128,      // Analyze image for opacity or alpha
+  PNG_INDEX_COLOR   = 256       // Try indexed (colormap) mode
+  };
+
+
+
 /// Portable Network Graphics (PNG) Image class
 class FXAPI FXPNGImage : public FXImage {
   FXDECLARE(FXPNGImage)
+protected:
+  FXuint flags;
 protected:
   FXPNGImage(){}
 private:
@@ -42,11 +64,17 @@ public:
 public:
 
   /// Construct an image from memory stream formatted in PNG format
-  FXPNGImage(FXApp *a,const void *pix=NULL,FXuint opts=0,FXint w=1,FXint h=1);
+  FXPNGImage(FXApp *a,const FXuchar *pix=nullptr,FXuint opts=0,FXint w=1,FXint h=1,FXuint fl=PNG_IMAGE_ANALYZE);
 
   /// True if format is supported
   static const FXbool supported;
 
+  /// Set image save flags
+  void setFlags(FXint opts){ options=opts; }
+
+  /// Get image save flags
+  FXint getFlags() const { return options; }
+
   /// Load pixels from stream in PNG format
   virtual FXbool savePixels(FXStream& store) const;
 
@@ -58,8 +86,6 @@ public:
   };
 
 
-#ifndef FXLOADPNG
-#define FXLOADPNG
 
 /**
 * Check if stream contains a PNG, return true if so.
@@ -78,9 +104,7 @@ extern FXAPI FXbool fxloadPNG(FXStream& store,FXColor*& data,FXint& width,FXint&
 /**
 * Save an PNG (Portable Network Graphics) file to a stream.
 */
-extern FXAPI FXbool fxsavePNG(FXStream& store,const FXColor* data,FXint width,FXint height);
-
-#endif
+extern FXAPI FXbool fxsavePNG(FXStream& store,const FXColor* data,FXint width,FXint height,FXuint flags=PNG_IMAGE_ANALYZE);
 
 }
 
