@@ -3,7 +3,7 @@
 *                  P a t h   N a m e   M a n i p u l a t i o n                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -63,16 +63,20 @@ namespace FXPath {
   extern FXAPI FXString name(const FXString& file);
 
   /**
-  * Return file title, i.e. document name only.
+  * Return file stem, i.e. file name without the file
+  * extension.  The extension is defined as the part past
+  * the last '.' of the last path-component, if the '.' is
+  * not the first character of the file name.
   */
-  extern FXAPI FXString title(const FXString& file);
+  extern FXAPI FXString stem(const FXString& file);
 
   /**
   * Return extension part of the file name.
-  * This returns the string after the last '.' in the last path-component of the
-  * file, provided that the '.' was not the first character of the path-component.
-  * For example, extension("/usr/share/icons/folder.png") returns "png", but the call to
-  * extension("../path.name/.bashrc") returns "".
+  * This returns the string after the last '.' in the last
+  * path-component of the file, provided that the '.' was not
+  * the first character of the path-component.
+  * For example, extension("/usr/share/icons/folder.png") returns "png",
+  * but the call to extension("../path.name/.bashrc") returns "".
   */
   extern FXAPI FXString extension(const FXString& file);
 
@@ -90,13 +94,13 @@ namespace FXPath {
   * Perform tilde or environment variable expansion.
   * A prefix of the form ~ or ~user is expanded to the user's home directory.
   * Environment variables of the form $HOME or ${HOME} are expanded by
-  * substituting the value of the variable.
+  * substituting the value of the variable, recusively up to given level.
   * On Windows, only environment variables of the form %HOME% are expanded.
   */
-  extern FXAPI FXString expand(const FXString& file);
+  extern FXAPI FXString expand(const FXString& file,FXint level=4);
 
   /**
- * Convert a foreign path(s) or paths to local conventions,
+  * Convert a foreign path(s) or paths to local conventions,
   * replacing environment variables etc.
   */
   extern FXAPI FXString convert(const FXString& path);
@@ -134,6 +138,9 @@ namespace FXPath {
   /// Return true if file name is absolute
   extern FXAPI FXbool isAbsolute(const FXString& file);
 
+  /// Return true if file name is relative
+  extern FXAPI FXbool isRelative(const FXString& file);
+
   /// Return true if input directory is a top-level directory
   extern FXAPI FXbool isTopDirectory(const FXString& file);
 
@@ -174,7 +181,7 @@ namespace FXPath {
   extern FXAPI FXint parseArgs(FXchar**& argv,const FXString& command);
 
   /**
-  * Perform match of a filename against a wildcard pattern.
+  * Perform match of a string against a wildcard pattern.
   * The wildcard pattern may comprise ordinary characters or special
   * matching characters, as given below:
   *
@@ -203,14 +210,19 @@ namespace FXPath {
   extern FXAPI FXbool match(const FXchar* string,const FXchar* pattern="*",FXuint flags=(NoEscape|PathName));
 
   /**
-  * Perform match of a filename against a wildcard pattern.
+  * Perform match of a string against a wildcard pattern.
   */
-  extern FXAPI FXbool match(const FXString& file,const FXchar* pattern="*",FXuint flags=(NoEscape|PathName));
+  extern FXAPI FXbool match(const FXString& string,const FXchar* pattern="*",FXuint flags=(NoEscape|PathName));
 
   /**
-  * Perform match of a filename against a wildcard pattern.
+  * Perform match of a string against a wildcard pattern.
   */
-  extern FXAPI FXbool match(const FXString& file,const FXString& pattern,FXuint flags=(NoEscape|PathName));
+  extern FXAPI FXbool match(const FXchar* string,const FXString& pattern,FXuint flags=(NoEscape|PathName));
+
+  /**
+  * Perform match of a string against a wildcard pattern.
+  */
+  extern FXAPI FXbool match(const FXString& string,const FXString& pattern,FXuint flags=(NoEscape|PathName));
 
   /**
   * Generate unique filename of the form pathnameXXX.ext, where
