@@ -3,7 +3,7 @@
 *         R e f e r e n c e   C o u n t e d   O b j e c t  P o i n t e r        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2004,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -32,7 +32,7 @@ private:
 public:
 
   /// Default constructor
-  FXRefPtr():ptr(NULL){
+  FXRefPtr():ptr(nullptr){
     }
 
   /// Construct and init
