@@ -3,7 +3,7 @@
 *                       S c r o l l A r e a   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -61,6 +61,10 @@ class FXScrollCorner;
 * will influence the width (height) of the scroll area widget.
 * For content which is time-consuming to repaint, continuous
 * scrolling may be turned off.
+* Mouse wheel in content area scrolls vertically, unless vertical
+* scrolling is disabled.  If both directions have scrolling disabled,
+* mouse wheel is not processed.  Subclasses may interpret wheel
+* events differently.
 */
 class FXAPI FXScrollArea : public FXComposite {
   FXDECLARE(FXScrollArea)
@@ -81,8 +85,7 @@ private:
   FXScrollArea(const FXScrollArea&);
   FXScrollArea &operator=(const FXScrollArea&);
 public:
-  long onHMouseWheel(FXObject*,FXSelector,void*);
-  long onVMouseWheel(FXObject*,FXSelector,void*);
+  long onMouseWheel(FXObject*,FXSelector,void*);
   long onHScrollerChanged(FXObject*,FXSelector,void*);
   long onVScrollerChanged(FXObject*,FXSelector,void*);
   long onHScrollerDragged(FXObject*,FXSelector,void*);
