@@ -3,7 +3,7 @@
 *                           S o c k e t   C l a s s                             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2005,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2005,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -45,10 +45,7 @@ public:
   FXSocket(){ }
 
   /// Construct file and attach existing handle h
-  FXSocket(FXInputHandle h,FXuint m);
-
-  /// Open device with access mode and handle
-  virtual FXbool open(FXInputHandle h,FXuint m);
+  FXSocket(FXInputHandle h);
   };
 
 }
