@@ -3,7 +3,7 @@
 *                          S p i n n e r   W i d g e t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Lyle Johnson.   All Rights Reserved.               *
+* Copyright (C) 1998,2024 by Lyle Johnson.   All Rights Reserved.               *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -85,7 +85,7 @@ public:
 public:
 
   /// Construct a spinner
-  FXSpinner(FXComposite *p,FXint cols,FXObject *tgt=NULL,FXSelector sel=0,FXuint opts=SPIN_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=DEFAULT_PAD,FXint pr=DEFAULT_PAD,FXint pt=DEFAULT_PAD,FXint pb=DEFAULT_PAD);
+  FXSpinner(FXComposite *p,FXint cols,FXObject *tgt=nullptr,FXSelector sel=0,FXuint opts=SPIN_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=DEFAULT_PAD,FXint pr=DEFAULT_PAD,FXint pt=DEFAULT_PAD,FXint pb=DEFAULT_PAD);
 
   /// Perform layout
   virtual void layout();
@@ -102,8 +102,11 @@ public:
   /// Return default height
   virtual FXint getDefaultHeight();
 
-  /// Notification that focus moved to new child
-  virtual void changeFocus(FXWindow *child);
+  /// Move the focus to this window
+  virtual void setFocus();
+
+  /// Remove the focus from this window
+  virtual void killFocus();
 
   /// Increment spinner
   void increment(FXbool notify=false);
