@@ -3,7 +3,7 @@
 *       P e r s i s t e n t   S t o r a g e   S t r e a m   C l a s s e s       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -24,6 +24,9 @@
 namespace FX {
 
 
+class FXObject;
+
+
 /// Stream data flow direction
 enum FXStreamDirection {
   FXStreamDead=0,               /// Unopened stream
@@ -114,7 +117,7 @@ public:
   * but which may be referenced by other objects.  These references will be
   * properly saved and restored.
   */
-  FXStream(const FXObject* cont=NULL);
+  FXStream(const FXObject* cont=nullptr);
 
   /**
   * Open stream for reading (FXStreamLoad) or for writing (FXStreamSave).
@@ -122,7 +125,7 @@ public:
   * If data is not NULL, it is expected to point to an external data buffer
   * of length size; otherwise stream will use an internally managed buffer.
   */
-  FXbool open(FXStreamDirection save_or_load,FXuchar* data=NULL,FXuval size=8192UL,FXbool owned=false);
+  FXbool open(FXStreamDirection save_or_load,FXuchar* data=nullptr,FXuval size=8192UL,FXbool owned=false);
 
   /// Flush buffer
   virtual FXbool flush();
@@ -188,7 +191,7 @@ public:
   /// Save single items to stream
   FXStream& operator<<(const FXuchar& v);
   FXStream& operator<<(const FXchar& v){ return *this << reinterpret_cast<const FXuchar&>(v); }
-  FXStream& operator<<(const FXbool& v){ return *this << reinterpret_cast<const FXuchar&>(v); }
+  FXStream& operator<<(const FXbool& v);
   FXStream& operator<<(const FXushort& v);
   FXStream& operator<<(const FXshort& v){ return *this << reinterpret_cast<const FXushort&>(v); }
   FXStream& operator<<(const FXuint& v);
@@ -201,7 +204,7 @@ public:
   /// Save arrays of items to stream
   FXStream& save(const FXuchar* p,FXuval n);
   FXStream& save(const FXchar* p,FXuval n){ return save(reinterpret_cast<const FXuchar*>(p),n); }
-  FXStream& save(const FXbool* p,FXuval n){ return save(reinterpret_cast<const FXuchar*>(p),n); }
+  FXStream& save(const FXbool* p,FXuval n);
   FXStream& save(const FXushort* p,FXuval n);
   FXStream& save(const FXshort* p,FXuval n){ return save(reinterpret_cast<const FXushort*>(p),n); }
   FXStream& save(const FXuint* p,FXuval n);
@@ -214,7 +217,7 @@ public:
   /// Load single items from stream
   FXStream& operator>>(FXuchar& v);
   FXStream& operator>>(FXchar& v){ return *this >> reinterpret_cast<FXuchar&>(v); }
-  FXStream& operator>>(FXbool& v){ return *this >> reinterpret_cast<FXuchar&>(v); }
+  FXStream& operator>>(FXbool& v);
   FXStream& operator>>(FXushort& v);
   FXStream& operator>>(FXshort& v){ return *this >> reinterpret_cast<FXushort&>(v); }
   FXStream& operator>>(FXuint& v);
@@ -227,7 +230,7 @@ public:
   /// Load arrays of items from stream
   FXStream& load(FXuchar* p,FXuval n);
   FXStream& load(FXchar* p,FXuval n){ return load(reinterpret_cast<FXuchar*>(p),n); }
-  FXStream& load(FXbool* p,FXuval n){ return load(reinterpret_cast<FXuchar*>(p),n); }
+  FXStream& load(FXbool* p,FXuval n);
   FXStream& load(FXushort* p,FXuval n);
   FXStream& load(FXshort* p,FXuval n){ return load(reinterpret_cast<FXushort*>(p),n); }
   FXStream& load(FXuint* p,FXuval n);
