@@ -3,7 +3,7 @@
 *                          T I F F   I c o n   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2021 Eric Gillet.   All Rights Reserved.                   *
+* Copyright (C) 2001,2024 Eric Gillet.   All Rights Reserved.                   *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -44,16 +44,16 @@ public:
 public:
 
   /// Construct an icon from memory stream formatted in TIFF format
-  FXTIFIcon(FXApp *a,const void *pix=NULL,FXColor clr=FXRGB(192,192,192),FXuint opts=0,FXint w=1,FXint h=1);
+  FXTIFIcon(FXApp *a,const FXuchar *pix=nullptr,FXColor clr=FXRGB(192,192,192),FXuint opts=0,FXint w=1,FXint h=1);
 
   /// True if format is supported
   static const FXbool supported;
 
   /// Set codec to save with
-  void setCodec(FXuint c){ codec=c; }
+  void setCodec(FXushort c){ codec=c; }
 
   /// Get codec setting
-  FXuint getCodec() const { return codec; }
+  FXushort getCodec() const { return codec; }
 
   /// Save pixels into stream in TIFF format
   virtual FXbool savePixels(FXStream& store) const;
