@@ -3,7 +3,7 @@
 *                   M u l t i - L i n e   T e x t   W i d g e t                 *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -61,11 +61,11 @@ struct FXHiliteStyle {
 * syntax highlighting.
 */
 struct FXTextChange {
-  FXint   pos;          /// Position in buffer
-  FXint   ndel;         /// Number characters deleted at position
-  FXint   nins;         /// Number characters inserted at position
-  FXchar *ins;          /// Text inserted at position
-  FXchar *del;          /// Text deleted at position
+  FXint         pos;          /// Position in buffer
+  FXint         ndel;         /// Number characters deleted at position
+  FXint         nins;         /// Number characters inserted at position
+  const FXchar *del;          /// Text deleted at position
+  const FXchar *ins;          /// Text inserted at position
   };
 
 
@@ -158,11 +158,12 @@ protected:
   FXchar         *buffer;               // Text buffer being edited
   FXchar         *sbuffer;              // Text style buffer
   FXint          *visrows;              // Starts of rows in buffer
-  FXint           length;               // Length of the actual text in the buffer
   FXint           nvisrows;             // Number of visible rows
+  FXint           gapbeg;               // Buffer gap begin
+  FXint           gaplen;               // Buffer gap length
+  FXint           gapend;               // Buffer gap end
+  FXint           length;               // Length of the actual text in the buffer
   FXint           nrows;                // Total number of rows
-  FXint           gapstart;             // Start of the insertion point (the gap)
-  FXint           gapend;               // End of the insertion point+1
   FXint           toppos;               // Start position of first visible row
   FXint           toprow;               // Row number of first visible row
   FXint           keeppos;              // Position to keep on top visible row
@@ -216,6 +217,8 @@ protected:
   FXText();
   void movegap(FXint pos);
   void sizegap(FXint sz);
+  FXwchar nxtChar(FXint& pos) const;
+  FXwchar prvChar(FXint& pos) const;
   FXint charWidth(FXwchar ch,FXint indent) const;
   FXint xoffset(FXint start,FXint pos) const;
   FXint wrap(FXint start) const;
@@ -223,6 +226,7 @@ protected:
   FXint posFromRow(FXint row) const;
   FXint columnFromPos(FXint start,FXint pos) const;
   FXint posFromColumn(FXint start,FXint col) const;
+  FXint indentOfLine(FXint start,FXint pos) const;
   FXbool isdelimiter(FXwchar w) const;
   FXint measureText(FXint start,FXint end,FXint& wmax,FXint& hmax) const;
   void calcVisRows(FXint s,FXint e);
@@ -251,7 +255,6 @@ protected:
   void updateLines(FXint startpos,FXint endpos) const;
   void updateRange(FXint startpos,FXint endpos) const;
   FXint shiftText(FXint startpos,FXint endpos,FXint shift,FXbool notify);
-  FXint caseShift(FXint startpos,FXint endpos,FXint upper,FXbool notify);
   FXbool deletePendingSelection(FXbool notify);
 protected:
   enum {
@@ -264,22 +267,6 @@ protected:
     MOUSE_DRAG,                 // Dragging text
     MOUSE_TRYDRAG               // Tentative drag
     };
-protected:
-  enum {
-    STYLE_MASK      = 0x00FF,   // Mask color table
-    STYLE_TEXT      = 0x0100,   // Draw some content
-    STYLE_SELECTED  = 0x0200,   // Selected
-    STYLE_CONTROL   = 0x0400,   // Control character
-    STYLE_HILITE    = 0x0800,   // Highlighted
-    STYLE_ACTIVE    = 0x1000,   // Active
-    STYLE_INSERT    = 0x2000    // Column insert
-    };
-public:
-  enum {
-    STYLE_UNDERLINE = 0x0001,   /// Underline text
-    STYLE_STRIKEOUT = 0x0002,   /// Strike out text
-    STYLE_BOLD      = 0x0004    /// Bold text
-    };
 private:
   FXText(const FXText&);
   FXText& operator=(const FXText&);
@@ -416,6 +403,8 @@ public:
   long onCmdBlockBeg(FXObject*,FXSelector,void*);
   long onCmdBlockEnd(FXObject*,FXSelector,void*);
   long onCmdGotoMatching(FXObject*,FXSelector,void*);
+  long onCmdCursorPos(FXObject*,FXSelector,void*);
+  long onUpdCursorPos(FXObject*,FXSelector,void*);
   long onCmdCursorRow(FXObject*,FXSelector,void*);
   long onUpdCursorRow(FXObject*,FXSelector,void*);
   long onCmdCursorColumn(FXObject*,FXSelector,void*);
@@ -424,22 +413,41 @@ public:
   long onUpdToggleEditable(FXObject*,FXSelector,void*);
   long onCmdToggleOverstrike(FXObject*,FXSelector,void*);
   long onUpdToggleOverstrike(FXObject*,FXSelector,void*);
+  long onUpdTextRows(FXObject*,FXSelector,void*);
+  long onUpdTextSize(FXObject*,FXSelector,void*);
 public:
-  static const FXchar textDelimiters[];
 
-public:
+  /// Internal style flags
+  enum {
+    STYLE_MASK      = 0x00FF,   // Mask color table
+    STYLE_TEXT      = 0x0100,   // Draw some content
+    STYLE_SELECTED  = 0x0200,   // Selected
+    STYLE_CONTROL   = 0x0400,   // Control character
+    STYLE_HILITE    = 0x0800,   // Highlighted
+    STYLE_ACTIVE    = 0x1000,   // Active
+    STYLE_INSERT    = 0x2000    // Column insert
+    };
+
+  /// Text highlight style flags
+  enum {
+    STYLE_UNDERLINE = 0x0001,   // Underline text
+    STYLE_STRIKEOUT = 0x0002,   // Strike out text
+    STYLE_BOLD      = 0x0004    // Bold text
+    };
 
   /// Selection modes
   enum {
-    SelectNone,         /// Select nothing
-    SelectChars,        /// Select characters
-    SelectWords,        /// Select words
-    SelectRows,         /// Select rows
-    SelectLines         /// Select lines
+    SelectNone,                 // Select nothing
+    SelectChars,                // Select characters
+    SelectWords,                // Select words
+    SelectRows,                 // Select rows
+    SelectLines                 // Select lines
     };
 
-public:
+  /// Default text delimiters
+  static const FXchar textDelimiters[];
 
+public:
   enum {
     ID_CURSOR_TOP=FXScrollArea::ID_LAST,
     ID_CURSOR_BOTTOM,
@@ -506,6 +514,7 @@ public:
     ID_DELETE_LINE,
     ID_TOGGLE_EDITABLE,
     ID_TOGGLE_OVERSTRIKE,
+    ID_CURSOR_POS,
     ID_CURSOR_ROW,
     ID_CURSOR_COLUMN,
     ID_JOIN_LINES,
@@ -530,13 +539,14 @@ public:
     ID_RIGHT_ANG,
     ID_BLINK,
     ID_FLASH,
+    ID_TEXT_ROWS,
+    ID_TEXT_SIZE,
     ID_LAST
     };
-
 public:
 
   /// Construct multi-line text widget
-  FXText(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=3,FXint pr=3,FXint pt=2,FXint pb=2);
+  FXText(FXComposite *p,FXObject* tgt=nullptr,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=3,FXint pr=3,FXint pt=2,FXint pb=2);
 
   /// Create server-side resources
   virtual void create();
@@ -616,14 +626,14 @@ public:
   /// Get byte at position in text buffer
   FXint getByte(FXint pos) const;
 
-  /// Get wide character at position pos
-  FXwchar getChar(FXint pos) const;
+  /// Get style at position pos
+  FXint getStyle(FXint pos) const;
 
   /// Get length of wide character at position pos
   FXint getCharLen(FXint pos) const;
 
-  /// Get style at position pos
-  FXint getStyle(FXint pos) const;
+  /// Get wide character at position pos
+  FXwchar getChar(FXint pos) const;
 
   /// Retreat to the previous valid utf8 character start
   FXint dec(FXint pos) const;
@@ -688,7 +698,6 @@ public:
   */
   FXint countLines(FXint start,FXint end) const;
 
-
   /// Change the text in the buffer to new text
   virtual FXint setText(const FXchar* text,FXint num,FXbool notify=false);
   virtual FXint setText(const FXString& text,FXbool notify=false);
@@ -697,6 +706,21 @@ public:
   virtual FXint setStyledText(const FXchar* text,FXint num,FXint style=0,FXbool notify=false);
   virtual FXint setStyledText(const FXString& text,FXint style=0,FXbool notify=false);
 
+  /// Change style of text range
+  virtual FXint changeStyle(FXint pos,FXint num,FXint style);
+
+  /// Change style of text range from style-array
+  virtual FXint changeStyle(FXint pos,const FXchar* style,FXint num);
+  virtual FXint changeStyle(FXint pos,const FXString& style);
+
+  /// Append n bytes of text at the end of the buffer
+  virtual FXint appendText(const FXchar *text,FXint num,FXbool notify=false);
+  virtual FXint appendText(const FXString& text,FXbool notify=false);
+
+  /// Append n bytes of text at the end of the buffer
+  virtual FXint appendStyledText(const FXchar *text,FXint num,FXint style=0,FXbool notify=false);
+  virtual FXint appendStyledText(const FXString& text,FXint style=0,FXbool notify=false);
+
   /// Replace del bytes at pos by ins characters of text
   virtual FXint replaceText(FXint pos,FXint del,const FXchar *text,FXint ins,FXbool notify=false);
   virtual FXint replaceText(FXint pos,FXint del,const FXString& text,FXbool notify=false);
@@ -713,22 +737,6 @@ public:
   virtual FXint replaceStyledTextBlock(FXint startpos,FXint endpos,FXint startcol,FXint endcol,const FXchar *text,FXint num,FXint style=0,FXbool notify=false);
   virtual FXint replaceStyledTextBlock(FXint startpos,FXint endpos,FXint startcol,FXint endcol,const FXString& text,FXint style=0,FXbool notify=false);
 
-  /// Overstrike text block
-  virtual FXint overstrikeTextBlock(FXint startpos,FXint endpos,FXint startcol,FXint endcol,const FXchar *text,FXint num,FXbool notify=false);
-  virtual FXint overstrikeTextBlock(FXint startpos,FXint endpos,FXint startcol,FXint endcol,const FXString& text,FXbool notify=false);
-
-  /// Overstrike styled text block
-  virtual FXint overstrikeStyledTextBlock(FXint startpos,FXint endpos,FXint startcol,FXint endcol,const FXchar *text,FXint num,FXint style=0,FXbool notify=false);
-  virtual FXint overstrikeStyledTextBlock(FXint startpos,FXint endpos,FXint startcol,FXint endcol,const FXString& text,FXint style=0,FXbool notify=false);
-
-  /// Append n bytes of text at the end of the buffer
-  virtual FXint appendText(const FXchar *text,FXint num,FXbool notify=false);
-  virtual FXint appendText(const FXString& text,FXbool notify=false);
-
-  /// Append n bytes of text at the end of the buffer
-  virtual FXint appendStyledText(const FXchar *text,FXint num,FXint style=0,FXbool notify=false);
-  virtual FXint appendStyledText(const FXString& text,FXint style=0,FXbool notify=false);
-
   /// Insert n bytes of text at position pos into the buffer
   virtual FXint insertText(FXint pos,const FXchar *text,FXint num,FXbool notify=false);
   virtual FXint insertText(FXint pos,const FXString& text,FXbool notify=false);
@@ -745,22 +753,23 @@ public:
   virtual FXint insertStyledTextBlock(FXint startpos,FXint endpos,FXint startcol,const FXchar *text,FXint num,FXint style=0,FXbool notify=false);
   virtual FXint insertStyledTextBlock(FXint startpos,FXint endpos,FXint startcol,const FXString& text,FXint style=0,FXbool notify=false);
 
-  /// Change style of text range
-  virtual FXint changeStyle(FXint pos,FXint num,FXint style);
+  /// Overstrike text block
+  virtual FXint overstrikeTextBlock(FXint startpos,FXint endpos,FXint startcol,const FXchar *text,FXint num,FXbool notify=false);
+  virtual FXint overstrikeTextBlock(FXint startpos,FXint endpos,FXint startcol,const FXString& text,FXbool notify=false);
 
-  /// Change style of text range from style-array
-  virtual FXint changeStyle(FXint pos,const FXchar* style,FXint num);
-  virtual FXint changeStyle(FXint pos,const FXString& style);
+  /// Overstrike styled text block
+  virtual FXint overstrikeStyledTextBlock(FXint startpos,FXint endpos,FXint startcol,const FXchar *text,FXint num,FXint style=0,FXbool notify=false);
+  virtual FXint overstrikeStyledTextBlock(FXint startpos,FXint endpos,FXint startcol,const FXString& text,FXint style=0,FXbool notify=false);
 
-  /// Remove n bytes of text at position pos from the buffer
-  virtual FXint removeText(FXint pos,FXint num,FXbool notify=false);
 
-  /// Remove columns startcol to endcol from lines starting at startpos to endpos
-  virtual FXint removeTextBlock(FXint startpos,FXint endpos,FXint startcol,FXint endcol,FXbool notify=false);
+  /// Return entire text as string
+  FXString getText() const;
 
-  /// Remove all text from the buffer
-  virtual FXint clearText(FXbool notify=false);
+  /// Retrieve text into buffer
+  void getText(FXchar* text,FXint num) const;
 
+  /// Retrieve text into string
+  void getText(FXString& text) const;
 
   /// Extract n bytes of text from position pos into already allocated buffer
   void extractText(FXchar *text,FXint pos,FXint num) const;
@@ -786,14 +795,15 @@ public:
   /// Return text columns startcol to endcol from lines starting at startpos to endpos
   FXString extractTextBlock(FXint startpos,FXint endpos,FXint startcol,FXint endcol) const;
 
-  /// Return entire text as string
-  FXString getText() const;
 
-  /// Retrieve text into buffer
-  void getText(FXchar* text,FXint num) const;
+  /// Remove n bytes of text at position pos from the buffer
+  virtual FXint removeText(FXint pos,FXint num,FXbool notify=false);
 
-  /// Retrieve text into string
-  void getText(FXString& text) const;
+  /// Remove columns startcol to endcol from lines starting at startpos to endpos
+  virtual FXint removeTextBlock(FXint startpos,FXint endpos,FXint startcol,FXint endcol,FXbool notify=false);
+
+  /// Remove all text from the buffer
+  virtual FXint clearText(FXbool notify=false);
 
 
   /// Select all text
@@ -811,9 +821,13 @@ public:
   /// Extend primary selection from anchor to given row, column
   virtual FXbool extendBlockSelection(FXint row,FXint col,FXbool notify=false);
 
+  /// Select range or block (scol<=ecol) of text
+  virtual FXbool setSelection(FXint spos,FXint epos,FXint scol,FXint ecol,FXbool notify=false);
+
   /// Kill or deselect primary selection
   virtual FXbool killSelection(FXbool notify=false);
 
+
   /// Return true if position pos is selected
   FXbool isPosSelected(FXint pos) const;
 
@@ -832,9 +846,6 @@ public:
   /// Return selection end column
   FXint getSelEndColumn() const { return select.endcol; }
 
-  /// Get selected text
-  FXString getSelectedText() const;
-
 
   /// Copy primary selection to clipboard
   FXbool copySelection();
@@ -854,6 +865,9 @@ public:
   /// Replace primary selection by other text
   FXbool replaceSelection(const FXString& text,FXbool notify=false);
 
+  /// Get selected text
+  FXString getSelectedText() const;
+
   /// Highlight len characters starting at given position pos
   FXbool setHighlight(FXint start,FXint len);
 
@@ -911,6 +925,7 @@ public:
   /// Return screen y-coordinate of unconstrained (row,col).
   FXint getYOfRowColumn(FXint row,FXint col) const;
 
+
   /// Set the cursor position
   virtual void setCursorPos(FXint pos,FXbool notify=false);
 
@@ -932,6 +947,7 @@ public:
   /// Return cursor row, i.e. indent position
   FXint getCursorColumn() const { return cursorcol; }
 
+
   /// Set the anchor position
   void setAnchorPos(FXint pos);
 
@@ -947,6 +963,7 @@ public:
   /// Return anchor row
   FXint getAnchorColumn() const { return anchorcol; }
 
+
   /// Move cursor to position, and scroll into view
   void moveCursor(FXint pos,FXbool notify=false);
 
@@ -959,6 +976,7 @@ public:
   /// Move cursor to row and column, and extend the block selection to this point
   void moveCursorRowColumnAndSelect(FXint row,FXint col,FXbool notify=false);
 
+
   /**
   * Search for string in text buffer, returning the extent of the string in beg and end.
   * The search starts from the given starting position, scans forward (SEARCH_FORWARD) or
@@ -971,7 +989,8 @@ public:
   * in this case, the number of entries in the beg[], end[] arrays must be npar also.
   * If either beg or end or both are NULL, internal arrays are used.
   */
-  FXbool findText(const FXString& string,FXint* beg=NULL,FXint* end=NULL,FXint start=0,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP|SEARCH_EXACT,FXint npar=1);
+  FXbool findText(const FXString& string,FXint* beg=nullptr,FXint* end=nullptr,FXint start=0,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP|SEARCH_EXACT,FXint npar=1);
+
 
   /// Change text widget style
   void setTextStyle(FXuint style);
@@ -1097,7 +1116,7 @@ public:
   FXbool setStyled(FXbool styled=true);
 
   /// Return true if style buffer
-  FXbool isStyled() const { return (sbuffer!=NULL); }
+  FXbool isStyled() const { return (sbuffer!=nullptr); }
 
   /**
   * Set highlight styles.
@@ -1111,12 +1130,6 @@ public:
   /// Return current value of the style table.
   FXHiliteStyle* getHiliteStyles() const { return hilitestyles; }
 
-  /// Change delimiters of words
-  void setDelimiters(const FXchar* delims=textDelimiters){ delimiters=delims; }
-
-  /// Return word delimiters
-  const FXchar* getDelimiters() const { return delimiters; }
-
   /**
   * Change brace and parenthesis match highlighting time, in nanoseconds.
   * If highlighting for a small interval, only flash if the matching brace
@@ -1130,6 +1143,12 @@ public:
   /// Return brace and parenthesis match highlighting time, in nanoseconds
   FXTime getHiliteMatchTime() const { return matchtime; }
 
+  /// Change delimiters of words
+  void setDelimiters(const FXchar* delims=textDelimiters){ delimiters=delims; }
+
+  /// Return word delimiters
+  const FXchar* getDelimiters() const { return delimiters; }
+
   /// Set help text
   void setHelpText(const FXString& text){ help=text; }
 
