@@ -3,7 +3,7 @@
 *                          T h r e a d   S u p p o r t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2004,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -165,6 +165,11 @@ public:
   */
   static void yield();
 
+  /**
+  * Processor pause/back-off.
+  */
+  static void pause();
+
   /**
   * Return time in nanoseconds since Epoch (Jan 1, 1970).
   */
@@ -173,7 +178,12 @@ public:
   /**
   * Get steady time in nanoseconds since some arbitrary start time.
   */
-  FXTime steadytime();
+  static FXTime steadytime();
+
+  /**
+  * Return time in processor ticks.
+  */
+  static FXTime ticks();
 
   /**
   * Make the calling thread sleep for a number of nanoseconds.
