@@ -3,7 +3,7 @@
 *                            X B M   I m a g e   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2003,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2003,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -42,7 +42,7 @@ public:
 public:
 
   /// Construct image from memory stream formatted in X Bitmap format
-  FXXBMImage(FXApp* a,const FXuchar *pixels=NULL,const FXuchar *mask=NULL,FXuint opts=0,FXint w=1,FXint h=1);
+  FXXBMImage(FXApp* a,const FXuchar *pixels=nullptr,const FXuchar *mask=nullptr,FXuint opts=0,FXint w=1,FXint h=1);
 
   /// Save pixels into stream in X Bitmap format
   virtual FXbool savePixels(FXStream& store) const;
