@@ -3,7 +3,7 @@
 *                     FOX Definitions, Types, and Macros                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -140,7 +140,6 @@
 #define __threadlocal
 #endif
 
-
 // Non-returning function
 #if defined(__GNUC__)
 #define __noreturn      __attribute__((__noreturn__))
@@ -159,6 +158,30 @@
 #define __unlikely(cond)  (!!(cond))
 #endif
 
+// An assumption that compiler may use to optimize
+#if (__GNUC__ >= 13)
+#define __assume(expr)  __attribute__((__assume__(expr)))
+#elif (__clang__ >= 14)
+#define __assume(expr)  __builtin_assume(expr)
+#elif !defined(_MSC_VER)
+#define __assume(expr)
+#endif
+
+// An unreachable part of code may be optimized away
+#if (__GNUC__ >= 4)
+#define __unreachable()    __builtin_unreachable()
+#elif defined(_MSC_VER)
+#define __unreachable()    __assume(false)
+#else
+#define __unreachable()
+#endif
+
+// Define parameters not-aliased hint
+#if defined(__GNUC__)
+#define __restrict  __restrict__
+#elif !defined(_MSC_VER)
+#define __restrict
+#endif
 
 // Prefetch address
 #if (__GNUC__ >= 4) && (defined(__i386__) || defined(__x86_64__))
@@ -169,7 +192,6 @@
 #define __prefetchw(addr)
 #endif
 
-
 // Standard call calling sequence
 #ifdef WIN32
 #ifndef CALLBACK
@@ -177,7 +199,6 @@
 #endif
 #endif
 
-
 // C Language calling sequence
 #ifdef WIN32
 #ifndef CDECL
@@ -189,7 +210,6 @@
 #endif
 #endif
 
-
 // Checking printf and scanf format strings
 #if defined(_CC_GNU_) || defined(__GNUG__) || defined(__GNUC__)
 #define FX_PRINTF(fmt,arg) __attribute__((format(printf,fmt,arg)))
@@ -201,7 +221,6 @@
 #define FX_FORMAT(arg)
 #endif
 
-
 // Word size issues
 #if defined(_MSC_VER) || defined(__MINGW32__) // Windows
 #if defined(_WIN64)
@@ -239,32 +258,6 @@ union _XEvent;
 namespace FX {
 
 
-/// Third logic state: unknown/indeterminate
-enum { maybe=2 };
-
-
-/// Exponent display
-enum FXExponent {
-  EXP_NEVER=0,                          /// Never use exponential notation
-  EXP_ALWAYS=1,                         /// Always use exponential notation
-  EXP_AUTO=2                            /// Use exponential notation if needed
-  };
-
-
-/// Search modes for search/replace dialogs
-enum {
-  SEARCH_BACKWARD   = 1,                            /// Search backward
-  SEARCH_FORWARD    = 2,                            /// Search forward
-  SEARCH_NOWRAP     = 0,                            /// Don't wrap (default)
-  SEARCH_WRAP       = 4,                            /// Wrap around to start
-  SEARCH_EXACT      = 0,                            /// Exact match (default)
-  SEARCH_IGNORECASE = 8,                            /// Ignore case
-  SEARCH_REGEX      = 16,                           /// Regular expression match
-  SEARCH_PREFIX     = 32,                           /// Prefix of subject string
-  SEARCH_SUFFIX     = 64                            /// Suffix of subject string
-  };
-
-
 /*********************************  Typedefs  **********************************/
 
 // Forward declarations
@@ -377,7 +370,7 @@ typedef _XEvent                 FXRawEvent;
 #endif
 
 
-/// Drag and drop data type
+// Drag and drop data type
 #ifdef WIN32
 typedef FXushort                FXDragType;
 #else
@@ -385,9 +378,25 @@ typedef FXID                    FXDragType;
 #endif
 
 
-/// A time in the far, far future
+// Third logic state: unknown/indeterminate
+enum { maybe=2 };
+
+// A time in the far, far future
 const FXTime forever=FXLONG(9223372036854775807);
 
+// Search modes for search/replace dialogs
+enum {
+  SEARCH_BACKWARD   = 1,        /// Search backward
+  SEARCH_FORWARD    = 2,        /// Search forward
+  SEARCH_NOWRAP     = 0,        /// Don't wrap (default)
+  SEARCH_WRAP       = 4,        /// Wrap around to start
+  SEARCH_EXACT      = 0,        /// Exact match (default)
+  SEARCH_IGNORECASE = 8,        /// Ignore case
+  SEARCH_REGEX      = 16,       /// Regular expression match
+  SEARCH_PREFIX     = 32,       /// Prefix of subject string
+  SEARCH_SUFFIX     = 64,       /// Suffix of subject string
+  SEARCH_WORDS      = 128       /// Whole words
+  };
 
 /**********************************  Macros  ***********************************/
 
@@ -457,35 +466,6 @@ const FXTime forever=FXLONG(9223372036854775807);
 /// Get ID from selector
 #define FXSELID(s)         ((FX::FXushort)((s)&0xffff))
 
-/// Test if character c is at the start of a utf8 sequence (not a follower byte)
-#define FXISUTF8(c)        (((c)&0xC0)!=0x80)
-
-/// Check if c is leader/follower of a utf8 multi-byte sequence
-#define FXISLEADUTF8(c)    (((c)&0xC0)==0xC0)
-#define FXISFOLLOWUTF8(c)  (((c)&0xC0)==0x80)
-
-/// Check if c is part of a utf8 multi-byte sequence
-#define FXISSEQUTF8(c)     (((c)&0x80)==0x80)
-
-/// Number of FXchars in utf8 sequence
-#define FXUTF8LEN(c)       (((0xE5000000>>((((FXuchar)(c))>>4)<<1))&3)+1)
-
-/// Test if character c is at start of utf16 sequence (not a follower from surrogate pair)
-#define FXISUTF16(c)       (((c)&0xFC00)!=0xDC00)
-
-/// Check if c is leader/follower of a utf16 surrogate pair sequence
-#define FXISLEADUTF16(c)   (((c)&0xFC00)==0xD800)
-#define FXISFOLLOWUTF16(c) (((c)&0xFC00)==0xDC00)
-
-/// Check if c is part of a utf16 surrogate pair sequence
-#define FXISSEQUTF16(c)    (((c)&0xF800)==0xD800)
-
-/// Number of FXnchars in utf16 sequence
-#define FXUTF16LEN(c)      (FXISLEADUTF16(c)+1)
-
-/// Test if c is a legal utf32 character
-#define FXISUTF32(c)       ((c)<0x110000)
-
 /// Average of two FXColor ca and FXColor cb
 #define FXAVGCOLOR(ca,cb)  (((ca)&(cb))+((((ca)^(cb))&0xFEFEFEFE)>>1))
 
@@ -592,7 +572,7 @@ const FXTime forever=FXLONG(9223372036854775807);
 #if (defined(__cplusplus) && (__cplusplus >= 201103L)) || (defined(_MSC_VER) && (_MSC_VER >= 1600))
 #define FXASSERT_STATIC(expr) static_assert(expr,#expr)
 #else
-#define FXASSERT_STATIC(expr) FXASSERT(exp)
+#define FXASSERT_STATIC(expr) FXASSERT(expr)
 #endif
 
 
@@ -663,6 +643,20 @@ const FXTime forever=FXLONG(9223372036854775807);
 
 /**********************************  Globals  **********************************/
 
+/// Aliasing cast pointer to other type
+template <typename to_type>
+static inline to_type* alias_cast(void* ptr){
+  union UNI { to_type dst[1]; };
+  return reinterpret_cast<UNI*>(ptr)->dst;
+  }
+
+/// Aliasing cast const-pointer to other type
+template <typename to_type>
+static inline const to_type* alias_cast(const void* ptr){
+  union UNI { to_type dst[1]; };
+  return reinterpret_cast<const UNI*>(ptr)->dst;
+  }
+
 /// Allocate memory
 extern FXAPI FXbool fxmalloc(void** ptr,FXuval size);
 
@@ -750,9 +744,6 @@ extern FXAPI FXint fxparsegeometry(const FXchar *string,FXint& x,FXint& y,FXint&
 /// True if executable with given path is a console application
 extern FXAPI FXbool fxisconsole(const FXchar *path);
 
-/// Return clock ticks from cpu tick-counter
-extern FXAPI FXTime fxgetticks();
-
 /// Version number that the library has been compiled with
 extern FXAPI const FXuchar fxversion[3];
 
@@ -777,106 +768,9 @@ extern FXAPI void setTraceLevel(FXuint level,FXbool flag=true);
 ///
 extern FXAPI FXbool setTraceTopics(const FXchar* topics,FXbool flag=true);
 
-/// Return wide character from utf8 string at ptr
-extern FXAPI FXwchar wc(const FXchar *ptr);
+/// Get operating system version string
+extern FXAPI FXival fxosversion(FXchar version[],FXival len);
 
-/// Return wide character from utf16 string at ptr
-extern FXAPI FXwchar wc(const FXnchar *ptr);
-
-
-/// Increment to start of next wide character in utf8 string
-extern FXAPI const FXchar* wcinc(const FXchar* ptr);
-
-/// Increment to start of next wide character in utf8 string
-extern FXAPI FXchar* wcinc(FXchar* ptr);
-
-/// Increment to start of next wide character in utf16 string
-extern FXAPI const FXnchar* wcinc(const FXnchar* ptr);
-
-/// Increment to start of next wide character in utf16 string
-extern FXAPI FXnchar* wcinc(FXnchar* ptr);
-
-/// Decrement to start of previous wide character in utf8 string
-extern FXAPI const FXchar* wcdec(const FXchar* ptr);
-
-/// Decrement to start of previous wide character in utf8 string
-extern FXAPI FXchar* wcdec(FXchar* ptr);
-
-/// Decrement to start of previous wide character in utf16 string
-extern FXAPI const FXnchar* wcdec(const FXnchar* ptr);
-
-/// Decrement to start of previous wide character in utf16 string
-extern FXAPI FXnchar* wcdec(FXnchar* ptr);
-
-/// Adjust ptr to point to leader of multi-byte sequence
-extern FXAPI const FXchar* wcstart(const FXchar* ptr);
-
-/// Adjust ptr to point to leader of multi-byte sequence
-extern FXAPI FXchar* wcstart(FXchar* ptr);
-
-/// Adjust ptr to point to leader of surrogate pair sequence
-extern FXAPI const FXnchar* wcstart(const FXnchar *ptr);
-
-/// Adjust ptr to point to leader of surrogate pair sequence
-extern FXAPI FXnchar* wcstart(FXnchar *ptr);
-
-/// Return number of FXchar's of wide character at ptr
-extern FXAPI FXival wclen(const FXchar *ptr);
-
-/// Return number of FXnchar's of narrow character at ptr
-extern FXAPI FXival wclen(const FXnchar *ptr);
-
-/// Check if valid utf8 wide character representation; returns length or 0
-extern FXAPI FXival wcvalid(const FXchar* ptr);
-
-/// Check if valid utf16 wide character representation; returns length or 0
-extern FXAPI FXival wcvalid(const FXnchar* ptr);
-
-
-/// Return number of bytes for utf8 representation of wide character w
-extern FXAPI FXival wc2utf(FXwchar w);
-
-/// Return number of narrow characters for utf16 representation of wide character w
-extern FXAPI FXival wc2nc(FXwchar w);
-
-/// Return number of bytes for utf8 representation of wide character string
-extern FXAPI FXival wcs2utf(const FXwchar* src,FXival srclen);
-extern FXAPI FXival wcs2utf(const FXwchar* src);
-
-/// Return number of bytes for utf8 representation of narrow character string
-extern FXAPI FXival ncs2utf(const FXnchar* src,FXival srclen);
-extern FXAPI FXival ncs2utf(const FXnchar* src);
-
-/// Return number of wide characters for utf8 character string
-extern FXAPI FXival utf2wcs(const FXchar src,FXival srclen);
-extern FXAPI FXival utf2wcs(const FXchar *src);
-
-/// Return number of narrow characters for utf8 character string
-extern FXAPI FXival utf2ncs(const FXchar *src,FXival srclen);
-extern FXAPI FXival utf2ncs(const FXchar *src);
-
-
-/// Convert wide character to utf8 string; return number of items written to dst
-extern FXAPI FXival wc2utf(FXchar *dst,FXwchar w);
-
-/// Convert wide character to narrow character string; return number of items written to dst
-extern FXAPI FXival wc2nc(FXnchar *dst,FXwchar w);
-
-/// Convert wide character string to utf8 string; return number of items written to dst
-extern FXAPI FXival wcs2utf(FXchar *dst,const FXwchar* src,FXival dstlen,FXival srclen);
-extern FXAPI FXival wcs2utf(FXchar *dst,const FXwchar* src,FXival dstlen);
-
-/// Convert narrow character string to utf8 string; return number of items written to dst
-extern FXAPI FXival ncs2utf(FXchar *dst,const FXnchar* src,FXival dsrlen,FXival srclen);
-extern FXAPI FXival ncs2utf(FXchar *dst,const FXnchar* src,FXival dsrlen);
-
-/// Convert utf8 string to wide character string; return number of items written to dst
-extern FXAPI FXival utf2wcs(FXwchar *dst,const FXchar* src,FXival dsrlen,FXival srclen);
-extern FXAPI FXival utf2wcs(FXwchar *dst,const FXchar* src,FXival dsrlen);
-
-/// Convert utf8 string to narrow character string; return number of items written to dst
-extern FXAPI FXival utf2ncs(FXnchar *dst,const FXchar* src,FXival dsrlen,FXival srclen);
-extern FXAPI FXival utf2ncs(FXnchar *dst,const FXchar* src,FXival dsrlen);
 
 }
 
