@@ -3,7 +3,7 @@
 *              F O X   P r i v a t e   I n c l u d e   F i l e s                *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -82,10 +82,11 @@
 // Common headers
 #include <windows.h>            // Core Windows stuff
 #include <winspool.h>           // Printer stuff
-#include <io.h>                 // For _access()
+#include <winternl.h>
 #ifndef __CYGWIN__
 #include <winsock2.h>
 #endif
+#include "winnt.h"
 #include <commctrl.h>           // For _TrackMouseEvent
 #include <shellapi.h>
 #include <imm.h>                // IME
@@ -106,7 +107,7 @@
 #ifdef HAVE_GL_H
 #include <GL/gl.h>
 #endif
-//#ifdef _WIN32
+//#ifdef WIN32
 //#include <GL/glext.h>
 //#endif
 #ifndef GLAPIENTRY
@@ -200,6 +201,9 @@
 #ifdef HAVE_SYS_INOTIFY_H
 #include <sys/inotify.h>
 #endif
+#ifdef HAVE_SYS_UTSNAME_H
+#include <sys/utsname.h>
+#endif
 #ifdef HAVE_SYS_SYSCTL_H
 #if !defined(__linux__)
 #include <sys/sysctl.h>
