@@ -3,7 +3,7 @@
 *                   A c c e l e r a t o r   T a b l e   C l a s s               *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,20 +21,20 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxchar.h"
 #include "fxkeys.h"
 #include "fxmath.h"
 #include "fxascii.h"
 #include "fxunicode.h"
-#include "FXArray.h"
-#include "FXHash.h"
 #include "FXMutex.h"
-#include "FXStream.h"
-#include "FXString.h"
-#include "FXElement.h"
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
-#include "FXObject.h"
+#include "FXElement.h"
+#include "FXHash.h"
+#include "FXMetaClass.h"
+#include "FXString.h"
+#include "FXStream.h"
 #include "FXStringDictionary.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
@@ -90,7 +90,7 @@ FXAccelTable::FXAccelTable(){
   FXTRACE((TOPIC_CONSTRUCT,"%p->FXAccelTable::FXAccelTable\n",this));
   allocElms(key,1);
   key[0].code=UNUSEDSLOT;
-  key[0].target=NULL;
+  key[0].target=nullptr;
   key[0].messagedn=0;
   key[0].messageup=0;
   max=0;
@@ -105,7 +105,7 @@ void FXAccelTable::resize(FXuint m){
   allocElms(newkey,m+1);
   for(i=0; i<=m; i++){
     newkey[i].code=UNUSEDSLOT;
-    newkey[i].target=NULL;
+    newkey[i].target=nullptr;
     newkey[i].messagedn=0;
     newkey[i].messageup=0;
     }
@@ -180,7 +180,7 @@ void FXAccelTable::removeAccel(FXHotKey hotkey){
     else{                               // Middle of chain
       key[p].code=EMPTYSLOT;
       }
-    key[p].target=NULL;
+    key[p].target=nullptr;
     key[p].messagedn=0;
     key[p].messageup=0;
     if(max>=(num<<2)) resize(max>>1);
@@ -241,12 +241,12 @@ FXObject* FXAccelTable::targetOfAccel(FXHotKey hotkey) const {
     FXASSERT(hotkey!=UNUSEDSLOT);
     FXASSERT(hotkey!=EMPTYSLOT);
     while((c=key[p].code)!=hotkey){
-      if(c==UNUSEDSLOT) return NULL;
+      if(c==UNUSEDSLOT) return nullptr;
       p=(p+1)&max;
       }
     return key[p].target;
     }
-  return NULL;
+  return nullptr;
   }
 
 
@@ -323,11 +323,11 @@ FXHotKey FXAccelTable::parseAccel(const FXchar* string){
   while(*ptr){
 
     // Modifier
-    if(comparecase(ptr,"ctl",3)==0){ mods|=CONTROLMASK; ptr+=3; }
-    else if(comparecase(ptr,"ctrl",4)==0){ mods|=CONTROLMASK; ptr+=4; }
-    else if(comparecase(ptr,"alt",3)==0){ mods|=ALTMASK; ptr+=3; }
-    else if(comparecase(ptr,"meta",4)==0){ mods|=METAMASK; ptr+=4; }
-    else if(comparecase(ptr,"shift",5)==0){ mods|=SHIFTMASK; ptr+=5; }
+    if(FXString::comparecase(ptr,"ctl",3)==0){ mods|=CONTROLMASK; ptr+=3; }
+    else if(FXString::comparecase(ptr,"ctrl",4)==0){ mods|=CONTROLMASK; ptr+=4; }
+    else if(FXString::comparecase(ptr,"alt",3)==0){ mods|=ALTMASK; ptr+=3; }
+    else if(FXString::comparecase(ptr,"meta",4)==0){ mods|=METAMASK; ptr+=4; }
+    else if(FXString::comparecase(ptr,"shift",5)==0){ mods|=SHIFTMASK; ptr+=5; }
     else break;
 
     // Separator
@@ -335,61 +335,61 @@ FXHotKey FXAccelTable::parseAccel(const FXchar* string){
     }
 
   // Test for some special keys
-  if(comparecase(ptr,"home",4)==0){
+  if(FXString::comparecase(ptr,"home",4)==0){
     code=KEY_Home;
     }
-  else if(comparecase(ptr,"end",3)==0){
+  else if(FXString::comparecase(ptr,"end",3)==0){
     code=KEY_End;
     }
-  else if(comparecase(ptr,"pgup",4)==0){
+  else if(FXString::comparecase(ptr,"pgup",4)==0){
     code=KEY_Page_Up;
     }
-  else if(comparecase(ptr,"pgdn",4)==0){
+  else if(FXString::comparecase(ptr,"pgdn",4)==0){
     code=KEY_Page_Down;
     }
-  else if(comparecase(ptr,"left",4)==0){
+  else if(FXString::comparecase(ptr,"left",4)==0){
     code=KEY_Left;
     }
-  else if(comparecase(ptr,"right",5)==0){
+  else if(FXString::comparecase(ptr,"right",5)==0){
     code=KEY_Right;
     }
-  else if(comparecase(ptr,"up",2)==0){
+  else if(FXString::comparecase(ptr,"up",2)==0){
     code=KEY_Up;
     }
-  else if(comparecase(ptr,"down",4)==0){
+  else if(FXString::comparecase(ptr,"down",4)==0){
     code=KEY_Down;
     }
-  else if(comparecase(ptr,"ins",3)==0){
+  else if(FXString::comparecase(ptr,"ins",3)==0){
     code=KEY_Insert;
     }
-  else if(comparecase(ptr,"del",3)==0){
+  else if(FXString::comparecase(ptr,"del",3)==0){
     code=KEY_Delete;
     }
-  else if(comparecase(ptr,"delete",6)==0){
+  else if(FXString::comparecase(ptr,"delete",6)==0){
     code=KEY_Delete;
     }
-  else if(comparecase(ptr,"esc",3)==0){
+  else if(FXString::comparecase(ptr,"esc",3)==0){
     code=KEY_Escape;
     }
-  else if(comparecase(ptr,"tab",3)==0){
+  else if(FXString::comparecase(ptr,"tab",3)==0){
     code=KEY_Tab;
     }
-  else if(comparecase(ptr,"return",6)==0){
+  else if(FXString::comparecase(ptr,"return",6)==0){
     code=KEY_Return;
     }
-  else if(comparecase(ptr,"enter",5)==0){
+  else if(FXString::comparecase(ptr,"enter",5)==0){
     code=KEY_Return;
     }
-  else if(comparecase(ptr,"back",4)==0){
+  else if(FXString::comparecase(ptr,"back",4)==0){
     code=KEY_BackSpace;
     }
-  else if(comparecase(ptr,"backspace",9)==0){
+  else if(FXString::comparecase(ptr,"backspace",9)==0){
     code=KEY_BackSpace;
     }
-  else if(comparecase(ptr,"spc",3)==0){
+  else if(FXString::comparecase(ptr,"spc",3)==0){
     code=KEY_space;
     }
-  else if(comparecase(ptr,"space",5)==0){
+  else if(FXString::comparecase(ptr,"space",5)==0){
     code=KEY_space;
     }
 
