@@ -3,7 +3,7 @@
 *                      C o l o r   N a m e   F u n c t i o n s                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,11 +22,7 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
-#include "fxkeys.h"
 #include "fxascii.h"
-#include "FXArray.h"
-#include "FXHash.h"
-#include "FXStream.h"
 #include "FXString.h"
 #include "FXColors.h"
 
@@ -1473,7 +1469,7 @@ FXColor colorFromName(const FXchar* name){
       h=ARRAYNUMBER(colorName)-1;
       do{
         m=(h+l)>>1;
-        eq=comparecase(temp,colorName[m]);
+        eq=FXString::comparecase(temp,colorName[m]);
         if(eq==0) return colorValue[m];
         if(eq<0) h=m-1; else l=m+1;
         }
