@@ -3,7 +3,7 @@
 *                         C o m p o s e - C o n t e x t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2005,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2005,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,14 +22,15 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
-#include "FXArray.h"
-#include "FXHash.h"
 #include "FXMutex.h"
-#include "FXStream.h"
-#include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
+#include "FXHash.h"
+#include "FXStream.h"
+#include "FXString.h"
 #include "FXStringDictionary.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
@@ -54,6 +55,11 @@
     widget away from the entry widget.
 */
 
+#define TOPIC_CONSTRUCT 1000
+#define TOPIC_CREATION  1001
+#define TOPIC_KEYBOARD  1009
+#define TOPIC_DETAIL    1010
+
 #define DISPLAY(app)     ((Display*)((app)->display))
 
 
@@ -65,21 +71,21 @@ namespace FX {
 
 
 // Object implementation
-FXIMPLEMENT(FXComposeContext,FXId,NULL,0)
+FXIMPLEMENT(FXComposeContext,FXId,nullptr,0)
 
 
 #ifdef WIN32   //////////////////////////  MS-Windows ///////////////////////////
 
 
 // Deserialization
-FXComposeContext::FXComposeContext():window(NULL),message(0){
-  FXTRACE((100,"FXComposeContext::FXComposeContext %p\n",this));
+FXComposeContext::FXComposeContext():window(nullptr),message(0){
+  FXTRACE((TOPIC_CONSTRUCT,"FXComposeContext::FXComposeContext %p\n",this));
   }
 
 
 // Create input context
 FXComposeContext::FXComposeContext(FXApp* a,FXWindow* win,FXSelector sel):FXId(a),window(win),message(sel){
-  FXTRACE((100,"FXComposeContext::FXComposeContext %p\n",this));
+  FXTRACE((TOPIC_CONSTRUCT,"FXComposeContext::FXComposeContext %p\n",this));
   }
 
 
@@ -87,7 +93,7 @@ FXComposeContext::FXComposeContext(FXApp* a,FXWindow* win,FXSelector sel):FXId(a
 void FXComposeContext::create(){
   if(!xid){
     if(getApp()->isInitialized()){
-      FXTRACE((100,"%s::create %p\n",getClassName(),this));
+      FXTRACE((TOPIC_CREATION,"%s::create %p\n",getClassName(),this));
       xid=window->id();
       }
     }
@@ -98,7 +104,7 @@ void FXComposeContext::create(){
 void FXComposeContext::destroy(){
   if(xid){
     if(getApp()->isInitialized()){
-      FXTRACE((100,"%s::destroy %p\n",getClassName(),this));
+      FXTRACE((TOPIC_CREATION,"%s::destroy %p\n",getClassName(),this));
       ///////
       }
     }
@@ -165,20 +171,20 @@ FXString FXComposeContext::translateEvent(FXRawEvent& event){
     LONG mlen=0;
     FXnchar* mstr;
     if(event.lParam&GCS_RESULTSTR){
-      mlen=ImmGetCompositionString(himc,GCS_RESULTSTR,NULL,0);
+      mlen=ImmGetCompositionString(himc,GCS_RESULTSTR,nullptr,0);
       mstr=new FXnchar [mlen];
       ImmGetCompositionString(himc,GCS_RESULTSTR,mstr,mlen);
       }
     else{
-      mlen=ImmGetCompositionString(himc,GCS_COMPSTR,NULL,0);
+      mlen=ImmGetCompositionString(himc,GCS_COMPSTR,nullptr,0);
       mstr=new FXnchar [mlen+1];
       ImmGetCompositionString(himc,GCS_COMPSTR,mstr,mlen);
       }
     mstr[mlen/sizeof(FXnchar)]=0;
     ImmReleaseContext(event.hwnd,himc);
-    int utf8len=WideCharToMultiByte(CP_UTF8,0,mstr,-1,NULL,0,NULL,NULL);
+    int utf8len=WideCharToMultiByte(CP_UTF8,0,mstr,-1,nullptr,0,nullptr,nullptr);
     FXchar* utf8str=new FXchar [utf8len];
-    WideCharToMultiByte(CP_UTF8,0,mstr,-1,utf8str,utf8len,NULL,NULL);
+    WideCharToMultiByte(CP_UTF8,0,mstr,-1,utf8str,utf8len,nullptr,nullptr);
     result.assign(utf8str,utf8len);
 
     delete [] mstr;
@@ -190,7 +196,7 @@ FXString FXComposeContext::translateEvent(FXRawEvent& event){
 
 // Delete input context
 FXComposeContext::~FXComposeContext(){
-  FXTRACE((100,"FXComposeContext::~FXComposeContext %p\n",this));
+  FXTRACE((TOPIC_CONSTRUCT,"FXComposeContext::~FXComposeContext %p\n",this));
   }
 
 
@@ -198,22 +204,22 @@ FXComposeContext::~FXComposeContext(){
 
 
 // Deserialization
-FXComposeContext::FXComposeContext():window(NULL),message(0),fontset(0){
-  FXTRACE((100,"FXComposeContext::FXComposeContext %p\n",this));
+FXComposeContext::FXComposeContext():window(nullptr),message(0),fontset(0){
+  FXTRACE((TOPIC_CONSTRUCT,"FXComposeContext::FXComposeContext %p\n",this));
   }
 
 
 // Create input context
 FXComposeContext::FXComposeContext(FXApp* a,FXWindow* win,FXSelector sel):FXId(a),window(win),message(sel),fontset(0){
-  FXTRACE((100,"FXComposeContext::FXComposeContext %p\n",this));
+  FXTRACE((TOPIC_CONSTRUCT,"FXComposeContext::FXComposeContext %p\n",this));
   }
 
 
 /*
 
     // Determine list of input styles
-    XIMStyles *ximstyles=NULL;
-    XGetIMValues((XIM)xim,XNQueryInputStyle,&ximstyles,NULL);
+    XIMStyles *ximstyles=nullptr;
+    XGetIMValues((XIM)xim,XNQueryInputStyle,&ximstyles,nullptr);
     if(ximstyles){
       FXuint s;
 
@@ -244,7 +250,7 @@ match:XFree(ximstyles);
 
 /*
 FXbool isIMRunning(Display *display){
-  const FXchar *p=XSetLocaleModifiers(NULL);
+  const FXchar *p=XSetLocaleModifiers(nullptr);
   if(p){
     FXTRACE((100,"XSetLocaleModifiers=%s\n",p));
     FXString server("@server=");
@@ -264,7 +270,7 @@ FXbool isIMRunning(Display *display){
 void FXComposeContext::create(){
   if(!xid){
     if(getApp()->isInitialized()){
-      FXTRACE((100,"%s::create %p\n",getClassName(),this));
+      FXTRACE((TOPIC_CREATION,"%s::create %p\n",getClassName(),this));
 #ifndef NO_XIM
       XIMCallback statusStartStruct;
       XIMCallback statusDoneStruct;
@@ -275,7 +281,7 @@ void FXComposeContext::create(){
       XIMCallback editCaretStruct;
       XVaNestedList editAttr;
       XVaNestedList statusAttr;
-      XIMStyles *ximstyles=NULL;
+      XIMStyles *ximstyles=nullptr;
       XRectangle rect;
       XPoint spot;
       FXuint style,s;
@@ -287,19 +293,19 @@ void FXComposeContext::create(){
       if(!window || !window->id()){ fxerror("FXComposeContext: illegal window parameter\n"); }
 
       // Get input style
-      if(comparecase(getApp()->inputstyle,"onthespot")==0)
+      if(FXString::comparecase(getApp()->inputstyle,"onthespot")==0)
         style=XIMPreeditCallbacks|XIMStatusNothing;
-      else if(comparecase(getApp()->inputstyle,"overthespot")==0)
+      else if(FXString::comparecase(getApp()->inputstyle,"overthespot")==0)
         style=XIMPreeditPosition|XIMStatusNothing;
-      else if(comparecase(getApp()->inputstyle,"offthespot")==0)
+      else if(FXString::comparecase(getApp()->inputstyle,"offthespot")==0)
         style=XIMPreeditArea|XIMStatusArea;
-      else if(comparecase(getApp()->inputstyle,"root")==0)
+      else if(FXString::comparecase(getApp()->inputstyle,"root")==0)
         style=XIMPreeditNothing|XIMStatusNothing;
       else
         style=XIMPreeditNone|XIMStatusNone;
 
       // Determine list of input styles
-      XGetIMValues((XIM)getApp()->xim,XNQueryInputStyle,&ximstyles,NULL);
+      XGetIMValues((XIM)getApp()->xim,XNQueryInputStyle,&ximstyles,nullptr);
       if(ximstyles){
 
         // Try preferred input style
@@ -338,67 +344,67 @@ m:      XFree(ximstyles);
         editDrawStruct.callback=(XIMProc)editDrawCallback;
         editCaretStruct.client_data=(XPointer)this;
         editCaretStruct.callback=(XIMProc)editCaretCallback;
-        editAttr=XVaCreateNestedList(0,XNPreeditStartCallback,&editStartStruct,XNPreeditDrawCallback,&editDrawStruct,XNPreeditDoneCallback,&editDoneStruct,XNPreeditCaretCallback,&editCaretStruct,NULL);
+        editAttr=XVaCreateNestedList(0,XNPreeditStartCallback,&editStartStruct,XNPreeditDrawCallback,&editDrawStruct,XNPreeditDoneCallback,&editDoneStruct,XNPreeditCaretCallback,&editCaretStruct,nullptr);
 
         // Have status callbacks
         if(style&XIMStatusCallbacks){
-          FXTRACE((100,"On the Spot/Status\n"));
+          FXTRACE((TOPIC_DETAIL,"On the Spot/Status\n"));
           statusStartStruct.client_data=(XPointer)this;
           statusStartStruct.callback=(XIMProc)statusStartCallback;
           statusDoneStruct.client_data=(XPointer)this;
           statusDoneStruct.callback=(XIMProc)statusDoneCallback;
           statusDrawStruct.client_data=(XPointer)this;
           statusDrawStruct.callback=(XIMProc)statusDrawCallback;
-          statusAttr=XVaCreateNestedList(0,XNStatusStartCallback,&statusStartStruct,XNStatusDoneCallback,&statusDoneStruct,XNStatusDrawCallback,&statusDrawStruct,NULL);
-          xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditCallbacks|XIMStatusCallbacks,XNClientWindow,window->id(),XNPreeditAttributes,editAttr,XNStatusAttributes,statusAttr,NULL);
+          statusAttr=XVaCreateNestedList(0,XNStatusStartCallback,&statusStartStruct,XNStatusDoneCallback,&statusDoneStruct,XNStatusDrawCallback,&statusDrawStruct,nullptr);
+          xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditCallbacks|XIMStatusCallbacks,XNClientWindow,window->id(),XNPreeditAttributes,editAttr,XNStatusAttributes,statusAttr,nullptr);
           XFree(statusAttr);
           }
 
         // No status callbacks
         else{
-          FXTRACE((100,"On the Spot\n"));
-          xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditCallbacks|XIMStatusNothing,XNClientWindow,window->id(),XNPreeditAttributes,editAttr,NULL);
+          FXTRACE((TOPIC_DETAIL,"On the Spot\n"));
+          xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditCallbacks|XIMStatusNothing,XNClientWindow,window->id(),XNPreeditAttributes,editAttr,nullptr);
           }
         XFree(editAttr);
         }
 
       // Off the spot method
       else if(style&XIMPreeditArea){
-        FXTRACE((100,"Off the Spot\n"));
+        FXTRACE((TOPIC_DETAIL,"Off the Spot\n"));
         rect.x=0;
         rect.y=0;
         rect.width=window->getWidth();
         rect.height=window->getHeight();
-        editAttr=XVaCreateNestedList(0,XNArea,&rect,NULL);
-        xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditArea|XIMStatusArea,XNClientWindow,window->id(),XNPreeditAttributes,editAttr,NULL);
+        editAttr=XVaCreateNestedList(0,XNArea,&rect,nullptr);
+        xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditArea|XIMStatusArea,XNClientWindow,window->id(),XNPreeditAttributes,editAttr,nullptr);
         XFree(editAttr);
         }
 
       // Over the spot method
       else if(style&XIMPreeditPosition){
-        FXTRACE((100,"Over the Spot\n"));
+        FXTRACE((TOPIC_DETAIL,"Over the Spot\n"));
         spot.x=1;
         spot.y=1;
         int missing_charcount;
         char** missing_charsetlist;
         char* def_string;
         fontset=XCreateFontSet(DISPLAY(getApp()),"10x20,10x20",&missing_charsetlist,&missing_charcount,&def_string);
-        editAttr=XVaCreateNestedList(0,XNSpotLocation,&spot,XNFontSet,fontset,NULL);
-        xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditPosition|XIMStatusNothing,XNClientWindow,window->id(),XNPreeditAttributes,editAttr,NULL);
+        editAttr=XVaCreateNestedList(0,XNSpotLocation,&spot,XNFontSet,fontset,nullptr);
+        xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditPosition|XIMStatusNothing,XNClientWindow,window->id(),XNPreeditAttributes,editAttr,nullptr);
         XFreeStringList(missing_charsetlist);
         XFree(editAttr);
         }
 
       // Root method
       else{
-        FXTRACE((100,"Root\n"));
-        xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditNothing|XIMStatusNothing,XNClientWindow,window->id(),NULL);
+        FXTRACE((TOPIC_DETAIL,"Root\n"));
+        xid=(FXID)XCreateIC((XIM)getApp()->xim,XNInputStyle,XIMPreeditNothing|XIMStatusNothing,XNClientWindow,window->id(),nullptr);
         }
 
       // Reset context
       if(xid){
         //long filterevents=0;
-        //XGetICValues((XIC)xid,XNFilterEvents,&filterevents,NULL);
+        //XGetICValues((XIC)xid,XNFilterEvents,&filterevents,nullptr);
         //XSelectInput((Display*)getApp()->getDisplay(),window->id(),BASIC_EVENT_MASK|ENABLED_EVENT_MASK|filterevents);
         XmbResetIC((XIC)xid);
         }
@@ -412,7 +418,7 @@ m:      XFree(ximstyles);
 void FXComposeContext::destroy(){
   if(xid){
     if(getApp()->isInitialized()){
-      FXTRACE((100,"%s::destroy %p\n",getClassName(),this));
+      FXTRACE((TOPIC_CREATION,"%s::destroy %p\n",getClassName(),this));
 #ifndef NO_XIM
       XDestroyIC((XIC)xid);
 #endif
@@ -459,8 +465,8 @@ void FXComposeContext::setSpot(FXint x,FXint y){
     XPoint spot;
     spot.x=x;
     spot.y=y;
-    editAttr=XVaCreateNestedList(0,XNSpotLocation,&spot,NULL);
-    XSetICValues((XIC)xid,XNPreeditAttributes,editAttr,NULL);
+    editAttr=XVaCreateNestedList(0,XNSpotLocation,&spot,nullptr);
+    XSetICValues((XIC)xid,XNPreeditAttributes,editAttr,nullptr);
     XFree(editAttr);
     }
 #endif
@@ -477,8 +483,8 @@ void FXComposeContext::setArea(FXint x,FXint y,FXint w,FXint h){
     rect.y=y;
     rect.width=w;
     rect.height=h;
-    editAttr=XVaCreateNestedList(0,XNArea,&rect,NULL);
-    XSetICValues((XIC)xid,XNPreeditAttributes,editAttr,NULL);
+    editAttr=XVaCreateNestedList(0,XNArea,&rect,nullptr);
+    XSetICValues((XIC)xid,XNPreeditAttributes,editAttr,nullptr);
     XFree(editAttr);
     }
 #endif
@@ -501,7 +507,7 @@ FXString FXComposeContext::translateEvent(FXRawEvent& event){
     if(s!=XLookupChars && s!=XLookupBoth) n=0;
     // FIXME decode buffer based on XLocaleOfIM(XIMOfIC((XIC)xid))
     buffer[n]=0;
-    FXTRACE((100,"XLocaleOfIM=%s\n",XLocaleOfIM(XIMOfIC((XIC)xid))));
+    FXTRACE((TOPIC_DETAIL,"XLocaleOfIM=%s\n",XLocaleOfIM(XIMOfIC((XIC)xid))));
     result.assign(buffer,n);
     delete [] buffer;
     }
@@ -511,13 +517,13 @@ FXString FXComposeContext::translateEvent(FXRawEvent& event){
 
 
 int FXComposeContext::editStartCallback(void*,FXComposeContext* cc,void*){
-  FXTRACE((100,"editStartCallback\n"));
+  FXTRACE((TOPIC_KEYBOARD,"editStartCallback\n"));
   return -1;			// No length limit
   }
 
 
 void FXComposeContext::editDoneCallback(void*,FXComposeContext* cc,void*){
-  FXTRACE((100,"editDoneCallback\n"));
+  FXTRACE((TOPIC_KEYBOARD,"editDoneCallback\n"));
   }
 
 
@@ -525,7 +531,7 @@ void FXComposeContext::editDrawCallback(void*,FXComposeContext* cc,void* ptr){
 #ifndef NO_XIM
   XIMPreeditDrawCallbackStruct *drawstruct=(XIMPreeditDrawCallbackStruct*)ptr;
   XIMText *ximtext=drawstruct->text;
-  FXTRACE((100,"editDrawCallback caret=%d first=%d len=%d\n",drawstruct->caret,drawstruct->chg_first,drawstruct->chg_length));
+  FXTRACE((TOPIC_KEYBOARD,"editDrawCallback caret=%d first=%d len=%d\n",drawstruct->caret,drawstruct->chg_first,drawstruct->chg_length));
 #endif
   }
 
@@ -533,32 +539,32 @@ void FXComposeContext::editDrawCallback(void*,FXComposeContext* cc,void* ptr){
 void FXComposeContext::editCaretCallback(void*,FXComposeContext* cc,void* ptr){
 #ifndef NO_XIM
   XIMPreeditCaretCallbackStruct *caretstruct=(XIMPreeditCaretCallbackStruct*)ptr;
-  FXTRACE((100,"editCaretCallback position=%d direction=%d style=%d\n",caretstruct->position,caretstruct->direction,caretstruct->style));
+  FXTRACE((TOPIC_KEYBOARD,"editCaretCallback position=%d direction=%d style=%d\n",caretstruct->position,caretstruct->direction,caretstruct->style));
 #endif
   }
 
 
 void FXComposeContext::statusStartCallback(void*,FXComposeContext* cc,void*){
-  FXTRACE((100,"statusStartCallback\n"));
+  FXTRACE((TOPIC_KEYBOARD,"statusStartCallback\n"));
   }
 
 
 void FXComposeContext::statusDoneCallback(void*,FXComposeContext* cc,void*){
-  FXTRACE((100,"statusDoneCallback\n"));
+  FXTRACE((TOPIC_KEYBOARD,"statusDoneCallback\n"));
   }
 
 
 void FXComposeContext::statusDrawCallback(void*,FXComposeContext* cc,void* ptr){
 #ifndef NO_XIM
   XIMStatusDrawCallbackStruct* drawstruct=(XIMStatusDrawCallbackStruct*)ptr;
-  FXTRACE((100,"statusDrawCallback\n"));
+  FXTRACE((TOPIC_KEYBOARD,"statusDrawCallback\n"));
 #endif
   }
 
 
 // Delete input context
 FXComposeContext::~FXComposeContext(){
-  FXTRACE((100,"FXComposeContext::~FXComposeContext %p\n",this));
+  FXTRACE((TOPIC_CONSTRUCT,"FXComposeContext::~FXComposeContext %p\n",this));
   destroy();
   window=(FXWindow*)-1L;
   if(fontset) XFreeFontSet(DISPLAY(getApp()),(XFontSet)fontset);
