@@ -3,7 +3,7 @@
 *                    D i r e c t o r y   E n u m e r a t o r                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2005,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2005,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,11 +21,11 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxchar.h"
 #include "fxmath.h"
-#include "FXArray.h"
-#include "FXHash.h"
-#include "FXStream.h"
+#include "FXElement.h"
 #include "FXString.h"
+#include "FXIO.h"
 #include "FXStat.h"
 #include "FXFile.h"
 #include "FXPath.h"
@@ -63,13 +63,13 @@ struct SPACE {
 // Construct directory enumerator
 FXDir::FXDir(){
   // If this fails on your machine, determine what sizeof(SPACE) is
-  // on your machine and mail it to: jeroen@fox-toolkit.com!
+  // on your machine and mail it to: jeroen@fox-toolkit.net!
   //FXTRACE((150,"sizeof(SPACE)=%ld\n",sizeof(SPACE)));
   FXASSERT(sizeof(SPACE)<=sizeof(space));
 #ifdef WIN32
-  ((SPACE*)space)->handle=INVALID_HANDLE_VALUE;
+  alias_cast<SPACE>(space)->handle=INVALID_HANDLE_VALUE;
 #else
-  ((SPACE*)space)->handle=NULL;
+  alias_cast<SPACE>(space)->handle=nullptr;
 #endif
   }
 
@@ -77,13 +77,13 @@ FXDir::FXDir(){
 // Construct directory enumerator
 FXDir::FXDir(const FXString& path){
   // If this fails on your machine, determine what sizeof(SPACE) is
-  // on your machine and mail it to: jeroen@fox-toolkit.com!
+  // on your machine and mail it to: jeroen@fox-toolkit.net!
   //FXTRACE((150,"sizeof(SPACE)=%ld\n",sizeof(SPACE)));
   FXASSERT(sizeof(SPACE)<=sizeof(space));
 #ifdef WIN32
-  ((SPACE*)space)->handle=INVALID_HANDLE_VALUE;
+  alias_cast<SPACE>(space)->handle=INVALID_HANDLE_VALUE;
 #else
-  ((SPACE*)space)->handle=NULL;
+  alias_cast<SPACE>(space)->handle=nullptr;
 #endif
   open(path);
   }
@@ -102,14 +102,14 @@ FXbool FXDir::open(const FXString& path){
     fxstrlcpy(buffer,path.text(),MAXPATHLEN);
     fxstrlcat(buffer,"\\*",MAXPATHLEN+2);
 #endif
-    ((SPACE*)space)->handle=FindFirstFile(buffer,&((SPACE*)space)->result);
-    if(((SPACE*)space)->handle!=INVALID_HANDLE_VALUE){
-      ((SPACE*)space)->first=true;
+    alias_cast<SPACE>(space)->handle=FindFirstFile(buffer,&alias_cast<SPACE>(space)->result);
+    if(alias_cast<SPACE>(space)->handle!=INVALID_HANDLE_VALUE){
+      alias_cast<SPACE>(space)->first=true;
       return true;
       }
 #else
-    ((SPACE*)space)->handle=opendir(path.text());
-    if(((SPACE*)space)->handle!=NULL){
+    alias_cast<SPACE>(space)->handle=opendir(path.text());
+    if(alias_cast<SPACE>(space)->handle){
       return true;
       }
 #endif
@@ -121,9 +121,9 @@ FXbool FXDir::open(const FXString& path){
 // Returns true if the directory is open
 FXbool FXDir::isOpen() const {
 #ifdef WIN32
-  return (((const SPACE*)space)->handle!=INVALID_HANDLE_VALUE);
+  return (alias_cast<const SPACE>(space)->handle!=INVALID_HANDLE_VALUE);
 #else
-  return (((const SPACE*)space)->handle!=NULL);
+  return alias_cast<const SPACE>(space)->handle!=nullptr;
 #endif
   }
 
@@ -132,14 +132,14 @@ FXbool FXDir::isOpen() const {
 FXbool FXDir::next(FXString& name){
   if(isOpen()){
 #if defined(WIN32)
-    if(((SPACE*)space)->first || FindNextFile(((SPACE*)space)->handle,&((SPACE*)space)->result)){
-      ((SPACE*)space)->first=false;
-      name.assign(((SPACE*)space)->result.cFileName);
+    if(alias_cast<SPACE>(space)->first || FindNextFile(alias_cast<SPACE>(space)->handle,&alias_cast<SPACE>(space)->result)){
+      alias_cast<SPACE>(space)->first=false;
+      name.assign(alias_cast<SPACE>(space)->result.cFileName);
       return true;
       }
 #else
-    if((((SPACE*)space)->dp=readdir(((SPACE*)space)->handle))!=NULL){
-      name.assign(((SPACE*)space)->dp->d_name);
+    if((alias_cast<SPACE>(space)->dp=readdir(alias_cast<SPACE>(space)->handle))!=nullptr){
+      name.assign(alias_cast<SPACE>(space)->dp->d_name);
       return true;
       }
 #endif
@@ -153,11 +153,11 @@ FXbool FXDir::next(FXString& name){
 void FXDir::close(){
   if(isOpen()){
 #ifdef WIN32
-    FindClose(((SPACE*)space)->handle);
-    ((SPACE*)space)->handle=INVALID_HANDLE_VALUE;
+    FindClose(alias_cast<SPACE>(space)->handle);
+    alias_cast<SPACE>(space)->handle=INVALID_HANDLE_VALUE;
 #else
-    closedir(((SPACE*)space)->handle);
-    ((SPACE*)space)->handle=NULL;
+    closedir(alias_cast<SPACE>(space)->handle);
+    alias_cast<SPACE>(space)->handle=nullptr;
 #endif
     }
   }
@@ -170,9 +170,9 @@ FXbool FXDir::create(const FXString& path,FXuint perm){
 #ifdef UNICODE
     FXnchar buffer[MAXPATHLEN];
     utf2ncs(buffer,path.text(),MAXPATHLEN);
-    return CreateDirectoryW(buffer,NULL)!=0;
+    return CreateDirectoryW(buffer,nullptr)!=0;
 #else
-    return CreateDirectoryA(path.text(),NULL)!=0;
+    return CreateDirectoryA(path.text(),nullptr)!=0;
 #endif
 #else
     return ::mkdir(path.text(),perm)==0;
@@ -206,7 +206,7 @@ FXint FXDir::listFiles(FXString*& filelist,const FXString& path,const FXString&
   FXDir dir(path);
 
   // Initialize to empty
-  filelist=NULL;
+  filelist=nullptr;
 
   // Get directory stream pointer
   if(dir.isOpen()){
@@ -341,7 +341,7 @@ FXint FXDir::listFiles(FXString*& filelist,const FXString& path,const FXString&
   FXchar server[200];
 
   // Initialize to empty
-  filelist=NULL;
+  filelist=nullptr;
 
 /*
   // Each drive is a root on windows
@@ -369,13 +369,13 @@ FXint FXDir::listFiles(FXString*& filelist,const FXString& path,const FXString&
     host.dwType=RESOURCETYPE_DISK;
     host.dwDisplayType=RESOURCEDISPLAYTYPE_GENERIC;
     host.dwUsage=RESOURCEUSAGE_CONTAINER;
-    host.lpLocalName=NULL;
+    host.lpLocalName=nullptr;
     host.lpRemoteName=(char*)path.text();
-    host.lpComment=NULL;
-    host.lpProvider=NULL;
+    host.lpComment=nullptr;
+    host.lpProvider=nullptr;
 
     // Open network enumeration
-    if(WNetOpenEnum((path[2]?RESOURCE_GLOBALNET:RESOURCE_CONTEXT),RESOURCETYPE_DISK,0,(path[2]?&host:NULL),&hEnum)==NO_ERROR){
+    if(WNetOpenEnum((path[2]?RESOURCE_GLOBALNET:RESOURCE_CONTEXT),RESOURCETYPE_DISK,0,(path[2]?&host:nullptr),&hEnum)==NO_ERROR){
       NETRESOURCE resource[16384/sizeof(NETRESOURCE)];
       FXTRACE((1,"Enumerating=%s\n",path.text()));
       while(1){
@@ -493,7 +493,7 @@ void fxenumWNetContainerResource(NETRESOURCE* netResource,FXObjectListOf<FXStrin
 
   NETRESOURCE *netResources;
   DWORD netResourcesSize=16*1024;               // 16 kB is a good size, according to MSDN
-  if ((netResources=(NETRESOURCE *)malloc(netResourcesSize))==NULL){
+  if ((netResources=(NETRESOURCE *)malloc(netResourcesSize))==nullptr){
     FXTRACE((1,"ERROR: Not enough memory for NETRESOURCE structures\n"));
     WNetCloseEnum(handle);
     return;
@@ -509,7 +509,7 @@ void fxenumWNetContainerResource(NETRESOURCE* netResource,FXObjectListOf<FXStrin
       // MSDN info is not correct; ERROR_MORE_DATA means the buffer was too
       //  small for a _single_ entry
       // netResourcesSize (now) contains required size
-      if((netResources=(NETRESOURCE *)realloc(netResources,netResourcesSize))==NULL){
+      if((netResources=(NETRESOURCE *)realloc(netResources,netResourcesSize))==nullptr){
         FXTRACE((1,"ERROR: Reallocation for NETRESOURCE structures failed\n"));
         WNetCloseEnum(handle);
         return;
@@ -544,7 +544,7 @@ void fxenumWNetContainerResource(NETRESOURCE* netResource,FXObjectListOf<FXStrin
         //  If RESOURCE_CONTEXT was passed to WNetOpenEnum(), the first entry is
         //  a "self reference". For example, starting from the network root one
         //  can find a container entry with lpComment "Entire Network"
-        //  (lpRemoteName and lpLocalName are NULL for me). This container
+        //  (lpRemoteName and lpLocalName are nullptr for me). This container
         //  contains an entry with the same properties. In order to avoid getting
         //  into an infinite loop, we must handle this case.
         //  However, trying to enumerate normal containers while RESOURCE_CONTEXT
@@ -657,6 +657,4 @@ void fxenumWNetContainerResource(NETRESOURCE* netResource,FXObjectListOf<FXStrin
   return count;
   }
 
-
-
 #endif
