@@ -3,7 +3,7 @@
 *                         D o c k   S i t e   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2004,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,14 +22,15 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
-#include "FXArray.h"
+#include "FXSize.h"
+#include "FXPoint.h"
+#include "FXRectangle.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXStream.h"
 #include "FXString.h"
-#include "FXSize.h"
-#include "FXPoint.h"
-#include "FXRectangle.h"
 #include "FXStringDictionary.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
@@ -908,7 +909,7 @@ void FXDockSite::moveToolBar(FXDockBar* bar,FXint barx,FXint bary){
       // Determine galley sizes
       galx=left;
       galw=0;
-      for(begin=getFirst(),cur=prv=nxt=curend=prvend=nxtend=NULL; begin; begin=end->getNext()){
+      for(begin=getFirst(),cur=prv=nxt=curend=prvend=nxtend=nullptr; begin; begin=end->getNext()){
         w=galleyWidth(begin,end,bottom-top,require,expand);
         if(!after(end,bar)){ if(left<=barx && barx<left+w){ prv=begin; prvend=end; } }
         else if(!after(bar,begin)){ if(left<=barx+barw && barx+barw<left+w){ nxt=begin; nxtend=end; } }
@@ -935,7 +936,7 @@ void FXDockSite::moveToolBar(FXDockBar* bar,FXint barx,FXint bary){
           if(cur==bar && bar!=curend) cur->getNext()->setLayoutHints(cur->getNext()->getLayoutHints()|LAYOUT_DOCK_NEXT);
           else cur->setLayoutHints(cur->getLayoutHints()|LAYOUT_DOCK_NEXT);
           bar->setLayoutHints(bar->getLayoutHints()|LAYOUT_DOCK_NEXT);
-          bar->reparent(this,NULL);
+          bar->reparent(this,nullptr);
           }
         }
 
@@ -958,7 +959,7 @@ void FXDockSite::moveToolBar(FXDockBar* bar,FXint barx,FXint bary){
       // Determine galley sizes
       galx=left;
       galw=0;
-      for(begin=getFirst(),cur=prv=nxt=curend=prvend=nxtend=NULL; begin; begin=end->getNext()){
+      for(begin=getFirst(),cur=prv=nxt=curend=prvend=nxtend=nullptr; begin; begin=end->getNext()){
         w=galleyWidth(begin,end,bottom-top,require,expand);
         if(!after(end,bar)){ if(left<=barx && barx<left+w){ prv=begin; prvend=end; } }
         else if(!after(bar,begin)){ if(left<=barx+barw && barx+barw<left+w){ nxt=begin; nxtend=end; }  }
@@ -985,7 +986,7 @@ void FXDockSite::moveToolBar(FXDockBar* bar,FXint barx,FXint bary){
           if(cur==bar && bar!=curend) cur->getNext()->setLayoutHints(cur->getNext()->getLayoutHints()|LAYOUT_DOCK_NEXT);
           else cur->setLayoutHints(cur->getLayoutHints()|LAYOUT_DOCK_NEXT);
           bar->setLayoutHints(bar->getLayoutHints()|LAYOUT_DOCK_NEXT);
-          bar->reparent(this,NULL);
+          bar->reparent(this,nullptr);
           }
         }
 
@@ -1013,7 +1014,7 @@ void FXDockSite::moveToolBar(FXDockBar* bar,FXint barx,FXint bary){
       // Determine galley sizes
       galy=top;
       galh=0;
-      for(begin=getFirst(),cur=prv=nxt=curend=prvend=nxtend=NULL; begin; begin=end->getNext()){
+      for(begin=getFirst(),cur=prv=nxt=curend=prvend=nxtend=nullptr; begin; begin=end->getNext()){
         h=galleyHeight(begin,end,right-left,require,expand);
         if(!after(end,bar)){ if(top<=bary && bary<top+h){ prv=begin; prvend=end; } }
         else if(!after(bar,begin)){ if(top<=bary+barh && bary+barh<top+h){ nxt=begin; nxtend=end; }  }
@@ -1040,7 +1041,7 @@ void FXDockSite::moveToolBar(FXDockBar* bar,FXint barx,FXint bary){
           if(cur==bar && bar!=curend) cur->getNext()->setLayoutHints(cur->getNext()->getLayoutHints()|LAYOUT_DOCK_NEXT);
           else cur->setLayoutHints(cur->getLayoutHints()|LAYOUT_DOCK_NEXT);
           bar->setLayoutHints(bar->getLayoutHints()|LAYOUT_DOCK_NEXT);
-          bar->reparent(this,NULL);
+          bar->reparent(this,nullptr);
           }
         }
 
@@ -1174,7 +1175,7 @@ void FXDockSite::dockToolBar(FXDockBar* bar,FXint barx,FXint bary){
             }
 
           // Link at the bottom
-          bar->reparent(this,NULL);
+          bar->reparent(this,nullptr);
           }
         }
 
@@ -1222,7 +1223,7 @@ ver:  bar->move(FXCLAMP(left,barx,right),bary);
             }
 
           // Link at the bottom
-          bar->reparent(this,NULL);
+          bar->reparent(this,nullptr);
           }
         }
 
