@@ -3,7 +3,7 @@
 *                          E v e n t   D i s p a t c h e r                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2019,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2019,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -36,6 +36,38 @@
 
   - FIXME link to chain of FXEventLoop items from this class, and add the modal
     loops here.
+
+  - These may be useful additions:
+
+      HANDLE CreateWaitableTimerEx(LPSECURITY_ATTRIBUTES lpTimerAttributes,
+                                   LPCWSTR lpTimerName,
+                                   DWORD dwFlags,DWORD dwDesiredAccess);
+      BOOL SetWaitableTimer(HANDLE hTimer,
+                            const LARGE_INTEGER *lpDueTime,
+                            LONG lPeriod,
+                            PTIMERAPCROUTINE pfnCompletionRoutine,
+                            LPVOID lpArgToCompletionRoutine,
+                            BOOL fResume);
+      BOOL SetWaitableTimerEx(HANDLE hTimer,
+                              const LARGE_INTEGER *lpDueTime,
+                              LONG lPeriod,
+                              PTIMERAPCROUTINE pfnCompletionRoutine,
+                              LPVOID lpArgToCompletionRoutine,
+                              PREASON_CONTEXT WakeContext,
+                              ULONG TolerableDelay);
+      BOOL CancelWaitableTimer(HANDLE hTimer);
+      DWORD WaitForSingleObject(HANDLE hHandle,
+                                DWORD  dwMilliseconds);
+
+      int timerfd_create(int clockid,
+                         int flags);
+      int timerfd_settime(int fd,
+                          int flags,
+                          const struct itimerspec* new_value,
+                          struct itimerspec* old_value);
+      int timerfd_gettime(int fd,
+                          struct itimerspec* curr_value);
+
 */
 
 
@@ -47,10 +79,12 @@ namespace FX {
 
 // Units of time in nanoseconds
 const FXTime seconds=1000000000;
+const FXTime milliseconds=1000000;
+const FXTime microseconds=1000;
 
 
 // Construct event dispatcher object
-FXEventDispatcher::FXEventDispatcher():display(NULL){
+FXEventDispatcher::FXEventDispatcher():display(nullptr){
   }
 
 
@@ -72,16 +106,16 @@ FXbool FXEventDispatcher::init(FXptr dpy){
 // Initialize dispatcher
 FXbool FXEventDispatcher::init(){
   if(FXDispatcher::init()){
-    display=NULL;
+    display=nullptr;
     return true;
     }
   return false;
   }
 
 
-#if defined(_WIN32) /////////////////////////////////////////////////////////////
+#if defined(WIN32) //////////////////////////////////////////////////////////////
 
-// Dispatch driver
+// Dispatch driver (using MsgWaitForMultipleObjectsEx())
 FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
   if(internals){
     FXTime now,due,delay,interval;
@@ -99,7 +133,7 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
         if(due<forever){
           now=FXThread::time();
           delay=due-now;
-          if(delay<FXLONG(1000)){
+          if(delay<microseconds){
             if(dispatchTimeout(due)) return true;       // Timer activity
             continue;
             }
@@ -122,7 +156,7 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
       // The fix is to call MsgWaitForMultipleObjects() only AFTER having ascertained
       // that there are NO unhandled messages queued up.
       if(flags&DispatchEvents){
-        if(PeekMessage(&event,NULL,0,0,PM_REMOVE)){
+        if(PeekMessage(&event,nullptr,0,0,PM_REMOVE)){
           if(dispatchEvent(event)) return true;         // Event activity
           continue;
           }
@@ -142,7 +176,7 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
 
       // Select active handles or events; don't block
       if(flags&DispatchEvents){
-        current=MsgWaitForMultipleObjectsEx(numhandles,internals->handles,0,QS_ALLINPUT,MWMO_ALERTABLE);
+        current=MsgWaitForMultipleObjectsEx(numhandles,internals->handles,0,QS_ALLINPUT,MWMO_ALERTABLE|MWMO_INPUTAVAILABLE);
         }
       else{
         current=WaitForMultipleObjectsEx(numhandles,internals->handles,false,0,true);
@@ -164,7 +198,7 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
         // A call to MsgWaitForMultipleObjects() when there are messages already in
         // the queue would block until the next message comes in.
         if(flags&DispatchEvents){
-          if(PeekMessage(&event,NULL,0,0,PM_REMOVE)){
+          if(PeekMessage(&event,nullptr,0,0,PM_REMOVE)){
            if(dispatchEvent(event)) return true;        // Event activity
            continue;
            }
@@ -177,12 +211,12 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
         interval=Math::imin(delay,blocking);
         if(interval<forever){
           interval=Math::imin(interval,maxwait);
-          ms=(FXuint)(interval/1000000);
+          ms=(FXuint)(interval/milliseconds);
           }
 
         // Select active handles or events; wait for timeout or maximum block time
         if(flags&DispatchEvents){
-          current=MsgWaitForMultipleObjectsEx(numhandles,internals->handles,ms,QS_ALLINPUT,MWMO_ALERTABLE);
+          current=MsgWaitForMultipleObjectsEx(numhandles,internals->handles,ms,QS_ALLINPUT,MWMO_ALERTABLE|MWMO_INPUTAVAILABLE);
           }
         else{
           current=WaitForMultipleObjectsEx(numhandles,internals->handles,false,ms,true);
@@ -213,13 +247,13 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
 
 #elif defined(HAVE_EPOLL_CREATE1) ///////////////////////////////////////////////
 
-// Dispatch driver
+// Dispatch driver (using epoll_pwait())
 FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
   if(internals){
     FXTime now,due,delay,interval;
-    FXuint sig,nxt,mode,ms;
+    FXuint sig,nxt,ms,mode,ticks;
     FXInputHandle hnd;
-    FXRawEvent event;
+    FXRawEvent event,ev;
 
     // Loop till we got something
     while(1){
@@ -231,7 +265,7 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
         if(due<forever){
           now=FXThread::time();
           delay=due-now;
-          if(delay<FXLONG(1000)){
+          if(delay<microseconds){
             if(dispatchTimeout(due)) return true;       // Timer activity
             continue;
             }
@@ -249,11 +283,45 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
           }
         }
 
-      // Handle messages
+      // Handle events
       if(flags&DispatchEvents){
         if(XEventsQueued((Display*)display,QueuedAfterFlush)){
           XNextEvent((Display*)display,&event);
-// FIXME compress events
+
+          // Compress motion events
+          if(event.xany.type==MotionNotify){
+            while(XPending((Display*)display)){
+              XPeekEvent((Display*)display,&ev);
+              if((ev.xany.type!=MotionNotify) || (event.xmotion.window!=ev.xmotion.window) || (event.xmotion.state!=ev.xmotion.state)) break;
+              XNextEvent((Display*)display,&event);
+              }
+            }
+
+          // Compress wheel events
+          else if((event.xany.type==ButtonPress) && (event.xbutton.button==Button4 || event.xbutton.button==Button5)){
+            ticks=1;
+            while(XPending((Display*)display)){
+              XPeekEvent((Display*)display,&ev);
+              if((ev.xany.type!=ButtonPress && ev.xany.type!=ButtonRelease) || (event.xany.window!=ev.xany.window) || (event.xbutton.button!=ev.xbutton.button)) break;
+              ticks+=(ev.xany.type==ButtonPress);
+              XNextEvent((Display*)display,&event);
+              }
+            event.xbutton.subwindow=(Window)ticks;      // Stick it here for later
+            }
+
+          // Compress configure events
+          else if(event.xany.type==ConfigureNotify){
+            while(XCheckTypedWindowEvent((Display*)display,event.xconfigure.window,ConfigureNotify,&ev)){
+              event.xconfigure.width=ev.xconfigure.width;
+              event.xconfigure.height=ev.xconfigure.height;
+              if(ev.xconfigure.send_event){
+                event.xconfigure.x=ev.xconfigure.x;
+                event.xconfigure.y=ev.xconfigure.y;
+                }
+              }
+            }
+
+          // Event activity
           if(dispatchEvent(event)) return true;         // Event activity
           continue;
           }
@@ -273,12 +341,15 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
         if(ConnectionNumber((Display*)display)==hnd) continue;
 
         // Regular handle became active
-        if(dispatchHandle(hnd,mode,flags)) return true;
+        if(dispatchHandle(hnd,mode,flags)) return true; // IO activity
         continue;
         }
 
+      // All handles have been handled...
+      FXASSERT(numraised==0);
+
       // Select active handles and check signals; don't block
-      numwatched=epoll_pwait(internals->handle,internals->events,ARRAYNUMBER(internals->events),0,NULL);
+      numwatched=epoll_pwait(internals->handle,internals->events,ARRAYNUMBER(internals->events),0,nullptr);
 
       // No active handles yet; need to wait
       if(numwatched==0){
@@ -298,11 +369,11 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
         interval=Math::imin(delay,blocking);
         if(interval<forever){
           interval=Math::imin(interval,maxwait);
-          ms=(FXuint)(interval/1000000);
+          ms=(FXuint)(interval/milliseconds);
           }
 
         // Select active handles and check signals, waiting for timeout or maximum block time
-        numwatched=epoll_pwait(internals->handle,internals->events,ARRAYNUMBER(internals->events),ms,NULL);
+        numwatched=epoll_pwait(internals->handle,internals->events,ARRAYNUMBER(internals->events),ms,nullptr);
 
         // Return if there was no timeout within maximum block time
         if(numwatched==0){
@@ -329,12 +400,12 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
 
 #else ///////////////////////////////////////////////////////////////////////////
 
-// Dispatch driver
+// Dispatch driver (using pselect() or select())
 FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
   if(internals){
     FXTime now,due,delay,interval;
-    FXuint sig,nxt,mode;
-    FXRawEvent event;
+    FXuint sig,nxt,mode,ticks;
+    FXRawEvent event,ev;
 #if (_POSIX_C_SOURCE >= 200112L)
     struct timespec delta;
 #else
@@ -351,7 +422,7 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
         if(due<forever){
           now=FXThread::time();
           delay=due-now;
-          if(delay<FXLONG(1000)){
+          if(delay<microseconds){
             if(dispatchTimeout(due)) return true;       // Timer activity
             continue;
             }
@@ -369,11 +440,45 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
           }
         }
 
-      // Handle messages
+      // Handle events
       if(flags&DispatchEvents){
         if(XEventsQueued((Display*)display,QueuedAfterFlush)){
           XNextEvent((Display*)display,&event);
-// FIXME compress events
+
+          // Compress motion events
+          if(event.xany.type==MotionNotify){
+            while(XPending((Display*)display)){
+              XPeekEvent((Display*)display,&ev);
+              if((ev.xany.type!=MotionNotify) || (event.xmotion.window!=ev.xmotion.window) || (event.xmotion.state!=ev.xmotion.state)) break;
+              XNextEvent((Display*)display,&event);
+              }
+            }
+
+          // Compress wheel events
+          else if((event.xany.type==ButtonPress) && (event.xbutton.button==Button4 || event.xbutton.button==Button5)){
+            ticks=1;
+            while(XPending((Display*)display)){
+              XPeekEvent((Display*)display,&ev);
+              if((ev.xany.type!=ButtonPress && ev.xany.type!=ButtonRelease) || (event.xany.window!=ev.xany.window) || (event.xbutton.button!=ev.xbutton.button)) break;
+              ticks+=(ev.xany.type==ButtonPress);
+              XNextEvent((Display*)display,&event);
+              }
+            event.xbutton.subwindow=(Window)ticks;   // Stick it here for later
+            }
+
+          // Compress configure events
+          else if(event.xany.type==ConfigureNotify){
+            while(XCheckTypedWindowEvent((Display*)display,event.xconfigure.window,ConfigureNotify,&ev)){
+              event.xconfigure.width=ev.xconfigure.width;
+              event.xconfigure.height=ev.xconfigure.height;
+              if(ev.xconfigure.send_event){
+                event.xconfigure.x=ev.xconfigure.x;
+                event.xconfigure.y=ev.xconfigure.y;
+                }
+              }
+            }
+
+          // Event activity
           if(dispatchEvent(event)) return true;         // Event activity
           continue;
           }
@@ -405,11 +510,14 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
         // Display connection became active
         if(ConnectionNumber((Display*)display)==current) continue;
 
-        // Regular handle became active
+        // IO handle became active
         if(dispatchHandle(current,mode,flags)) return true;     // IO activity
         continue;
         }
 
+      // All handles have been handled...
+      FXASSERT(numraised==0);
+
       // Prepare handles to check
       internals->watched[0]=internals->handles[0];
       internals->watched[1]=internals->handles[1];
@@ -417,9 +525,9 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
 
       // Select active handles and check signals; don't block
 #if (_POSIX_C_SOURCE >= 200112L)
-      numraised=pselect(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],NULL,NULL);
+      numraised=pselect(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],nullptr,nullptr);
 #else
-      numraised=select(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],NULL);
+      numraised=select(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],nullptr);
 #endif
 
       // No handles were active
@@ -448,10 +556,10 @@ FXbool FXEventDispatcher::dispatch(FXTime blocking,FXuint flags){
 #if (_POSIX_C_SOURCE >= 200112L)
         delta.tv_sec=interval/seconds;
         delta.tv_nsec=(interval-seconds*delta.tv_sec);
-        numraised=pselect(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],&delta,NULL);
+        numraised=pselect(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],&delta,nullptr);
 #else
         delta.tv_sec=interval/seconds;
-        delta.tv_usec=(interval-seconds*delta.tv_sec)/1000;
+        delta.tv_usec=(interval-seconds*delta.tv_sec)/microseconds;
         numraised=select(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],&delta);
 #endif
 
@@ -491,7 +599,7 @@ FXbool FXEventDispatcher::dispatchEvent(FXRawEvent& event){
 // Exit dispatcher
 FXbool FXEventDispatcher::exit(){
   if(FXDispatcher::exit()){
-    display=NULL;
+    display=nullptr;
     return true;
     }
   return false;
