@@ -3,7 +3,7 @@
 *                  F i l e   S e l e c t i o n   W i d g e t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -24,17 +24,19 @@
 #include "fxmath.h"
 #include "fxascii.h"
 #include "fxkeys.h"
-#include "FXArray.h"
-#include "FXHash.h"
 #include "FXMutex.h"
-#include "FXStream.h"
-#include "FXObjectList.h"
-#include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
+#include "FXHash.h"
+#include "FXStream.h"
+#include "FXObjectList.h"
+#include "FXString.h"
 #include "FXPath.h"
 #include "FXSystem.h"
+#include "FXIO.h"
 #include "FXStat.h"
 #include "FXFile.h"
 #include "FXDir.h"
@@ -208,23 +210,24 @@ FXFileSelector::FXFileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
   message=sel;
   navbuttons=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0, 0,0);
   entryblock=new FXMatrix(this,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0);
-  new FXLabel(entryblock,tr("&File Name:"),NULL,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
+  new FXLabel(entryblock,tr("&File Name:"),nullptr,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
   filename=new FXTextField(entryblock,25,this,ID_ACCEPT,TEXTFIELD_ENTER_ONLY|LAYOUT_FILL_COLUMN|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
-  new FXButton(entryblock,tr("&OK"),NULL,this,ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
-  accept=new FXButton(navbuttons,FXString::null,NULL,NULL,0,LAYOUT_FIX_X|LAYOUT_FIX_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,0,0, 0,0,0,0);
+  new FXButton(entryblock,tr("&OK"),nullptr,this,ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
+  accept=new FXButton(navbuttons,FXString::null,nullptr,nullptr,0,LAYOUT_FIX_X|LAYOUT_FIX_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,0,0, 0,0,0,0);
   accept->hide();
-  new FXLabel(entryblock,tr("File F&ilter:"),NULL,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
+  new FXLabel(entryblock,tr("File F&ilter:"),nullptr,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
   FXHorizontalFrame *filterframe=new FXHorizontalFrame(entryblock,LAYOUT_FILL_COLUMN|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
   filefilter=new FXComboBox(filterframe,10,this,ID_FILEFILTER,COMBOBOX_STATIC|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
   filefilter->setNumVisible(4);
-  readonly=new FXCheckButton(filterframe,tr("Read Only"),NULL,0,ICON_BEFORE_TEXT|JUSTIFY_LEFT|LAYOUT_CENTER_Y);
-  cancel=new FXButton(entryblock,tr("&Cancel"),NULL,NULL,0,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
+  readonly=new FXCheckButton(filterframe,tr("Read Only"),nullptr,0,ICON_BEFORE_TEXT|JUSTIFY_LEFT|LAYOUT_CENTER_Y);
+  cancel=new FXButton(entryblock,tr("&Cancel"),nullptr,nullptr,0,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
   fileboxframe=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0,0,0,0,0);
   filebox=new FXFileList(fileboxframe,this,ID_FILELIST,ICONLIST_MINI_ICONS|ICONLIST_BROWSESELECT|ICONLIST_AUTOSIZE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+  filebox->horizontalScrollBar()->setWheelLines(1);
   filebox->setDraggableFiles(false);
   filebox->setFocus();
-  new FXLabel(navbuttons,tr("Directory:"),NULL,LAYOUT_CENTER_Y);
-  updiricon=new FXGIFIcon(getApp(),dirupicon);
+  new FXLabel(navbuttons,tr("Directory:"),nullptr,LAYOUT_CENTER_Y);
+  updiricon=new FXGIFIcon(getApp(),dirup_gif);
   listicon=new FXGIFIcon(getApp(),showsmallicons);
   iconsicon=new FXGIFIcon(getApp(),showbigicons);
   detailicon=new FXGIFIcon(getApp(),showdetails);
@@ -232,10 +235,10 @@ FXFileSelector::FXFileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
   workicon=new FXGIFIcon(getApp(),gotowork);
   shownicon=new FXGIFIcon(getApp(),fileshown);
   hiddenicon=new FXGIFIcon(getApp(),filehidden);
-  bookmarkicon=new FXGIFIcon(getApp(),bookset);
-  bookaddicon=new FXBMPIcon(getApp(),bookadd,0,IMAGE_ALPHAGUESS);
-  bookdelicon=new FXBMPIcon(getApp(),bookdel,0,IMAGE_ALPHAGUESS);
-  bookclricon=new FXGIFIcon(getApp(),bookclr);
+  bookmarkicon=new FXGIFIcon(getApp(),bookmrk_gif);
+  bookaddicon=new FXGIFIcon(getApp(),bookset_gif);
+  bookdelicon=new FXGIFIcon(getApp(),bookdel_gif);
+  bookclricon=new FXGIFIcon(getApp(),bookclr_gif);
   sortingicon=new FXBMPIcon(getApp(),sorting,0,IMAGE_ALPHAGUESS);
   newicon=new FXGIFIcon(getApp(),foldernew);
   renameicon=new FXGIFIcon(getApp(),filerename);
@@ -253,26 +256,26 @@ FXFileSelector::FXFileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
   FXMenuSeparator* sep1=new FXMenuSeparator(bookmarkmenu);
   sep1->setTarget(&bookmarks);
   sep1->setSelector(FXRecentFiles::ID_ANYFILES);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_1);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_2);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_3);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_4);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_5);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_6);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_7);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_8);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_9);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_10);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_11);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_12);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_13);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_14);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_15);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_16);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_17);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_18);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_19);
-  new FXMenuCommand(bookmarkmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_20);
+  new FXMenuCommand(bookmarkmenu,"&1",nullptr,&bookmarks,FXRecentFiles::ID_FILE_1);
+  new FXMenuCommand(bookmarkmenu,"&2",nullptr,&bookmarks,FXRecentFiles::ID_FILE_2);
+  new FXMenuCommand(bookmarkmenu,"&3",nullptr,&bookmarks,FXRecentFiles::ID_FILE_3);
+  new FXMenuCommand(bookmarkmenu,"&4",nullptr,&bookmarks,FXRecentFiles::ID_FILE_4);
+  new FXMenuCommand(bookmarkmenu,"&5",nullptr,&bookmarks,FXRecentFiles::ID_FILE_5);
+  new FXMenuCommand(bookmarkmenu,"&6",nullptr,&bookmarks,FXRecentFiles::ID_FILE_6);
+  new FXMenuCommand(bookmarkmenu,"&7",nullptr,&bookmarks,FXRecentFiles::ID_FILE_7);
+  new FXMenuCommand(bookmarkmenu,"&8",nullptr,&bookmarks,FXRecentFiles::ID_FILE_8);
+  new FXMenuCommand(bookmarkmenu,"&9",nullptr,&bookmarks,FXRecentFiles::ID_FILE_9);
+  new FXMenuCommand(bookmarkmenu,"1&0",nullptr,&bookmarks,FXRecentFiles::ID_FILE_10);
+  new FXMenuCommand(bookmarkmenu,"11",nullptr,&bookmarks,FXRecentFiles::ID_FILE_11);
+  new FXMenuCommand(bookmarkmenu,"12",nullptr,&bookmarks,FXRecentFiles::ID_FILE_12);
+  new FXMenuCommand(bookmarkmenu,"13",nullptr,&bookmarks,FXRecentFiles::ID_FILE_13);
+  new FXMenuCommand(bookmarkmenu,"14",nullptr,&bookmarks,FXRecentFiles::ID_FILE_14);
+  new FXMenuCommand(bookmarkmenu,"15",nullptr,&bookmarks,FXRecentFiles::ID_FILE_15);
+  new FXMenuCommand(bookmarkmenu,"16",nullptr,&bookmarks,FXRecentFiles::ID_FILE_16);
+  new FXMenuCommand(bookmarkmenu,"17",nullptr,&bookmarks,FXRecentFiles::ID_FILE_17);
+  new FXMenuCommand(bookmarkmenu,"18",nullptr,&bookmarks,FXRecentFiles::ID_FILE_18);
+  new FXMenuCommand(bookmarkmenu,"19",nullptr,&bookmarks,FXRecentFiles::ID_FILE_19);
+  new FXMenuCommand(bookmarkmenu,"20",nullptr,&bookmarks,FXRecentFiles::ID_FILE_20);
   new FXFrame(navbuttons,LAYOUT_FIX_WIDTH,0,0,4,1);
   new FXButton(navbuttons,tr("\tGo up one directory\tMove up to higher directory."),updiricon,this,ID_DIRECTORY_UP,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
   new FXButton(navbuttons,tr("\tGo to home directory\tBack to home directory."),homeicon,this,ID_HOME,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
@@ -299,6 +302,8 @@ FXFileSelector::FXFileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
     table->addAccel(MKUINT(KEY_c,CONTROLMASK),filebox,FXSEL(SEL_COMMAND,FXFileList::ID_COPY_SEL));
     table->addAccel(MKUINT(KEY_x,CONTROLMASK),filebox,FXSEL(SEL_COMMAND,FXFileList::ID_CUT_SEL));
     table->addAccel(MKUINT(KEY_v,CONTROLMASK),filebox,FXSEL(SEL_COMMAND,FXFileList::ID_PASTE_SEL));
+    table->addAccel(MKUINT(KEY_h,ALTMASK),filebox,FXSEL(SEL_COMMAND,FXFileList::ID_TOGGLE_HIDDEN));
+    table->addAccel(MKUINT(KEY_i,ALTMASK),filebox,FXSEL(SEL_COMMAND,FXFileList::ID_TOGGLE_IMAGES));
     }
 
   // Now use up to 15 bookmarked directories
@@ -320,128 +325,86 @@ FXFileSelector::FXFileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuin
   }
 
 
+// Create server-side resources
+void FXFileSelector::create(){
+  FXPacker::create();
+  if(selectmode==SELECTFILE_ANY){
+    filename->setFocus();
+    filename->selectAll();
+    }
+  }
+
+
 // Count number of files in encoded list of filenames
 FXint FXFileSelector::countFilenames(const FXString& string){
-  FXint result=0;
-  FXint p=0;
-  while(p<string.length()){
-    if(string[p]>' '){
-      if(string[p]=='\''){
-        p++;
-        while(p<string.length() && string[p]!='\''){
-          if(string[p]=='\\' && p<string.length()) p++;
-          p++;
-          }
-        if(p>=string.length()) goto x;
+  FXint result=0,p=0;
+  do{
+    while(string[p]){
+      if(string[p]==','){
+        if(string[p+1]!=',') break;
         p++;
         }
-      else{
-        while(p<string.length() && string[p]>' '){
-          p++;
-          }
-        }
-      result++;
-      continue;
+      p++;
       }
-    p++;
+    result++;
     }
-x:return result;
+  while(string[p++]==',');
+  return result;
   }
 
 
-// Decode the n-th filename from string containing multiple, possibly quoted,
-// filenames surrounded by whitespace.
-// Return the empty string if n exceeds the number of filenames present, or if
-// unmatching quotes are encountered.
+// Decode the n-th filename from string containing multiple filenames
+// Return the empty string if n exceeds the number of filenames present
 FXString FXFileSelector::decodeFilename(const FXString& string,FXint n){
   FXString result;
-  FXint p=0;
-  while(p<string.length()){
-    if(' '<string[p]){
-      FXint pp=p;
-      FXint q=0;
-
-      // Parse over enquoted file
-      if(string[p]=='\''){
-        p++;                                            // Skip opening quote
-        while(p<string.length() && string[p]!='\''){
-          if(string[p]=='\\' && p<string.length()) p++;
-          p++;
-          q++;
-          }
-        if(p>=string.length()) goto x;                  // Bail if missing quote!
-        p++;                                            // Skip trailing quote
+  FXint p=0,pp,q;
+  do{
+    pp=p;
+    q=0;
+    while(string[p]){
+      if(string[p]==','){
+        if(string[p+1]!=',') break;
+        p++;
         }
-
-      // Parse over normal file
-      else{
-        while(p<string.length() && string[p]>' '){
+      p++;
+      q++;
+      }
+    if(--n<0){
+      result.length(q);
+      p=pp;
+      q=0;
+      while(string[p]){
+        if(string[p]==','){
+          if(string[p+1]!=',') break;
           p++;
-          q++;
           }
+        result[q++]=string[p++];
         }
-
-      // Found n-th filename encoding; decode it
-      if(--n<0){
-        result.length(q);
-        p=pp;
-        q=0;
-
-        // Parse and decode file
-        if(string[p]=='\''){
-          p++;                                          // Skip opening quote
-          while(p<string.length() && string[p]!='\''){
-            if(string[p]=='\\' && p<string.length()) p++;
-            result[q++]=string[p++];
-            }
-          p++;                                          // Skip trailing quote
-          }
-
-        // Parse normal file
-        else{
-          while(p<string.length() && string[p]>' '){
-            result[q++]=string[p++];
-            }
-          }
-
-        // Check for fit
-        FXASSERT(q<=result.length());
-        break;
-        }
-      continue;
+      FXASSERT(q<=result.length());
+      break;
       }
-    p++;
     }
-x:return result;
+  while(string[p++]==',');
+  return result;
   }
 
 
-// Enquote filename if it contains spaces, control characters; also force
-// quoting if "'" or "\" appear, and escape them as "\'" and "\\".
-// Leave normal filenames consisting of uninterrupted sequence of printable
-// characters unchanged.
+// Encode a filename
+// Filenames that contain a ',' will replace it with ',,'.
 FXString FXFileSelector::encodeFilename(const FXString& string){
-  FXint p,q,e;
-  FXuchar c;
   FXString result;
-  p=q=e=0;
-  while(p<string.length()){
-    c=string[p++];
-    if(c=='\\'){ e=2; q+=2; continue; }
-    if(c=='\''){ e=2; q+=2; continue; }
-    if(c<=' '){ e=2; }
+  FXint p=0,q=0;
+  while(string[p]){
+    if(string[p]==',') q++;
+    p++;
     q++;
     }
-  result.length(q+e);
+  result.length(q);
   p=q=0;
-  if(e) result[q++]='\'';
-  while(p<string.length()){
-    c=string[p++];
-    if(c=='\\'){ result[q++]='\\'; result[q++]='\\'; continue; }
-    if(c=='\''){ result[q++]='\\'; result[q++]='\''; continue; }
-    result[q++]=c;
+  while(string[p]){
+    if(string[p]==','){ result[q++]=','; }
+    result[q++]=string[p++];
     }
-  if(e) result[q++]='\'';
   FXASSERT(q<=result.length());
   return result;
   }
@@ -450,21 +413,20 @@ FXString FXFileSelector::encodeFilename(const FXString& string){
 // Change in items which are selected
 long FXFileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr){
   FXint index=(FXint)(FXival)ptr;
-  FXint i;
   FXString text;
   if(selectmode==SELECTFILE_MULTIPLE){
-    for(i=0; i<filebox->getNumItems(); i++){
-      if(filebox->isItemSelected(i) && !filebox->isItemDirectory(i)){
-        if(!text.empty()) text+=' ';
+    for(FXint i=0; i<filebox->getNumItems(); i++){
+      if(!filebox->isItemDirectory(i) && filebox->isItemSelected(i)){
+        if(!text.empty()) text+=',';
         text+=encodeFilename(filebox->getItemFilename(i));
         }
       }
     filename->setText(text);
     }
   else if(selectmode==SELECTFILE_MULTIPLE_ALL){
-    for(i=0; i<filebox->getNumItems(); i++){
-      if(filebox->isItemSelected(i) && !filebox->isItemNavigational(i)){
-        if(!text.empty()) text+=' ';
+    for(FXint i=0; i<filebox->getNumItems(); i++){
+      if(!filebox->isItemNavigational(i) && filebox->isItemSelected(i)){
+        if(!text.empty()) text+=',';
         text+=encodeFilename(filebox->getItemFilename(i));
         }
       }
@@ -488,21 +450,20 @@ long FXFileSelector::onCmdItemSelected(FXObject*,FXSelector,void* ptr){
 
 // Change in items which are selected
 long FXFileSelector::onCmdItemDeselected(FXObject*,FXSelector,void*){
-  FXint i;
   FXString text;
   if(selectmode==SELECTFILE_MULTIPLE){
-    for(i=0; i<filebox->getNumItems(); i++){
-      if(filebox->isItemSelected(i) && !filebox->isItemDirectory(i)){
-        if(!text.empty()) text+=' ';
+    for(FXint i=0; i<filebox->getNumItems(); i++){
+      if(!filebox->isItemDirectory(i) && filebox->isItemSelected(i)){
+        if(!text.empty()) text+=',';
         text+=encodeFilename(filebox->getItemFilename(i));
         }
       }
     filename->setText(text);
     }
   else if(selectmode==SELECTFILE_MULTIPLE_ALL){
-    for(i=0; i<filebox->getNumItems(); i++){
-      if(filebox->isItemSelected(i) && !filebox->isItemNavigational(i)){
-        if(!text.empty()) text+=' ';
+    for(FXint i=0; i<filebox->getNumItems(); i++){
+      if(!filebox->isItemNavigational(i) && filebox->isItemSelected(i)){
+        if(!text.empty()) text+=',';
         text+=encodeFilename(filebox->getItemFilename(i));
         }
       }
@@ -517,8 +478,8 @@ long FXFileSelector::onCmdItemDeselected(FXObject*,FXSelector,void*){
 
 // Double-clicked item in file list
 long FXFileSelector::onCmdItemDblClicked(FXObject*,FXSelector,void* ptr){
-  FXSelector sel=accept->getSelector();
   FXObject *tgt=accept->getTarget();
+  FXSelector sel=accept->getSelector();
   FXint index=(FXint)(FXival)ptr;
   if(0<=index){
 
@@ -539,8 +500,8 @@ long FXFileSelector::onCmdItemDblClicked(FXObject*,FXSelector,void* ptr){
 
 // Hit the accept button or enter in text field
 long FXFileSelector::onCmdAccept(FXObject*,FXSelector,void*){
-  FXSelector sel=accept->getSelector();
   FXObject *tgt=accept->getTarget();
+  FXSelector sel=accept->getSelector();
 
   // Get (first) filename or directory
   FXString path=getFilename();
@@ -625,7 +586,7 @@ long FXFileSelector::onCmdAccept(FXObject*,FXSelector,void*){
 // and select the directory we just came from in that directory; this allows
 // a quick jump back into the original directory in case we went up too far.
 long FXFileSelector::onCmdDirectoryUp(FXObject*,FXSelector,void*){
-  if(allowNavigation()){
+  if(allowNavigation() && !FXPath::isTopDirectory(getDirectory())){
     FXString dir(getDirectory());
     setDirectory(FXPath::upLevel(dir));
     filebox->setCurrentFile(dir);
@@ -638,14 +599,14 @@ long FXFileSelector::onCmdDirectoryUp(FXObject*,FXSelector,void*){
 
 // Can we still go up
 long FXFileSelector::onUpdDirectoryUp(FXObject* sender,FXSelector,void*){
-  sender->handle(this,allowNavigation() && !FXPath::isTopDirectory(getDirectory()) ? FXSEL(SEL_COMMAND,ID_ENABLE) : FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
+  sender->handle(this,allowNavigation() && !FXPath::isTopDirectory(getDirectory()) ? FXSEL(SEL_COMMAND,ID_ENABLE) : FXSEL(SEL_COMMAND,ID_DISABLE),nullptr);
   return 1;
   }
 
 
 // Can we navigate
 long FXFileSelector::onUpdNavigable(FXObject* sender,FXSelector,void*){
-  sender->handle(this,allowNavigation() ? FXSEL(SEL_COMMAND,ID_ENABLE) : FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
+  sender->handle(this,allowNavigation() ? FXSEL(SEL_COMMAND,ID_ENABLE) : FXSEL(SEL_COMMAND,ID_DISABLE),nullptr);
   return 1;
   }
 
@@ -743,7 +704,7 @@ long FXFileSelector::onCmdNew(FXObject*,FXSelector,void*){
 
 // Update create new directory
 long FXFileSelector::onUpdNew(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXStat::isAccessible(getDirectory(),FXIO::Writing)?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
+  sender->handle(this,FXStat::isAccessible(getDirectory(),FXIO::Writing)?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),nullptr);
   return 1;
   }
 
@@ -761,7 +722,7 @@ long FXFileSelector::onCmdRename(FXObject*,FXSelector,void*){
     for(FXint i=0; !filenamelist[i].empty(); i++){
       oldname=FXPath::name(filenamelist[i]);
       renamemessage.format(tr("Rename file from:\n\n%s\n\nto: "),oldname.text());
-      FXInputDialog inputdialog(this,tr("Rename File"),renamemessage,NULL,INPUTDIALOG_STRING,0,0,0,0);
+      FXInputDialog inputdialog(this,tr("Rename File"),renamemessage,nullptr,INPUTDIALOG_STRING,0,0,0,0);
       inputdialog.setText(oldname);
       inputdialog.setNumColumns(60);
       if(inputdialog.execute()){
@@ -784,7 +745,7 @@ long FXFileSelector::onCmdCopy(FXObject*,FXSelector,void*){
   if(filenamelist){
     for(FXint i=0; !filenamelist[i].empty(); i++){
       copymessage.format(tr("Copy file from location:\n\n%s\n\nto location: "),filenamelist[i].text());
-      FXInputDialog inputdialog(this,tr("Copy File"),copymessage,NULL,INPUTDIALOG_STRING,0,0,0,0);
+      FXInputDialog inputdialog(this,tr("Copy File"),copymessage,nullptr,INPUTDIALOG_STRING,0,0,0,0);
       inputdialog.setText(FXPath::absolute(FXPath::directory(filenamelist[i]),"CopyOf"+FXPath::name(filenamelist[i])));
       inputdialog.setNumColumns(60);
       if(inputdialog.execute()){
@@ -807,7 +768,7 @@ long FXFileSelector::onCmdMove(FXObject*,FXSelector,void*){
   if(filenamelist){
     for(FXint i=0; !filenamelist[i].empty(); i++){
       movemessage.format(tr("Move file from location:\n\n%s\n\nto location: "),filenamelist[i].text());
-      FXInputDialog inputdialog(this,tr("Move File"),movemessage,NULL,INPUTDIALOG_STRING,0,0,0,0);
+      FXInputDialog inputdialog(this,tr("Move File"),movemessage,nullptr,INPUTDIALOG_STRING,0,0,0,0);
       inputdialog.setText(filenamelist[i]);
       inputdialog.setNumColumns(60);
       if(inputdialog.execute()){
@@ -830,7 +791,7 @@ long FXFileSelector::onCmdLink(FXObject*,FXSelector,void*){
   if(filenamelist){
     for(FXint i=0; !filenamelist[i].empty(); i++){
       linkmessage.format(tr("Link file from location:\n\n%s\n\nto location: "),filenamelist[i].text());
-      FXInputDialog inputdialog(this,tr("Link File"),linkmessage,NULL,INPUTDIALOG_STRING,0,0,0,0);
+      FXInputDialog inputdialog(this,tr("Link File"),linkmessage,nullptr,INPUTDIALOG_STRING,0,0,0,0);
       inputdialog.setText(FXPath::absolute(FXPath::directory(filenamelist[i]),"LinkTo"+FXPath::name(filenamelist[i])));
       inputdialog.setNumColumns(60);
       if(inputdialog.execute()){
@@ -864,17 +825,16 @@ long FXFileSelector::onCmdRemove(FXObject*,FXSelector,void*){
   return 1;
   }
 
-// FIXME maybe should sensitize based on text, not items
 
 // Sensitize when files are selected
 long FXFileSelector::onUpdSelected(FXObject* sender,FXSelector,void*){
   for(FXint i=0; i<filebox->getNumItems(); i++){
     if(filebox->isItemSelected(i) && !filebox->isItemNavigational(i)){
-      sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
+      sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
       return 1;
       }
     }
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),nullptr);
   return 1;
   }
 
@@ -900,7 +860,7 @@ long FXFileSelector::onUpdImageSize(FXObject* sender,FXSelector sel,void*){
     case ID_MEDIUM_SIZE: check=(getImageSize()==64); break;
     case ID_GIANT_SIZE: check=(getImageSize()==128); break;
     }
-  sender->handle(this,check?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,check?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -925,26 +885,26 @@ long FXFileSelector::onPopupMenu(FXObject*,FXSelector,void* ptr){
     FXMenuSeparator* sep1=new FXMenuSeparator(&bookmenu);
     sep1->setTarget(&bookmarks);
     sep1->setSelector(FXRecentFiles::ID_ANYFILES);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_1);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_2);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_3);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_4);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_5);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_6);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_7);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_8);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_9);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_10);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_11);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_12);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_13);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_14);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_15);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_16);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_17);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_18);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_19);
-    new FXMenuCommand(&bookmenu,FXString::null,NULL,&bookmarks,FXRecentFiles::ID_FILE_20);
+    new FXMenuCommand(&bookmenu,"&1",nullptr,&bookmarks,FXRecentFiles::ID_FILE_1);
+    new FXMenuCommand(&bookmenu,"&2",nullptr,&bookmarks,FXRecentFiles::ID_FILE_2);
+    new FXMenuCommand(&bookmenu,"&3",nullptr,&bookmarks,FXRecentFiles::ID_FILE_3);
+    new FXMenuCommand(&bookmenu,"&4",nullptr,&bookmarks,FXRecentFiles::ID_FILE_4);
+    new FXMenuCommand(&bookmenu,"&5",nullptr,&bookmarks,FXRecentFiles::ID_FILE_5);
+    new FXMenuCommand(&bookmenu,"&6",nullptr,&bookmarks,FXRecentFiles::ID_FILE_6);
+    new FXMenuCommand(&bookmenu,"&7",nullptr,&bookmarks,FXRecentFiles::ID_FILE_7);
+    new FXMenuCommand(&bookmenu,"&8",nullptr,&bookmarks,FXRecentFiles::ID_FILE_8);
+    new FXMenuCommand(&bookmenu,"&9",nullptr,&bookmarks,FXRecentFiles::ID_FILE_9);
+    new FXMenuCommand(&bookmenu,"1&0",nullptr,&bookmarks,FXRecentFiles::ID_FILE_10);
+    new FXMenuCommand(&bookmenu,"11",nullptr,&bookmarks,FXRecentFiles::ID_FILE_11);
+    new FXMenuCommand(&bookmenu,"12",nullptr,&bookmarks,FXRecentFiles::ID_FILE_12);
+    new FXMenuCommand(&bookmenu,"13",nullptr,&bookmarks,FXRecentFiles::ID_FILE_13);
+    new FXMenuCommand(&bookmenu,"14",nullptr,&bookmarks,FXRecentFiles::ID_FILE_14);
+    new FXMenuCommand(&bookmenu,"15",nullptr,&bookmarks,FXRecentFiles::ID_FILE_15);
+    new FXMenuCommand(&bookmenu,"16",nullptr,&bookmarks,FXRecentFiles::ID_FILE_16);
+    new FXMenuCommand(&bookmenu,"17",nullptr,&bookmarks,FXRecentFiles::ID_FILE_17);
+    new FXMenuCommand(&bookmenu,"18",nullptr,&bookmarks,FXRecentFiles::ID_FILE_18);
+    new FXMenuCommand(&bookmenu,"19",nullptr,&bookmarks,FXRecentFiles::ID_FILE_19);
+    new FXMenuCommand(&bookmenu,"20",nullptr,&bookmarks,FXRecentFiles::ID_FILE_20);
 
     FXMenuPane sortmenu(this);
     new FXMenuCascade(&filemenu,tr("Sort by"),sortingicon,&sortmenu);
@@ -984,7 +944,7 @@ long FXFileSelector::onPopupMenu(FXObject*,FXSelector,void* ptr){
     new FXMenuCommand(&filemenu,tr("Delete..."),deleteicon,this,ID_REMOVE);
 
     filemenu.create();
-    filemenu.popup(NULL,event->root_x,event->root_y);
+    filemenu.popup(nullptr,event->root_x,event->root_y);
     getApp()->runModalWhileShown(&filemenu);
     }
   return 1;
@@ -1074,19 +1034,24 @@ void FXFileSelector::setFilename(const FXString& path){
   FXString name(FXPath::name(fullname));
   filebox->setCurrentFile(fullname);
   dirbox->setDirectory(filebox->getDirectory());
-  filename->setText(name);
+  if(selectmode==SELECTFILE_MULTIPLE_ALL || selectmode==SELECTFILE_MULTIPLE){
+    filename->setText(encodeFilename(name));
+    }
+  else{
+    filename->setText(name);
+    }
   }
 
 
 // Get complete path + filename
 FXString FXFileSelector::getFilename() const {
-  FXString file=filename->getText();
-  if(!file.empty()){
+  FXString name=filename->getText();
+  if(!name.empty()){
     if(selectmode==SELECTFILE_MULTIPLE_ALL || selectmode==SELECTFILE_MULTIPLE){
-      return FXPath::absolute(getDirectory(),decodeFilename(file));
+      return FXPath::absolute(getDirectory(),decodeFilename(name));
       }
     else{
-      return FXPath::absolute(getDirectory(),file);
+      return FXPath::absolute(getDirectory(),name);
       }
     }
   return FXString::null;
@@ -1095,22 +1060,22 @@ FXString FXFileSelector::getFilename() const {
 
 // Return empty-string terminated list of selected file names, or NULL
 FXString* FXFileSelector::getFilenames() const {
-  FXString file=filename->getText();
-  FXString *filelist=NULL;
-  if(!file.empty()){
+  FXString names=filename->getText();
+  FXString *filelist=nullptr;
+  if(!names.empty()){
     if(selectmode==SELECTFILE_MULTIPLE || selectmode==SELECTFILE_MULTIPLE_ALL){
-      FXint n=countFilenames(file);
+      FXint n=countFilenames(names);
       if(n){
         filelist=new FXString [n+1];
         for(FXint i=0; i<n; ++i){
-          filelist[i]=FXPath::absolute(getDirectory(),decodeFilename(file,i));
+          filelist[i]=FXPath::absolute(getDirectory(),decodeFilename(names,i));
           }
         filelist[n]=FXString::null;
         }
       }
     else{
       filelist=new FXString [2];
-      filelist[0]=FXPath::absolute(getDirectory(),file);
+      filelist[0]=FXPath::absolute(getDirectory(),names);
       filelist[1]=FXString::null;
       }
     }
@@ -1154,7 +1119,7 @@ FXString FXFileSelector::getPattern() const {
 
 // Set current file pattern from the list
 void FXFileSelector::setCurrentPattern(FXint patno){
-  if(patno<0 || patno>=filefilter->getNumItems()){ fxerror("%s::setCurrentPattern: index out of range.\n",getClassName()); }
+  patno=FXCLAMP(0,patno,filefilter->getNumItems()-1);
   filefilter->setCurrentItem(patno);
   filebox->setPattern(patternFromText(filefilter->getItemText(patno)));
   }
@@ -1319,7 +1284,14 @@ void FXFileSelector::setReadOnly(FXbool flag){
 
 // Get readonly state
 FXbool FXFileSelector::getReadOnly() const {
-  return (FXbool)readonly->getCheck();
+  return readonly->getCheck()==true;
+  }
+
+
+// Allow or disallow navigation
+void FXFileSelector::allowNavigation(FXbool flag){
+  filebox->showParents(flag,true);
+  navigable=flag;
   }
 
 
@@ -1347,10 +1319,12 @@ FXString FXFileSelector::getTimeFormat() const {
   }
 
 
-// Change file associations
+// Change file associations.
+// Share associations between filebox and dirbox widgets.
+// Optionally, share associations between other parts of the application as well.
 void FXFileSelector::setAssociations(FXFileAssociations* assoc,FXbool owned){
   filebox->setAssociations(assoc,owned);
-  dirbox->setAssociations(assoc,false);         // Shared file associations
+  dirbox->setAssociations(assoc,false);
   }
 
 
@@ -1464,6 +1438,8 @@ FXFileSelector::~FXFileSelector(){
     table->removeAccel(MKUINT(KEY_c,CONTROLMASK));
     table->removeAccel(MKUINT(KEY_x,CONTROLMASK));
     table->removeAccel(MKUINT(KEY_v,CONTROLMASK));
+    table->removeAccel(MKUINT(KEY_h,ALTMASK));
+    table->removeAccel(MKUINT(KEY_i,ALTMASK));
     }
   delete bookmarkmenu;
   delete updiricon;
