@@ -3,7 +3,7 @@
 *                               F o n t   O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,9 +21,11 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxchar.h"
 #include "fxmath.h"
 #include "fxascii.h"
-#include "FXArray.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXStream.h"
@@ -49,8 +51,9 @@
   - Interpretation of the hints:
 
       0                    No preference for pitch
-      FXFont::Fixed        If specified, match for fixed pitch fonts are strongly preferred
+      FXFont::Mono         If specified, match for fixed pitch fonts are strongly preferred
       FXFont::Variable     If specified, match for variable pitch font strongly preferred
+      FXFont::Dual         If specified, match for dual pitch font strongly preferred
 
       0                    No hints given
       FXFont::Decorative   Ye Olde Fonte
@@ -124,7 +127,6 @@
 
   - Get encoding from locale (see X11).
 
-  - ix|xi
 */
 
 #define TOPIC_CONSTRUCT 1000
@@ -149,17 +151,18 @@ extern FXAPI FXint __snprintf(FXchar* string,FXint length,const FXchar* format,.
 // Character set encoding
 static BYTE FXFontEncoding2CharSet(FXuint encoding){
   switch(encoding){
-    case FONTENCODING_DEFAULT: return DEFAULT_CHARSET;
-    case FONTENCODING_TURKISH: return TURKISH_CHARSET;
-    case FONTENCODING_BALTIC: return BALTIC_CHARSET;
-    case FONTENCODING_CYRILLIC: return RUSSIAN_CHARSET;
+    case FONTENCODING_USASCII: return ANSI_CHARSET;
     case FONTENCODING_ARABIC: return ARABIC_CHARSET;
+    case FONTENCODING_BALTIC: return BALTIC_CHARSET;
+    case FONTENCODING_EASTEUROPE: return EASTEUROPE_CHARSET;
     case FONTENCODING_GREEK: return GREEK_CHARSET;
     case FONTENCODING_HEBREW: return HEBREW_CHARSET;
+    case FONTENCODING_CYRILLIC: return RUSSIAN_CHARSET;
+    case FONTENCODING_TURKISH: return TURKISH_CHARSET;
     case FONTENCODING_THAI: return THAI_CHARSET;
-    case FONTENCODING_EASTEUROPE: return EASTEUROPE_CHARSET;
-    case FONTENCODING_USASCII: return ANSI_CHARSET;
-//    case FONTENCODING_UNICODE: return ANSI_CHARSET;
+    case FONTENCODING_CP1258: return VIETNAMESE_CHARSET;
+    case FONTENCODING_DEFAULT: return DEFAULT_CHARSET;
+    //case FONTENCODING_UNICODE: return ANSI_CHARSET;
     }
   return DEFAULT_CHARSET;
   }
@@ -176,9 +179,7 @@ static FXuint CharSet2FXFontEncoding(BYTE lfCharSet){
     case EASTEUROPE_CHARSET: return FONTENCODING_EASTEUROPE;
     case GB2312_CHARSET: return FONTENCODING_DEFAULT;
     case GREEK_CHARSET: return FONTENCODING_GREEK;
-#if !defined (__WATCOMC__) || (__WATCOMC__ >= 1200)
     case HANGUL_CHARSET: return FONTENCODING_DEFAULT;
-#endif
     case HEBREW_CHARSET: return FONTENCODING_HEBREW;
     case MAC_CHARSET: return FONTENCODING_DEFAULT;
     case OEM_CHARSET: return FONTENCODING_DEFAULT;
@@ -187,6 +188,7 @@ static FXuint CharSet2FXFontEncoding(BYTE lfCharSet){
     case SHIFTJIS_CHARSET: return FONTENCODING_DEFAULT;
     case THAI_CHARSET: return FONTENCODING_THAI;
     case TURKISH_CHARSET: return FONTENCODING_TURKISH;
+    case VIETNAMESE_CHARSET: return FONTENCODING_CP1258;
     }
   return FONTENCODING_DEFAULT;
   }
@@ -200,7 +202,7 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
   FXchar buffer[256];
 
   // Hang on to this for text metrics functions
-  dc=CreateCompatibleDC(NULL);
+  dc=CreateCompatibleDC(nullptr);
 
   // Now fill in the fields
   lf.lfHeight=-MulDiv(wantsize,GetDeviceCaps((HDC)dc,LOGPIXELSY),720);
@@ -240,8 +242,9 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
   lf.lfPitchAndFamily=0;
 
   // Pitch
-  if(wanthints&FXFont::Fixed) lf.lfPitchAndFamily|=FIXED_PITCH;
-  else if(wanthints&FXFont::Variable) lf.lfPitchAndFamily|=VARIABLE_PITCH;
+  if(wanthints&FXFont::Variable) lf.lfPitchAndFamily|=VARIABLE_PITCH;
+  else if(wanthints&FXFont::Mono) lf.lfPitchAndFamily|=MONO_FONT;
+  else if(wanthints&FXFont::Cell) lf.lfPitchAndFamily|=FIXED_PITCH;
   else lf.lfPitchAndFamily|=DEFAULT_PITCH;
 
   // Family
@@ -263,10 +266,10 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
   xid=CreateFontIndirect(&lf);
 
   // Uh-oh, we failed
-  if(!xid) return NULL;
+  if(!xid) return nullptr;
 
   // Obtain text metrics
-  if(!callocElms(font,1)) return NULL;
+  if(!callocElms(font,1)) return nullptr;
 
   SelectObject((HDC)dc,xid);
   GetTextMetrics((HDC)dc,(TEXTMETRIC*)font);
@@ -291,22 +294,6 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
 // Access to display
 #define DISPLAY(app)      ((Display*)((app)->display))
 
-// For Fontconfig 1.0.2
-#ifndef FC_WEIGHT_THIN
-#define FC_WEIGHT_THIN              0
-#undef FC_WEIGHT_LIGHT
-#define FC_WEIGHT_LIGHT             50
-#endif
-#ifndef FC_WEIGHT_EXTRALIGHT
-#define FC_WEIGHT_EXTRALIGHT        40
-#endif
-#ifndef FC_WEIGHT_NORMAL
-#define FC_WEIGHT_NORMAL            80
-#endif
-#ifndef FC_WEIGHT_EXTRABOLD
-#define FC_WEIGHT_EXTRABOLD         205
-#endif
-
 
 // From FOX weight to fontconfig weight
 static FXint weight2FcWeight(FXint weight){
@@ -344,7 +331,6 @@ static FXint fcWeight2Weight(FXint fcWeight){
 
 // From FOX setwidth to fontconfig setwidth
 static FXint setWidth2FcSetWidth(FXint setwidth){
-#ifdef FC_WIDTH
   switch(setwidth){
     case FXFont::UltraCondensed:return FC_WIDTH_ULTRACONDENSED;
     case FXFont::ExtraCondensed:return FC_WIDTH_EXTRACONDENSED;
@@ -357,15 +343,11 @@ static FXint setWidth2FcSetWidth(FXint setwidth){
     case FXFont::UltraExpanded: return FC_WIDTH_ULTRAEXPANDED;
     }
   return FC_WIDTH_NORMAL;
-#else
-  return 0;
-#endif
   }
 
 
 // From fontconfig setwidth to FOX setwidth
 static FXint fcSetWidth2SetWidth(FXint fcSetWidth){
-#ifdef FC_WIDTH
   switch(fcSetWidth){
     case FC_WIDTH_ULTRACONDENSED:return FXFont::UltraCondensed;
     case FC_WIDTH_EXTRACONDENSED:return FXFont::ExtraCondensed;
@@ -377,7 +359,6 @@ static FXint fcSetWidth2SetWidth(FXint fcSetWidth){
     case FC_WIDTH_EXTRAEXPANDED: return FXFont::ExtraExpanded;
     case FC_WIDTH_ULTRAEXPANDED: return FXFont::UltraExpanded;
     }
-#endif
   return FXFont::NonExpanded;
   }
 
@@ -414,11 +395,9 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
   FXbool     fc_autohint=getApp()->reg().readBoolEntry("Xft","autohint",false);
   FXbool     fc_antialias=getApp()->reg().readBoolEntry("Xft","antialias",true);
   FXint      fc_rgba=FC_RGBA_UNKNOWN;
-#ifdef FC_HINT_STYLE
   FXint      fc_hintstyle=FC_HINT_FULL;
-#endif
-  int        pp,sw,wt,sl;
-  double     a,s,c,sz;
+  FXint      pp,sw,wt,sl;
+  FXdouble   a,s,c,sz;
   FcPattern *pattern,*p;
   FcChar8   *fam,*fdy;
   FcCharSet *charset;
@@ -438,21 +417,19 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
   else if(rgba[0]=='b') fc_rgba=FC_RGBA_BGR;
   else if(rgba[0]=='v' && rgba[1]=='r') fc_rgba=FC_RGBA_VRGB;
   else if(rgba[0]=='v' && rgba[1]=='b') fc_rgba=FC_RGBA_VBGR;
+  else if(rgba[0]=='n') fc_rgba=FC_RGBA_NONE;
 
-#ifdef FC_HINT_STYLE
   if(hs[0]=='s') fc_hintstyle=FC_HINT_SLIGHT;
-  else if(hs[0]=='m') fc_hintstyle=FC_HINT_SLIGHT;
+  else if(hs[0]=='m') fc_hintstyle=FC_HINT_MEDIUM;
   else if(hs[0]=='f') fc_hintstyle=FC_HINT_FULL;
-#endif
+  else if(hs[0]=='n') fc_hintstyle=FC_HINT_NONE;
 
   // Set additional hints
   FcPatternAddBool(pattern,FC_HINTING,fc_hinting);
   FcPatternAddBool(pattern,FC_ANTIALIAS,fc_antialias);
   FcPatternAddBool(pattern,FC_AUTOHINT,fc_autohint);
   FcPatternAddInteger(pattern,FC_RGBA,fc_rgba);
-#ifdef FC_HINT_STYLE
   FcPatternAddInteger(pattern,FC_HINT_STYLE,fc_hintstyle);
-#endif
 
   // Set family
   if(!wantfamily.empty()){
@@ -471,7 +448,7 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
 
   // Set font weight
   if(wantweight!=0){
-    FcPatternAddInteger(pattern,FC_WEIGHT,weight2FcWeight(wantweight));
+    FcPatternAddInteger(pattern,FC_WEIGHT,weight2FcWeight(wantweight));         // FIXME
     }
 
   // Set slant
@@ -479,27 +456,31 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
     FcPatternAddInteger(pattern,FC_SLANT,slant2FcSlant(wantslant));
     }
 
-#ifdef FC_WIDTH
   // Set setwidth
   if(wantsetwidth!=0){
     FcPatternAddInteger(pattern,FC_WIDTH,setWidth2FcSetWidth(wantsetwidth));
     }
-#endif
 
   // Set encoding
   if(wantencoding!=FONTENCODING_DEFAULT){                                       // FIXME
 //    FcCharSet* charSet=FcCharSetCreate();
 //    encoding2FcCharSet((void*)charSet, (FXFontEncoding)encoding);
-//    FcPatternAddCharSet(pattern, FC_CHARSET, charSet);
+//    FcPatternAddCharSet(pattern,FC_CHARSET,charSet);
 //    FcCharSetDestroy(charSet);
     }
 
   // Set pitch
-  if(wanthints&FXFont::Fixed){
+  if(wanthints&FXFont::Variable){
+    FcPatternAddInteger(pattern,FC_SPACING,FC_PROPORTIONAL);
+    }
+  else if(wanthints&FXFont::Mono){
     FcPatternAddInteger(pattern,FC_SPACING,FC_MONO);
     }
-  else if(wanthints&FXFont::Variable){
-    FcPatternAddInteger(pattern,FC_SPACING,FC_PROPORTIONAL);
+  else if(wanthints&FXFont::Cell){
+    FcPatternAddInteger(pattern,FC_SPACING,FC_CHARCELL);
+    }
+  else if(wanthints&FXFont::Dual){
+    FcPatternAddInteger(pattern,FC_SPACING,FC_DUAL);
     }
 
   // Scalable font hint; also set if we want rotation
@@ -523,7 +504,7 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
 
   // Find pattern matching a font
   p=FcFontMatch(0,pattern,&result);
-  if(!p) return NULL;
+  if(!p) return nullptr;
 
   // Get name and foundry
   if(FcPatternGetString(p,FC_FAMILY,0,&fam)==FcResultMatch){
@@ -535,16 +516,14 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
       }
     }
 
-#ifdef FC_WIDTH
   // Get setwidth
   if(FcPatternGetInteger(p,FC_WIDTH,0,&sw)==FcResultMatch){
     actualSetwidth=fcSetWidth2SetWidth(sw);
     }
-#endif
 
   // Get weight
   if(FcPatternGetInteger(p,FC_WEIGHT,0,&wt)==FcResultMatch){
-    actualWeight=fcWeight2Weight(wt);
+    actualWeight=fcWeight2Weight(wt);                                   // FIXME
     }
 
   // Get slant
@@ -554,10 +533,11 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
 
   // Get pitch
   if(FcPatternGetInteger(p,FC_SPACING,0,&pp)==FcResultMatch){
-    flags&=~(FXFont::Fixed|FXFont::Variable);
-//    if(pp==FC_MONO || pp==FC_DUAL || pp==FC_CHARCELL) flags|=FXFont::Fixed;
-    if(pp==FC_MONO || pp==FC_CHARCELL) flags|=FXFont::Fixed;
+    flags&=~(FXFont::Mono|FXFont::Variable|FXFont::Dual);
+    if(pp==FC_MONO) flags|=FXFont::Mono;
+    else if(pp==FC_DUAL) flags|=FXFont::Dual;
     else if(pp==FC_PROPORTIONAL) flags|=FXFont::Variable;
+    else if(pp==FC_CHARCELL) flags|=FXFont::Mono;
     }
 
   // Get scalable flag
@@ -567,7 +547,7 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
 
   // Get pixel size and work it back to deci-points using given screen res
   if(FcPatternGetDouble(p,FC_PIXEL_SIZE,0,&sz)==FcResultMatch){
-    actualSize=(int)((720.0*sz)/res);
+    actualSize=(FXushort)((720.0*sz)/res);
     }
 
   // Get charset
@@ -661,7 +641,8 @@ static FXuint xlfdSetwidth(const FXchar* text){
 static FXuint xlfdPitch(const FXchar* text){
   FXchar c=Ascii::toLower(text[0]);
   if(c=='p') return FXFont::Variable;
-  if(c=='m' || c=='c') return FXFont::Fixed;
+  if(c=='m') return FXFont::Mono;
+  if(c=='c') return FXFont::Cell;
   return 0;
   }
 
@@ -751,7 +732,7 @@ static void xlfdSplit(const char *fld[],char* font){
 static FXString xlfdFont(Display *dpy,const FXString& font){
   char **fontnames; int nfontnames;
   FXString fontname(font);
-  if((fontnames=XListFonts(dpy,font.text(),1,&nfontnames))!=NULL){
+  if((fontnames=XListFonts(dpy,font.text(),1,&nfontnames))!=nullptr){
     fontname=fontnames[0];
     XFreeFontNames(fontnames);
     }
@@ -852,14 +833,17 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
         }
 
       // Pitch
-      if(wanthints&FXFont::Fixed){
-        dpitch=(FXFont::Fixed!=pitch);
+      dpitch=0;
+      if(wanthints&FXFont::Variable){
+        if(!(pitch&FXFont::Variable)) dpitch+=3;
         }
-      else if(wanthints&FXFont::Variable){
-        dpitch=(FXFont::Variable!=pitch);
+      else if(wanthints&FXFont::Mono){
+        if(!(pitch&FXFont::Mono)) dpitch+=2;
+        if(!(pitch&FXFont::Cell)) dpitch+=1;
         }
-      else{
-        dpitch=0;
+      else if(wanthints&FXFont::Cell){
+        if(!(pitch&FXFont::Cell)) dpitch+=2;
+        if(!(pitch&FXFont::Mono)) dpitch+=1;
         }
 
       // Scalable
@@ -1038,7 +1022,7 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
       return fs;
       }
     }
-  return NULL;
+  return nullptr;
   }
 
 
@@ -1048,7 +1032,7 @@ void* FXFont::match(const FXString& wantfamily,const FXString& wantforge,FXuint
 /*******************************************************************************/
 
 // Object implementation
-FXIMPLEMENT(FXFont,FXId,NULL,0)
+FXIMPLEMENT(FXFont,FXId,nullptr,0)
 
 
 // Deserialization
@@ -1066,9 +1050,9 @@ FXFont::FXFont(){
   hints=0;
   flags=0;
   angle=0;
-  font=NULL;
+  font=nullptr;
 #ifdef WIN32
-  dc=NULL;
+  dc=nullptr;
 #endif
   }
 
@@ -1089,9 +1073,9 @@ FXFont::FXFont(FXApp* a,const FXString& string):FXId(a){
   hints=0;
   flags=0;
   angle=0;
-  font=NULL;
+  font=nullptr;
 #ifdef WIN32
-  dc=NULL;
+  dc=nullptr;
 #endif
   setFont(string);
   }
@@ -1113,9 +1097,9 @@ FXFont::FXFont(FXApp* a,const FXString& face,FXuint size,FXuint weight,FXuint sl
   hints=(h&~FXFont::X11);          // System-independent method
   flags=0;
   angle=0;
-  font=NULL;
+  font=nullptr;
 #ifdef WIN32
-  dc=NULL;
+  dc=nullptr;
 #endif
   }
 
@@ -1136,9 +1120,9 @@ FXFont::FXFont(FXApp* a,const FXFontDesc& fontdesc):FXId(a),wantedName(fontdesc.
   hints=fontdesc.flags;
   flags=0;
   angle=0;
-  font=NULL;
+  font=nullptr;
 #ifdef WIN32
-  dc=NULL;
+  dc=nullptr;
 #endif
   }
 
@@ -1340,7 +1324,7 @@ void FXFont::detach(){
     actualSlant=0;
     actualSetwidth=0;
     actualEncoding=0;
-    font=NULL;
+    font=nullptr;
     xid=0;
     }
   }
@@ -1386,7 +1370,7 @@ void FXFont::destroy(){
     actualSlant=0;
     actualSetwidth=0;
     actualEncoding=0;
-    font=NULL;
+    font=nullptr;
     xid=0;
     }
   }
@@ -1755,7 +1739,7 @@ FXint FXFont::getTextHeight(const FXchar *string,FXuint length) const {
   if(font){
 #if defined(WIN32)              ///// WIN32 /////
 //    SIZE size;
-//    FXASSERT(dc!=NULL);
+//    FXASSERT(dc);
 //    GetTextExtentPoint32((HDC)dc,string,length,&size);
 //    return size.cy;
     return ((TEXTMETRIC*)font)->tmHeight;
@@ -1954,7 +1938,6 @@ static int CDECL comparefont(const void *a,const void *b){
   }
 
 
-
 #if defined(WIN32)              ///////  MS-Windows ///////
 
 // Need to get some data into the callback function.
@@ -1976,29 +1959,30 @@ static int CALLBACK EnumFontFamExProc(const LOGFONTA *lf,const TEXTMETRICA *lptm
 
   // Get pitch
   FXuint flags=0;
-  if(lf->lfPitchAndFamily&FIXED_PITCH) flags|=FXFont::Fixed;
+  if(lf->lfPitchAndFamily&MONO_FONT) flags|=FXFont::Mono;
+  if(lf->lfPitchAndFamily&FIXED_PITCH) flags|=FXFont::Cell;
   if(lf->lfPitchAndFamily&VARIABLE_PITCH) flags|=FXFont::Variable;
 
   // Get hints
-  if(lf->lfPitchAndFamily&FF_DONTCARE) flags|=0;
   if(lf->lfPitchAndFamily&FF_MODERN) flags|=FXFont::Modern;
   if(lf->lfPitchAndFamily&FF_ROMAN) flags|=FXFont::Roman;
   if(lf->lfPitchAndFamily&FF_SCRIPT) flags|=FXFont::Script;
   if(lf->lfPitchAndFamily&FF_DECORATIVE) flags|=FXFont::Decorative;
   if(lf->lfPitchAndFamily&FF_SWISS) flags|=FXFont::Swiss;
+  if(lf->lfPitchAndFamily&FF_DONTCARE) flags&=~(FXFont::Modern|FXFont::Roman|FXFont::Script|FXFont::Decorative|FXFont::Swiss);
 
   // Skip if no match
   FXuint h=pFontStore->desc.flags;
-  if((h&FXFont::Fixed) && !(flags&FXFont::Fixed)) return 1;
+  if((h&FXFont::Mono) && !(flags&FXFont::Mono)) return 1;
   if((h&FXFont::Variable) && !(flags&FXFont::Variable)) return 1;
 
   // Get weight (also guess from the name)
   FXuint weight=lf->lfWeight/10;
-  if(strstr(lf->lfFaceName,"Bold")!=NULL) weight=FXFont::Bold;
-  if(strstr(lf->lfFaceName,"Black")!=NULL) weight=FXFont::Black;
-  if(strstr(lf->lfFaceName,"Demi")!=NULL) weight=FXFont::DemiBold;
-  if(strstr(lf->lfFaceName,"Light")!=NULL) weight=FXFont::Light;
-  if(strstr(lf->lfFaceName,"Medium")!=NULL) weight=FXFont::Medium;
+  if(!strstr(lf->lfFaceName,"Bold")) weight=FXFont::Bold;
+  if(!strstr(lf->lfFaceName,"Black")) weight=FXFont::Black;
+  if(!strstr(lf->lfFaceName,"Demi")) weight=FXFont::DemiBold;
+  if(!strstr(lf->lfFaceName,"Light")) weight=FXFont::Light;
+  if(!strstr(lf->lfFaceName,"Medium")) weight=FXFont::Medium;
 
   // Skip if weight doesn't match
   FXuint wt=pFontStore->desc.weight;
@@ -2007,8 +1991,8 @@ static int CALLBACK EnumFontFamExProc(const LOGFONTA *lf,const TEXTMETRICA *lptm
   // Get slant
   FXuint slant=FXFont::Straight;
   if(lf->lfItalic) slant=FXFont::Italic;
-  if(strstr(lf->lfFaceName,"Italic")!=NULL) slant=FXFont::Italic;
-  if(strstr(lf->lfFaceName,"Roman")!=NULL) slant=FXFont::Straight;
+  if(!strstr(lf->lfFaceName,"Italic")) slant=FXFont::Italic;
+  if(!strstr(lf->lfFaceName,"Roman")) slant=FXFont::Straight;
 
   // Skip if no match
   FXuint sl=pFontStore->desc.slant;
@@ -2016,9 +2000,9 @@ static int CALLBACK EnumFontFamExProc(const LOGFONTA *lf,const TEXTMETRICA *lptm
 
   // Get set width (also guess from the name)
   FXuint setwidth=0;
-  if(strstr(lf->lfFaceName,"Cond")!=NULL) setwidth=FXFont::Condensed;
-  if(strstr(lf->lfFaceName,"Narrow")!=NULL) setwidth=FXFont::Condensed;
-  if(strstr(lf->lfFaceName,"Ext Cond")!=NULL) setwidth=FXFont::ExtraCondensed;
+  if(!strstr(lf->lfFaceName,"Cond")) setwidth=FXFont::Condensed;
+  if(!strstr(lf->lfFaceName,"Narrow")) setwidth=FXFont::Condensed;
+  if(!strstr(lf->lfFaceName,"Ext Cond")) setwidth=FXFont::ExtraCondensed;
 
   // Skip if no match
   FXuint sw=pFontStore->desc.setwidth;
@@ -2084,7 +2068,7 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
   FXuint i,j;
 
   // Initialize return values
-  fonts=NULL;
+  fonts=nullptr;
   numfonts=0;
 
   // This data gets passed into the callback function
@@ -2181,7 +2165,7 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
   FXString     foundry;
   double       points;
 
-  fonts=NULL;
+  fonts=nullptr;
   numfonts=0;
 
   // Need to have application
@@ -2203,9 +2187,9 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
 
   // Build object set
 #ifdef FC_WIDTH
-  objset=FcObjectSetBuild(FC_FAMILY,FC_FOUNDRY,FC_SPACING,FC_SCALABLE,FC_WIDTH,FC_WEIGHT,FC_SLANT,FC_PIXEL_SIZE,NULL);
+  objset=FcObjectSetBuild(FC_FAMILY,FC_FOUNDRY,FC_SPACING,FC_SCALABLE,FC_WIDTH,FC_WEIGHT,FC_SLANT,FC_PIXEL_SIZE,nullptr);
 #else
-  objset=FcObjectSetBuild(FC_FAMILY,FC_FOUNDRY,FC_SPACING,FC_SCALABLE,FC_WEIGHT,FC_SLANT,FC_PIXEL_SIZE,NULL);
+  objset=FcObjectSetBuild(FC_FAMILY,FC_FOUNDRY,FC_SPACING,FC_SCALABLE,FC_WEIGHT,FC_SLANT,FC_PIXEL_SIZE,nullptr);
 #endif
   if(objset){
 
@@ -2251,18 +2235,16 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
                 }
               }
 
-#ifdef FC_WIDTH
             // Get setwidth
             setwidth=0;
             if(FcPatternGetInteger(p,FC_WIDTH,0,&setwidth)==FcResultMatch){
               setwidth=fcSetWidth2SetWidth(setwidth);
               }
-#endif
 
             // Get weight
             weight=0;
             if(FcPatternGetInteger(p,FC_WEIGHT,0,&weight)==FcResultMatch){
-              weight=fcWeight2Weight(weight);
+              weight=fcWeight2Weight(weight);   // FIXME
               }
 
             // Get slant
@@ -2274,8 +2256,10 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
             // Get pitch
             pitch=FXFont::Variable;
             if(FcPatternGetInteger(p,FC_SPACING,0,&pitch)==FcResultMatch){
-//              if(pitch==FC_MONO || pitch==FC_DUAL || pitch==FC_CHARCELL) pitch=FXFont::Fixed;
-              if(pitch==FC_MONO || pitch==FC_CHARCELL) pitch=FXFont::Fixed;
+              if(pitch==FC_PROPORTIONAL) pitch=FXFont::Variable;
+              else if(pitch==FC_MONO) pitch=FXFont::Mono;
+              else if(pitch==FC_CHARCELL) pitch=FXFont::Cell;
+              else if(pitch==FC_DUAL) pitch=FXFont::Dual;
               }
 
             // Pixel size works for both bitmap and scalable fonts
@@ -2300,17 +2284,18 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
             FXTRACE((160,"wt=%2d sl=%d sw=%3d en=%5d sz=%3d sc=%4x pi=%d name=%s\n",weight,slant,setwidth,encoding,size,scalable,pitch,fullname));
 
             // Skip if pitch does not match
-            if((h&FXFont::Fixed) && (pitch!=FXFont::Fixed)) continue;
+            if((h&FXFont::Mono) && (pitch!=FXFont::Mono)) continue;
+            if((h&FXFont::Dual) && (pitch!=FXFont::Dual)) continue;
             if((h&FXFont::Variable) && (pitch!=FXFont::Variable)) continue;
 
             // Skip if weight does not match
-            if((wt!=0) && (wt!=weight)) continue;
+            if((wt!=0) && (wt!=(FXuint)weight)) continue;
 
             // Skip if slant does not match
-            if((sl!=0) && (sl!=slant)) continue;
+            if((sl!=0) && (sl!=(FXuint)slant)) continue;
 
             // Skip if setwidth does not match
-            if((sw!=0) && (sw!=setwidth)) continue;
+            if((sw!=0) && (sw!=(FXuint)setwidth)) continue;
 
             // Want scalable
             if((h&FXFont::Scalable) && (scalable!=FXFont::Scalable)) continue;
@@ -2365,7 +2350,7 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
   FXString family;
   FXString foundry;
 
-  fonts=NULL;
+  fonts=nullptr;
   numfonts=0;
 
   // Need to have application
@@ -2431,8 +2416,8 @@ FXbool FXFont::listFonts(FXFontDesc*& fonts,FXuint& numfonts,const FXString& fac
       if((en!=FONTENCODING_DEFAULT) && (en!=encoding)) continue;
 
       // Skip if pitch does not match
-      if((h&FXFont::Fixed) && (pitch!=FXFont::Fixed)) continue;
-      if((h&FXFont::Variable) && (pitch!=FXFont::Variable)) continue;
+      if((h&FXFont::Variable) && !(pitch&FXFont::Variable)) continue;
+      if((h&(FXFont::Mono|FXFont::Cell)) && !(pitch&(FXFont::Mono|FXFont::Cell))) continue;
 
       // Skip if weight does not match
       if((wt!=0) && (wt!=weight)) continue;
@@ -2579,13 +2564,13 @@ static const ENTRY styletable[]={
 // Font pitch table
 static const ENTRY pitchtable[]={
   {"",0},
-  {"mono",FXFont::Fixed},
-  {"fixed",FXFont::Fixed},
-  {"constant",FXFont::Fixed},
+  {"mono",FXFont::Mono},
+  {"dual",FXFont::Dual},
+  {"cell",FXFont::Cell},
   {"variable",FXFont::Variable},
   {"proportional",FXFont::Variable},
-  {"c",FXFont::Fixed},
-  {"m",FXFont::Fixed},
+  {"c",FXFont::Cell},
+  {"m",FXFont::Mono},
   {"p",FXFont::Variable}
   };
 
@@ -2665,7 +2650,7 @@ static FXString findbyvalue(const ENTRY* table,FXint n,FXuint value){
 
 // Search for name and return value
 static FXuint findbyname(const ENTRY* table,FXint n,const FXString& name){
-  for(int i=0; i<n; i++){ if(comparecase(table[i].name,name)==0) return table[i].value; }
+  for(int i=0; i<n; i++){ if(FXString::comparecase(table[i].name,name)==0) return table[i].value; }
   return name.toUInt();
   }
 
@@ -2771,29 +2756,12 @@ FXFontDesc FXFont::getActualFontDesc() const {
 
 /*******************************************************************************/
 
-#if 0
-  /// Construct font description
-  FXFontDesc(const FXString& fc,FXuint sz,FXuint wt,FXuint sl,FXuint enc,FXuint sw,FXuint h);
-
-// Construct font description
-FXFontDesc::FXFontDesc(const FXString& fc,FXuint sz,FXuint wt,FXuint sl,FXuint enc,FXuint sw,FXuint h){
-  memcpy(face,fc.text(),sizeof(face)-1);    // FIXME yes, not liking this...
-  size=10*sz;
-  weight=wt;
-  slant=sl;
-  setwidth=sw;
-  encoding=enc;
-  flags=(h&~FXFont::X11);          // System-independent method
-  }
-#endif
-
-
 // Set font description from a string
 void FXFontDesc::setFont(const FXString& string){
   FXint len=string.find(',');
   clearElms(face,sizeof(face));
   if(0<=len){
-    memcpy(face,string.text(),Math::imin(len,sizeof(face)-1));
+    memcpy(face,string.text(),Math::imin(len,(FXint)sizeof(face)-1));
     size=string.section(',',1).toUInt();
     weight=FXFont::weightFromString(string.section(',',2));
     slant=FXFont::slantFromString(string.section(',',3));
