@@ -3,7 +3,7 @@
 *                           O p e n G L   V i e w e r                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -23,7 +23,8 @@
 #include "fxdefs.h"
 #include "fxmath.h"
 #include "fxkeys.h"
-#include "FXArray.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXElement.h"
@@ -142,10 +143,10 @@
 #define MAX_SELPATH    64
 
 // Rotation tolerance
-#define EPS            1.0E-2
+//#define EPS            1.0E-2
 
 // Pick tolerance
-#define PICK_TOL       3
+//#define PICK_TOL       3
 
 using namespace FX;
 
@@ -278,6 +279,12 @@ FXIMPLEMENT(FXGLViewer,FXGLCanvas,FXGLViewerMap,ARRAYNUMBER(FXGLViewerMap))
 
 /*******************************************************************************/
 
+// Rotation tolerance
+const FXfloat EPS=0.01f;
+
+// Pick tolerance
+const FXint PICK_TOL=3;
+
 // Drag type names for generic object
 const FXchar FXGLViewer::objectTypeName[]="application/x-globject";
 
@@ -295,9 +302,9 @@ FXGLViewer::FXGLViewer(){
   dial[0]=0;
   dial[1]=0;
   dial[2]=0;
-  dropped=NULL;
-  selection=NULL;
-  zsortfunc=NULL;
+  dropped=nullptr;
+  selection=nullptr;
+  zsortfunc=nullptr;
   doesturbo=false;
   mode=HOVERING;
   }
@@ -408,10 +415,10 @@ void FXGLViewer::initialize(){
   dial[0]=0;                                    // Old dial position
   dial[1]=0;                                    // Old dial position
   dial[2]=0;                                    // Old dial position
-  dropped=NULL;                                 // Nobody being dropped on
-  selection=NULL;                               // No initial selection
-  zsortfunc=NULL;                               // Routine to sort feedback buffer
-  scene=NULL;                                   // Scene to look at
+  dropped=nullptr;                              // Nobody being dropped on
+  selection=nullptr;                            // No initial selection
+  zsortfunc=nullptr;                            // Routine to sort feedback buffer
+  scene=nullptr;                                // Scene to look at
   doesturbo=false;                              // In interaction
   turbomode=false;                              // Turbo mode
   mode=HOVERING;                                // Mouse operation
@@ -684,7 +691,7 @@ FXint FXGLViewer::selectHits(FXuint*& hits,FXint& nhits,FXint x,FXint y,FXint w,
 #ifdef HAVE_GL_H
   FXfloat pickx,picky,pickw,pickh;
   FXint mh=maxhits;
-  hits=NULL;
+  hits=nullptr;
   nhits=0;
   if(makeCurrent()){
 
@@ -751,22 +758,22 @@ FXGLObject* FXGLViewer::processHits(FXuint *pickbuffer,FXint nhits){
       }
     return scene->identify(&pickbuffer[4+sel]);
     }
-  return NULL;
+  return nullptr;
   }
 
 
 // Build NULL-terminated list of ALL picked objects overlapping rectangle
 FXGLObject** FXGLViewer::select(FXint x,FXint y,FXint w,FXint h){
-  FXGLObject *obj,**objects=NULL;
+  FXGLObject *obj,**objects=nullptr;
   FXint nhits,i,j;
   FXuint *hits;
   if(scene && maxhits){
     if(selectHits(hits,nhits,x,y,w,h)){     // FIXME leak
       resizeElms(objects,nhits+1);
       for(i=j=0; nhits>0; i+=hits[i]+3,nhits--){
-        if((obj=scene->identify(&hits[4+i]))!=NULL) objects[j++]=obj;
+        if((obj=scene->identify(&hits[4+i]))!=nullptr) objects[j++]=obj;
         }
-      objects[j]=NULL;
+      objects[j]=nullptr;
       freeElms(hits);
       }
     }
@@ -785,7 +792,7 @@ FXGLObject** FXGLViewer::lasso(FXint x1,FXint y1,FXint x2,FXint y2){
 
 // Pick ONE object at x,y
 FXGLObject* FXGLViewer::pick(FXint x,FXint y){
-  FXGLObject *obj=NULL;
+  FXGLObject *obj=nullptr;
   FXuint *hits;
   FXint nhits;
   if(scene && maxhits){
@@ -918,10 +925,9 @@ void FXGLViewer::setScale(FXVec3f s){
 
 
 // Change orientation to new quaternion
-void FXGLViewer::setOrientation(FXQuatf rot){
+void FXGLViewer::setOrientation(const FXQuatf& rot){
   if(rot!=rotation){
-    rotation=rot;
-    rotation.adjust();
+    rotation=normalize(rot);
     updateTransform();
     update();
     }
@@ -1619,7 +1625,7 @@ long FXGLViewer::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
       setOp(HOVERING);
       if(!handle(this,FXSEL(SEL_PICKED,0),ptr)){
         objects[0]=pick(event->click_x,event->click_y);
-        objects[1]=NULL;
+        objects[1]=nullptr;
         handle(this,FXSEL(SEL_CHANGED,0),(void*)objects[0]);        // FIXME want multiple objects
         handle(this,FXSEL(SEL_SELECTED,0),(void*)objects);
         }
@@ -2090,9 +2096,9 @@ long FXGLViewer::onCmdPerspective(FXObject*,FXSelector,void*){
 
 // Update sender
 long FXGLViewer::onUpdPerspective(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(projection==PERSPECTIVE)?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(projection==PERSPECTIVE)?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2106,9 +2112,9 @@ long FXGLViewer::onCmdParallel(FXObject*,FXSelector,void*){
 
 // Update sender
 long FXGLViewer::onUpdParallel(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(projection==PARALLEL)?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(projection==PARALLEL)?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2126,9 +2132,9 @@ long FXGLViewer::onCmdFront(FXObject*,FXSelector,void*){
 
 // Update sender
 long FXGLViewer::onUpdFront(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(EPS>Math::fabs(rotation[0]) && EPS>Math::fabs(rotation[1]) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-1.0)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(EPS>Math::fabs(rotation[0]) && EPS>Math::fabs(rotation[1]) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-1.0f)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2143,9 +2149,9 @@ long FXGLViewer::onCmdBack(FXObject*,FXSelector,void*){
 
 // Update sender
 long FXGLViewer::onUpdBack(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(EPS>Math::fabs(rotation[0]) && EPS>Math::fabs(rotation[1]+1.0) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3])) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(EPS>Math::fabs(rotation[0]) && EPS>Math::fabs(rotation[1]+1.0f) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3])) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2160,9 +2166,9 @@ long FXGLViewer::onCmdLeft(FXObject*,FXSelector,void*){
 
 // Update sender
 long FXGLViewer::onUpdLeft(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(EPS>Math::fabs(rotation[0]) && EPS>Math::fabs(rotation[1]-0.7071067811865) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-0.7071067811865)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(EPS>Math::fabs(rotation[0]) && EPS>Math::fabs(rotation[1]-0.7071067811865f) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-0.7071067811865f)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2177,9 +2183,9 @@ long FXGLViewer::onCmdRight(FXObject*,FXSelector,void*){
 
 // Update sender
 long FXGLViewer::onUpdRight(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(EPS>Math::fabs(rotation[0]) && EPS>Math::fabs(rotation[1]+0.7071067811865) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-0.7071067811865)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(EPS>Math::fabs(rotation[0]) && EPS>Math::fabs(rotation[1]+0.7071067811865f) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-0.7071067811865f)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2194,9 +2200,9 @@ long FXGLViewer::onCmdTop(FXObject*,FXSelector,void*){
 
 // Update sender
 long FXGLViewer::onUpdTop(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(EPS>Math::fabs(rotation[0]-0.7071067811865) && EPS>Math::fabs(rotation[1]) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-0.7071067811865)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(EPS>Math::fabs(rotation[0]-0.7071067811865f) && EPS>Math::fabs(rotation[1]) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-0.7071067811865f)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2211,9 +2217,9 @@ long FXGLViewer::onCmdBottom(FXObject*,FXSelector,void*){
 
 // Update sender
 long FXGLViewer::onUpdBottom(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(EPS>Math::fabs(rotation[0]+0.7071067811865) && EPS>Math::fabs(rotation[1]) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-0.7071067811865)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(EPS>Math::fabs(rotation[0]+0.7071067811865f) && EPS>Math::fabs(rotation[1]) && EPS>Math::fabs(rotation[2]) && EPS>Math::fabs(rotation[3]-0.7071067811865f)) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2523,7 +2529,7 @@ FXint FXGLViewer::renderFeedback(FXfloat *buffer,FXint x,FXint y,FXint w,FXint h
 // Read feedback buffer
 FXbool FXGLViewer::readFeedback(FXfloat*& buffer,FXint& used,FXint& size,FXint x,FXint y,FXint w,FXint h){
   FXbool ok=false;
-  buffer=NULL;
+  buffer=nullptr;
   used=0;
   size=10000;
   while(1){
@@ -2558,7 +2564,7 @@ void FXGLViewer::drawFeedback(FXDCPrint& pdc,const FXfloat* buffer,FXint used){
   FXint nvertices,smooth,token,i,p;
 
   // Draw background
-  pdc.outf("%lg %lg %lg C\n",background[0][0],background[0][1],background[0][2]);
+  pdc.outf("%lg %lg %lg C\n",(FXdouble)background[0][0],(FXdouble)background[0][1],(FXdouble)background[0][2]);
   pdc.outf("newpath\n");
   pdc.outf("%lg %lg moveto\n",0.0,0.0);
   pdc.outf("%lg %lg lineto\n",0.0,(FXdouble)height);
@@ -2576,18 +2582,18 @@ void FXGLViewer::drawFeedback(FXDCPrint& pdc,const FXfloat* buffer,FXint used){
 
       // Point primitive
       case GL_POINT_TOKEN:
-        pdc.outf("%lg %lg %lg %lg %lg P\n",buffer[p+0],buffer[p+1],buffer[p+3],buffer[p+4],buffer[p+5]);
+        pdc.outf("%lg %lg %lg %lg %lg P\n",(FXdouble)buffer[p+0],(FXdouble)buffer[p+1],(FXdouble)buffer[p+3],(FXdouble)buffer[p+4],(FXdouble)buffer[p+5]);
         p+=7;             // Each vertex element in the feedback buffer is 7 floats
         break;
 
       // Line primitive
       case GL_LINE_RESET_TOKEN:
       case GL_LINE_TOKEN:
-        if(Math::fabs(buffer[p+3]-buffer[p+7+3])<1E-4 || Math::fabs(buffer[p+4]-buffer[p+7+4])<1E-4 || Math::fabs(buffer[p+5]-buffer[p+7+5])<1E-4){
-          pdc.outf("%lg %lg %lg %lg %lg %lg %lg %lg %lg %lg SL\n",buffer[p+0],buffer[p+1],buffer[p+3],buffer[p+4],buffer[p+5], buffer[p+7+0],buffer[p+7+1],buffer[p+7+3],buffer[p+7+4],buffer[p+7+5]);
+        if(Math::fabs(buffer[p+3]-buffer[p+7+3])<1E-4f || Math::fabs(buffer[p+4]-buffer[p+7+4])<1E-4f || Math::fabs(buffer[p+5]-buffer[p+7+5])<1E-4f){
+          pdc.outf("%lg %lg %lg %lg %lg %lg %lg %lg %lg %lg SL\n",(FXdouble)buffer[p+0],(FXdouble)buffer[p+1],(FXdouble)buffer[p+3],(FXdouble)buffer[p+4],(FXdouble)buffer[p+5],(FXdouble)buffer[p+7+0],(FXdouble)buffer[p+7+1],(FXdouble)buffer[p+7+3],(FXdouble)buffer[p+7+4],(FXdouble)buffer[p+7+5]);
           }
         else{
-          pdc.outf("%lg %lg %lg %lg %lg %lg %lg L\n",buffer[p+0],buffer[p+1],buffer[p+7+0],buffer[p+7+1],buffer[p+3],buffer[p+4],buffer[p+5]);
+          pdc.outf("%lg %lg %lg %lg %lg %lg %lg L\n",(FXdouble)buffer[p+0],(FXdouble)buffer[p+1],(FXdouble)buffer[p+7+0],(FXdouble)buffer[p+7+1],(FXdouble)buffer[p+3],(FXdouble)buffer[p+4],(FXdouble)buffer[p+5]);
           }
         p+=14;            // Each vertex element in the feedback buffer is 7 GLfloats
         break;
@@ -2598,13 +2604,13 @@ void FXGLViewer::drawFeedback(FXDCPrint& pdc,const FXfloat* buffer,FXint used){
         if(nvertices==3){ // We assume polybusting has taken place already!
           smooth=0;
           for(i=1; i<nvertices; i++){
-            if(Math::fabs(buffer[p+3]-buffer[p+i*7+3])<1E-4 || Math::fabs(buffer[p+4]-buffer[p+i*7+4])<1E-4 || Math::fabs(buffer[p+5]-buffer[p+i*7+5])<1E-4){ smooth=1; break; }
+            if(Math::fabs(buffer[p+3]-buffer[p+i*7+3])<1E-4f || Math::fabs(buffer[p+4]-buffer[p+i*7+4])<1E-4f || Math::fabs(buffer[p+5]-buffer[p+i*7+5])<1E-4f){ smooth=1; break; }
             }
           if(smooth){
-            pdc.outf("%lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg ST\n",buffer[p+0],buffer[p+1],buffer[p+3],buffer[p+4],buffer[p+5], buffer[p+7+0],buffer[p+7+1],buffer[p+7+3],buffer[p+7+4],buffer[p+7+5], buffer[p+14+0],buffer[p+14+1],buffer[p+14+3],buffer[p+14+4],buffer[p+14+5]);
+            pdc.outf("%lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg %lg ST\n",(FXdouble)buffer[p+0],(FXdouble)buffer[p+1],(FXdouble)buffer[p+3],(FXdouble)buffer[p+4],(FXdouble)buffer[p+5],(FXdouble)buffer[p+7+0],(FXdouble)buffer[p+7+1],(FXdouble)buffer[p+7+3],(FXdouble)buffer[p+7+4],(FXdouble)buffer[p+7+5],(FXdouble)buffer[p+14+0],(FXdouble)buffer[p+14+1],(FXdouble)buffer[p+14+3],(FXdouble)buffer[p+14+4],(FXdouble)buffer[p+14+5]);
             }
           else{
-            pdc.outf("%lg %lg %lg %lg %lg %lg %lg %lg %lg T\n",buffer[p+0],buffer[p+1], buffer[p+7+0],buffer[p+7+1], buffer[p+14+0],buffer[p+14+1], buffer[p+3],buffer[p+4],buffer[p+5]);
+            pdc.outf("%lg %lg %lg %lg %lg %lg %lg %lg %lg T\n",(FXdouble)buffer[p+0],(FXdouble)buffer[p+1],(FXdouble)buffer[p+7+0],(FXdouble)buffer[p+7+1],(FXdouble)buffer[p+14+0],(FXdouble)buffer[p+14+1],(FXdouble)buffer[p+3],(FXdouble)buffer[p+4],(FXdouble)buffer[p+5]);
             }
           }
         p+=nvertices*7;   // Each vertex element in the feedback buffer is 7 GLfloats
@@ -2710,7 +2716,7 @@ long FXGLViewer::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr){
   if(event->target==objectType){
     FXTRACE((100,"requested objectType\n"));
 //    FXMemoryStream stream;
-//    stream.open(NULL,0,FXStreamSave);
+//    stream.open(nullptr,0,FXStreamSave);
 //    stream.takeBuffer(data,len);
 //    stream.close();
 //    setDNDData(FROM_CLIPBOARD,objectType,data,len);
@@ -2751,9 +2757,9 @@ long FXGLViewer::onCmdPasteSel(FXObject*,FXSelector,void*){
 long FXGLViewer::onCmdDeleteSel(FXObject*,FXSelector,void*){
   FXGLObject *obj[2];
   obj[0]=selection;
-  obj[1]=NULL;
+  obj[1]=nullptr;
   if(obj[0] && obj[0]->canDelete()){
-    handle(this,FXSEL(SEL_CHANGED,0),NULL);
+    handle(this,FXSEL(SEL_CHANGED,0),nullptr);
     handle(this,FXSEL(SEL_DELETED,0),(void*)obj);
     //delete obj[0];
     }
@@ -2767,8 +2773,8 @@ long FXGLViewer::onCmdDeleteSel(FXObject*,FXSelector,void*){
 // Update delete object
 long FXGLViewer::onUpdDeleteSel(FXObject* sender,FXSelector,void*){
   if(selection && selection->canDelete()){
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
     return 1;
     }
   return 0;
@@ -2778,8 +2784,8 @@ long FXGLViewer::onUpdDeleteSel(FXObject* sender,FXSelector,void*){
 // Update for current object
 long FXGLViewer::onUpdCurrent(FXObject* sender,FXSelector,void*){
   if(selection){
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-    sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+    sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
     return 1;
     }
   return 0;
@@ -2903,9 +2909,9 @@ long FXGLViewer::onCmdTurbo(FXObject*,FXSelector,void*){
 
 // Update Turbo Mode
 long FXGLViewer::onUpdTurbo(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,getTurboMode() ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,getTurboMode() ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2920,9 +2926,9 @@ long FXGLViewer::onCmdLighting(FXObject*,FXSelector,void*){
 
 // Update lighting
 long FXGLViewer::onUpdLighting(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(options&GLVIEWER_LIGHTING) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(options&GLVIEWER_LIGHTING) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2937,9 +2943,9 @@ long FXGLViewer::onCmdFog(FXObject*,FXSelector,void*){
 
 // Update fog
 long FXGLViewer::onUpdFog(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(options&GLVIEWER_FOG) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(options&GLVIEWER_FOG) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2954,9 +2960,9 @@ long FXGLViewer::onCmdDither(FXObject*,FXSelector,void*){
 
 // Update dithering
 long FXGLViewer::onUpdDither(FXObject* sender,FXSelector,void*){
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),NULL);
-  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
-  sender->handle(this,(options&GLVIEWER_DITHER) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_SHOW),nullptr);
+  sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),nullptr);
+  sender->handle(this,(options&GLVIEWER_DITHER) ? FXSEL(SEL_COMMAND,ID_CHECK) : FXSEL(SEL_COMMAND,ID_UNCHECK),nullptr);
   return 1;
   }
 
@@ -2967,14 +2973,14 @@ long FXGLViewer::onUpdDither(FXObject* sender,FXSelector,void*){
 // Handle drag-and-drop enter
 long FXGLViewer::onDNDEnter(FXObject* sender,FXSelector sel,void* ptr){
   if(FXGLCanvas::onDNDEnter(sender,sel,ptr)) return 1;
-  dropped=NULL;
+  dropped=nullptr;
   return 1;
   }
 
 // Handle drag-and-drop leave
 long FXGLViewer::onDNDLeave(FXObject* sender,FXSelector sel,void* ptr){
   if(FXGLCanvas::onDNDLeave(sender,sel,ptr)) return 1;
-  dropped=NULL;
+  dropped=nullptr;
   return 1;
   }
 
@@ -2987,7 +2993,7 @@ long FXGLViewer::onDNDMotion(FXObject* sender,FXSelector sel,void* ptr){
   if(FXGLCanvas::onDNDMotion(sender,sel,ptr)) return 1;
 
   // Dropped on some object
-  if((dropped=pick(event->win_x,event->win_y))!=NULL){
+  if((dropped=pick(event->win_x,event->win_y))!=nullptr){
 
     // Object agrees with drop type
     if(dropped->handle(this,sel,ptr)){
@@ -2996,7 +3002,7 @@ long FXGLViewer::onDNDMotion(FXObject* sender,FXSelector sel,void* ptr){
       }
 
     // Forget about the whole thing
-    dropped=NULL;
+    dropped=nullptr;
     return 0;
     }
 
