@@ -3,7 +3,7 @@
 *                            V i s u a l   C l a s s                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,7 +22,8 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
-#include "FXArray.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXElement.h"
@@ -94,7 +95,7 @@ using namespace FX;
 namespace FX {
 
 // Object implementation
-FXIMPLEMENT(FXGLVisual,FXVisual,NULL,0)
+FXIMPLEMENT(FXGLVisual,FXVisual,nullptr,0)
 
 
 // Deserialization
@@ -167,7 +168,7 @@ FXbool FXGLVisual::hasOpenGL(FXApp* application){
 #ifdef WIN32            // WIN32
     return true;
 #else                   // UNIX
-    return glXQueryExtension((Display*)application->getDisplay(),NULL,NULL);
+    return glXQueryExtension((Display*)application->getDisplay(),nullptr,nullptr);
 #endif
 #endif
     }
@@ -544,7 +545,7 @@ void FXGLVisual::create(){
       ::ReleaseDC(GetDesktopWindow(),hdc);
 
       // Make non-current
-      wglMakeCurrent(NULL,NULL);
+      wglMakeCurrent(nullptr,nullptr);
 #endif
       }
 
@@ -598,7 +599,7 @@ void FXGLVisual::create(){
             vitemplate.screen=DefaultScreen((Display*)getApp()->getDisplay());
             vi=XGetVisualInfo((Display*)getApp()->getDisplay(),VisualScreenMask,&vitemplate,&nvi);
             if(vi){
-              int defvisualid=XVisualIDFromVisual(DefaultVisual((Display*)getApp()->getDisplay(),DefaultScreen((Display*)getApp()->getDisplay())));
+              VisualID defvisualid=XVisualIDFromVisual(DefaultVisual((Display*)getApp()->getDisplay(),DefaultScreen((Display*)getApp()->getDisplay())));
               int samplebuffers=0;
               int bestmatch=1000000000;
               int best=-1;
