@@ -3,7 +3,7 @@
 *                             G a u g e   W i d g e t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2010,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2010,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,7 +22,8 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
-#include "FXArray.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXStream.h"
