@@ -3,7 +3,7 @@
 *                               I c o n - O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,7 +22,8 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
-#include "FXArray.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXElement.h"
@@ -69,7 +70,7 @@ using namespace FX;
 namespace FX {
 
 // Object implementation
-FXIMPLEMENT(FXIcon,FXImage,NULL,0)
+FXIMPLEMENT(FXIcon,FXImage,nullptr,0)
 
 
 // For deserialization
@@ -143,11 +144,11 @@ void FXIcon::create(){
       if(!xid){ fxerror("%s::create: unable to create image.\n",getClassName()); }
 
       // Make shape bitmap
-      shape=::CreateBitmap(FXMAX(width,1),FXMAX(height,1),1,1,NULL);
+      shape=::CreateBitmap(FXMAX(width,1),FXMAX(height,1),1,1,nullptr);
       if(!shape){ fxerror("%s::create: unable to create icon.\n",getClassName()); }
 
       // Make etch bitmap
-      etch=::CreateBitmap(FXMAX(width,1),FXMAX(height,1),1,1,NULL);
+      etch=::CreateBitmap(FXMAX(width,1),FXMAX(height,1),1,1,nullptr);
       if(!etch){ fxerror("%s::create: unable to create icon.\n",getClassName()); }
 #else
 
@@ -305,7 +306,7 @@ void FXIcon::render(){
       // Win95 you must pass in a non-NULL hdc for the first parameter; otherwise
       // this call to SetDIBits() will fail (in contrast, it works fine under
       // Windows NT if you pass in a NULL hdc).
-      hdcmsk=::CreateCompatibleDC(NULL);
+      hdcmsk=::CreateCompatibleDC(nullptr);
 
       // Set mask data
       if(!::SetDIBits(hdcmsk,(HBITMAP)shape,0,height,maskdata,(BITMAPINFO*)&bmi,DIB_RGB_COLORS)){
@@ -323,7 +324,7 @@ void FXIcon::render(){
       // We AND the image with the mask, then we can do faster and more
       // flicker-free icon painting later using the `black source' method
       HBITMAP hmsk=(HBITMAP)::SelectObject(hdcmsk,(HBITMAP)shape);
-      HDC hdcmem=::CreateCompatibleDC(NULL);
+      HDC hdcmem=::CreateCompatibleDC(nullptr);
       HBITMAP hbmp=(HBITMAP)::SelectObject(hdcmem,(HBITMAP)xid);
       ::SetBkColor(hdcmem,RGB(0,0,0));                // 1 -> black
       ::SetTextColor(hdcmem,RGB(255,255,255));        // 0 -> white
@@ -343,7 +344,7 @@ void FXIcon::render(){
 // Render icon X Windows
 void FXIcon::render(){
   if(xid){
-    XImage *xim=NULL;
+    XImage *xim=nullptr;
     FXbool shmi=false;
     FXColor *img;
     FXint x,y;
@@ -369,11 +370,11 @@ void FXIcon::render(){
       // First try XShm
 #ifdef HAVE_XSHM_H
       if(shmi){
-        xim=XShmCreateImage((Display*)getApp()->getDisplay(),(Visual*)visual->visual,1,ZPixmap,NULL,&shminfo,width,height);
+        xim=XShmCreateImage((Display*)getApp()->getDisplay(),(Visual*)visual->visual,1,ZPixmap,nullptr,&shminfo,width,height);
         if(!xim){ shmi=0; }
         if(shmi){
           shminfo.shmid=shmget(IPC_PRIVATE,xim->bytes_per_line*xim->height,IPC_CREAT|0777);
-          if(shminfo.shmid==-1){ xim->data=NULL; XDestroyImage(xim); xim=NULL; shmi=0; }
+          if(shminfo.shmid==-1){ xim->data=nullptr; XDestroyImage(xim); xim=nullptr; shmi=0; }
           if(shmi){
             shminfo.shmaddr=xim->data=(char*)shmat(shminfo.shmid,0,0);
             shminfo.readOnly=false;
@@ -388,7 +389,7 @@ void FXIcon::render(){
       if(!shmi){
 
         // Try create image
-        xim=XCreateImage((Display*)getApp()->getDisplay(),(Visual*)visual->visual,1,ZPixmap,0,NULL,width,height,32,0);
+        xim=XCreateImage((Display*)getApp()->getDisplay(),(Visual*)visual->visual,1,ZPixmap,0,nullptr,width,height,32,0);
         if(!xim){ fxerror("%s::render: unable to render icon.\n",getClassName()); }
 
         // Try create temp pixel store
@@ -497,7 +498,7 @@ void FXIcon::render(){
       if(shmi){
         FXTRACE((150,"Bitmap XSHM detached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
         XShmDetach((Display*)getApp()->getDisplay(),&shminfo);
-        xim->data=NULL;
+        xim->data=nullptr;
         XDestroyImage(xim);
         shmdt(shminfo.shmaddr);
         shmctl(shminfo.shmid,IPC_RMID,0);
@@ -537,11 +538,11 @@ void FXIcon::resize(FXint w,FXint h){
       if(!xid){ fxerror("%s::resize: unable to resize image.\n",getClassName()); }
 
       // Make shape bitmap
-      shape=::CreateBitmap(w,h,1,1,NULL);
+      shape=::CreateBitmap(w,h,1,1,nullptr);
       if(!shape){ fxerror("%s::create: unable to create icon.\n",getClassName()); }
 
       // Make etch bitmap
-      etch=::CreateBitmap(w,h,1,1,NULL);
+      etch=::CreateBitmap(w,h,1,1,nullptr);
       if(!etch){ fxerror("%s::create: unable to create icon.\n",getClassName()); }
 #else
       // Get depth (should use visual!!)
