@@ -3,7 +3,7 @@
 *                             I m a g e    O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,7 +22,8 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
-#include "FXArray.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXElement.h"
@@ -162,6 +163,7 @@
 
 #define TOPIC_CONSTRUCT 1000
 #define TOPIC_CREATION  1001
+#define TOPIC_DETAIL    1002
 
 #define DISPLAY(app) ((Display*)((app)->display))
 
@@ -194,11 +196,11 @@ enum {
 
 
 // Object implementation
-FXIMPLEMENT(FXImage,FXDrawable,NULL,0)
+FXIMPLEMENT(FXImage,FXDrawable,nullptr,0)
 
 
 // For deserialization
-FXImage::FXImage():data(NULL),options(0){
+FXImage::FXImage():data(nullptr),options(0){
   }
 
 
@@ -207,7 +209,7 @@ FXImage::FXImage(FXApp* a,const FXColor *pix,FXuint opts,FXint w,FXint h):FXDraw
   FXTRACE((TOPIC_CONSTRUCT,"FXImage::FXImage %p\n",this));
   FXASSERT((opts&~(IMAGE_OWNED|IMAGE_MASK))==0);
   visual=getApp()->getDefaultVisual();
-  data=(FXColor*)pix;
+  data=const_cast<FXColor*>(pix);
   options=opts;
   if(!data && (options&IMAGE_OWNED)){           // This is confusing use of IMAGE_OWNED
     if(!callocElms(data,width*height)){ throw FXMemoryException("unable to construct image"); }
@@ -291,7 +293,7 @@ FXbool FXImage::hasAlpha() const {
 
 // Return the device context; the image already selected into it
 FXID FXImage::GetDC() const {
-  HDC hdc=::CreateCompatibleDC(NULL);
+  HDC hdc=::CreateCompatibleDC(nullptr);
   SelectObject(hdc,(HBITMAP)xid);
   return hdc;
   }
@@ -419,7 +421,7 @@ void FXImage::restore(){
       if(!pixels){ throw FXMemoryException("unable to restore image"); }
 
       // Make device context
-      hdcmem=::CreateCompatibleDC(NULL);
+      hdcmem=::CreateCompatibleDC(nullptr);
       if(!GetDIBits(hdcmem,(HBITMAP)xid,0,height,pixels,&bmi,DIB_RGB_COLORS)){
         throw FXImageException("unable to restore image");
         }
@@ -470,7 +472,7 @@ void FXImage::restore(){
     FXPixel redmask,greenmask,bluemask;
     int size,i;
     FXbool shmi=false;
-    XImage *xim=NULL;
+    XImage *xim=nullptr;
     Visual *vis;
     FXint x,y;
     FXuchar *img;
@@ -511,16 +513,16 @@ void FXImage::restore(){
       // First try XShm
 #ifdef HAVE_XSHM_H
       if(shmi){
-        xim=XShmCreateImage(DISPLAY(getApp()),vis,visual->depth,(visual->depth==1)?XYPixmap:ZPixmap,NULL,&shminfo,width,height);
+        xim=XShmCreateImage(DISPLAY(getApp()),vis,visual->depth,(visual->depth==1)?XYPixmap:ZPixmap,nullptr,&shminfo,width,height);
         if(!xim){ shmi=0; }
         if(shmi){
           shminfo.shmid=shmget(IPC_PRIVATE,xim->bytes_per_line*xim->height,IPC_CREAT|0777);
-          if(shminfo.shmid==-1){ xim->data=NULL; XDestroyImage(xim); xim=NULL; shmi=0; }
+          if(shminfo.shmid==-1){ xim->data=nullptr; XDestroyImage(xim); xim=nullptr; shmi=0; }
           if(shmi){
             shminfo.shmaddr=xim->data=(char*)shmat(shminfo.shmid,0,0);
             shminfo.readOnly=false;
             XShmAttach(DISPLAY(getApp()),&shminfo);
-            FXTRACE((150,"RGBPixmap XSHM attached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
+            FXTRACE((TOPIC_DETAIL,"RGBPixmap XSHM attached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
             XShmGetImage(DISPLAY(getApp()),xid,xim,0,0,AllPlanes);
             XSync(DISPLAY(getApp()),False);
             }
@@ -537,17 +539,17 @@ void FXImage::restore(){
       // Should have succeeded
       FXASSERT(xim);
 
-      FXTRACE((150,"im width = %d\n",xim->width));
-      FXTRACE((150,"im height = %d\n",xim->height));
-      FXTRACE((150,"im format = %s\n",xim->format==XYBitmap?"XYBitmap":xim->format==XYPixmap?"XYPixmap":"ZPixmap"));
-      FXTRACE((150,"im byte_order = %s\n",(xim->byte_order==MSBFirst)?"MSBFirst":"LSBFirst"));
-      FXTRACE((150,"im bitmap_unit = %d\n",xim->bitmap_unit));
-      FXTRACE((150,"im bitmap_bit_order = %s\n",(xim->bitmap_bit_order==MSBFirst)?"MSBFirst":"LSBFirst"));
-      FXTRACE((150,"im bitmap_pad = %d\n",xim->bitmap_pad));
-      FXTRACE((150,"im bitmap_unit = %d\n",xim->bitmap_unit));
-      FXTRACE((150,"im depth = %d\n",xim->depth));
-      FXTRACE((150,"im bytes_per_line = %d\n",xim->bytes_per_line));
-      FXTRACE((150,"im bits_per_pixel = %d\n",xim->bits_per_pixel));
+      FXTRACE((TOPIC_DETAIL,"im width = %d\n",xim->width));
+      FXTRACE((TOPIC_DETAIL,"im height = %d\n",xim->height));
+      FXTRACE((TOPIC_DETAIL,"im format = %s\n",xim->format==XYBitmap?"XYBitmap":xim->format==XYPixmap?"XYPixmap":"ZPixmap"));
+      FXTRACE((TOPIC_DETAIL,"im byte_order = %s\n",(xim->byte_order==MSBFirst)?"MSBFirst":"LSBFirst"));
+      FXTRACE((TOPIC_DETAIL,"im bitmap_unit = %d\n",xim->bitmap_unit));
+      FXTRACE((TOPIC_DETAIL,"im bitmap_bit_order = %s\n",(xim->bitmap_bit_order==MSBFirst)?"MSBFirst":"LSBFirst"));
+      FXTRACE((TOPIC_DETAIL,"im bitmap_pad = %d\n",xim->bitmap_pad));
+      FXTRACE((TOPIC_DETAIL,"im bitmap_unit = %d\n",xim->bitmap_unit));
+      FXTRACE((TOPIC_DETAIL,"im depth = %d\n",xim->depth));
+      FXTRACE((TOPIC_DETAIL,"im bytes_per_line = %d\n",xim->bytes_per_line));
+      FXTRACE((TOPIC_DETAIL,"im bits_per_pixel = %d\n",xim->bits_per_pixel));
 
 
       {
@@ -636,7 +638,7 @@ void FXImage::restore(){
       // Destroy image
 #ifdef HAVE_XSHM_H
       if(shmi){
-        FXTRACE((150,"RGBPixmap XSHM detached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
+        FXTRACE((TOPIC_DETAIL,"RGBPixmap XSHM detached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
         XShmDetach(DISPLAY(getApp()),&shminfo);
         XDestroyImage(xim);
         shmdt(shminfo.shmaddr);
@@ -713,7 +715,7 @@ void FXImage::render(){
       // Win95 you must pass in a non-NULL hdc for the first parameter; otherwise
       // this call to SetDIBits() will fail (in contrast, it works fine under
       // Windows NT if you pass in a NULL hdc).
-      hdcmem=::CreateCompatibleDC(NULL);
+      hdcmem=::CreateCompatibleDC(nullptr);
       if(!SetDIBits(hdcmem,(HBITMAP)xid,0,height,pixels,&bmi,DIB_RGB_COLORS)){
 //    if(!StretchDIBits(hdcmem,0,0,width,height,0,0,width,height,pixels,&bmi,DIB_RGB_COLORS,SRCCOPY)){
         throw FXImageException("unable to render image");
@@ -732,7 +734,7 @@ void FXImage::render(){
 // True generic mode
 void FXImage::render_true_N_fast(void *xim,FXuchar *img){
   FXint x,y;
-  FXTRACE((150,"True MSB/LSB N bpp render nearest\n"));
+  FXTRACE((TOPIC_DETAIL,"True MSB/LSB N bpp render nearest\n"));
   y=0;
   do{
     x=0;
@@ -749,7 +751,7 @@ void FXImage::render_true_N_fast(void *xim,FXuchar *img){
 // True generic mode
 void FXImage::render_true_N_dither(void *xim,FXuchar *img){
   FXint x,y,d;
-  FXTRACE((150,"True MSB/LSB N bpp render dither\n"));
+  FXTRACE((TOPIC_DETAIL,"True MSB/LSB N bpp render dither\n"));
   y=0;
   do{
     x=0;
@@ -771,7 +773,7 @@ void FXImage::render_true_24(void *xim,FXuchar *img){
   FXPixel val;
   FXint w,h;
   if(((XImage*)xim)->byte_order==MSBFirst){    // MSB
-    FXTRACE((150,"True MSB 24bpp render\n"));
+    FXTRACE((TOPIC_DETAIL,"True MSB 24bpp render\n"));
     h=height-1;
     do{
       w=width-1;
@@ -789,7 +791,7 @@ void FXImage::render_true_24(void *xim,FXuchar *img){
     while(--h>=0);
     }
   else{                             // LSB
-    FXTRACE((150,"True LSB 24bpp render\n"));
+    FXTRACE((TOPIC_DETAIL,"True LSB 24bpp render\n"));
     h=height-1;
     do{
       w=width-1;
@@ -818,7 +820,7 @@ void FXImage::render_true_32(void *xim,FXuchar *img){
 
   // Byte order matches
   if(((XImage*)xim)->byte_order == FOX_BIGENDIAN){
-    FXTRACE((150,"True MSB/LSB 32bpp render\n"));
+    FXTRACE((TOPIC_DETAIL,"True MSB/LSB 32bpp render\n"));
     h=height-1;
     do{
       w=width-1;
@@ -835,7 +837,7 @@ void FXImage::render_true_32(void *xim,FXuchar *img){
 
   // MSB Byte order
   else if(((XImage*)xim)->byte_order==MSBFirst){
-    FXTRACE((150,"True MSB 32bpp render\n"));
+    FXTRACE((TOPIC_DETAIL,"True MSB 32bpp render\n"));
     h=height-1;
     do{
       w=width-1;
@@ -856,7 +858,7 @@ void FXImage::render_true_32(void *xim,FXuchar *img){
 
   // LSB Byte order
   else{
-    FXTRACE((150,"True LSB 32bpp render\n"));
+    FXTRACE((TOPIC_DETAIL,"True LSB 32bpp render\n"));
     h=height-1;
     do{
       w=width-1;
@@ -886,7 +888,7 @@ void FXImage::render_true_16_fast(void *xim,FXuchar *img){
 
   // Byte order matches
   if(((XImage*)xim)->byte_order == FOX_BIGENDIAN){
-    FXTRACE((150,"True MSB/LSB 16bpp 5,6,5/5,5,5 render nearest\n"));
+    FXTRACE((TOPIC_DETAIL,"True MSB/LSB 16bpp 5,6,5/5,5,5 render nearest\n"));
     h=height-1;
     do{
       w=width-1;
@@ -903,7 +905,7 @@ void FXImage::render_true_16_fast(void *xim,FXuchar *img){
 
   // MSB Byte order
   else if(((XImage*)xim)->byte_order==MSBFirst){
-    FXTRACE((150,"True MSB 16bpp 5,6,5/5,5,5 render nearest\n"));
+    FXTRACE((TOPIC_DETAIL,"True MSB 16bpp 5,6,5/5,5,5 render nearest\n"));
     h=height-1;
     do{
       w=width-1;
@@ -922,7 +924,7 @@ void FXImage::render_true_16_fast(void *xim,FXuchar *img){
 
   // LSB Byte order
   else{
-    FXTRACE((150,"True LSB 16bpp 5,6,5/5,5,5 render nearest\n"));
+    FXTRACE((TOPIC_DETAIL,"True LSB 16bpp 5,6,5/5,5,5 render nearest\n"));
     h=height-1;
     do{
       w=width-1;
@@ -950,7 +952,7 @@ void FXImage::render_true_16_dither(void *xim,FXuchar *img){
 
   // Byte order matches
   if(((XImage*)xim)->byte_order == FOX_BIGENDIAN){
-    FXTRACE((150,"True MSB/LSB 16bpp 5,6,5/5,5,5 render dither\n"));
+    FXTRACE((TOPIC_DETAIL,"True MSB/LSB 16bpp 5,6,5/5,5,5 render dither\n"));
     h=height-1;
     do{
       w=width-1;
@@ -968,7 +970,7 @@ void FXImage::render_true_16_dither(void *xim,FXuchar *img){
 
   // MSB Byte order
   else if(((XImage*)xim)->byte_order==MSBFirst){
-    FXTRACE((150,"True MSB 16bpp 5,6,5/5,5,5 render dither\n"));
+    FXTRACE((TOPIC_DETAIL,"True MSB 16bpp 5,6,5/5,5,5 render dither\n"));
     h=height-1;
     do{
       w=width-1;
@@ -988,7 +990,7 @@ void FXImage::render_true_16_dither(void *xim,FXuchar *img){
 
   // LSB Byte order
   else{
-    FXTRACE((150,"True LSB 16bpp 5,6,5/5,5,5 render dither\n"));
+    FXTRACE((TOPIC_DETAIL,"True LSB 16bpp 5,6,5/5,5,5 render dither\n"));
     h=height-1;
     do{
       w=width-1;
@@ -1013,7 +1015,7 @@ void FXImage::render_true_8_fast(void *xim,FXuchar *img){
   FXuint jmp=((XImage*)xim)->bytes_per_line-width;
   FXuchar *pix=(FXuchar*)((XImage*)xim)->data;
   FXint w,h;
-  FXTRACE((150,"True MSB/LSB 8bpp render nearest\n"));
+  FXTRACE((TOPIC_DETAIL,"True MSB/LSB 8bpp render nearest\n"));
   h=height-1;
   do{
     w=width-1;
@@ -1034,7 +1036,7 @@ void FXImage::render_true_8_dither(void *xim,FXuchar *img){
   FXuint jmp=((XImage*)xim)->bytes_per_line-width;
   FXuchar *pix=(FXuchar*)((XImage*)xim)->data;
   FXint w,h,d;
-  FXTRACE((150,"True MSB/LSB 8bpp render dither\n"));
+  FXTRACE((TOPIC_DETAIL,"True MSB/LSB 8bpp render dither\n"));
   h=height-1;
   do{
     w=width-1;
@@ -1058,7 +1060,7 @@ void FXImage::render_index_4_fast(void *xim,FXuchar *img){
   FXuint val,half;
   FXint w,h;
   if(((XImage*)xim)->byte_order==MSBFirst){    // MSB
-    FXTRACE((150,"Index MSB 4bpp render nearest\n"));
+    FXTRACE((TOPIC_DETAIL,"Index MSB 4bpp render nearest\n"));
     h=height-1;
     do{
       w=width-1;
@@ -1076,7 +1078,7 @@ void FXImage::render_index_4_fast(void *xim,FXuchar *img){
     while(--h>=0);
     }
   else{                               // LSB
-    FXTRACE((150,"Index LSB 4bpp render nearest\n"));
+    FXTRACE((TOPIC_DETAIL,"Index LSB 4bpp render nearest\n"));
     h=height-1;
     do{
       w=width-1;
@@ -1103,7 +1105,7 @@ void FXImage::render_index_4_dither(void *xim,FXuchar *img){
   FXuint val,half,d;
   FXint w,h;
   if(((XImage*)xim)->byte_order==MSBFirst){    // MSB
-    FXTRACE((150,"Index MSB 4bpp render dither\n"));
+    FXTRACE((TOPIC_DETAIL,"Index MSB 4bpp render dither\n"));
     h=height-1;
     do{
       w=width-1;
@@ -1122,7 +1124,7 @@ void FXImage::render_index_4_dither(void *xim,FXuchar *img){
     while(--h>=0);
     }
   else{                               // LSB
-    FXTRACE((150,"Index LSB 4bpp render dither\n"));
+    FXTRACE((TOPIC_DETAIL,"Index LSB 4bpp render dither\n"));
     h=height-1;
     do{
       w=width-1;
@@ -1148,7 +1150,7 @@ void FXImage::render_index_8_fast(void *xim,FXuchar *img){
   FXuint jmp=((XImage*)xim)->bytes_per_line-width;
   FXuchar *pix=(FXuchar*)((XImage*)xim)->data;
   FXint w,h;
-  FXTRACE((150,"Index MSB/LSB 8bpp render nearest\n"));
+  FXTRACE((TOPIC_DETAIL,"Index MSB/LSB 8bpp render nearest\n"));
   h=height-1;
   do{
     w=width-1;
@@ -1169,7 +1171,7 @@ void FXImage::render_index_8_dither(void *xim,FXuchar *img){
   FXuint jmp=((XImage*)xim)->bytes_per_line-width;
   FXuchar *pix=(FXuchar*)((XImage*)xim)->data;
   FXint w,h,d;
-  FXTRACE((150,"Index MSB/LSB 8bpp render dither\n"));
+  FXTRACE((TOPIC_DETAIL,"Index MSB/LSB 8bpp render dither\n"));
   h=height-1;
   do{
     w=width-1;
@@ -1189,7 +1191,7 @@ void FXImage::render_index_8_dither(void *xim,FXuchar *img){
 // Render generic N bit index color mode
 void FXImage::render_index_N_fast(void *xim,FXuchar *img){
   FXint x,y;
-  FXTRACE((150,"Index MSB/LSB N bpp render nearest\n"));
+  FXTRACE((TOPIC_DETAIL,"Index MSB/LSB N bpp render nearest\n"));
   y=0;
   do{
     x=0;
@@ -1206,7 +1208,7 @@ void FXImage::render_index_N_fast(void *xim,FXuchar *img){
 // Render generic N bit index color mode
 void FXImage::render_index_N_dither(void *xim,FXuchar *img){
   FXint x,y,d;
-  FXTRACE((150,"Index MSB/LSB N bpp render dither\n"));
+  FXTRACE((TOPIC_DETAIL,"Index MSB/LSB N bpp render dither\n"));
   y=0;
   do{
     x=0;
@@ -1226,7 +1228,7 @@ void FXImage::render_gray_8_fast(void *xim,FXuchar *img){
   FXuchar *pix=(FXuchar*)((XImage*)xim)->data;
   FXuint jmp=((XImage*)xim)->bytes_per_line-width;
   FXint w,h;
-  FXTRACE((150,"Gray MSB/LSB 8bpp render nearest\n"));
+  FXTRACE((TOPIC_DETAIL,"Gray MSB/LSB 8bpp render nearest\n"));
   h=height-1;
   do{
     w=width-1;
@@ -1247,7 +1249,7 @@ void FXImage::render_gray_8_dither(void *xim,FXuchar *img){
   FXuchar *pix=(FXuchar*)((XImage*)xim)->data;
   FXuint jmp=((XImage*)xim)->bytes_per_line-width;
   FXint w,h;
-  FXTRACE((150,"Gray MSB/LSB 8bpp render dither\n"));
+  FXTRACE((TOPIC_DETAIL,"Gray MSB/LSB 8bpp render dither\n"));
   h=height-1;
   do{
     w=width-1;
@@ -1266,7 +1268,7 @@ void FXImage::render_gray_8_dither(void *xim,FXuchar *img){
 // Render generic N bit gray mode
 void FXImage::render_gray_N_fast(void *xim,FXuchar *img){
   FXint x,y;
-  FXTRACE((150,"Gray MSB/LSB N bpp render nearest\n"));
+  FXTRACE((TOPIC_DETAIL,"Gray MSB/LSB N bpp render nearest\n"));
   y=0;
   do{
     x=0;
@@ -1283,7 +1285,7 @@ void FXImage::render_gray_N_fast(void *xim,FXuchar *img){
 // Render generic N bit gray mode
 void FXImage::render_gray_N_dither(void *xim,FXuchar *img){
   FXint x,y;
-  FXTRACE((150,"Gray MSB/LSB N bpp render dither\n"));
+  FXTRACE((TOPIC_DETAIL,"Gray MSB/LSB N bpp render dither\n"));
   y=0;
   do{
     x=0;
@@ -1300,7 +1302,7 @@ void FXImage::render_gray_N_dither(void *xim,FXuchar *img){
 // Render monochrome mode
 void FXImage::render_mono_1_fast(void *xim,FXuchar *img){
   FXint x,y;
-  FXTRACE((150,"Monochrome MSB/LSB 1bpp render nearest\n"));
+  FXTRACE((TOPIC_DETAIL,"Monochrome MSB/LSB 1bpp render nearest\n"));
   y=0;
   do{
     x=0;
@@ -1317,7 +1319,7 @@ void FXImage::render_mono_1_fast(void *xim,FXuchar *img){
 // Render monochrome mode
 void FXImage::render_mono_1_dither(void *xim,FXuchar *img){
   FXint x,y;
-  FXTRACE((150,"Monochrome MSB/LSB 1bpp render dither\n"));
+  FXTRACE((TOPIC_DETAIL,"Monochrome MSB/LSB 1bpp render dither\n"));
   y=0;
   do{
     x=0;
@@ -1335,7 +1337,7 @@ void FXImage::render_mono_1_dither(void *xim,FXuchar *img){
 void FXImage::render(){
   if(xid){
     FXbool shmi=false;
-    XImage *xim=NULL;
+    XImage *xim=nullptr;
     XGCValues values;
     GC gc;
 #ifdef HAVE_XSHM_H
@@ -1360,16 +1362,16 @@ void FXImage::render(){
       // First try XShm
 #ifdef HAVE_XSHM_H
       if(shmi){
-        xim=XShmCreateImage(DISPLAY(getApp()),(Visual*)visual->visual,visual->depth,(visual->depth==1)?XYPixmap:ZPixmap,NULL,&shminfo,width,height);
+        xim=XShmCreateImage(DISPLAY(getApp()),(Visual*)visual->visual,visual->depth,(visual->depth==1)?XYPixmap:ZPixmap,nullptr,&shminfo,width,height);
         if(!xim){ shmi=0; }
         if(shmi){
           shminfo.shmid=shmget(IPC_PRIVATE,xim->bytes_per_line*xim->height,IPC_CREAT|0777);
-          if(shminfo.shmid==-1){ xim->data=NULL; XDestroyImage(xim); xim=NULL; shmi=0; }
+          if(shminfo.shmid==-1){ xim->data=nullptr; XDestroyImage(xim); xim=nullptr; shmi=0; }
           if(shmi){
             shminfo.shmaddr=xim->data=(char*)shmat(shminfo.shmid,0,0);
             shminfo.readOnly=false;
             XShmAttach(DISPLAY(getApp()),&shminfo);
-            FXTRACE((150,"RGBPixmap XSHM attached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
+            FXTRACE((TOPIC_DETAIL,"RGBPixmap XSHM attached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
             }
           }
         }
@@ -1377,7 +1379,7 @@ void FXImage::render(){
 
       // Try the old fashioned way
       if(!shmi){
-        xim=XCreateImage(DISPLAY(getApp()),(Visual*)visual->visual,visual->depth,(visual->depth==1)?XYPixmap:ZPixmap,0,NULL,width,height,32,0);
+        xim=XCreateImage(DISPLAY(getApp()),(Visual*)visual->visual,visual->depth,(visual->depth==1)?XYPixmap:ZPixmap,0,nullptr,width,height,32,0);
         if(!xim){ throw FXImageException("unable to render image"); }
 
         // Try create temp pixel store
@@ -1387,17 +1389,17 @@ void FXImage::render(){
       // Should have succeeded
       FXASSERT(xim);
 
-      FXTRACE((150,"im width = %d\n",xim->width));
-      FXTRACE((150,"im height = %d\n",xim->height));
-      FXTRACE((150,"im format = %s\n",xim->format==XYBitmap?"XYBitmap":xim->format==XYPixmap?"XYPixmap":"ZPixmap"));
-      FXTRACE((150,"im byte_order = %s\n",(xim->byte_order==MSBFirst)?"MSBFirst":"LSBFirst"));
-      FXTRACE((150,"im bitmap_unit = %d\n",xim->bitmap_unit));
-      FXTRACE((150,"im bitmap_bit_order = %s\n",(xim->bitmap_bit_order==MSBFirst)?"MSBFirst":"LSBFirst"));
-      FXTRACE((150,"im bitmap_pad = %d\n",xim->bitmap_pad));
-      FXTRACE((150,"im bitmap_unit = %d\n",xim->bitmap_unit));
-      FXTRACE((150,"im depth = %d\n",xim->depth));
-      FXTRACE((150,"im bytes_per_line = %d\n",xim->bytes_per_line));
-      FXTRACE((150,"im bits_per_pixel = %d\n",xim->bits_per_pixel));
+      FXTRACE((TOPIC_DETAIL,"im width = %d\n",xim->width));
+      FXTRACE((TOPIC_DETAIL,"im height = %d\n",xim->height));
+      FXTRACE((TOPIC_DETAIL,"im format = %s\n",xim->format==XYBitmap?"XYBitmap":xim->format==XYPixmap?"XYPixmap":"ZPixmap"));
+      FXTRACE((TOPIC_DETAIL,"im byte_order = %s\n",(xim->byte_order==MSBFirst)?"MSBFirst":"LSBFirst"));
+      FXTRACE((TOPIC_DETAIL,"im bitmap_unit = %d\n",xim->bitmap_unit));
+      FXTRACE((TOPIC_DETAIL,"im bitmap_bit_order = %s\n",(xim->bitmap_bit_order==MSBFirst)?"MSBFirst":"LSBFirst"));
+      FXTRACE((TOPIC_DETAIL,"im bitmap_pad = %d\n",xim->bitmap_pad));
+      FXTRACE((TOPIC_DETAIL,"im bitmap_unit = %d\n",xim->bitmap_unit));
+      FXTRACE((TOPIC_DETAIL,"im depth = %d\n",xim->depth));
+      FXTRACE((TOPIC_DETAIL,"im bytes_per_line = %d\n",xim->bytes_per_line));
+      FXTRACE((TOPIC_DETAIL,"im bits_per_pixel = %d\n",xim->bits_per_pixel));
 
       // Determine what to do
       switch(visual->getType()){
@@ -1486,9 +1488,9 @@ void FXImage::render(){
       if(shmi){
         XShmPutImage(DISPLAY(getApp()),xid,gc,xim,0,0,0,0,width,height,False);
         XSync(DISPLAY(getApp()),False);
-        FXTRACE((150,"RGBPixmap XSHM detached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
+        FXTRACE((TOPIC_DETAIL,"RGBPixmap XSHM detached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
         XShmDetach(DISPLAY(getApp()),&shminfo);
-        xim->data=NULL;
+        xim->data=nullptr;
         XDestroyImage(xim);
         shmdt(shminfo.shmaddr);
         shmctl(shminfo.shmid,IPC_RMID,0);
@@ -1515,7 +1517,7 @@ void FXImage::release(){
     options&=~IMAGE_OWNED;
     freeElms(data);
     }
-  data=NULL;
+  data=nullptr;
   }
 
 
@@ -2684,7 +2686,7 @@ FXbool FXImage::loadPixels(FXStream& store){
 
 // Save data
 void FXImage::save(FXStream& store) const {
-  FXuchar haspixels=(data!=NULL);
+  FXuchar haspixels=(data!=nullptr);
   FXDrawable::save(store);
   store << options;
   store << haspixels;
