@@ -3,7 +3,7 @@
 *            S i n g l e - P r e c i s i o n   3 x 3   M a t r i x              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2003,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2003,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,10 +22,11 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
+#include "FXElement.h"
 #include "FXArray.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXStream.h"
-#include "FXObject.h"
 #include "FXVec2f.h"
 #include "FXVec3f.h"
 #include "FXVec4f.h"
@@ -629,6 +630,36 @@ FXMat3f& FXMat3f::scale(FXfloat s){
   }
 
 
+// Set mirror-matrix with plane normal n, which performs
+// the following operation:
+//
+//      Y    N    X
+//       \   |   /
+//        \  |  /
+//         \ | /
+//          \|/
+//   --------*--------
+//
+//    Y = X - 2 * (N.X) * X
+//
+FXMat3f& FXMat3f::mirror(const FXVec3f& n){
+  FXfloat tnx=-2.0f*n.x;
+  FXfloat tny=-2.0f*n.y;
+  FXfloat tnz=-2.0f*n.z;
+  FXfloat tnxnx=tnx*n.x;
+  FXfloat tnyny=tny*n.y;
+  FXfloat tnznz=tnz*n.z;
+  FXfloat tnxny=tnx*n.y;
+  FXfloat tnxnz=tnx*n.z;
+  FXfloat tnynz=tny*n.z;
+  FXMat3f reflect(tnxnx+1.0f,tnxny,tnxnz,
+                  tnxny,tnyny+1.0f,tnynz,
+                  tnxnz,tnynz,tnznz+1.0f);
+  *this *= reflect;
+  return *this;
+  }
+
+
 // Calculate determinant
 FXfloat FXMat3f::det() const {
   return m[0][0]*(m[1][1]*m[2][2]-m[2][1]*m[1][2])+
