@@ -3,7 +3,7 @@
 *                P a c k e r   C o n t a i n e r   O b j e c t                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,7 +22,9 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
+#include "FXElement.h"
 #include "FXArray.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXStream.h"
@@ -374,7 +376,7 @@ long FXPacker::onFocusUp(FXObject*,FXSelector,void* ptr){
   if(getFocus()){
     cury=getFocus()->getY();
     while(1){
-      child=NULL;
+      child=nullptr;
       childy=-10000000;
       for(c=getFirst(); c; c=c->getNext()){
         if(c->shown() && c->getY()<cury && childy<c->getY()){ childy=c->getY(); child=c; }
@@ -406,7 +408,7 @@ long FXPacker::onFocusDown(FXObject*,FXSelector,void* ptr){
   if(getFocus()){
     cury=getFocus()->getY();
     while(1){
-      child=NULL;
+      child=nullptr;
       childy=10000000;
       for(c=getFirst(); c; c=c->getNext()){
         if(c->shown() && cury<c->getY() && c->getY()<childy){ childy=c->getY(); child=c; }
@@ -438,7 +440,7 @@ long FXPacker::onFocusLeft(FXObject*,FXSelector,void* ptr){
   if(getFocus()){
     curx=getFocus()->getX();
     while(1){
-      child=NULL;
+      child=nullptr;
       childx=-10000000;
       for(c=getFirst(); c; c=c->getNext()){
         if(c->shown() && c->getX()<curx && childx<c->getX()){ childx=c->getX(); child=c; }
@@ -470,7 +472,7 @@ long FXPacker::onFocusRight(FXObject*,FXSelector,void* ptr){
   if(getFocus()){
     curx=getFocus()->getX();
     while(1){
-      child=NULL;
+      child=nullptr;
       childx=10000000;
       for(c=getFirst(); c; c=c->getNext()){
         if(c->shown() && curx<c->getX() && c->getX()<childx){ childx=c->getX(); child=c; }
