@@ -3,7 +3,7 @@
 *                  P a t h   N a m e   M a n i p u l a t i o n                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,14 +21,18 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxchar.h"
 #include "fxascii.h"
 #include "fxunicode.h"
+#include "FXElement.h"
 #include "FXArray.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXStream.h"
 #include "FXString.h"
 #include "FXPath.h"
 #include "FXSystem.h"
+#include "FXIO.h"
 #include "FXStat.h"
 #include "FXFile.h"
 #include "FXDir.h"
@@ -37,7 +41,6 @@
 #endif
 
 
-
 /*
   Notes:
 
@@ -75,7 +78,6 @@
       - The first character of the name must not be numeric.
 */
 
-
 using namespace FX;
 
 /*******************************************************************************/
@@ -229,13 +231,13 @@ FXString FXPath::name(const FXString& file){
 
 /*******************************************************************************/
 
-// Return file title, i.e. document name only:
+// Return file stem, i.e. document name only:
 //
 //  /path/aa        -> aa
 //  /path/aa.bb     -> aa
 //  /path/aa.bb.cc  -> aa.bb
 //  /path/.aa       -> .aa
-FXString FXPath::title(const FXString& file){
+FXString FXPath::stem(const FXString& file){
   if(!file.empty()){
     FXint i=0,f,e,b;
 #if defined(WIN32)
@@ -363,94 +365,74 @@ FXString FXPath::drive(const FXString&){
 
 /*******************************************************************************/
 
-// Perform tilde or environment variable expansion
-// On Windows, environment variables are of the form '%ENVVAR%'.
-// On Unix, environment variables are of the form '$ENVVAR' or '${ENVVAR}'.
-// Also, on unix tilde-expansion '~' or '~user' is replaced by the
-// home directory of the current user or designated user.
-FXString FXPath::expand(const FXString& file){
-  if(!file.empty()){
-    FXString result,value; FXint b=0,e=0,p;
+// Expand environment variables recursively, stopping when recursion goes too deep
+static FXString expandEnvironmentVariables(const FXString& file,FXint level){
+  FXint s=0,r=0,b=0,e=0;
+  FXString result;
 #if defined(WIN32)
-    while(file[e]){
-      if(file[e]=='%'){
-        p=++e;
-        while(Ascii::isAlphaNumeric(file[e]) || file[e]=='_') e++;
-        if(file[e]=='%'){
-          if(p<e){
-            value=FXSystem::getEnvironment(file.mid(p,e-p));
-            if(!value.empty()){
-              result.append(&file[b],p-b-1);
-              result.append(value);
-              b=e+1;
-              }
-            }
-          ++e;
-          }
-        continue;
+  while(e<file.length()){
+    r=e;
+    if(file[e++]=='%'){       // %VAR%
+      b=e;
+      while(Ascii::isAlphaNumeric(file[e]) || file[e]=='_') e++;
+      if(file[e]=='%' && b<e && 0<level){
+        result.append(&file[s],r-s);
+        result.append(expandEnvironmentVariables(FXSystem::getEnvironment(file.mid(b,e-b)),level-1));
+        s=++e;
         }
-      ++e;
       }
-    result.append(&file[b],e-b);
+    }
+  result.append(&file[s],e-s);
 #else
-
-    // Expand leading tilde of the form ~/filename or ~user/filename
-    // Also don't expand if non-existing user-directory.
-    if(file[e]=='~'){
-      ++e;
-      while(file[e] && !(ISPATHSEP(file[e]) && file[e-1]!='\\')){
-        ++e;
+  while(e<file.length()){
+    r=e;
+    if(file[e++]=='$'){
+      b=e;
+      if(file[e]=='{'){       // ${VAR}...
+        b=++e;
+        while(Ascii::isAlphaNumeric(file[e]) || file[e]=='_') e++;
+        if(file[e]=='}' && b<e && 0<level){
+          result.append(&file[s],r-s);
+          result.append(expandEnvironmentVariables(FXSystem::getEnvironment(file.mid(b,e-b)),level-1));
+          s=++e;
+          }
         }
-      if(e==1){
-        result=FXSystem::getHomeDirectory();
-        }
-      else{
-        result=FXSystem::getUserDirectory(file.mid(b+1,e-b-1));
-        }
-      if(result.empty()){
-        e=b;
+      else{                   // $VAR...
+        while(Ascii::isAlphaNumeric(file[e]) || file[e]=='_') e++;
+        if(b<e && 0<level){
+          result.append(&file[s],r-s);
+          result.append(expandEnvironmentVariables(FXSystem::getEnvironment(file.mid(b,e-b)),level-1));
+          s=e;
+          }
         }
       }
+    }
+  result.append(&file[s],e-s);
+#endif
+  return result;
+  }
 
-    // Expand environment variables of the form $HOME or ${HOME}
-    b=e;
-    while(file[e]){
-      if(file[e]=='$'){
-        ++e;
-        if(file[e]=='{'){       // ${VAR}...
-          p=++e;
-          while(Ascii::isAlphaNumeric(file[e]) || file[e]=='_') e++;
-          if(file[e]=='}'){
-            if(p<e){
-              value=FXSystem::getEnvironment(file.mid(p,e-p));
-              if(!value.empty()){
-                result.append(&file[b],p-b-2);
-                result.append(value);
-                b=e+1;
-                }
-              }
-            ++e;
-            }
-          }
-        else{                   // $VAR...
-          p=e;
-          while(Ascii::isAlphaNumeric(file[e]) || file[e]=='_') e++;
-          if(p<e){
-            value=FXSystem::getEnvironment(file.mid(p,e-p));
-            if(!value.empty()){
-              result.append(&file[b],p-b-1);
-              result.append(value);
-              b=e;
-              }
-            }
-          }
-        continue;
+
+// Perform tilde or environment variable expansion.
+// A prefix of the form ~ or ~user is expanded to the user's home directory.
+// Environment variables of the form $HOME or ${HOME} are expanded by
+// substituting the value of the variable, recusively up to given level.
+// On Windows, only environment variables of the form %HOME% are expanded.
+FXString FXPath::expand(const FXString& file,FXint level){
+  if(!file.empty()){
+#if defined(WIN32)
+    return expandEnvironmentVariables(file,level);
+#else
+    if(file[0]=='~'){
+      FXint e=1;
+      while(Ascii::isAlphaNumeric(file[e]) || file[e]=='_') e++;
+      if(1<e){
+        return FXSystem::getUserDirectory(file.mid(1,e-1))+expandEnvironmentVariables(file.mid(e,file.length()-e),level);
         }
-      ++e;
+      return FXSystem::getHomeDirectory()+expandEnvironmentVariables(file.mid(e,file.length()-e),level);
       }
-    result.append(&file[b],e-b);
+    return expandEnvironmentVariables(file,level);
 #endif
-    return result;
     }
   return FXString::null;
   }
@@ -631,7 +613,7 @@ FXString FXPath::contract(const FXString& file,const FXString& user,const FXStri
     FXString result(file);
     if(FXPath::isAbsolute(result)){
       FXString val=FXSystem::getUserDirectory(user);
-      if(!val.empty() && compare(result,val,val.length())==0 && ((result.length()==val.length()) || ISPATHSEP(result[val.length()]))){
+      if(!val.empty() && FXString::compare(result,val,val.length())==0 && ((result.length()==val.length()) || ISPATHSEP(result[val.length()]))){
         result.replace(0,val.length(),"~"+user);
         }
       }
@@ -867,10 +849,10 @@ FXString FXPath::absolute(const FXString& base,const FXString& file){
 //  a          b            ../b        Branch point is assumed ..
 //  ./a        ./b          ../b        Branch point is assumed ..
 //
-//  /a/b/c     /a/b/c       .           Equal
-//  /a/b/c/    /a/b/c/      .           Equal
-//  /a/b/c     /a/b/c/      .           Equal
-//  /a/b/c/    /a/b/c       .           Equal
+//  /a/b/c     /a/b/c       ../c        Branch point is /a/b
+//  /a/b/c/    /a/b/c       ../c        Branch point is /a/b
+//  /a/b/c/    /a/b/c/      .           Branch point is /a/b/c
+//  /a/b/c     /a/b/c/      .           Branch point is /a/b/c
 //
 //  ../a/b/c   ../a/b/c/d   d           Branch point is ../a/b/c
 //
@@ -884,6 +866,8 @@ FXString FXPath::absolute(const FXString& base,const FXString& file){
 //  /          /a/b         a/b         Branch point is /
 //  /p/q       /a/b         ../../a/b   Branch point is /
 //
+// Note that absolute(base,relative(base,file)) should be equal to file
+// [after simplify()].
 FXString FXPath::relative(const FXString& base,const FXString& file){
   if(!base.empty() && !file.empty()){
 
@@ -922,8 +906,11 @@ FXString FXPath::relative(const FXString& base,const FXString& file){
         }
 #endif
 
-      // Common prefix except for trailing path separator
-      if((base[p]=='\0' || ISPATHSEP(base[p])) && (file[q]=='\0' || ISPATHSEP(file[q]))){
+      // Check if common prefix extends to the end of the base-path.
+      // If the file-path ends in "/", the final component is a directory,
+      // in which case it is OK to return ".".  Otherwise we prefer
+      // to prefix the file-part with "../".
+      if(ISPATHSEP(file[q]) && (base[p]=='\0' || ISPATHSEP(base[p]))){
         bp=p;
         bq=q;
         }
@@ -1100,6 +1087,7 @@ FXString FXPath::upLevel(const FXString& file){
 /*******************************************************************************/
 
 // Check if file represents absolute pathname
+// Which means '/blabla' or '\blabla' or 'c:\blabla'
 FXbool FXPath::isAbsolute(const FXString& file){
 #if defined(WIN32)
   return ISPATHSEP(file[0]) || (Ascii::isLetter(file[0]) && file[1]==':' && ISPATHSEP(file[2]));
@@ -1108,6 +1096,14 @@ FXbool FXPath::isAbsolute(const FXString& file){
 #endif
   }
 
+
+// Return true if file name is relative
+// Which means '.' or './blabla' or '..' or '../blabla'.
+// But '.blabla' is NOT relative.
+FXbool FXPath::isRelative(const FXString& file){
+  return file[0]=='.' && ((file[1]=='\0' || ISPATHSEP(file[1])) || (file[1]=='.' && (file[2]=='\0' || ISPATHSEP(file[2]))));
+  }
+
 /*******************************************************************************/
 
 // Does file represent topmost directory
@@ -1187,54 +1183,58 @@ FXbool FXPath::isValidPath(const FXString& file){
 // Quoting with double quotes is needed:
 //   - If force=true
 //   - If white space before, in, or after letters
+//   - If filename is empty
 // Escaping is done when:
 //   - Special characters (^ " < > | & * ?) are encountered
 FXString FXPath::enquote(const FXString& file,FXbool force){
-  FXString result(file);
   if(0<file.length()){
+    FXString result(file);
     FXint p,q,c,n;
 
     // Check if quotes needed, if not already forced
-    if(!force && 0<=file.find_first_of(" \t\n\v\"")) force=true;
+    if(!force){
+      force=(0<=file.find_first_of(" \t\n\v\"",5,0));
+      }
 
     // Measure new string size
     p=q=n=0;
     while(p<=file.length()){
       switch(file[p++]){
-        case '\0':              // End of string
-          if(force){
-            q+=n;               // Extra n backslashes makes for 2n backslashes
-            }
-          continue;
-        case '\\':              // Backslashes
-          q++;
-          n++;
-          continue;
-        case '"':               // Quotes
-          if(force){
-            q+=n+2;             // Extra n+1 backslashes makes for 2n+1 backslashes
-            }
-          else{
-            q+=2;               // Escaped normally
-            }
-          n=0;
-          continue;
-        case '^':               // Escape character
-        case '<':               // Redirection
-        case '>':
-        case '(':
-        case ')':
-        case '|':               // Pipe
-        case '%':               // Environment variables
-        case '!':               // Wildcard
-        case '&':               // Command separators
-        case '*':               // Wildcard
-        case '?':
-          if(!force) q++;
-        default:                // Normal characters
-          q++;
-          n=0;
-          continue;
+      case '\0':                // End of string
+        if(force){
+          q+=n;                 // Extra n backslashes makes for 2n backslashes
+          }
+        continue;
+      case '\\':                // Backslashes
+        q++;
+        n++;
+        continue;
+      case '"':                 // Quotes
+        if(force){
+          q+=n+2;               // Extra n+1 backslashes makes for 2n+1 backslashes
+          }
+        else{
+          q+=2;                 // Escaped normally
+          }
+        n=0;
+        continue;
+      case '^':                 // Escape character
+      case '<':                 // Redirection
+      case '>':
+      case '(':
+      case ')':
+      case '|':                 // Pipe
+      case '%':                 // Environment variables
+      case '!':                 // Wildcard
+      case '&':                 // Command separators
+      case '*':                 // Wildcard
+      case '?':
+        if(!force) q++;
+        /*FALL*/
+      default:                  // Normal characters
+        q++;
+        n=0;
+        continue;
         }
       }
 
@@ -1248,49 +1248,51 @@ FXString FXPath::enquote(const FXString& file,FXbool force){
       if(force) result[q++]='"';
       while(p<=file.length()){
         switch(c=file[p++]){
-          case '\0':            // End of string
-            if(force){
-              while(--n>=0) result[q++]='\\';
-              }
-            continue;
-          case '\\':            // Backslashes
+        case '\0':              // End of string
+          if(force){
+            while(--n>=0) result[q++]='\\';
+            }
+          continue;
+        case '\\':              // Backslashes
+          result[q++]='\\';
+          n++;
+          continue;
+        case '"':               // Quotes not preceeded by backslashes
+          if(force){
+            while(--n>=0) result[q++]='\\';
             result[q++]='\\';
-            n++;
-            continue;
-          case '"':             // Quotes not preceeded by backslashes
-            if(force){
-              while(--n>=0) result[q++]='\\';
-              result[q++]='\\';
-              }
-            else{
-              result[q++]='^';
-              }
-            result[q++]='"';
-            n=0;
-            continue;
-          case '^':             // Escape character
-          case '<':             // Redirection
-          case '>':
-          case '(':
-          case ')':
-          case '|':             // Pipe
-          case '%':             // Environment variables
-          case '!':             // Wildcard
-          case '&':             // Command separators
-          case '*':             // Wildcard
-          case '?':
-            if(!force) result[q++]='^';
-          default:              // Normal characters
-            result[q++]=c;
-            n=0;
-            continue;
+            }
+          else{
+            result[q++]='^';
+            }
+          result[q++]='"';
+          n=0;
+          continue;
+        case '^':               // Escape character
+        case '<':               // Redirection
+        case '>':
+        case '(':
+        case ')':
+        case '|':               // Pipe
+        case '%':               // Environment variables
+        case '!':               // Wildcard
+        case '&':               // Command separators
+        case '*':               // Wildcard
+        case '?':
+          if(!force) result[q++]='^';
+          /*FALL*/
+        default:                // Normal characters
+          result[q++]=c;
+          n=0;
+          continue;
           }
         }
       if(force) result[q++]='"';
       }
     FXASSERT(result.length()==q);
+    return result;
     }
-  return result;
+  return "\"\"";
   }
 
 
@@ -1321,12 +1323,12 @@ FXString FXPath::dequote(const FXString& file){
   if(0<result.length()){
     FXint e=file.length(),b=0,r=0,q=0,n=0;
 
-    // Trim tail
-    while(0<e && Ascii::isSpace(file[e-1])) --e;
-
     // Trim head
     while(b<e && Ascii::isSpace(file[b])) ++b;
 
+    // Trim tail
+    while(b<e && Ascii::isSpace(file[e-1])) --e;
+
     // Dequote the rest
     while(b<e){
       while(file[b]=='\\'){     // Track runs of backslashes
@@ -1365,12 +1367,13 @@ FXString FXPath::dequote(const FXString& file){
 // Quoting with single quote when:
 //   - If force=true
 //   - If white space before, in, or after letters
+//   - If filename is empty
 //   - If any special character from the set |&;<>()$`\"'*+?[]#~!^=% is found
 // Escaping is done when:
 //   - Quote character (') are encountered
 FXString FXPath::enquote(const FXString& file,FXbool force){
-  FXString result(file);
   if(0<file.length()){
+    FXString result(file);
     FXint p,q,e,c;
 
     // Measure new string size
@@ -1384,7 +1387,7 @@ FXString FXPath::enquote(const FXString& file,FXbool force){
       case '`':                 // Command substitution
       case '"':                 // Double quote
       case '\\':                // Back slash
-      case '!':                 // Special in csh
+      case '!':                 // History expansion
       case '$':                 // Variable substitution
       case '(':
       case ')':
@@ -1393,24 +1396,27 @@ FXString FXPath::enquote(const FXString& file,FXbool force){
       case '<':                 // Redirections, pipe
       case '>':
       case '|':
-      case '^':                 // Special in sh
       case '*':                 // Wildcard characters
+      case '^':
       case '+':
       case '?':
       case '[':
       case ']':
+      case '{':                 // Brace expansion
+      case '}':
       case '=':                 // Equals
       case '%':                 // Job control
+      case '#':                 // Comments
       case '\t':                // White space
       case '\n':
       case '\v':
       case ' ':
-      case '#':                 // Comments
         force=true;             // Force quotes
         q++;
         continue;
       case '~':                 // Username substitution
         if(p==1) force=true;    // Force quotes if at beginning
+        /*FALL*/
       default:                  // Normal character
         q++;
         continue;
@@ -1438,14 +1444,15 @@ FXString FXPath::enquote(const FXString& file,FXbool force){
       if(force) result[q++]='\'';
       }
     FXASSERT(result.length()==q);
+    return result;
     }
-  return result;
+  return "''";
   }
 
 
 // Dequote filename to get original again
 // The input text may contain multiple quoted segments, or even no quoted
-// segments at all, but leading and trailing spaces are removed from the output.
+// segments at all, but leading and trailing spaces are removed.
 // Single quotes preserve the literal string exactly; escape sequences are
 // not allowed; not even \' - if you want a ' in the quoted text, you have
 // to do something like 'foo'\''bar'.
@@ -1508,7 +1515,7 @@ FXString FXPath::dequote(const FXString& file){
 // N backslashes          : N backslashes
 //
 FXint FXPath::parseArgs(FXchar**& argv,const FXchar* command){
-  argv=NULL;
+  argv=nullptr;
   if(command){
     const FXchar *p=command;
     FXint token=0;
@@ -1640,7 +1647,7 @@ FXint FXPath::parseArgs(FXchar**& argv,const FXchar* command){
           }
 
         // Argv closeout
-        *ptr=NULL;
+        *ptr=nullptr;
         return count;
         }
       }
@@ -1660,7 +1667,7 @@ FXint FXPath::parseArgs(FXchar**& argv,const FXchar* command){
 // '......'     : No characters can be escaped inside single-quoted text
 //
 FXint FXPath::parseArgs(FXchar**& argv,const FXchar* command){
-  argv=NULL;
+  argv=nullptr;
   if(command){
     const FXchar *p=command;
     FXint token=0;
@@ -1809,7 +1816,7 @@ FXint FXPath::parseArgs(FXchar**& argv,const FXchar* command){
           }
 
         // Argv closeout
-        *ptr=NULL;
+        *ptr=nullptr;
         return count;
         }
       }
@@ -1882,7 +1889,7 @@ n:switch(*p){
       goto n;
     case '\\':          // Escape code
       if(!(flags&FXPath::NoEscape)){ if(*++p=='\0') goto x; }
-      // FALL //
+      /*FALL*/
     default:            // Regular character
       p=wcinc(p);       // Next unicode character
       set++;
@@ -1992,7 +1999,7 @@ static FXbool domatch(const FXchar* string,const FXchar* s,const FXchar* p,FXuin
         break;
       case '\\':        // Escaped character follows
         if(!(flags&FXPath::NoEscape)){ if(*++p=='\0') return false; }
-        // FALL //
+        /*FALL*/
       default:          // Match characters against pattern
         pp=wc(p);
         ss=wc(s);
@@ -2010,7 +2017,7 @@ static FXbool domatch(const FXchar* string,const FXchar* s,const FXchar* p,FXuin
   }
 
 
-// Match filename against a pattern, subject to flags
+// Match string against a pattern, subject to flags
 FXbool FXPath::match(const FXchar* string,const FXchar* pattern,FXuint flags){
   const FXchar* end=skip(pattern,flags,false);  // Check pattern syntax
   if(*end=='\0'){
@@ -2025,15 +2032,22 @@ FXbool FXPath::match(const FXchar* string,const FXchar* pattern,FXuint flags){
   }
 
 
-// Match filename against pattern (like *, ?, [^a-z], and so on)
-FXbool FXPath::match(const FXString& file,const FXchar* pattern,FXuint flags){
-  return FXPath::match(file.text(),pattern,flags);
+// Match string against pattern (like *, ?, [^a-z], and so on)
+FXbool FXPath::match(const FXString& string,const FXchar* pattern,FXuint flags){
+  return FXPath::match(string.text(),pattern,flags);
   }
 
 
-// Match filename against pattern (like *, ?, [^a-z], and so on)
-FXbool FXPath::match(const FXString& file,const FXString& pattern,FXuint flags){
-  return FXPath::match(file.text(),pattern.text(),flags);
+// Match string against pattern (like *, ?, [^a-z], and so on)
+FXbool FXPath::match(const FXchar* string,const FXString& pattern,FXuint flags){
+  return FXPath::match(string,pattern.text(),flags);
+  }
+
+
+
+// Match string against pattern (like *, ?, [^a-z], and so on)
+FXbool FXPath::match(const FXString& string,const FXString& pattern,FXuint flags){
+  return FXPath::match(string.text(),pattern.text(),flags);
   }
 
 /*******************************************************************************/
@@ -2043,7 +2057,7 @@ FXbool FXPath::match(const FXString& file,const FXString& pattern,FXuint flags){
 FXString FXPath::unique(const FXString& file){
   if(!FXStat::exists(file)) return file;
   FXString ext=FXPath::extension(file);
-  FXString path=FXPath::stripExtension(file);           // Use the new API (Jeroen)
+  FXString path=FXPath::stripExtension(file);   // Use the new API (Jeroen)
   FXString filename;
   FXint count=0;
   if(!ext.empty()) ext.prepend('.');            // Only add period when non-empty extension
@@ -2061,14 +2075,15 @@ FXString FXPath::unique(const FXString& file){
 FXString FXPath::search(const FXString& pathlist,const FXString& file){
   if(!file.empty()){
     FXString path;
-    FXint beg,end;
+    FXint beg=0;
+    FXint end=0;
     if(FXPath::isAbsolute(file)){
       if(FXStat::exists(file)) return file;
       return FXString::null;
       }
-    for(beg=0; pathlist[beg]; beg=end){
-      while(pathlist[beg]==PATHLISTSEP) beg++;
-      end=beg;
+    while(pathlist[end]){
+      while(pathlist[end]==PATHLISTSEP) end++;
+      beg=end;
       while(pathlist[end] && pathlist[end]!=PATHLISTSEP) end++;
       if(beg==end) break;
       path=FXPath::absolute(FXPath::expand(pathlist.mid(beg,end-beg)),file);
@@ -2084,18 +2099,21 @@ FXString FXPath::search(const FXString& pathlist,const FXString& file){
 FXString FXPath::relativize(const FXString& pathlist,const FXString& file){
   FXString result(file);
   if(!file.empty()){
-    FXint beg,end;
-    FXString base,rr,r;
-    for(beg=0; pathlist[beg]; beg=end){
-      while(pathlist[beg]==PATHLISTSEP) beg++;
-      for(end=beg; pathlist[end] && pathlist[end]!=PATHLISTSEP; end++){}
+    FXString base;
+    FXString res;
+    FXint beg=0;
+    FXint end=0;
+    while(pathlist[end]){
+      while(pathlist[end]==PATHLISTSEP) end++;
+      beg=end;
+      while(pathlist[end] && pathlist[end]!=PATHLISTSEP) end++;
       if(beg==end) break;
       base=FXPath::absolute(FXPath::expand(pathlist.mid(beg,end-beg)));
-      if(isInside(base,file)){
-        r=FXPath::relative(base,file);
-        if(r.length()<result.length()){         // ??
-          if(FXPath::search(pathlist,r)==file){
-            result=r;
+      if(FXPath::isInside(base,file)){
+        res=FXPath::relative(base,file);
+        if(res.length()<result.length()){
+          if(FXPath::search(pathlist,res)==file){
+            result=res;
             }
           }
         }
@@ -2112,11 +2130,14 @@ FXString FXPath::relativize(const FXString& pathlist,const FXString& file){
 FXbool FXPath::hasExecExtension(const FXString& file){
   if(!file.empty()){
     FXString pathext(FXSystem::getExecExtensions());
-    FXint beg=0,end;
+    FXint beg=0;
+    FXint end=0;
     do{
       end=beg;
       while(end<pathext.length() && pathext[end]!=PATHLISTSEP) end++;
-      if(0<=(file.length()-end+beg) && comparecase(&file[file.length()-end+beg],&pathext[beg],end-beg)==0) return true;
+      if((end-beg)<=file.length()){
+        if(FXString::comparecase(&file[file.length()-(end-beg)],&pathext[beg],(end-beg))==0) return true;
+        }
       beg=end+1;
       }
     while(end<pathext.length());
@@ -2135,7 +2156,7 @@ static const char *fxstrcasestr(const FXchar *haystack,const FXchar *needle){
       if(!*b) return haystack;
       }
     }
-  return NULL;
+  return nullptr;
   }
 
 
@@ -2144,10 +2165,10 @@ FXbool FXPath::isReservedName(const FXString& file){
   static const FXchar reserved3[]="CON\nPRN\nAUX\nNUL\n";
   static const FXchar reserved4[]="COM1\nCOM2\nCOM3\nCOM4\nCOM5\nCOM6\nCOM7\nCOM8\nCOM9\nLPT1\nLPT2\nLPT3\nLPT4\nLPT5\nLPT6\nLPT7\nLPT8\nLPT9\n";
   if(file.length()==3){
-    return (fxstrcasestr(reserved3,file.text())!=NULL);
+    return (fxstrcasestr(reserved3,file.text())!=nullptr);
     }
   if(file.length()==4){
-    return (fxstrcasestr(reserved4,file.text())!=NULL);
+    return (fxstrcasestr(reserved4,file.text())!=nullptr);
     }
   return false;
   }
