@@ -3,7 +3,7 @@
 *                            R e a c t o r   C l a s s                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2006,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2006,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -105,10 +105,15 @@
     may be multiple FXReactors, each one handling a different, non-overlapping set of
     signals.
 
+  - Look into whether timerfd_create() may have some advantages for timers, as opposed
+    to falling out of epoll system call after a set time (less checking?).
+
+  - If using epoll() instead of select() or pselect(), we may want to raise
+    RLIMIT_NOFILE as we're able to go beyond FD_SETSIZE.
 */
 
 // Bad handle value
-#if defined(_WIN32)
+#if defined(WIN32)
 #define BadHandle INVALID_HANDLE_VALUE
 #else
 #define BadHandle -1
@@ -122,14 +127,16 @@ namespace FX {
 
 // Units of time in nanoseconds
 const FXTime seconds=1000000000;
+const FXTime milliseconds=1000000;
+const FXTime microseconds=1000;
 
 // Sleep no longer than this
 const FXTime FXReactor::maxwait=86400*seconds;
 
 
 // Construct reactor object
-FXReactor::FXReactor():internals(NULL),sigreceived(0),numhandles(0),numwatched(0),numraised(0){
-#if defined(_WIN32)
+FXReactor::FXReactor():internals(nullptr),sigreceived(0),numhandles(0),numwatched(0),numraised(0){
+#if defined(WIN32)
   current=-1;
 #else
   current=0;
@@ -188,7 +195,7 @@ FXbool FXReactor::addSignal(FXint sig,FXbool async){
   if(internals){
     if(sig<=0) return false;
     if(sig>=64) return false;
-    if(atomicBoolCas(&sigmanager[sig],(FXReactor*)NULL,this)){
+    if(atomicBoolCas(&sigmanager[sig],(FXReactor*)nullptr,this)){
       void (CDECL *handler)(int);
       if(async){
         handler=FXReactor::signalhandlerasync;  // Asynchronous callback
@@ -197,9 +204,9 @@ FXbool FXReactor::addSignal(FXint sig,FXbool async){
         handler=FXReactor::signalhandler;       // Normal callback
         }
       internals->signotified[sig]=0;            // Set non-raised
-#if defined(_WIN32)
+#if defined(WIN32)
       if(signal(sig,handler)==SIG_ERR){         // Set handler
-        sigmanager[sig]=NULL;
+        sigmanager[sig]=nullptr;
         return false;
         }
 #elif defined(_POSIX_SOURCE) || defined(_INCLUDE_POSIX_SOURCE) || defined(_XOPEN_SOURCE)
@@ -207,13 +214,13 @@ FXbool FXReactor::addSignal(FXint sig,FXbool async){
       sigact.sa_handler=handler;
       sigact.sa_flags=0;
       sigfillset(&sigact.sa_mask);              // Block signals while running handler
-      if(sigaction(sig,&sigact,NULL)==-1){      // Set handler
-        sigmanager[sig]=NULL;
+      if(sigaction(sig,&sigact,nullptr)==-1){   // Set handler
+        sigmanager[sig]=nullptr;
         return false;
         }
 #else
       if(signal(sig,handler)==SIG_ERR){         // Set handler
-        sigmanager[sig]=NULL;
+        sigmanager[sig]=nullptr;
         return false;
         }
 #endif
@@ -230,7 +237,7 @@ FXbool FXReactor::remSignal(FXint sig){
     if(sig<=0) return false;
     if(sig>=64) return false;
     if(sigmanager[sig]==this){
-#if defined(_WIN32)
+#if defined(WIN32)
       if(signal(sig,SIG_DFL)==SIG_ERR){         // Unset handler
         return false;
         }
@@ -239,7 +246,7 @@ FXbool FXReactor::remSignal(FXint sig){
       sigact.sa_handler=SIG_DFL;
       sigact.sa_flags=0;
       sigemptyset(&sigact.sa_mask);             // Pass signals while running handler
-      if(sigaction(sig,&sigact,NULL)==-1){      // Unset handler
+      if(sigaction(sig,&sigact,nullptr)==-1){   // Unset handler
         return false;
         }
 #else
@@ -247,7 +254,7 @@ FXbool FXReactor::remSignal(FXint sig){
         return false;
         }
 #endif
-      sigmanager[sig]=NULL;                     // Now release it
+      sigmanager[sig]=nullptr;                  // Now release it
       internals->signotified[sig]=0;            // Set non-raised
       return true;
       }
@@ -283,7 +290,7 @@ FXbool FXReactor::dispatchIdle(){
 
 /*******************************************************************************/
 
-#if defined(_WIN32)
+#if defined(WIN32)
 
 // Find index of the given handle; -1 if not found
 static inline FXint findHandle(FXInputHandle hnd,const FXInputHandle handles[],FXint n){
@@ -296,7 +303,7 @@ static inline FXint findHandle(FXInputHandle hnd,const FXInputHandle handles[],F
 // Append new handle hnd to watch-list
 FXbool FXReactor::addHandle(FXInputHandle hnd,FXuint mode){
   if(internals){
-#if defined(_WIN32)
+#if defined(WIN32)
     if(hnd==BadHandle) return false;
     if(numhandles>=MAXIMUM_WAIT_OBJECTS) return false;
     if(findHandle(hnd,internals->handles,numhandles)>=0) return false;
@@ -333,7 +340,7 @@ FXbool FXReactor::addHandle(FXInputHandle hnd,FXuint mode){
 // Remove handle hnd from list
 FXbool FXReactor::remHandle(FXInputHandle hnd){
   if(internals){
-#if defined(_WIN32)
+#if defined(WIN32)
     FXint s;
     if(hnd==BadHandle) return false;
     if((s=findHandle(hnd,internals->handles,numhandles))<0) return false;
@@ -378,9 +385,9 @@ FXbool FXReactor::dispatchHandle(FXInputHandle,FXuint,FXuint){
   return false;
   }
 
-#if defined(_WIN32) /////////////////////////////////////////////////////////////
+#if defined(WIN32) //////////////////////////////////////////////////////////////
 
-// Dispatch driver
+// Dispatch driver (using WaitForMultipleObjectsEx())
 FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
   if(internals){
     FXTime now,due,delay,interval;
@@ -397,7 +404,7 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
         if(due<forever){
           now=FXThread::time();
           delay=due-now;
-          if(delay<FXLONG(1000)){
+          if(delay<microseconds){
             if(dispatchTimeout(due)) return true;       // Timer activity
             continue;
             }
@@ -427,7 +434,7 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
         continue;
         }
 
-      // Select active handles; don't block
+      // Select active handles (0<numhandles); don't block
       current=WaitForMultipleObjectsEx(numhandles,internals->handles,false,0,true);
 
       // No handles were active
@@ -448,10 +455,10 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
         interval=Math::imin(delay,blocking);
         if(interval<forever){
           interval=Math::imin(interval,maxwait);
-          ms=(FXuint)(interval/1000000);
+          ms=(FXuint)(interval/milliseconds);
           }
 
-        // Select active handles, wait for timeout or maximum block time
+        // Select active handles (0<numhandles); wait for timeout or maximum block time
         current=WaitForMultipleObjectsEx(numhandles,internals->handles,false,ms,true);
 
         // Return if there was no timeout within maximum block time
@@ -479,7 +486,7 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
 
 #elif defined(HAVE_EPOLL_CREATE1) ///////////////////////////////////////////////
 
-// Dispatch driver
+// Dispatch driver (using epoll_pwait())
 FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
   if(internals){
     FXTime now,due,delay,interval;
@@ -496,7 +503,7 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
         if(due<forever){
           now=FXThread::time();
           delay=due-now;
-          if(delay<FXLONG(1000)){
+          if(delay<microseconds){
             if(dispatchTimeout(due)) return true;       // Timer activity
             continue;
             }
@@ -527,8 +534,11 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
         continue;
         }
 
+      // All handles have been handled...
+      FXASSERT(numraised==0);
+
       // Select active handles and check signals; don't block
-      numwatched=epoll_pwait(internals->handle,internals->events,ARRAYNUMBER(internals->events),0,NULL);
+      numwatched=epoll_pwait(internals->handle,internals->events,ARRAYNUMBER(internals->events),0,nullptr);
 
       // No active handles yet; need to wait
       if(numwatched==0){
@@ -548,11 +558,11 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
         interval=Math::imin(delay,blocking);
         if(interval<forever){
           interval=Math::imin(interval,maxwait);
-          ms=(FXuint)(interval/1000000);
+          ms=(FXuint)(interval/milliseconds);
           }
 
         // Select active handles and check signals, waiting for timeout or maximum block time
-        numwatched=epoll_pwait(internals->handle,internals->events,ARRAYNUMBER(internals->events),ms,NULL);
+        numwatched=epoll_pwait(internals->handle,internals->events,ARRAYNUMBER(internals->events),ms,nullptr);
 
         // Return if there was no timeout within maximum block time
         if(numwatched==0){
@@ -579,7 +589,7 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
 
 #else ///////////////////////////////////////////////////////////////////////////
 
-// Dispatch driver
+// Dispatch driver (using pselect() or select())
 FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
   if(internals){
     FXTime now,due,delay,interval;
@@ -600,7 +610,7 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
         if(due<forever){
           now=FXThread::time();
           delay=due-now;
-          if(delay<FXLONG(1000)){
+          if(delay<microseconds){
             if(dispatchTimeout(due)) return true;       // Timer activity
             continue;
             }
@@ -640,10 +650,15 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
             }
           }
         while(mode==0);
+
+        // IO handle became active
         if(dispatchHandle(current,mode,flags)) return true;     // IO activity
         continue;
         }
 
+      // All handles have been handled...
+      FXASSERT(numraised==0);
+
       // Prepare handles to check
       internals->watched[0]=internals->handles[0];
       internals->watched[1]=internals->handles[1];
@@ -651,9 +666,9 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
 
       // Select active handles and check signals; don't block
 #if (_POSIX_C_SOURCE >= 200112L)
-      numraised=pselect(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],NULL,NULL);
+      numraised=pselect(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],nullptr,nullptr);
 #else
-      numraised=select(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],NULL);
+      numraised=select(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],nullptr);
 #endif
 
       // No handles were active
@@ -682,10 +697,10 @@ FXbool FXReactor::dispatch(FXTime blocking,FXuint flags){
 #if (_POSIX_C_SOURCE >= 200112L)
         delta.tv_sec=interval/seconds;
         delta.tv_nsec=(interval-seconds*delta.tv_sec);
-        numraised=pselect(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],&delta,NULL);
+        numraised=pselect(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],&delta,nullptr);
 #else
         delta.tv_sec=interval/seconds;
-        delta.tv_usec=(interval-seconds*delta.tv_sec)/1000;
+        delta.tv_usec=(interval-seconds*delta.tv_sec)/microseconds;
         numraised=select(numhandles,&internals->watched[0],&internals->watched[1],&internals->watched[2],&delta);
 #endif
 
