@@ -3,7 +3,7 @@
 *                      S c r o l l A r e a   W i d g e t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,7 +22,9 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
+#include "FXElement.h"
 #include "FXArray.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXStream.h"
@@ -96,7 +98,7 @@ using namespace FX;
 namespace FX {
 
 FXDEFMAP(FXScrollArea) FXScrollAreaMap[]={
-  FXMAPFUNC(SEL_MOUSEWHEEL,0,FXScrollArea::onVMouseWheel),
+  FXMAPFUNC(SEL_MOUSEWHEEL,0,FXScrollArea::onMouseWheel),
   FXMAPFUNC(SEL_TIMEOUT,FXScrollArea::ID_AUTOSCROLL,FXScrollArea::onAutoScroll),
   FXMAPFUNC(SEL_COMMAND,FXScrollArea::ID_HSCROLLED,FXScrollArea::onHScrollerChanged),
   FXMAPFUNC(SEL_COMMAND,FXScrollArea::ID_VSCROLLED,FXScrollArea::onVScrollerChanged),
@@ -116,9 +118,9 @@ static const FXint acceleration[AUTOSCROLL_FUDGE+1]={1,1,1,2,3,4,6,7,8,16,32,64}
 // Deserialization
 FXScrollArea::FXScrollArea(){
   flags|=FLAG_SHOWN;
-  horizontal=NULL;
-  vertical=NULL;
-  corner=NULL;
+  horizontal=nullptr;
+  vertical=nullptr;
+  corner=nullptr;
   pos_x=0;
   pos_y=0;
   }
@@ -192,7 +194,11 @@ FXint FXScrollArea::getDefaultHeight(){
 
 // Move content
 void FXScrollArea::moveContents(FXint x,FXint y){
+
+  // Scroll pixels
   scroll(getVisibleX(),getVisibleY(),getVisibleWidth(),getVisibleHeight(),x-pos_x,y-pos_y);
+
+  // Update scroll position
   pos_x=x;
   pos_y=y;
   }
@@ -291,12 +297,16 @@ void FXScrollArea::placeScrollBars(FXint vw,FXint vh){
 
   // Scroll to force position back into range
   if(new_x!=pos_x || new_y!=pos_y){
+
+    // Shift to achieve position
     moveContents(new_x,new_y);
+
+    // Should have reached the scroll position
+    FXASSERT(pos_x==new_x && pos_y==new_y);
     }
 
-  // Read back validated position
-  pos_x=-horizontal->getPosition();
-  pos_y=-vertical->getPosition();
+  // Scroll position is good
+  FXASSERT(pos_x<=0 && pos_y<=0);
 
   // Place horizontal scroll bar
   horizontal->position(0,height-sh_h,width-sv_w,sh_h);
@@ -390,17 +400,20 @@ long FXScrollArea::onVScrollerDragged(FXObject*,FXSelector,void* ptr){
   }
 
 
-// Mouse wheel used for vertical scrolling
-long FXScrollArea::onVMouseWheel(FXObject* sender,FXSelector sel,void* ptr){
-  vertical->handle(sender,sel,ptr);
-  return 1;
-  }
-
-
-// Mouse wheel used for horizontal scrolling
-long FXScrollArea::onHMouseWheel(FXObject* sender,FXSelector sel,void* ptr){
-  horizontal->handle(sender,sel,ptr);
-  return 1;
+// Mouse wheel used for scrolling, preferentially, in vertical
+// direction if scrolling is allowed; if vertical scrolling is
+// not allowed, try horizontal scrolling instead.
+// If neither is allowed, return not handled (0).
+long FXScrollArea::onMouseWheel(FXObject* sender,FXSelector sel,void* ptr){
+  if((options&VSCROLLING_OFF)!=VSCROLLING_OFF){
+    vertical->handle(sender,sel,ptr);
+    return 1;
+    }
+  if((options&HSCROLLING_OFF)!=HSCROLLING_OFF){
+    horizontal->handle(sender,sel,ptr);
+    return 1;
+    }
+  return 0;
   }
 
 
