@@ -3,7 +3,7 @@
 *                         S c r o l l b a r   O b j e c t s                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -23,7 +23,9 @@
 #include "fxdefs.h"
 #include "fxmath.h"
 #include "fxkeys.h"
+#include "FXElement.h"
 #include "FXArray.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXStream.h"
@@ -101,14 +103,19 @@ FXIMPLEMENT(FXScrollBar,FXWindow,FXScrollBarMap,ARRAYNUMBER(FXScrollBarMap))
 // For deserialization
 FXScrollBar::FXScrollBar(){
   flags|=FLAG_ENABLED|FLAG_SHOWN;
-  barsize=15;
-  thumbsize=8;
-  thumbpos=15;
-  dragpoint=0;
   range=0;
   page=0;
   line=0;
   pos=0;
+  barsize=15;
+  thumbsize=8;
+  thumbpos=15;
+  wheelLines=1;
+  hiliteColor=0;
+  shadowColor=0;
+  borderColor=0;
+  arrowColor=0;
+  dragpoint=0;
   mode=MODE_NONE;
   }
 
@@ -116,6 +123,7 @@ FXScrollBar::FXScrollBar(){
 // Make a scrollbar
 FXScrollBar::FXScrollBar(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):FXWindow(p,opts,x,y,w,h){
   flags|=FLAG_ENABLED|FLAG_SHOWN;
+  wheelLines=getApp()->getWheelLines();
   backColor=getApp()->getBaseColor();
   hiliteColor=getApp()->getHiliteColor();
   shadowColor=getApp()->getShadowColor();
@@ -126,11 +134,11 @@ FXScrollBar::FXScrollBar(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts
   thumbsize=barsize>>1;
   target=tgt;
   message=sel;
-  dragpoint=0;
   range=100;
   page=1;
   line=1;
   pos=0;
+  dragpoint=0;
   mode=MODE_NONE;
   }
 
@@ -607,10 +615,11 @@ long FXScrollBar::onMouseWheel(FXObject*,FXSelector,void* ptr){
     getApp()->removeTimeout(this,ID_AUTOSCROLL);
     if(!(ev->state&(LEFTBUTTONMASK|MIDDLEBUTTONMASK|RIGHTBUTTONMASK))){
 
-      // Scroll by a line-at-a-time, page-at-a-time, or by given wheel-lines
-      if(ev->state&ALTMASK) jump=line;
+      // With modifiers, scroll multiples of lines or pages
+      if(ev->state&SHIFTMASK) jump=7*page;      // Siebenmeilenstiefel
       else if(ev->state&CONTROLMASK) jump=page;
-      else jump=FXMIN(page,getApp()->getWheelLines()*line);
+      else if(ev->state&ALTMASK) jump=line;
+      else jump=wheelLines*line;
 
       // Move scroll position
       dragpoint-=ev->code*jump/120;
