@@ -3,7 +3,7 @@
 *                          S e t t i n g s   C l a s s                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -23,7 +23,9 @@
 #include "fxdefs.h"
 #include "fxmath.h"
 #include "fxascii.h"
+#include "FXElement.h"
 #include "FXArray.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXStream.h"
 #include "FXElement.h"
@@ -58,7 +60,7 @@
 */
 
 
-#define EMPTY     ((Entry*)(__settings__empty__+3))
+#define EMPTY     (const_cast<Entry*>((const Entry*)(__settings__empty__+3)))
 #define BSHIFT    5
 
 using namespace FX;
@@ -91,7 +93,7 @@ FXbool FXSettings::no(FXival n){
 
     // Allocate new table
     if(1<n){
-      if(__unlikely((p=::calloc(sizeof(FXival)*3+sizeof(Entry)*n,1))==NULL)) return false;
+      if(__unlikely((p=::calloc(sizeof(FXival)*3+sizeof(Entry)*n,1))==nullptr)) return false;
       elbat=(Entry*)(((FXival*)p)+3);
       ((FXival*)elbat)[-3]=n;
       ((FXival*)elbat)[-2]=0;
@@ -176,6 +178,7 @@ FXSettings& FXSettings::adopt(FXSettings& other){
   if(__likely(table!=other.table)){
     swap(table,other.table);
     other.clear();
+    other.modified=true;
     modified=true;
     }
   return *this;
@@ -798,14 +801,14 @@ FXbool FXSettings::writeColorEntry(const FXString& section,const FXString& name,
 FXbool FXSettings::readBoolEntry(const FXchar* section,const FXchar* name,FXbool def) const {
   const FXString& value=at(section).at(name);
   if(!value.empty()){
-    if(comparecase(value,"true")==0) return true;
-    else if(comparecase(value,"false")==0) return false;
-    else if(comparecase(value,"yes")==0) return true;
-    else if(comparecase(value,"no")==0) return false;
-    else if(comparecase(value,"on")==0) return true;
-    else if(comparecase(value,"off")==0) return false;
-    else if(comparecase(value,"1")==0) return true;
-    else if(comparecase(value,"0")==0) return false;
+    if(FXString::comparecase(value,"true")==0) return true;
+    if(FXString::comparecase(value,"false")==0) return false;
+    if(FXString::comparecase(value,"yes")==0) return true;
+    if(FXString::comparecase(value,"no")==0) return false;
+    if(FXString::comparecase(value,"on")==0) return true;
+    if(FXString::comparecase(value,"off")==0) return false;
+    if(FXString::comparecase(value,"1")==0) return true;
+    if(FXString::comparecase(value,"0")==0) return false;
     }
   return def;
   }
