@@ -3,7 +3,7 @@
 *                S p l i t t e r   W i n d o w   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,7 +22,9 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
+#include "FXElement.h"
 #include "FXArray.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXMutex.h"
 #include "FXStream.h"
@@ -97,7 +99,7 @@ FXIMPLEMENT(FXSplitter,FXComposite,FXSplitterMap,ARRAYNUMBER(FXSplitterMap))
 // Make a splitter
 FXSplitter::FXSplitter(){
   flags|=FLAG_ENABLED|FLAG_SHOWN;
-  window=NULL;
+  window=nullptr;
   split=0;
   offset=0;
   barsize=4;
@@ -109,7 +111,7 @@ FXSplitter::FXSplitter(FXComposite* p,FXuint opts,FXint x,FXint y,FXint w,FXint
   flags|=FLAG_ENABLED|FLAG_SHOWN;
   defaultCursor=(options&SPLITTER_VERTICAL) ? getApp()->getDefaultCursor(DEF_VSPLIT_CURSOR) : getApp()->getDefaultCursor(DEF_HSPLIT_CURSOR);
   dragCursor=defaultCursor;
-  window=NULL;
+  window=nullptr;
   split=0;
   offset=0;
   barsize=4;
@@ -123,7 +125,7 @@ FXSplitter::FXSplitter(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts,F
   dragCursor=defaultCursor;
   target=tgt;
   message=sel;
-  window=NULL;
+  window=nullptr;
   split=0;
   offset=0;
   barsize=4;
@@ -386,7 +388,7 @@ FXWindow* FXSplitter::findHSplit(FXint pos){
       child=child->getNext();
       }
     }
-  return NULL;
+  return nullptr;
   }
 
 
@@ -409,7 +411,7 @@ FXWindow* FXSplitter::findVSplit(FXint pos){
       child=child->getNext();
       }
     }
-  return NULL;
+  return nullptr;
   }
 
 
