@@ -3,7 +3,7 @@
 *                        F i l e   S t a t i s t i c s                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2005,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2005,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,12 +21,16 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxchar.h"
 #include "fxmath.h"
 #include "fxascii.h"
+#include "FXElement.h"
 #include "FXArray.h"
+#include "FXMetaClass.h"
 #include "FXHash.h"
 #include "FXStream.h"
 #include "FXString.h"
+#include "FXIO.h"
 #include "FXPath.h"
 #include "FXStat.h"
 #include "FXFile.h"
@@ -185,13 +189,22 @@ FXbool FXStat::isOtherExecutable() const {
 #if defined(WIN32)
 
 // Convert 100ns since 01/01/1601 to ns since 01/01/1970
-static inline FXTime fxunixtime(FXTime ft){
-  return (ft-FXLONG(116444736000000000))*FXLONG(100);
+static inline FXTime fxunixtime(const FILETIME& ft){
+  const FXTime BIAS=FXLONG(116444736000000000);
+  const FXTime HIGH=FXLONG(4294967296);
+  const FXTime MULT=FXLONG(100);
+  return (ft.dwHighDateTime*HIGH+ft.dwLowDateTime-BIAS)*MULT;
   }
 
 // Convert ns since 01/01/1970 to 100ns since 01/01/1601
-static inline FXTime fxwintime(FXTime ut){
-  return ut/FXLONG(100)+FXLONG(116444736000000000);
+static inline FILETIME fxwintime(FXTime ut){
+  const FXTime BIAS=FXLONG(116444736000000000);
+  const FXTime MULT=FXLONG(100);
+  FILETIME ft;
+  ut=BIAS+ut/MULT;
+  ft.dwLowDateTime=(DWORD)ut;
+  ft.dwHighDateTime=(DWORD)(ut>>32);
+  return ft;
   }
 
 #endif
@@ -216,20 +229,31 @@ FXbool FXStat::statFile(const FXString& file,FXStat& info){
     FXnchar unifile[MAXPATHLEN];
     HANDLE hfile;
     utf2ncs(unifile,file.text(),MAXPATHLEN);
-    if((hfile=::CreateFile(unifile,FILE_READ_ATTRIBUTES,FILE_SHARE_READ,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL|FILE_FLAG_BACKUP_SEMANTICS,NULL))!=INVALID_HANDLE_VALUE){
+    if((hfile=::CreateFile(unifile,FILE_READ_ATTRIBUTES,FILE_SHARE_READ,nullptr,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL|FILE_FLAG_BACKUP_SEMANTICS,nullptr))!=INVALID_HANDLE_VALUE){
       BY_HANDLE_FILE_INFORMATION data;
       if(::GetFileInformationByHandle(hfile,&data)){
         info.modeFlags=FXIO::AllFull;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN) info.modeFlags|=FXIO::Hidden;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY) info.modeFlags&=~FXIO::AllWrite;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY) info.modeFlags|=FXIO::Directory|FXIO::AllWrite; else info.modeFlags|=FXIO::File;     // Directories (folders) always writable on Windows
-        if((info.modeFlags&FXIO::File) && !FXPath::hasExecExtension(file)) info.modeFlags&=~FXIO::AllExec;
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY){
+          info.modeFlags|=FXIO::Directory;
+          }
+        else{
+          info.modeFlags|=FXIO::File;
+          }
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN){
+          info.modeFlags|=FXIO::Hidden;
+          }
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY){
+          info.modeFlags&=~FXIO::AllWrite;
+          }
+        if((info.modeFlags&FXIO::File) && !FXPath::hasExecExtension(file)){
+          info.modeFlags&=~FXIO::AllExec;
+          }
         info.userNumber=0;
         info.groupNumber=0;
         info.linkCount=data.nNumberOfLinks;
-        info.accessTime=fxunixtime(*((FXTime*)&data.ftLastAccessTime));
-        info.modifyTime=fxunixtime(*((FXTime*)&data.ftLastWriteTime));
-        info.createTime=fxunixtime(*((FXTime*)&data.ftCreationTime));
+        info.accessTime=fxunixtime(data.ftLastAccessTime);
+        info.modifyTime=fxunixtime(data.ftLastWriteTime);
+        info.createTime=fxunixtime(data.ftCreationTime);
         info.fileVolume=data.dwVolumeSerialNumber;
         info.fileIndex=(((FXulong)data.nFileIndexHigh)<<32)|((FXulong)data.nFileIndexLow);
         info.fileSize=(((FXlong)data.nFileSizeHigh)<<32)|((FXlong)data.nFileSizeLow);
@@ -239,20 +263,31 @@ FXbool FXStat::statFile(const FXString& file,FXStat& info){
       }
 #else
     HANDLE hfile;
-    if((hfile=::CreateFile(file.text(),FILE_READ_ATTRIBUTES,FILE_SHARE_READ,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL|FILE_FLAG_BACKUP_SEMANTICS,NULL))!=INVALID_HANDLE_VALUE){
+    if((hfile=::CreateFile(file.text(),FILE_READ_ATTRIBUTES,FILE_SHARE_READ,nullptr,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL|FILE_FLAG_BACKUP_SEMANTICS,nullptr))!=INVALID_HANDLE_VALUE){
       BY_HANDLE_FILE_INFORMATION data;
       if(::GetFileInformationByHandle(hfile,&data)){
         info.modeFlags=FXIO::AllFull;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN) info.modeFlags|=FXIO::Hidden;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY) info.modeFlags&=~FXIO::AllWrite;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY) info.modeFlags|=FXIO::Directory|FXIO::AllWrite; else info.modeFlags|=FXIO::File;     // Directories (folders) always writable on Windows
-        if((info.modeFlags&FXIO::File) && !FXPath::hasExecExtension(file)) info.modeFlags&=~FXIO::AllExec;
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY){
+          info.modeFlags|=FXIO::Directory;
+          }
+        else{
+          info.modeFlags|=FXIO::File;
+          }
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN){
+          info.modeFlags|=FXIO::Hidden;
+          }
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY){
+          info.modeFlags&=~FXIO::AllWrite;
+          }
+        if((info.modeFlags&FXIO::File) && !FXPath::hasExecExtension(file)){
+          info.modeFlags&=~FXIO::AllExec;
+          }
         info.userNumber=0;
         info.groupNumber=0;
         info.linkCount=data.nNumberOfLinks;
-        info.accessTime=fxunixtime(*((FXTime*)&data.ftLastAccessTime));
-        info.modifyTime=fxunixtime(*((FXTime*)&data.ftLastWriteTime));
-        info.createTime=fxunixtime(*((FXTime*)&data.ftCreationTime));
+        info.accessTime=fxunixtime(data.ftLastAccessTime);
+        info.modifyTime=fxunixtime(data.ftLastWriteTime);
+        info.createTime=fxunixtime(data.ftCreationTime);
         info.fileVolume=data.dwVolumeSerialNumber;
         info.fileIndex=(((FXulong)data.nFileIndexHigh)<<32)|((FXulong)data.nFileIndexLow);
         info.fileSize=(((FXlong)data.nFileSizeHigh)<<32)|((FXlong)data.nFileSizeLow);
@@ -318,20 +353,31 @@ FXbool FXStat::statLink(const FXString& file,FXStat& info){
     FXnchar unifile[MAXPATHLEN];
     HANDLE hfile;
     utf2ncs(unifile,file.text(),MAXPATHLEN);
-    if((hfile=::CreateFile(unifile,FILE_READ_ATTRIBUTES,FILE_SHARE_READ,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL|FILE_FLAG_BACKUP_SEMANTICS,NULL))!=INVALID_HANDLE_VALUE){
+    if((hfile=::CreateFile(unifile,FILE_READ_ATTRIBUTES,FILE_SHARE_READ,nullptr,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL|FILE_FLAG_BACKUP_SEMANTICS,nullptr))!=INVALID_HANDLE_VALUE){
       BY_HANDLE_FILE_INFORMATION data;
       if(::GetFileInformationByHandle(hfile,&data)){
         info.modeFlags=FXIO::AllFull;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN) info.modeFlags|=FXIO::Hidden;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY) info.modeFlags&=~FXIO::AllWrite;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY) info.modeFlags|=FXIO::Directory|FXIO::AllWrite; else info.modeFlags|=FXIO::File;     // Directories (folders) always writable on Windows
-        if((info.modeFlags&FXIO::File) && !FXPath::hasExecExtension(file)) info.modeFlags&=~FXIO::AllExec;
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY){
+          info.modeFlags|=FXIO::Directory;
+          }
+        else{
+          info.modeFlags|=FXIO::File;
+          }
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN){
+          info.modeFlags|=FXIO::Hidden;
+          }
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY){
+          info.modeFlags&=~FXIO::AllWrite;
+          }
+        if((info.modeFlags&FXIO::File) && !FXPath::hasExecExtension(file)){
+          info.modeFlags&=~FXIO::AllExec;
+          }
         info.userNumber=0;
         info.groupNumber=0;
         info.linkCount=data.nNumberOfLinks;
-        info.accessTime=fxunixtime(*((FXTime*)&data.ftLastAccessTime));
-        info.modifyTime=fxunixtime(*((FXTime*)&data.ftLastWriteTime));
-        info.createTime=fxunixtime(*((FXTime*)&data.ftCreationTime));
+        info.accessTime=fxunixtime(data.ftLastAccessTime);
+        info.modifyTime=fxunixtime(data.ftLastWriteTime);
+        info.createTime=fxunixtime(data.ftCreationTime);
         info.fileVolume=data.dwVolumeSerialNumber;
         info.fileIndex=(((FXulong)data.nFileIndexHigh)<<32)|((FXulong)data.nFileIndexLow);
         info.fileSize=(((FXlong)data.nFileSizeHigh)<<32)|((FXlong)data.nFileSizeLow);
@@ -341,20 +387,31 @@ FXbool FXStat::statLink(const FXString& file,FXStat& info){
       }
 #else
     HANDLE hfile;
-    if((hfile=::CreateFile(file.text(),FILE_READ_ATTRIBUTES,FILE_SHARE_READ,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL|FILE_FLAG_BACKUP_SEMANTICS,NULL))!=INVALID_HANDLE_VALUE){
+    if((hfile=::CreateFile(file.text(),FILE_READ_ATTRIBUTES,FILE_SHARE_READ,nullptr,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL|FILE_FLAG_BACKUP_SEMANTICS,nullptr))!=INVALID_HANDLE_VALUE){
       BY_HANDLE_FILE_INFORMATION data;
       if(::GetFileInformationByHandle(hfile,&data)){
         info.modeFlags=FXIO::AllFull;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN) info.modeFlags|=FXIO::Hidden;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY) info.modeFlags&=~FXIO::AllWrite;
-        if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY) info.modeFlags|=FXIO::Directory|FXIO::AllWrite; else info.modeFlags|=FXIO::File;     // Directories (folders) always writable on Windows
-        if((info.modeFlags&FXIO::File) && !FXPath::hasExecExtension(file)) info.modeFlags&=~FXIO::AllExec;
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY){
+          info.modeFlags|=FXIO::Directory;
+          }
+        else{
+          info.modeFlags|=FXIO::File;
+          }
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN){
+          info.modeFlags|=FXIO::Hidden;
+          }
+        if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY){
+          info.modeFlags&=~FXIO::AllWrite;
+          }
+        if((info.modeFlags&FXIO::File) && !FXPath::hasExecExtension(file)){
+          info.modeFlags&=~FXIO::AllExec;
+          }
         info.userNumber=0;
         info.groupNumber=0;
         info.linkCount=data.nNumberOfLinks;
-        info.accessTime=fxunixtime(*((FXTime*)&data.ftLastAccessTime));
-        info.modifyTime=fxunixtime(*((FXTime*)&data.ftLastWriteTime));
-        info.createTime=fxunixtime(*((FXTime*)&data.ftCreationTime));
+        info.accessTime=fxunixtime(data.ftLastAccessTime);
+        info.modifyTime=fxunixtime(data.ftLastWriteTime);
+        info.createTime=fxunixtime(data.ftCreationTime);
         info.fileVolume=data.dwVolumeSerialNumber;
         info.fileIndex=(((FXulong)data.nFileIndexHigh)<<32)|((FXulong)data.nFileIndexLow);
         info.fileSize=(((FXlong)data.nFileSizeHigh)<<32)|((FXlong)data.nFileSizeLow);
@@ -417,15 +474,24 @@ FXbool FXStat::stat(const FXFile& file,FXStat& info){
   BY_HANDLE_FILE_INFORMATION data;
   if(::GetFileInformationByHandle(file.handle(),&data)){
     info.modeFlags=FXIO::AllFull;
-    if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN) info.modeFlags|=FXIO::Hidden;
-    if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY) info.modeFlags&=~FXIO::AllWrite;
-    if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY) info.modeFlags|=FXIO::Directory|FXIO::AllWrite; else info.modeFlags|=FXIO::File; // Directories (folders) always writable on Windows
+    if(data.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY){
+      info.modeFlags|=FXIO::Directory;
+      }
+    else{
+      info.modeFlags|=FXIO::File;
+      }
+    if(data.dwFileAttributes&FILE_ATTRIBUTE_HIDDEN){
+      info.modeFlags|=FXIO::Hidden;
+      }
+    if(data.dwFileAttributes&FILE_ATTRIBUTE_READONLY){
+      info.modeFlags&=~FXIO::AllWrite;
+      }
     info.userNumber=0;
     info.groupNumber=0;
     info.linkCount=data.nNumberOfLinks;
-    info.accessTime=fxunixtime(*((FXTime*)&data.ftLastAccessTime));
-    info.modifyTime=fxunixtime(*((FXTime*)&data.ftLastWriteTime));
-    info.createTime=fxunixtime(*((FXTime*)&data.ftCreationTime));
+    info.accessTime=fxunixtime(data.ftLastAccessTime);
+    info.modifyTime=fxunixtime(data.ftLastWriteTime);
+    info.createTime=fxunixtime(data.ftCreationTime);
     info.fileVolume=data.dwVolumeSerialNumber;
     info.fileIndex=(((FXulong)data.nFileIndexHigh)<<32)|((FXulong)data.nFileIndexLow);
     info.fileSize=(((FXulong)data.nFileSizeHigh)<<32)|((FXulong)data.nFileSizeLow);
@@ -528,21 +594,17 @@ FXbool FXStat::mode(const FXString& file,FXuint perm){
 
 // Return true if file exists
 FXbool FXStat::exists(const FXString& file){
-  FXTRACE((100,"FXStat::exists(\"%s\"\n",file.text()));
   if(!file.empty()){
 #ifdef WIN32
 #ifdef UNICODE
     FXnchar unifile[MAXPATHLEN];
     utf2ncs(unifile,file.text(),MAXPATHLEN);
-    FXTRACE((100,"FXStat::exists: %d\n",(::GetFileAttributesW(unifile)!=INVALID_FILE_ATTRIBUTES)));
     return ::GetFileAttributesW(unifile)!=INVALID_FILE_ATTRIBUTES;
 #else
-    FXTRACE((100,"FXStat::exists: %d\n",(::GetFileAttributesA(file.text())!=INVALID_FILE_ATTRIBUTES)));
     return ::GetFileAttributesA(file.text())!=INVALID_FILE_ATTRIBUTES;
 #endif
 #else
     struct stat status;
-    FXTRACE((100,"FXStat::exists: %d\n",(::stat(file.text(),&status)==0)));
     return ::stat(file.text(),&status)==0;
 #endif
     }
@@ -597,14 +659,13 @@ FXbool FXStat::modified(const FXString& file,FXTime ns){
 #ifdef UNICODE
     FXnchar unifile[MAXPATHLEN];
     utf2ncs(unifile,file.text(),MAXPATHLEN);
-    FXInputHandle hnd=CreateFileW(unifile,GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,NULL,OPEN_EXISTING,0,NULL);
+    FXInputHandle hnd=CreateFileW(unifile,GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,nullptr,OPEN_EXISTING,0,nullptr);
 #else
-    FXInputHandle hnd=CreateFileA(file.text(),GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,NULL,OPEN_EXISTING,0,NULL);
+    FXInputHandle hnd=CreateFileA(file.text(),GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,nullptr,OPEN_EXISTING,0,nullptr);
 #endif
     if(hnd!=INVALID_HANDLE_VALUE){
-      FILETIME wintime;
-      *((FXTime*)&wintime)=fxwintime(ns);
-      if(SetFileTime(hnd,NULL,NULL,&wintime)!=0){
+      FILETIME wintime=fxwintime(ns);
+      if(SetFileTime(hnd,nullptr,nullptr,&wintime)!=0){
         CloseHandle(hnd);
         return true;
         }
@@ -652,14 +713,13 @@ FXbool FXStat::accessed(const FXString& file,FXTime ns){
 #ifdef UNICODE
     FXnchar unifile[MAXPATHLEN];
     utf2ncs(unifile,file.text(),MAXPATHLEN);
-    FXInputHandle hnd=CreateFileW(unifile,GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,NULL,OPEN_EXISTING,0,NULL);
+    FXInputHandle hnd=CreateFileW(unifile,GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,nullptr,OPEN_EXISTING,0,nullptr);
 #else
-    FXInputHandle hnd=CreateFileA(file.text(),GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,NULL,OPEN_EXISTING,0,NULL);
+    FXInputHandle hnd=CreateFileA(file.text(),GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,nullptr,OPEN_EXISTING,0,nullptr);
 #endif
     if(hnd!=INVALID_HANDLE_VALUE){
-      FILETIME wintime;
-      *((FXTime*)&wintime)=fxwintime(ns);
-      if(SetFileTime(hnd,NULL,&wintime,NULL)!=0){
+      FILETIME wintime=fxwintime(ns);
+      if(SetFileTime(hnd,nullptr,&wintime,nullptr)!=0){
         CloseHandle(hnd);
         return true;
         }
@@ -699,34 +759,39 @@ FXTime FXStat::created(const FXString& file){
   return data.created();
   }
 
+#ifdef WIN32
 
 // Change time when file was last created
 FXbool FXStat::created(const FXString& file,FXTime ns){
   if(!file.empty()){
-#ifdef WIN32
 #ifdef UNICODE
     FXnchar unifile[MAXPATHLEN];
     utf2ncs(unifile,file.text(),MAXPATHLEN);
-    FXInputHandle hnd=CreateFileW(unifile,GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,NULL,OPEN_EXISTING,0,NULL);
+    FXInputHandle hnd=CreateFileW(unifile,GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,nullptr,OPEN_EXISTING,0,nullptr);
 #else
-    FXInputHandle hnd=CreateFileA(file.text(),GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,NULL,OPEN_EXISTING,0,NULL);
+    FXInputHandle hnd=CreateFileA(file.text(),GENERIC_READ|FILE_WRITE_ATTRIBUTES,0,nullptr,OPEN_EXISTING,0,nullptr);
 #endif
     if(hnd!=INVALID_HANDLE_VALUE){
-      FILETIME wintime;
-      *((FXTime*)&wintime)=fxwintime(ns);
-      if(SetFileTime(hnd,&wintime,NULL,NULL)!=0){
+      FILETIME wintime=fxwintime(ns);
+      if(SetFileTime(hnd,&wintime,nullptr,nullptr)!=0){
         CloseHandle(hnd);
         return true;
         }
       CloseHandle(hnd);
       }
-#else
-    return false;               // Not available on *NIX
-#endif
     }
   return false;
   }
 
+#else
+
+// Change time when file was last created
+FXbool FXStat::created(const FXString&,FXTime){
+  return false;
+  }
+
+#endif
+
 
 // Return true if file is hidden
 FXbool FXStat::isHidden(const FXString& file){
@@ -888,16 +953,16 @@ FXbool FXStat::isAccessible(const FXString& file,FXuint m){
 #ifdef WIN32
 #ifdef UNICODE
     FXnchar unifile[MAXPATHLEN];
-    FXuint mode=0;
-    if(m&FXIO::ReadOnly) mode|=4;
-    if(m&FXIO::WriteOnly) mode|=2;
+    WIN32_FILE_ATTRIBUTE_DATA attr;
     utf2ncs(unifile,file.text(),MAXPATHLEN);
-    return _waccess(unifile,mode)==0;
+    if(GetFileAttributesExW(unifile,GetFileExInfoStandard,&attr)){
+      return (attr.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY) || !(m&FXIO::WriteOnly) || !(attr.dwFileAttributes&FILE_ATTRIBUTE_READONLY);
+      }
 #else
-    FXuint mode=0;
-    if(m&FXIO::ReadOnly) mode|=4;
-    if(m&FXIO::WriteOnly) mode|=2;
-    return _access(file.text(),mode)==0;
+    WIN32_FILE_ATTRIBUTE_DATA attr;
+    if(GetFileAttributesExA(file.text(),GetFileExInfoStandard,&attr)){
+      return (attr.dwFileAttributes&FILE_ATTRIBUTE_DIRECTORY) || !(m&FXIO::WriteOnly) || !(attr.dwFileAttributes&FILE_ATTRIBUTE_READONLY);
+      }
 #endif
 #else
     FXuint mode=F_OK;
@@ -911,17 +976,29 @@ FXbool FXStat::isAccessible(const FXString& file,FXuint m){
   }
 
 
+// Return true if file1 is the same as file2
+FXbool FXStat::isSame(const FXString& file1,const FXString& file2){
+  if(!file1.empty() && !file2.empty()){
+    FXStat info1,info2;
+    if(statFile(file1,info1) && statFile(file2,info2)){
+      return info1.index()==info2.index() && info1.volume()==info2.volume();
+      }
+    }
+  return false;
+  }
+
+
 // Obtain total amount of space on disk
 FXbool FXStat::getTotalDiskSpace(const FXString& path,FXulong& space){
 #ifdef WIN32
 #ifdef UNICODE
   FXnchar unifile[MAXPATHLEN];
   utf2ncs(unifile,path.text(),MAXPATHLEN);
-  if(GetDiskFreeSpaceExW(unifile,NULL,(PULARGE_INTEGER)&space,NULL)){
+  if(GetDiskFreeSpaceExW(unifile,nullptr,(PULARGE_INTEGER)&space,nullptr)){
     return true;
     }
 #else
-  if(GetDiskFreeSpaceExA(path.text(),NULL,(PULARGE_INTEGER)&space,NULL)){
+  if(GetDiskFreeSpaceExA(path.text(),nullptr,(PULARGE_INTEGER)&space,nullptr)){
     return true;
     }
 #endif
@@ -944,11 +1021,11 @@ FXbool FXStat::getAvailableDiskSpace(const FXString& path,FXulong& space){
 #ifdef UNICODE
   FXnchar unifile[MAXPATHLEN];
   utf2ncs(unifile,path.text(),MAXPATHLEN);
-  if(GetDiskFreeSpaceExW(unifile,(PULARGE_INTEGER)&space,NULL,NULL)){
+  if(GetDiskFreeSpaceExW(unifile,(PULARGE_INTEGER)&space,nullptr,nullptr)){
     return true;
     }
 #else
-  if(GetDiskFreeSpaceExA(path.text(),(PULARGE_INTEGER)&space,NULL,NULL)){
+  if(GetDiskFreeSpaceExA(path.text(),(PULARGE_INTEGER)&space,nullptr,nullptr)){
     return true;
     }
 #endif
