@@ -3,7 +3,7 @@
 *         M i s c e l l a n e o u s   S y s t e m   F u n c t i o n s           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2005,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2005,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,6 +21,7 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxchar.h"
 #include "fxmath.h"
 #include "fxascii.h"
 #include "FXArray.h"
@@ -232,12 +233,12 @@ FXbool FXSystem::setEnvironment(const FXString& name,const FXString& value){
       utf2ncs(buffer,value.text(),ARRAYNUMBER(buffer));
       return SetEnvironmentVariableW(variable,buffer)!=0;
       }
-    return SetEnvironmentVariableW(variable,NULL)!=0;
+    return SetEnvironmentVariableW(variable,nullptr)!=0;
 #else
     if(!value.empty()){
       return SetEnvironmentVariableA(name.text(),value.text())!=0;
       }
-    return SetEnvironmentVariableA(name.text(),NULL)!=0;
+    return SetEnvironmentVariableA(name.text(),nullptr)!=0;
 #endif
 #elif defined(__GNU_LIBRARY__)
     if(!value.empty()){
@@ -332,6 +333,10 @@ FXString FXSystem::getExecPath(){
 
 
 // Return known executable file extensions (Windows)
+// Default list is:
+//
+//   .COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC
+//
 FXString FXSystem::getExecExtensions(){
 #if defined(WIN32)
   return FXSystem::getEnvironment("PATHEXT");
@@ -345,7 +350,7 @@ FXString FXSystem::getExecExtensions(){
 FXString FXSystem::getExecFilename(){
 #if defined(WIN32)
   TCHAR buffer[MAXPATHLEN];
-  DWORD len=GetModuleFileName(NULL,buffer,MAXPATHLEN);
+  DWORD len=GetModuleFileName(nullptr,buffer,MAXPATHLEN);
   return FXString(buffer,len);
 #elif defined(__linux__)
   FXint pid=FXProcess::current();
@@ -362,7 +367,38 @@ FXString FXSystem::getHomeDirectory(){
   return FXSystem::getUserDirectory(FXString::null);
   }
 
+
+// Return temporary directory.
+FXString FXSystem::getTempDirectory(){
+#if defined(WIN32)
+  TCHAR buffer[MAXPATHLEN];
+  DWORD len=GetTempPath(MAXPATHLEN,buffer);
+  if(1<len && ISPATHSEP(buffer[len-1]) && !ISPATHSEP(buffer[len-2])) len--;
+  return FXString(buffer,len);
+#else
+  const FXchar* dir;
+  if((dir=getenv("TMPDIR"))!=nullptr){
+    return FXString(dir);
+    }
+  return FXString("/tmp");
+#endif
+  }
+
+
+// Return system directory
+FXString FXSystem::getSystemDirectory(){
+#if defined(WIN32)
+  TCHAR buffer[MAXPATHLEN];
+  DWORD len=GetSystemDirectory(buffer,MAXPATHLEN);
+  return FXString(buffer,len);
+#else
+  return FXString("/bin");
+#endif
+  }
+
+
 /*
+
 BOOL WINAPI LookupAccountName(
   _In_opt_   LPCTSTR lpSystemName,
   _In_       LPCTSTR lpAccountName,
@@ -376,21 +412,21 @@ BOOL WINAPI LookupAccountName(
 PSID GetUserSID(const FXString& name){
   FXString user=name.empty()?currentUserName():name;
   if(!user.empty()){
-    PSID   sid=NULL;
+    PSID   sid=nullptr;
     DWORD  sid_size=0;
-    TCHAR *domain=NULL;
+    TCHAR *domain=nullptr;
     DWORD  domain_size=0;
     SID_NAME_USE use=SidTypeUnknown;
 
     // First call to LookupAccountName to get the buffer sizes
-    if(LookupAccountNameA(NULL,user.text(),sid,&sid_size,domain,&domain_size,&use)){
+    if(LookupAccountNameA(nullptr,user.text(),sid,&sid_size,domain,&domain_size,&use)){
 
       // Allocate
       sid=(PSID)LocalAlloc(LMEM_FIXED,sid_size);
       domain=new TCHAR [domain_size];
 
       // Second call to LookupAccountName to get the actual account info
-      if(LookupAccountName(NULL,user.text(),sid,&sid_size,domain,&domain_size,&use)){
+      if(LookupAccountName(nullptr,user.text(),sid,&sid_size,domain,&domain_size,&use)){
         delete [] domain;
         return sid;
         }
@@ -400,7 +436,7 @@ PSID GetUserSID(const FXString& name){
       delete [] domain;
       }
     }
-  return NULL
+  return nullptr;
   }
 */
 
@@ -430,7 +466,7 @@ FXString FXSystem::getUserDirectory(const FXString& user){
       return result;
       }
     if(RegOpenKeyExW(HKEY_CURRENT_USER,L"Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders",0,KEY_READ,&hKey)==ERROR_SUCCESS){
-      result=RegQueryValueExW(hKey,L"Personal",NULL,NULL,(LPBYTE)path,&pathlen);        // Change "Personal" to "Desktop" if you want...
+      result=RegQueryValueExW(hKey,L"Personal",nullptr,nullptr,(LPBYTE)path,&pathlen);        // Change "Personal" to "Desktop" if you want...
       RegCloseKey(hKey);
       if(result==ERROR_SUCCESS){
         return FXString(path,pathlen);
@@ -461,7 +497,7 @@ FXString FXSystem::getUserDirectory(const FXString& user){
       return result;
       }
     if(RegOpenKeyExA(HKEY_CURRENT_USER,"Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders",0,KEY_READ,&hKey)==ERROR_SUCCESS){
-      result=RegQueryValueExA(hKey,"Personal",NULL,NULL,(LPBYTE)path,&pathlen);         // Change "Personal" to "Desktop" if you want...
+      result=RegQueryValueExA(hKey,"Personal",nullptr,nullptr,(LPBYTE)path,&pathlen);         // Change "Personal" to "Desktop" if you want...
       RegCloseKey(hKey);
       if(result==ERROR_SUCCESS){
         return FXString(path,pathlen);
@@ -475,10 +511,10 @@ FXString FXSystem::getUserDirectory(const FXString& user){
   const FXchar* str;
   char buffer[1024];
   if(user.empty()){
-    if((str=getenv("HOME"))!=NULL){
+    if((str=getenv("HOME"))!=nullptr){
       return FXString(str);
       }
-    if((str=getenv("USER"))!=NULL || (str=getenv("LOGNAME"))!=NULL){
+    if((str=getenv("USER"))!=nullptr || (str=getenv("LOGNAME"))!=nullptr){
       if(getpwnam_r(str,&pwdresult,buffer,sizeof(buffer),&pwd)==0 && pwd){
         return FXString(pwd->pw_dir);
         }
@@ -496,20 +532,20 @@ FXString FXSystem::getUserDirectory(const FXString& user){
   struct passwd *pwd;
   const FXchar* str;
   if(user.empty()){
-    if((str=getenv("HOME"))!=NULL){
+    if((str=getenv("HOME"))!=nullptr){
       return FXString(str);
       }
-    if((str=getenv("USER"))!=NULL || (str=getenv("LOGNAME"))!=NULL){
-      if((pwd=getpwnam(str))!=NULL){
+    if((str=getenv("USER"))!=nullptr || (str=getenv("LOGNAME"))!=nullptr){
+      if((pwd=getpwnam(str))!=nullptr){
         return FXString(pwd->pw_dir);
         }
       }
-    if((pwd=getpwuid(getuid()))!=NULL){
+    if((pwd=getpwuid(getuid()))!=nullptr){
       return FXString(pwd->pw_dir);
       }
     return FXString::null;
     }
-  if((pwd=getpwnam(user.text()))!=NULL){
+  if((pwd=getpwnam(user.text()))!=nullptr){
     return FXString(pwd->pw_dir);
     }
   return FXString::null;
@@ -517,23 +553,121 @@ FXString FXSystem::getUserDirectory(const FXString& user){
   }
 
 
-// Return temporary directory.
-FXString FXSystem::getTempDirectory(){
 #if defined(WIN32)
-  TCHAR buffer[MAXPATHLEN];
-  DWORD len=GetTempPath(MAXPATHLEN,buffer);
-  if(1<len && ISPATHSEP(buffer[len-1]) && !ISPATHSEP(buffer[len-2])) len--;
-  return FXString(buffer,len);
+
+// Kick off a command to the system
+// Note, this version launches cmd.exe w/o creating a terminal window.
+FXint FXSystem::system(const FXString& cmd){
+  FXint res=-1;
+  if(!cmd.empty()){
+#if defined(UNICODE)
+    FXnchar* cmd_arg;
+    if(callocElms(cmd_arg,cmd.length()+4)){
+      FXnchar cmd_exe[MAXPATHLEN];
+      PROCESS_INFORMATION pi;
+      STARTUPINFO si;
+
+      // Zero out process info and startup info
+      clearElms(&pi,1);
+      clearElms(&si,1);
+
+      // Init startup info
+      si.cb=sizeof(si);
+
+      // Also suggested; not sure if this is better than CREATE_NO_WINDOW
+      // for dwCreationFlags...
+//      si.dwFlags=STARTF_USESHOWWINDOW;
+//      si.wShowWindow=SW_HIDE;
+
+      // Option for cmd.exe
+      cmd_arg[0]='/';
+      cmd_arg[1]='c';
+      cmd_arg[2]=' ';
+
+      // Copy command
+      utf2ncs(&cmd_arg[3],cmd.text(),cmd.length());
+
+      // Path to cmd.exe
+      GetEnvironmentVariableW(L"COMSPEC",cmd_exe,MAXPATHLEN);
+
+      // Probably required
+     _flushall();
+
+      // Kick off command
+      DWORD dwCreationFlags = !GetConsoleWindow() ? CREATE_NO_WINDOW : 0;
+      if(CreateProcessW(cmd_exe,cmd_arg,nullptr,nullptr,false,dwCreationFlags,nullptr,nullptr,&si,&pi)){
+        WaitForSingleObject(pi.hProcess,INFINITE);
+        GetExitCodeProcess(pi.hProcess,(DWORD*)&res);
+        CloseHandle(pi.hProcess);
+        CloseHandle(pi.hThread);
+        }
+
+      // Free argument
+      freeElms(cmd_arg);
+      }
 #else
-  const FXchar* dir;
-  if((dir=getenv("TMPDIR"))!=NULL){
-    return FXString(dir);
-    }
-  return FXString("/tmp");
+    FXchar* cmd_arg;
+    if(callocElms(cmd_arg,cmd.length()+4)){
+      FXchar cmd_exe[MAXPATHLEN];
+      PROCESS_INFORMATION pi;
+      STARTUPINFO si;
+
+      // Zero out process info and startup info
+      clearElms(&pi,1);
+      clearElms(&si,1);
+
+      // Init startup info
+      si.cb=sizeof(si);
+
+      // Also suggested:
+//      si.dwFlags=STARTF_USESHOWWINDOW;
+//      si.wShowWindow=SW_HIDE;
+
+      // Option for cmd.exe
+      cmd_arg[0]='/';
+      cmd_arg[1]='c';
+      cmd_arg[2]=' ';
+
+      // Copy command
+      strncpy(&cmd_arg[3],cmd.text(),cmd.length());
+
+      // Path to cmd.exe
+      GetEnvironmentVariableA("COMSPEC",cmd_exe,MAXPATHLEN);
+
+      // Probably required
+     _flushall();
+
+      // Kick off command
+      DWORD dwCreationFlags = !GetConsoleWindow() ? CREATE_NO_WINDOW : 0;
+      if(CreateProcessA(cmd_exe,cmd_arg,nullptr,nullptr,false,dwCreationFlags,nullptr,nullptr,&si,&pi)){
+        WaitForSingleObject(pi.hProcess,INFINITE);
+        GetExitCodeProcess(pi.hProcess,(DWORD*)&res);
+        CloseHandle(pi.hProcess);
+        CloseHandle(pi.hThread);
+        }
+
+      // Free argument
+      freeElms(cmd_arg);
+      }
 #endif
+    }
+  return res;
   }
 
 
+#else
+
+// Kick off a command to the system
+FXint FXSystem::system(const FXString& cmd){
+  if(!cmd.empty()){
+    return ::system(cmd.text());
+    }
+  return -1;
+  }
+
+#endif
+
+
 // Return host name
 FXString FXSystem::getHostName(){
   FXchar name[MAXHOSTNAMELEN];
@@ -551,8 +685,8 @@ FXbool FXSystem::localeIsUTF8(){
   return GetACP()==CP_UTF8;
 #else
   const FXchar* str;
-  if((str=getenv("LC_CTYPE"))!=NULL || (str=getenv("LC_ALL"))!=NULL || (str=getenv("LANG"))!=NULL){
-    return (strstr(str,"utf")!=NULL || strstr(str,"UTF")!=NULL);
+  if((str=getenv("LC_CTYPE"))!=nullptr || (str=getenv("LC_ALL"))!=nullptr || (str=getenv("LANG"))!=nullptr){
+    return (strstr(str,"utf")!=nullptr || strstr(str,"UTF")!=nullptr);
     }
   return false;
 #endif
