@@ -3,7 +3,7 @@
 *                          T h r e a d   S u p p o r t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2004,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,6 +21,7 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxchar.h"
 #include "fxmath.h"
 #include "FXException.h"
 #include "FXString.h"
@@ -127,8 +128,8 @@ void* FXThread::function(void* ptr){
   FXThread *thread=(FXThread*)ptr;
   FXint code=-1;
   self(thread);
-  pthread_setcancelstate(PTHREAD_CANCEL_ENABLE,NULL);
-  pthread_setcanceltype(PTHREAD_CANCEL_ASYNCHRONOUS,NULL);
+  pthread_setcancelstate(PTHREAD_CANCEL_ENABLE,nullptr);
+  pthread_setcanceltype(PTHREAD_CANCEL_ASYNCHRONOUS,nullptr);
   try{
     code=thread->run();
     }
@@ -154,8 +155,8 @@ FXbool FXThread::start(FXuval stacksize){
   if(busy){ fxerror("FXThread::start: thread already running.\n"); }
   if(tid){ fxerror("FXThread::start: thread still attached.\n"); }
   busy=true;
-  if((tid=(FXThreadID)CreateThread(NULL,stacksize,(LPTHREAD_START_ROUTINE)FXThread::function,this,0,&thd))==NULL) busy=false;
-//  if((tid=(FXThreadID)_beginthreadex(NULL,stacksize,(LPTHREAD_START_ROUTINE)FXThread::function,this,0,&thd))==NULL) busy=false;
+  if((tid=(FXThreadID)CreateThread(nullptr,stacksize,(LPTHREAD_START_ROUTINE)FXThread::function,this,0,&thd))==nullptr) busy=false;
+//  if((tid=(FXThreadID)_beginthreadex(nullptr,stacksize,(LPTHREAD_START_ROUTINE)FXThread::function,this,0,&thd))==nullptr) busy=false;
 #else
   pthread_attr_t attr;
   if(busy){ fxerror("FXThread::start: thread already running.\n"); }
@@ -169,7 +170,7 @@ FXbool FXThread::start(FXuval stacksize){
   sigfillset(&newset);
   pthread_sigmask(SIG_SETMASK,&newset,&oldset); // No signals except to main thread
   if(pthread_create((pthread_t*)&tid,&attr,FXThread::function,(void*)this)!=0) busy=false;
-  pthread_sigmask(SIG_SETMASK,&oldset,NULL);    // Restore old mask
+  pthread_sigmask(SIG_SETMASK,&oldset,nullptr);    // Restore old mask
 #else
   if(pthread_create((pthread_t*)&tid,&attr,FXThread::function,(void*)this)!=0) busy=false;
 #endif
@@ -190,7 +191,7 @@ FXbool FXThread::join(FXint& code){
     }
   return false;
 #else
-  void *trc=NULL;
+  void *trc=nullptr;
   if(tid && pthread_join((pthread_t)tid,&trc)==0){
     code=(FXint)(FXival)trc;
     tid=0;
@@ -211,7 +212,7 @@ FXbool FXThread::join(){
     }
   return false;
 #else
-  if(tid && pthread_join((pthread_t)tid,NULL)==0){
+  if(tid && pthread_join((pthread_t)tid,nullptr)==0){
     tid=0;
     return true;
     }
@@ -234,7 +235,7 @@ FXbool FXThread::cancel(){
 #else
   if(tid){
     if(busy && pthread_cancel((pthread_t)tid)==0) busy=false;
-    if(pthread_join((pthread_t)tid,NULL)==0){
+    if(pthread_join((pthread_t)tid,nullptr)==0){
       tid=0;
       return true;
       }
@@ -285,71 +286,116 @@ void FXThread::yield(){
   }
 
 
+// Processor pause/back-off
+void FXThread::pause(){
 #if defined(WIN32)
-
-// Convert 100ns since 01/01/1601 to ns since 01/01/1970
-static inline FXTime fxunixtime(FXTime ft){
-  return (ft-FXLONG(116444736000000000))*FXLONG(100);
-  }
-
-// Convert ns since 01/01/1970 to 100ns since 01/01/1601
-static inline FXTime fxwintime(FXTime ut){
-  return ut/FXLONG(100)+FXLONG(116444736000000000);
-  }
-
+#if defined(_MSC_VER)
+  YieldProcessor();
 #endif
+#elif (defined(__GNUC__) || defined(__INTEL_COMPILER)) && (defined(__i386__) || defined(__x86_64__))
+  __asm__ __volatile__("rep; nop\n" : : : "memory" );
+//  _mm_pause();
+#elif defined(__GNUC__) && defined(__aarch64__)
+  __asm__ __volatile__("yield" ::: "memory");
+#endif
+  }
 
 
 // Get time in nanoseconds since Epoch
 FXTime FXThread::time(){
 #if defined(WIN32)
-  FXTime now;
-  FXASSERT(sizeof(FXTime)==sizeof(FILETIME));
-  GetSystemTimeAsFileTime((FILETIME*)&now);
-  return fxunixtime(now);
+  const FXTime BIAS=FXLONG(116444736000000000);
+  const FXTime HIGH=FXLONG(4294967296);
+  FILETIME now;
+  GetSystemTimeAsFileTime(&now);
+  return (now.dwHighDateTime*HIGH+now.dwLowDateTime-BIAS)*100;
 #elif (_POSIX_C_SOURCE >= 199309L)
   const FXTime seconds=1000000000;
   struct timespec ts;
-  clock_gettime(CLOCK_REALTIME,&ts);
+  clock_gettime(CLOCK_REALTIME,&ts);            // Wallclock time!
   return ts.tv_sec*seconds+ts.tv_nsec;
 #else
   const FXTime seconds=1000000000;
   const FXTime microseconds=1000;
   struct timeval tv;
-  gettimeofday(&tv,NULL);
+  gettimeofday(&tv,nullptr);
   return tv.tv_sec*seconds+tv.tv_usec*microseconds;
 #endif
   }
 
 
-#if defined(WIN32)
-static FXTime frequency=0;
-#endif
-
 // Get steady time in nanoseconds since some arbitrary start time
 FXTime FXThread::steadytime(){
 #if defined(WIN32)
   const FXTime seconds=1000000000;
-  FXTime now,s,f;
-  FXASSERT(sizeof(FXTime)==sizeof(LARGE_INTEGER));
-  if(__unlikely(frequency==0)){
-    ::QueryPerformanceFrequency((LARGE_INTEGER*)&frequency);
-    }
-  FXASSERT(frequency<FXLONG(9223372036));               // Overflow possible if CPU speed exceeds 9.2GHz
-  ::QueryPerformanceCounter((LARGE_INTEGER*)&now);
-  s=now/frequency;
-  f=now%frequency;
-  return seconds*s + ((seconds*f)/frequency);
+  LARGE_INTEGER frq,clk;
+  ::QueryPerformanceFrequency(&frq);
+  ::QueryPerformanceCounter(&clk);
+  FXASSERT(frq.QuadPart<FXLONG(9223372036));    // Overflow possible if CPU speed exceeds 9.2GHz
+  FXTime s=clk.QuadPart/frq.QuadPart;
+  FXTime f=clk.QuadPart%frq.QuadPart;
+  return seconds*s+(seconds*f)/frq.QuadPart;
 #elif (_POSIX_C_SOURCE >= 199309L)
   const FXTime seconds=1000000000;
   struct timespec ts;
-  clock_gettime(CLOCK_MONOTONIC,&ts);
+  clock_gettime(CLOCK_MONOTONIC,&ts);           // Monotonic: no jumps!
   return ts.tv_sec*seconds+ts.tv_nsec;
 #else
   const FXTime seconds=1000000000;
   const FXTime microseconds=1000;
   struct timeval tv;
-  gettimeofday(&tv,NULL);
+  gettimeofday(&tv,nullptr);
+  return tv.tv_sec*seconds+tv.tv_usec*microseconds;
+#endif
+  }
+
+
+// Return time in processor ticks.
+FXTime FXThread::ticks(){
+#if defined(WIN32) && defined(_MSC_VER)
+#if defined(_M_IX86) || defined(_M_X64)
+  return __rdtsc();
+#else
+  FXTime value;
+  FXASSERT_STATIC(sizeof(FXTime)==sizeof(LARGE_INTEGER));
+  QueryPerformanceCounter((LARGE_INTEGER*)&value);
+  return value;
+#endif
+#elif (defined(__GNUC__) || defined(__INTEL_COMPILER)) && defined(__i386__)
+  FXTime value;
+  __asm__ __volatile__ ( "rdtsc" : "=A" (value) : : "memory");
+  return value;
+#elif (defined(__GNUC__) || defined(__INTEL_COMPILER)) && defined(__x86_64__)
+  FXTime value;
+  __asm__ __volatile__ ( "rdtsc              \n\t"
+                         "salq	$32, %%rdx   \n\t"
+                         "orq	%%rdx, %%rax \n\t" : "=q"(value) : : "memory");
+  return value;
+#elif (defined(__GNUC__) && defined(__aarch64__))
+   FXTime value;
+   __asm__ __volatile__("mrs %0, cntvct_el0" : "=r"(value) : : "memory");
+   return value;
+#elif defined(__GNUC__) && (defined(__powerpc64__) || defined(__ppc64__))
+  FXTime value;
+  __asm__ __volatile__("mfspr %0, 268" : "=r"(value) : : "memory");
+  return value;
+#elif defined(__GNUC__) && (defined(__powerpc__) || defined(__ppc__))
+  FXuint tbl,tbu0,tbu1;
+  __asm__ __volatile__( "mftbu %0 \n\t"
+                        "mftb  %1 \n\t"
+                        "mftbu %2 \n\t" : "=r"(tbu0), "=r"(tbl), "=r"(tbu1) : : "memory");
+  tbl&=-(FXint)(tbu0==tbu1);
+  return (((FXTime)tbu1) << 32) | tbl;
+#elif (_POSIX_C_SOURCE >= 199309L)
+  const NSTime seconds=1000000000;
+  struct timespec ts;
+  clock_gettime(CLOCK_MONOTONIC,&ts);   // Monotonic: no jumps!
+  return ts.tv_sec*seconds+ts.tv_nsec;
+#else
+  const NSTime seconds=1000000000;
+  const NSTime microseconds=1000;
+  struct timeval tv;
+  gettimeofday(&tv,nullptr);
   return tv.tv_sec*seconds+tv.tv_usec*microseconds;
 #endif
   }
@@ -389,8 +435,9 @@ static DWORD WINAPI NtDelayExecutionStub(BOOLEAN Alertable,LARGE_INTEGER* DelayI
 void FXThread::sleep(FXTime nsec){
 #if defined(WIN32)
   if(100<=nsec){
-    FXTime jiffies=-nsec/FXLONG(100);
-    fxNtDelayExecution((BOOLEAN)false,(LARGE_INTEGER*)&jiffies);
+    LARGE_INTEGER jiffies;
+    jiffies.QuadPart=-nsec/100;
+    fxNtDelayExecution((BOOLEAN)false,&jiffies);
     }
 #elif (_XOPEN_SOURCE >= 600) || (_POSIX_C_SOURCE >= 200112L)
   const FXTime seconds=1000000000;
@@ -416,26 +463,19 @@ void FXThread::sleep(FXTime nsec){
   if(microseconds<=nsec){
     value.tv_usec=(nsec/microseconds)%milliseconds;
     value.tv_sec=nsec/seconds;
-    select(0,NULL,NULL,NULL,&value);
+    select(0,nullptr,nullptr,nullptr,&value);
     }
 #endif
   }
 
-/*
-HANDLE CreateWaitableTimerEx(LPSECURITY_ATTRIBUTES lpTimerAttributes,LPCWSTR lpTimerName,DWORD dwFlags,DWORD dwDesiredAccess);
-BOOL SetWaitableTimer(HANDLE hTimer,const LARGE_INTEGER *lpDueTime,LONG lPeriod,PTIMERAPCROUTINE pfnCompletionRoutine,LPVOID lpArgToCompletionRoutine,BOOL fResume);
-BOOL SetWaitableTimerEx(HANDLE hTimer,const LARGE_INTEGER *lpDueTime,LONG lPeriod,PTIMERAPCROUTINE pfnCompletionRoutine,LPVOID lpArgToCompletionRoutine,PREASON_CONTEXT WakeContext,ULONG TolerableDelay);
-BOOL CancelWaitableTimer(HANDLE hTimer);
-DWORD WaitForSingleObject(HANDLE hHandle,DWORD  dwMilliseconds);
-*/
-
 
 // Wake at appointed absolute time
 void FXThread::wakeat(FXTime nsec){
 #if defined(WIN32)
-  FXTime jiffies=fxwintime(nsec);
-  if(0<=jiffies){
-    fxNtDelayExecution((BOOLEAN)false,(LARGE_INTEGER*)&jiffies);
+  LARGE_INTEGER jiffies;
+  jiffies.QuadPart=FXLONG(116444736000000000)+nsec/100;
+  if(0<=jiffies.QuadPart){
+    fxNtDelayExecution((BOOLEAN)false,&jiffies);
     }
 #elif (_XOPEN_SOURCE >= 600) || (_POSIX_C_SOURCE >= 200112L)
   const FXTime seconds=1000000000;
@@ -443,7 +483,7 @@ void FXThread::wakeat(FXTime nsec){
   if(0<=nsec){
     value.tv_sec=nsec/seconds;
     value.tv_nsec=nsec%seconds;
-    while(clock_nanosleep(CLOCK_REALTIME,TIMER_ABSTIME,&value,NULL)!=0){ }
+    while(clock_nanosleep(CLOCK_REALTIME,TIMER_ABSTIME,&value,nullptr)!=0){ }
     }
 #elif (_POSIX_C_SOURCE >= 199309L)
   const FXTime seconds=1000000000;
@@ -463,7 +503,7 @@ void FXThread::wakeat(FXTime nsec){
   if(microseconds<=nsec){
     value.tv_usec=(nsec/microseconds)%milliseconds;
     value.tv_sec=nsec/seconds;
-    select(0,NULL,NULL,NULL,&value);
+    select(0,nullptr,nullptr,nullptr,&value);
     }
 #endif
   }
@@ -472,8 +512,7 @@ void FXThread::wakeat(FXTime nsec){
 // Return thread id of caller
 FXThreadID FXThread::current(){
 #if defined(WIN32)
-//return (FXThreadID)GetCurrentThreadId();
-  return (FXThreadID)GetCurrentThread();
+  return (FXThreadID)GetCurrentThreadId();
 #else
   return (FXThreadID)pthread_self();
 #endif
@@ -498,13 +537,13 @@ FXint FXThread::processors(){
   mib[0]=CTL_HW;
   mib[1]=HW_AVAILCPU;
   len=sizeof(result);
-  if(sysctl(mib,2,&result,&len,NULL,0)!=-1){
+  if(sysctl(mib,2,&result,&len,nullptr,0)!=-1){
     return result;
     }
   mib[0]=CTL_HW;
   mib[1]=HW_NCPU;
   len=sizeof(result);
-  if(sysctl(mib,2,&result,&len,NULL,0)!=-1){
+  if(sysctl(mib,2,&result,&len,nullptr,0)!=-1){
     return result;
     }
 #elif defined(__IRIX__) && defined(_SC_NPROC_ONLN)              // IRIX
@@ -545,7 +584,7 @@ FXThreadStorageKey FXThread::createStorageKey(){
   return (FXThreadStorageKey)TlsAlloc();
 #else
   pthread_key_t key;
-  return pthread_key_create(&key,NULL)==0UL ? (FXThreadStorageKey)key : ~0UL;
+  return pthread_key_create(&key,nullptr)==0UL ? (FXThreadStorageKey)key : ~0UL;
 #endif
   }
 
@@ -985,7 +1024,7 @@ FXbool FXThread::resume(){
 // Destroy
 FXThread::~FXThread(){
   if(self()==this){
-    self(NULL);
+    self(nullptr);
     detach();
     }
   else{
