@@ -3,7 +3,7 @@
 *                   T o g g l e    B u t t o n    O b j e c t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -23,14 +23,15 @@
 #include "fxdefs.h"
 #include "fxmath.h"
 #include "fxkeys.h"
-#include "FXArray.h"
-#include "FXHash.h"
 #include "FXMutex.h"
-#include "FXStream.h"
-#include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
 #include "FXRectangle.h"
+#include "FXElement.h"
+#include "FXMetaClass.h"
+#include "FXHash.h"
+#include "FXStream.h"
+#include "FXString.h"
 #include "FXStringDictionary.h"
 #include "FXSettings.h"
 #include "FXRegistry.h"
@@ -552,23 +553,34 @@ long FXToggleButton::onPaint(FXObject*,FXSelector,void* ptr){
   }
 
 
-// Change text
+// Change alternate text, removing hotkey if changed
 void FXToggleButton::setAltText(const FXString& text){
-  FXString string=stripHotKey(text);
-  FXHotKey hkey=parseHotKey(text);
-  FXint hoff=findHotKey(text);
-  if(altlabel!=string || althotkey!=hkey || althotoff!=hoff){
-    altlabel.adopt(string);
+  if(text!=altlabel){
     remHotKey(althotkey);
-    althotkey=hkey;
-    althotoff=hoff;
-    addHotKey(althotkey);
+    althotkey=0;
+    althotoff=-1;
+    altlabel=text;
     recalc();
     update();
     }
   }
 
 
+// Change alternate text and hotkey
+void FXToggleButton::setAltTextAndHotKey(const FXString& hotkeytext){
+  FXString string=stripHotKey(hotkeytext);
+  FXHotKey hkey=parseHotKey(hotkeytext);
+  FXint hoff=findHotKey(hotkeytext);
+  if(string!=altlabel || hkey!=althotkey || hoff!=althotoff){
+    setAltText(string);
+    remHotKey(althotkey);
+    addHotKey(hkey);
+    althotkey=hkey;
+    althotoff=hoff;
+    }
+  }
+
+
 // Change icon
 void FXToggleButton::setAltIcon(FXIcon* ic){
   if(alticon!=ic){
