@@ -3,7 +3,7 @@
 *                       U R L   M a n i p u l a t i o n                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -23,7 +23,7 @@
 #include "fxdefs.h"
 #include "fxmath.h"
 #include "fxascii.h"
-#include "FXArray.h"
+#include "FXElement.h"
 #include "FXHash.h"
 #include "FXStream.h"
 #include "FXString.h"
@@ -329,8 +329,8 @@ FXString FXURL::encode(const FXString& url,const FXchar* set){
       c=(FXuchar)url[p];
       if(c<0x20 || 128<=c || c=='%' || (set && strchr(set,c))){
         result[q++]='%';
-        result[q++]=FXString::value2Digit[c>>4];
-        result[q++]=FXString::value2Digit[c&15];
+        result[q++]=Ascii::valueDigit(c>>4);
+        result[q++]=Ascii::valueDigit(c&15);
         continue;
         }
       result[q++]=c;
@@ -438,7 +438,7 @@ FXString FXURL::fileToURL(const FXString& file){
 
 // Return filename from URL, empty if url is not a local file
 FXString FXURL::fileFromURL(const FXString& string){
-  if(comparecase(string,"file:",5)==0){
+  if(FXString::comparecase(string,"file:",5)==0){
 #ifdef WIN32
     URL url(string);
     if(url.host[0]<url.host[1]){
@@ -471,7 +471,7 @@ FXString FXURL::filesToURIList(const FXString* files){
 
 // Make array of filenames from URI list
 FXString* FXURL::filesFromURIList(const FXString& urilist){
-  FXString* result=NULL;
+  FXString* result=nullptr;
   if(!urilist.empty()){
     FXint beg,end,n=0;
     result=new FXString [urilist.contains("\r\n")+2];
