@@ -3,7 +3,7 @@
 *                       X M L   R e a d e r  &  W r i t e r                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2016,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2016,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,14 +21,14 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxchar.h"
 #include "fxmath.h"
 #include "fxascii.h"
 #include "fxunicode.h"
 #include "FXElement.h"
-#include "FXArray.h"
+#include "FXMetaClass.h"
 #include "FXString.h"
-#include "FXStat.h"
-#include "FXFile.h"
+#include "FXParseBuffer.h"
 #include "FXException.h"
 #include "FXStringDictionary.h"
 #include "FXCallback.h"
@@ -347,9 +347,9 @@ FXbool FXXML::decode(FXString& dst,const FXString& src,FXuint flags){
         if(src[q+1]=='x'){                      // &#xXXXX;
           q+=2;
           if(!Ascii::isHexDigit(src[q])) return false;  // Expected at least one hex digit
-          wc=FXString::digit2Value[(FXuchar)src[q++]];
+          wc=Ascii::digitValue(src[q++]);
           while(Ascii::isHexDigit(src[q])){
-            wc=wc*16+FXString::digit2Value[(FXuchar)src[q++]];
+            wc=wc*16+Ascii::digitValue(src[q++]);
             }
           if(src[q++]!=';') return false;       // Expected semicolon
           }
@@ -417,9 +417,9 @@ FXbool FXXML::decode(FXString& dst,const FXString& src,FXuint flags){
         if(src[q+1]=='x'){                      // &#xXXXX;
           q+=2;
           FXASSERT(Ascii::isHexDigit(src[q]));  // Expected at least one hex digit
-          wc=FXString::digit2Value[(FXuchar)src[q++]];
+          wc=Ascii::digitValue(src[q++]);
           while(Ascii::isHexDigit(src[q])){
-            wc=wc*16+FXString::digit2Value[(FXuchar)src[q++]];
+            wc=wc*16+Ascii::digitValue(src[q++]);
             }
           FXASSERT(src[q]==';');                // Expected semicolon
           q++;
@@ -575,8 +575,8 @@ FXbool FXXML::encode(FXString& dst,const FXString& src,FXuint flags){
         dst[p+0]='&';
         dst[p+1]='#';
         dst[p+2]='x';
-        dst[p+3]=FXString::value2Digit[ch>>4];
-        dst[p+4]=FXString::value2Digit[ch&15];
+        dst[p+3]=Ascii::valueDigit(ch>>4);
+        dst[p+4]=Ascii::valueDigit(ch&15);
         dst[p+5]=';';
         p+=6;
         continue;
@@ -591,13 +591,13 @@ FXbool FXXML::encode(FXString& dst,const FXString& src,FXuint flags){
 /*******************************************************************************/
 
 // Construct XML parser instance
-FXXML::FXXML():begptr(NULL),endptr(NULL),wptr(NULL),rptr(NULL),sptr(NULL),offset(0),current(NULL),column(0),line(1),dir(Stop),enc(UTF8){
+FXXML::FXXML():offset(0),current(nullptr),column(0),line(1),enc(UTF8){
   FXTRACE((100,"FXXML::FXXML\n"));
   }
 
 
 // Construct XML parser instance and pass it external buffer
-FXXML::FXXML(FXchar* buffer,FXuval sz,Direction d):begptr(NULL),endptr(NULL),wptr(NULL),rptr(NULL),sptr(NULL),offset(0),current(NULL),column(0),line(1),dir(Stop),enc(UTF8){
+FXXML::FXXML(FXchar* buffer,FXuval sz,Direction d):FXParseBuffer(buffer,sz,d),offset(0),current(nullptr),column(0),line(1),enc(UTF8){
   FXTRACE((100,"FXXML::FXXML(%p,%ld,%s)\n",buffer,sz,d==Load?"Load":d==Save?"Save":"Stop"));
   open(buffer,sz,d);
   }
@@ -606,18 +606,12 @@ FXXML::FXXML(FXchar* buffer,FXuval sz,Direction d):begptr(NULL),endptr(NULL),wpt
 // Open XML stream for given direction d
 FXbool FXXML::open(FXchar* buffer,FXuval sz,Direction d){
   FXTRACE((101,"FXXML::open(%p,%ld,%s)\n",buffer,sz,d==Load?"Load":d==Save?"Save":"Stop"));
-  FXASSERT(dir==Stop);
-  if((dir==Stop) && (d!=Stop) && (0<sz) && buffer){
-    begptr=buffer;
-    endptr=buffer+sz;
-    wptr=(d==Load)?endptr:begptr;
-    rptr=begptr;
-    sptr=begptr;
-    offset=0;
-    current=NULL;
+  if(FXParseBuffer::open(buffer,sz,d)){
+    current=nullptr;
     column=0;
+    offset=0;
     line=1;
-    dir=d;
+    vers="1.0";
     enc=UTF8;
     return true;
     }
@@ -626,74 +620,6 @@ FXbool FXXML::open(FXchar* buffer,FXuval sz,Direction d){
 
 /*******************************************************************************/
 
-// Read at least count bytes into buffer; return bytes available, or -1 for error
-FXival FXXML::fill(FXival){
-  FXASSERT(dir==Load);
-  return wptr-sptr;
-  }
-
-
-// Write at least count bytes from buffer; return space available, or -1 for error
-FXival FXXML::flush(FXival){
-  FXASSERT(dir==Save);
-  return endptr-wptr;
-  }
-
-
-// Ensure we have a requisite number of bytes in the buffer, calling fill()
-// to load additional data into the buffer if needed.
-// Near the end of the file, there may be fewer than n bytes in the buffer
-// even after fill() is called.
-FXbool FXXML::need(FXival count){
-  FXASSERT(dir==Load);
-  if(sptr+count>wptr){
-    if(wptr==endptr){
-      if(fill(count)<0) return false;
-      }
-    return sptr<wptr;
-    }
-  return true;
-  }
-
-
-// Emit characters to buffer
-FXbool FXXML::emit(FXchar ch,FXint count){
-  FXival num;
-  FXASSERT(dir==Save);
-  while(0<count){
-    if(wptr>=endptr){
-      if(flush(count)<=0) return false;
-      }
-    FXASSERT(wptr<endptr);
-    num=FXMIN(count,endptr-wptr);
-    fillElms(wptr,ch,num);
-    wptr+=num;
-    count-=num;
-    }
-  return true;
-  }
-
-
-// Emit text to buffer
-FXbool FXXML::emit(const FXchar* str,FXint count){
-  FXival num;
-  FXASSERT(dir==Save);
-  while(0<count){
-    if(wptr>=endptr){
-      if(flush(count)<=0) return false;
-      }
-    FXASSERT(wptr<endptr);
-    num=FXMIN(count,endptr-wptr);
-    copyElms(wptr,str,num);
-    wptr+=num;
-    str+=num;
-    count-=num;
-    }
-  return true;
-  }
-
-/*******************************************************************************/
-
 // Boiler plate emitted prior to main document
 static const FXchar boilerplate[]="<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
 
@@ -899,7 +825,7 @@ FXbool FXXML::name(){
   if(nameStartChar(sptr[0])){
     rptr=sptr;
     do{
-      column+=FXISUTF8(*sptr);          // Increment if UTF8 leader only
+      column+=isUTF8(*sptr);            // Increment if UTF8 leader only
       offset++;
       sptr++;
       if(sptr>=wptr) return false;
@@ -927,7 +853,7 @@ FXbool FXXML::match(FXchar ch){
 // Match name with given name str of length len
 FXbool FXXML::match(const FXchar* str,FXint len){
   if(name() && rptr+len==sptr){
-    return compare(rptr,str,len)==0;
+    return FXString::compare(rptr,str,len)==0;
     }
   return false;
   }
@@ -978,7 +904,7 @@ nxt:    if((sptr-rptr)>=(endptr-begptr-MAXTOKEN)){
           str.append(rptr,sptr-rptr);
           rptr=sptr;
           }
-        column+=FXISUTF8(*sptr);        // Increment if UTF8 leader only
+        column+=isUTF8(*sptr);          // Increment if UTF8 leader only
         offset++;
         sptr++;
         continue;
@@ -1300,7 +1226,7 @@ nxt:    if((sptr-rptr)>=(endptr-begptr-MAXTOKEN)){
           data.append(rptr,sptr-rptr);  // Add another chunk
           rptr=sptr;
           }
-        column+=FXISUTF8(*sptr);        // Increment if UTF8 leader only
+        column+=isUTF8(*sptr);          // Increment if UTF8 leader only
         offset++;
         sptr++;
         continue;
@@ -1352,7 +1278,7 @@ nxt:  if((sptr-rptr)>=(endptr-begptr-MAXTOKEN)){
         text.append(rptr,sptr-rptr);    // Pass comment undecoded
         rptr=sptr;
         }
-      column+=FXISUTF8(*sptr);          // Increment if UTF8 leader only
+      column+=isUTF8(*sptr);            // Increment if UTF8 leader only
       offset++;
       sptr++;
       continue;
@@ -1513,7 +1439,7 @@ nxt:  if((sptr-rptr)>=(endptr-begptr-MAXTOKEN)){
         if((err=charactersCB(text))!=ErrOK) return err;
         rptr=sptr;
         }
-      column+=FXISUTF8(*sptr);          // Increment if UTF8 leader only
+      column+=isUTF8(*sptr);            // Increment if UTF8 leader only
       offset++;
       sptr++;
       continue;
@@ -1635,7 +1561,7 @@ FXXML::Error FXXML::parsecontents(Element& elm){
         // Eat text
         rptr=sptr;
         }
-      column+=FXISUTF8(*sptr);          // Increment if UTF8 leader only
+      column+=isUTF8(*sptr);            // Increment if UTF8 leader only
       offset++;
       sptr++;
       continue;
@@ -1677,7 +1603,7 @@ FXXML::Error FXXML::parseelement(){
 // Parse it
 FXXML::Error FXXML::parse(){
   FXXML::Error err;
-  current=NULL;
+  current=nullptr;
   if(need(MAXTOKEN)){
     enc=guess();
     FXTRACE((101,"encoding=%s\n",encodingName[enc]));
@@ -1771,23 +1697,9 @@ FXXML::Error FXXML::parse(){
 // Close it
 FXbool FXXML::close(){
   FXTRACE((101,"XML::close()\n"));
-  if(dir!=Stop){
-    if((dir==Load) || 0<=flush(0)){             // Error during final flush is possible
-      begptr=NULL;
-      endptr=NULL;
-      rptr=NULL;
-      sptr=NULL;
-      wptr=NULL;
-      current=NULL;
-      dir=Stop;
-      return true;
-      }
-    begptr=NULL;
-    endptr=NULL;
-    wptr=NULL;
-    rptr=NULL;
-    sptr=NULL;
-    dir=Stop;
+  if(FXParseBuffer::close()){
+    current=nullptr;
+    return true;
     }
   return false;
   }
