@@ -3,7 +3,7 @@
 *                     H a l f - F l o a t   S u p p o r t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2008,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2008,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -21,10 +21,6 @@
 #include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
-#include "FXArray.h"
-#include "FXHash.h"
-#include "FXStream.h"
-#include "FXObject.h"
 #include "FXhalf.h"
 
 
