@@ -3,7 +3,7 @@
 *                          B M P   I n p u t / O u t p u t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -23,9 +23,8 @@
 #include "fxdefs.h"
 #include "fxmath.h"
 #include "fxendian.h"
-#include "FXArray.h"
-#include "FXHash.h"
 #include "FXElement.h"
+#include "FXHash.h"
 #include "FXStream.h"
 
 /*
@@ -41,12 +40,16 @@
 */
 
 // Bitmap compression values
-#define BIH_RGB       0         // RGB mode
-#define BIH_RLE8      1         // 8-bit/pixel rle mode
-#define BIH_RLE4      2         // 4-bit/pixel rle mode
-#define BIH_BITFIELDS 3         // Bit field mode
-#define BIH_JPEG      4         // Not supported
-#define BIH_PNG       5         // Not supported
+#define BIH_RGB            0    // RGB mode
+#define BIH_RLE8           1    // 8-bit/pixel rle mode
+#define BIH_RLE4           2    // 4-bit/pixel rle mode
+#define BIH_BITFIELDS      3    // Bit field mode
+#define BIH_JPEG           4    // Not supported
+#define BIH_PNG            5    // Not supported
+#define BIH_ALPHABITFIELDS 6    // RGBA bit field masks
+#define BIH_CMYK           11   // none
+#define BIH_CMYKRLE8       12   // RLE-8
+#define BIH_CMYKRLE4       13   // RLE-4
 
 #define RLE_ESC       0         // RLE escape sequence
 #define RLE_LINE      0         // RLE end of line
@@ -471,7 +474,7 @@ FXbool fxloadBMP(FXStream& store,FXColor*& data,FXint& width,FXint& height){
   FXushort ss;
 
   // Null out
-  data=NULL;
+  data=nullptr;
   width=0;
   height=0;
 
@@ -525,7 +528,7 @@ FXbool fxloadBMP(FXStream& store,FXColor*& data,FXint& width,FXint& height){
     FXTRACE((100,"fxloadBMP: biSize=%d biWidth=%d biHeight=%d biPlanes=%d biBitCount=%d biCompression=%d biSizeImage=%u biClrUsed=%u biClrImportant=%u\n",bmi.biSize,bmi.biWidth,bmi.biHeight,bmi.biPlanes,bmi.biBitCount,bmi.biCompression,bmi.biSizeImage,bmi.biClrUsed,bmi.biClrImportant));
 
     // Check for sensible inputs
-    if(bmi.biPlanes==1 && 0<bmi.biWidth && 0<bmi.biHeight && bmi.biClrUsed<=256){
+    if(bmi.biPlanes==1 && 0<bmi.biWidth && 0<bmi.biHeight && bmi.biClrUsed<=256 && bmi.biCompression<=BIH_RLE4){
 
       // Width and height
       width=bmi.biWidth;
@@ -552,7 +555,7 @@ FXbool fxloadDIB(FXStream& store,FXColor*& data,FXint& width,FXint& height){
   FXint colors;
 
   // Null out
-  data=NULL;
+  data=nullptr;
   width=0;
   height=0;
 
@@ -576,7 +579,7 @@ FXbool fxloadDIB(FXStream& store,FXColor*& data,FXint& width,FXint& height){
   FXTRACE((100,"fxloadBMPStream: biSize=%d biWidth=%d biHeight=%d biPlanes=%d biBitCount=%d biCompression=%d biSizeImage=%u biClrUsed=%u biClrImportant=%u\n",bmi.biSize,bmi.biWidth,bmi.biHeight,bmi.biPlanes,bmi.biBitCount,bmi.biCompression,bmi.biSizeImage,bmi.biClrUsed,bmi.biClrImportant));
 
   // Check for sensible inputs
-  if(bmi.biPlanes==1 && 0<bmi.biWidth && 0<bmi.biHeight && bmi.biClrUsed<=256){
+  if(bmi.biPlanes==1 && 0<bmi.biWidth && 0<bmi.biHeight && bmi.biClrUsed<=256 && bmi.biCompression<=BIH_RLE4){
 
     // Width and height
     width=bmi.biWidth;
@@ -700,7 +703,7 @@ FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint
   FXint colors;
 
   // Null out
-  data=NULL;
+  data=nullptr;
   width=0;
   height=0;
   xspot=-1;
@@ -784,7 +787,7 @@ FXbool fxloadICOStream(FXStream& store,FXColor*& data,FXint& width,FXint& height
   FXint colors;
 
   // Null out
-  data=NULL;
+  data=nullptr;
   width=0;
   height=0;
 
@@ -811,7 +814,7 @@ FXbool fxloadICOStream(FXStream& store,FXColor*& data,FXint& width,FXint& height
   FXTRACE((100,"fxloadICOStream: biSize=%d biWidth=%d biHeight=%d biBitCount=%d biCompression=%d biSizeImage=%d biClrUsed=%d\n",bmi.biSize,bmi.biWidth,bmi.biHeight,bmi.biBitCount,bmi.biCompression,bmi.biSizeImage,bmi.biClrUsed));
 
   // Check for sensible inputs
-  if(bmi.biPlanes==1 && 0<bmi.biWidth && 0<bmi.biHeight && bmi.biClrUsed<=256){
+  if(bmi.biPlanes==1 && 0<bmi.biWidth && 0<bmi.biHeight && bmi.biClrUsed<=256 && bmi.biCompression<=BIH_RLE4){
 
     // Width and height
     width=bmi.biWidth;
