@@ -3,7 +3,7 @@
 *                        G I F   I n p u t / O u t p u t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -22,7 +22,7 @@
 #include "fxver.h"
 #include "fxdefs.h"
 #include "fxmath.h"
-#include "FXArray.h"
+#include "FXElement.h"
 #include "FXHash.h"
 #include "FXElement.h"
 #include "FXStream.h"
@@ -128,7 +128,7 @@ FXbool fxloadGIF(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXboo
   FXint   OutCode[4097];              // An output array used by the decompressor
 
   // Null out
-  data=NULL;
+  data=nullptr;
   width=0;
   height=0;
 
