@@ -3,7 +3,7 @@
 *                   V a r a r g s   S c a n f   R o u t i n e s                 *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2002,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2002,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU Lesser General Public License as published by   *
@@ -109,11 +109,6 @@ using namespace FX;
 namespace FX {
 
 
-// Declarations
-extern FXAPI FXint __sscanf(const FXchar* string,const FXchar* format,...);
-extern FXAPI FXint __vsscanf(const FXchar* string,const FXchar* format,va_list arg_ptr);
-
-
 // Type modifiers
 enum {
   ARG_HALFHALF,         // 'hh'
@@ -126,8 +121,8 @@ enum {
 
 
 // Some floating point magick
-const union{ FXulong u; FXdouble f; } inf={FXULONG(0x7ff0000000000000)};
-const union{ FXulong u; FXdouble f; } nan={FXULONG(0x7fffffffffffffff)};
+static const union{ FXulong u; FXdouble f; } dblinf={FXULONG(0x7ff0000000000000)};
+static const union{ FXulong u; FXdouble f; } dblnan={FXULONG(0x7fffffffffffffff)};
 
 // Normal mode (non-ascii character)
 const FXint NORMAL=0x100;
@@ -135,6 +130,10 @@ const FXint NORMAL=0x100;
 // Thousands separator
 const FXint COMMA=',';
 
+// Declarations
+extern FXAPI FXint __sscanf(const FXchar* string,const FXchar* format,...);
+extern FXAPI FXint __vsscanf(const FXchar* string,const FXchar* format,va_list arg_ptr);
+
 /*******************************************************************************/
 
 // Make double from sign, exponent, and mantissa
@@ -157,7 +156,8 @@ FXint __vsscanf(const FXchar* string,const FXchar* format,va_list args){
   const FXchar *start=string;
   const FXchar *ss;
   FXdouble dvalue;
-  FXulong  ivalue,imult;
+  FXulong  ivalue;
+  FXulong  imult;
   FXchar   set[256];
   FXchar  *ptr;
   FXuchar  ch,nn;
@@ -185,7 +185,6 @@ FXint __vsscanf(const FXchar* string,const FXchar* format,va_list args){
       done=0;
       comma=NORMAL;
       base=0;
-      pos=-1;
 
       // Parse format specifier
 flg:  switch(ch){
@@ -337,8 +336,8 @@ integer:  ivalue=0;
             width--;
             digits++;
             }
-          if(3<width && string[0]==comma && 0<digits && digits<4){
-            while(3<width && string[0]==comma){                 // Thousands group is ',ddd' or nothing
+          if(3<width && string[0]==comma && 0<digits && digits<4){ // Thousands group is ',ddd' or nothing
+            do{
               if((ch=string[1])<'0' || ch>'9') break;
               if((ch=string[2])<'0' || ch>'9') break;
               if((ch=string[3])<'0' || ch>'9') break;
@@ -347,6 +346,7 @@ integer:  ivalue=0;
               width-=4;
               digits+=3;
               }
+            while(3<width && string[0]==comma);
             }
           if(!digits) goto x;                                   // No digits seen!
           if(neg){                                              // Apply sign
@@ -395,7 +395,7 @@ integer:  ivalue=0;
             if((string[1]|0x20)!='a') goto x;
             if((string[2]|0x20)!='n') goto x;
             string+=3;
-            dvalue=nan.f;
+            dvalue=dblnan.f;
             }
           else if(2<width && (string[0]|0x20)=='i'){            // Inf{inity}
             if((string[1]|0x20)!='n') goto x;
@@ -404,7 +404,7 @@ integer:  ivalue=0;
               string+=5;
               }
             string+=3;
-            dvalue=inf.f;
+            dvalue=dblinf.f;
             }
           else if(1<width && string[0]=='0' && (string[1]|0x20)=='x'){  // Hexadecimal float
             string+=2;
@@ -509,8 +509,8 @@ integer:  ivalue=0;
               width--;
               digits++;
               }
-            if(3<width && string[0]==comma && 0<digits && digits<4){
-              while(3<width && string[0]==comma){               // Thousands group is ',ddd' or nothing
+            if(3<width && string[0]==comma && 0<digits && digits<4){ // Thousands group is ',ddd' or nothing
+              do{
                 if((ch=string[1])<'0' || ch>'9') break;
                 if((ch=string[2])<'0' || ch>'9') break;
                 if((ch=string[3])<'0' || ch>'9') break;
@@ -524,6 +524,7 @@ integer:  ivalue=0;
                 width-=4;
                 digits+=3;
                 }
+              while(3<width && string[0]==comma);
               }
             if(0<width && string[0]=='.'){                      // Decimals following '.'
               string++;
