@@ -3,7 +3,7 @@
 *              T h e   P a t h F i n d e r   F i l e   B r o w s e r            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2021 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2024 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -27,8 +27,8 @@ class Preferences;
 
 
 // Version
-#define VERSION_MAJOR 2
-#define VERSION_MINOR 1
+#define VERSION_MAJOR 3
+#define VERSION_MINOR 0
 #define VERSION_PATCH 0
 
 
@@ -83,10 +83,10 @@ protected:
   FXIcon             *unmapicon;
   FXIcon             *propicon;
   FXIcon             *deleteicon;
-  FXIcon             *setbookicon;
+  FXIcon             *bookmarkicon;
   FXIcon             *addbookicon;
   FXIcon             *delbookicon;
-  FXIcon             *clrbookicon;
+  FXIcon             *clrbooksicon;
   FXIcon             *sortingicon;
   FXIcon             *execicon;
   FXIcon             *newdiricon;
@@ -101,6 +101,7 @@ protected:
   FXIcon             *warningicon;
   FXIcon             *shownicon;
   FXIcon             *hiddenicon;
+  FXIcon             *searchicon;
   FXString            editor;		        // Editor command
   FXString            execpaths;                // Search in these paths
   FXString            terminal;		        // Terminal command
@@ -109,7 +110,7 @@ protected:
   FXint               visiting;		        // Currently visited directory
   FXint               totalCount;
   FXlong              totalSpace;
-  FXint               selectedCount;
+  FXuint              selectedCount;
   FXlong              selectedSpace;
   FXuint              selectedModeBits[16];
   FXString            statusInfo;
